function boomSim
global boomParams
global Lhist Rhist

boomParams.n = 10;
boomParams.M = (0.8/boomParams.n) * ones(boomParams.n,1);
boomParams.L = (60*0.3048/boomParams.n) * ones(boomParams.n,1);
boomParams.Cs = 0.05; %0.00627552;
boomParams.Cv = 0.05; %0.00628319;

% v = [xL,yL,th1,th2,...,thn, DxL,DyL,Dth1,Dth2,...,Dthn]
v0 = [0, 0, -pi/3, -pi/4, -pi/8, pi/8, pi/12, -pi/12, -pi/8, pi/8, pi/4, pi/3, ...
      0, 0.0, zeros(1,boomParams.n)];
  
options = odeset('RelTol',1e-6);
timeRange = [0 40];
[tt, YY] = ode45(@boomODEs, timeRange, v0, options);
t = timeRange(1):0.1:timeRange(2);
Y = interp1(tt, YY, t);

Lhist = [];
Rhist = [];
fCount = 1;
figure;
axis equal;
hold on;
grid on;
set(gca,'XLim',[-1 5]);
for a=1:10:size(Y, 1)
    cla;
    pts = drawFrame(Y(a,:),t(a));
    set(gca,'YLim',[mean(pts(2,:))-7.9, mean(pts(2,:))+7.9]);
    set(gca,'XLim',[mean(pts(1,:))-8.5, mean(pts(1,:))+8.5]);
    title(sprintf('t = %f', t(a)));
    drawnow;
    F(fCount) = getframe;
    %if fCount>1
    %    F(fCount).cdata = F(fCount).cdata(1:(size(F(1).cdata,1)-5),1:(size(F(1).cdata,2)-5),1:3);
    %end
    F(fCount).cdata = F(fCount).cdata(1:339,1:363,1:3);
    fCount = fCount + 1;
    pause; %(0.01);
end

%% movie(F);
%movie2avi(F,'FullDynamic(40s)_ForceControl(right-turn)_ExptParams.avi', 'compression','Cinepak', 'fps',10);

% =============================================

function pts = drawFrame(y, t)
global boomParams
global Lhist Rhist

xs(1) = y(1);
ys(1) = y(2);
for a=3:(boomParams.n+2)
    pNext = [xs(end),ys(end)] + boomParams.L(a-2)*[cos(y(a)),sin(y(a))];
    xs(end+1) = pNext(1);
    ys(end+1) = pNext(2);
end

Lhist(end+1,:) = [xs(1),ys(1)];
Rhist(end+1,:) = [xs(end),ys(end)];
plot(Lhist(:,1), Lhist(:,2), 'm:', 'LineWidth',2.5);
plot(Rhist(:,1), Rhist(:,2), 'm:', 'LineWidth',2.5);

f = ForceProfile(t);

plot(xs, ys, 'b.-', 'LineWidth',2.5);
plot(xs(1), ys(1), 'ro', 'LineWidth',2.5);
plot(xs(end), ys(end), 'ro', 'LineWidth',2.5);
plot([xs(1),xs(1)+0.1*f(2)], [ys(1),ys(1)+0.1*f(3)], 'r-', 'LineWidth',3);
plot([xs(end),xs(end)+0.1*f(5)], [ys(end),ys(end)+0.1*f(6)], 'r-', 'LineWidth',3);

pts = [xs; ys];

