function et = EndTraj(t_init, pLinitial, v0)
% Returns [xL,yL,xR,yR, dxL,dyL,dxR,dyR, ddxL,ddyL,ddxR,ddyR]

global pR0 pL0 boomParams
global MaxTime EndTrajSoln

if (length(t_init)==4 && all(t_init=='init'))
    pL0 = pLinitial;
    pR0 = pL0;
    for a=1:boomParams.n
        pR0 = pR0 + boomParams.L(a)*[cos(v0(a)),sin(v0(a))];
    end
    options = odeset; %odeset('RelTol',1e-6);
    [EndTrajSoln.t, EndTrajSoln.s] = ode45(@derTraj, [0,MaxTime], [pL0, pR0, zeros(1,4)], options);
    EndTrajSoln.s = [EndTrajSoln.s, TrajAccelerations(EndTrajSoln.t)]; % [xL,yL,xR,yR, dxL,dyL,dxR,dyR, ddxL,ddyL,ddxR,ddyR]
    return;
end

% else return [xL,yL,xR,yR, dxL,dyL,dxR,dyR, ddxL,ddyL,ddxR,ddyR]
et = interp1(EndTrajSoln.t, EndTrajSoln.s, t_init, 'cubic');

% ------------------
function ds = derTraj(t, s)
% s = [xL,yL,xR,yR, dxL,dyL,dxR,dyR]'
ds = [s(5:8); TrajAccelerations(t)'];


% =======================================================
function outAcc = TrajAccelerations(t)
global pR0 pL0
tCount = length(t);
onesCol = ones(tCount, 1);

trajName = 'circle';

switch (trajName)
    
    case 'turn_back'
        vv = 0.1*(t<2) - 0.1*(t>2 & t<4);
        ddxL = -vv;
        ddyL = -0.1 * onesCol;
        ddxR = vv;
        ddyR = -0.1 * onesCol;
        outAcc = [ddxL, ddyL, ddxR, ddyR];
        
    case 'circle'
        %{
        alp = 0.1*onesCol;
        omg = 0.1*t;
        omgSq = omg.*omg;
        accL = [omgSq.*s(:,1), omgSq.*s(:,2)] + [-alp.*s(:,2), alp.*s(:,1)]; % omg.*omg*[s(1),s(2)] + alp.*[-s(2),s(1)];
        accR = [omgSq.*s(:,3), omgSq.*s(:,4)] + [-alp.*s(:,4), alp.*s(:,3)]; % omg.*omg*[s(3),s(4)] + alp.*[-s(4),s(3)];
        outAcc = [accL, accR];
        %}
        omg = 0.1 * (1 - exp(-t*0.1));
        alpha = 0.1 * 0.1 * exp(-t*0.1);
        beta = -0.1 * 0.1 * 0.1 * exp(-t*0.1);
        rL = sqrt(sum(pL0.^2));
        rR = sqrt(sum(pR0.^2));
        accVec = [ -(power(omg + alpha.*t, 2).*cos(omg.*t)) - (2.*alpha + beta.*t).*sin(omg.*t), ...
                     (2*alpha + beta.*t).*cos(omg.*t) - power(omg + alpha.*t, 2).*sin(omg.*t)  ];
        accL = rL*accVec;
        accR = rR*accVec;
        outAcc = [accL, accR];
       
        
end
