function boomSim_quasistatic
clear all
clear global

global boomParams dt

boomParams.n = 10;
boomParams.M = (0.8/boomParams.n) * ones(boomParams.n,1);
boomParams.L = (60*0.3048/boomParams.n) * ones(boomParams.n,1);
boomParams.Cs = 0.05; %0.00627552;
boomParams.Cv = 0.05; %0.00628319;

dt = 0.1;

th0 = [-pi/3, -pi/4, -pi/8, pi/8, pi/12, -pi/12, -pi/8, pi/8, pi/4, pi/3]';
thDes = (pi/4)*ones(10,1); 
                         %(-(pi-pi/10):(2*pi/10):(pi-pi/10))';
                         %((pi-pi/10):(-2*pi/10):(-pi+pi/10))'; thDes = sign(thDes).*(abs(thDes).^0.5) * (pi^0.5);
                         
pL0 = [10, 0];
pR0 = pL0;
for a=1:boomParams.n
    pR0 = pR0 + boomParams.L(a)*[cos(th0(a)),sin(th0(a))];
end

% Plot init
Lhist = [];
Rhist = [];
fCount = 1;
figure;
axis equal;
hold on;
grid on;
set(gca,'XLim',[-1 5]);

% Loop
th = th0;
p = [pL0,pR0];
t = 0;
while(t < 40)
    
    Dp = control_quasistatic(th, p, thDes); % Obtain control commands
    
    % Simulate the system
    matSys = getMat_quasistatic(th, p, boomParams.M, boomParams.L, [boomParams.Cs boomParams.Cv]);
    matSys_DthFr = matSys(:,[1:boomParams.n, end-1,end]);
    matSys_Dp = matSys(:,[(boomParams.n+1):(boomParams.n+4)]);
    DthFr = inv(matSys_DthFr) * (-matSys_Dp*Dp);

    p = p + (Dp')*dt;
    th = th + DthFr(1:boomParams.n)*dt;
    t = t + dt;
    
    % Plot
    cla;
    pts = drawFrame([p(1:2),th'],t);
    set(gca,'YLim',[mean(pts(2,:))-7.9, mean(pts(2,:))+7.9]);
    set(gca,'XLim',[mean(pts(1,:))-8.9, mean(pts(1,:))+8.9]);
    title(sprintf('t = %f', t));
    drawnow;
    F(fCount) = getframe;
    F(fCount).cdata = F(fCount).cdata(1:339,1:383,1:3); %F(fCount).cdata = F(fCount).cdata(1:286,1:430,1:3);
    fCount = fCount + 1;
    pause(0.01);
end

movie2avi(F,'QuasiStatic(40s)_ShapeControl(diagonal)_ExptParams.avi', 'compression','Cinepak', 'fps',10);

% =====================

function pts = drawFrame(y, t)
global boomParams
global Lhist Rhist

xs(1) = y(1);
ys(1) = y(2);
for a=3:(boomParams.n+2)
    pNext = [xs(end),ys(end)] + boomParams.L(a-2)*[cos(y(a)),sin(y(a))];
    xs(end+1) = pNext(1);
    ys(end+1) = pNext(2);
end

Lhist(end+1,:) = [xs(1),ys(1)];
Rhist(end+1,:) = [xs(end),ys(end)];
plot(Lhist(:,1), Lhist(:,2), 'm--', 'LineWidth',2.5);
plot(Rhist(:,1), Rhist(:,2), 'm--', 'LineWidth',2.5);

%f = ForceProfile(t);

plot(xs, ys, 'b.-', 'LineWidth',2.5);
plot(xs(1), ys(1), 'ro', 'LineWidth',2.5);
plot(xs(end), ys(end), 'ro', 'LineWidth',2.5);
%plot([xs(1),xs(1)+0.01*fs(1)], [ys(1),ys(1)+0.01*fs(2)], 'r-', 'LineWidth',3);
%plot([xs(end),xs(end)+0.01*fs(3)], [ys(end),ys(end)+0.01*fs(4)], 'r-', 'LineWidth',3);

pts = [xs; ys];

