/*
Use: matSys = getMat_quasistatic(v, p, M, L, [Cs Cv])
 where,
  v = [th1,th2,...,thn] is the state vector
  p = [xL, yL, xR, yR]
 The main equations of motion are given by
  matSys * [Dth1,Dth2,...,Dthn, DxL,DyL,DxR,DyR, fRX,fRY]' = 0;
 matSys is a (n+2) by (n+6) matrix.
*/

#include "math.h"
#include "stdio.h"
#include "stdlib.h"
#include "mex.h"   //--This one is required

void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
    int n, a;
    double* v0;
    double* Th;
    double* dTh;
    double* endPoses;
    double* matSys;
    double* rhsVec;
    double xL,yL,xR,yR;
    double* M0;
    double* L0;
    double* M;
    double* L;
    double* fricCoefs;
    double Cv, Cs;
    
    v0 = mxGetPr(prhs[0]);
    n = mxGetM(prhs[0]);
    Th = (double*) mxMalloc((n+1)*sizeof(double));
    for(a=0; a<n; a++)
        Th[a+1] = v0[a];
    
    endPoses = mxGetPr(prhs[1]);
    xL = endPoses[0];
    yL = endPoses[1];
    xR = endPoses[2];
    yR = endPoses[3];
    
    M0 = (double*) mxMalloc(n*sizeof(double));
    L0 = (double*) mxMalloc(n*sizeof(double));
    M0 = mxGetPr(prhs[2]);
    L0 = mxGetPr(prhs[3]);
    M = (double*) mxMalloc(n*sizeof(double));
    L = (double*) mxMalloc(n*sizeof(double));
    for(a=0; a<n; a++)
    {
        M[a+1] = M0[a];
        L[a+1] = L0[a];
    }
    fricCoefs = mxGetPr(prhs[4]);
    Cs = fricCoefs[0];
    Cv = fricCoefs[1];
    
    plhs[0] = mxCreateDoubleMatrix(n+2, n+6, mxREAL);
    matSys = mxGetPr(plhs[0]);
    
    // Assignments go here
    // ===================


 matSys[0] = -(pow(L[1],2)*(Cs*(2*L[1] + 3*(2*pow(cos(Th[1] - Th[2]),2)*L[2] + 2*pow(cos(Th[1] - Th[3]),2)*L[3] + L[4] + cos(2*(Th[1] - Th[4]))*L[4] + L[5] + cos(2*(Th[1] - Th[5]))*L[5] + L[6] + cos(2*(Th[1] - Th[6]))*L[6] + L[7] + cos(2*(Th[1] - Th[7]))*L[7] + L[8] + cos(2*(Th[1] - Th[8]))*L[8] + L[9] + cos(2*(Th[1] - Th[9]))*L[9] + L[10] + cos(2*(Th[1] - Th[10]))*L[10])) + 3*Cv*(L[4] - cos(2*(Th[1] - Th[4]))*L[4] + L[5] - cos(2*(Th[1] - Th[5]))*L[5] + L[6] - cos(2*(Th[1] - Th[6]))*L[6] + L[7] - cos(2*(Th[1] - Th[7]))*L[7] + L[8] - cos(2*(Th[1] - Th[8]))*L[8] + L[9] - cos(2*(Th[1] - Th[9]))*L[9] + L[10] - cos(2*(Th[1] - Th[10]))*L[10] + 2*L[2]*pow(sin(Th[1] - Th[2]),2) + 2*L[3]*pow(sin(Th[1] - Th[3]),2))))/6.;
 matSys[12] = -(L[1]*L[2]*(Cs*(cos(Th[1] - Th[2])*L[2] + 2*cos(Th[1] - Th[3])*cos(Th[2] - Th[3])*L[3] + cos(Th[1] - Th[2])*L[4] + cos(Th[1] + Th[2] - 2*Th[4])*L[4] + cos(Th[1] - Th[2])*L[5] + cos(Th[1] + Th[2] - 2*Th[5])*L[5] + cos(Th[1] - Th[2])*L[6] + cos(Th[1] + Th[2] - 2*Th[6])*L[6] + cos(Th[1] - Th[2])*L[7] + cos(Th[1] + Th[2] - 2*Th[7])*L[7] + cos(Th[1] - Th[2])*L[8] + cos(Th[1] + Th[2] - 2*Th[8])*L[8] + cos(Th[1] - Th[2])*L[9] + cos(Th[1] + Th[2] - 2*Th[9])*L[9] + cos(Th[1] - Th[2])*L[10] + cos(Th[1] + Th[2] - 2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[2])*L[5] - cos(Th[1] + Th[2] - 2*Th[5])*L[5] + cos(Th[1] - Th[2])*L[6] - cos(Th[1] + Th[2] - 2*Th[6])*L[6] + cos(Th[1] - Th[2])*L[7] - cos(Th[1] + Th[2] - 2*Th[7])*L[7] + cos(Th[1] - Th[2])*L[8] - cos(Th[1] + Th[2] - 2*Th[8])*L[8] + cos(Th[1] - Th[2])*L[9] - cos(Th[1] + Th[2] - 2*Th[9])*L[9] + cos(Th[1] - Th[2])*L[10] - cos(Th[1] + Th[2] - 2*Th[10])*L[10] + 2*L[3]*sin(Th[1] - Th[3])*sin(Th[2] - Th[3]) + 2*L[4]*sin(Th[1] - Th[4])*sin(Th[2] - Th[4]))))/2.;
 matSys[24] = -(L[1]*L[3]*(Cs*(cos(Th[1] - Th[3])*L[3] + 2*cos(Th[1] - Th[4])*cos(Th[3] - Th[4])*L[4] + cos(Th[1] - Th[3])*L[5] + cos(Th[1] + Th[3] - 2*Th[5])*L[5] + cos(Th[1] - Th[3])*L[6] + cos(Th[1] + Th[3] - 2*Th[6])*L[6] + cos(Th[1] - Th[3])*L[7] + cos(Th[1] + Th[3] - 2*Th[7])*L[7] + cos(Th[1] - Th[3])*L[8] + cos(Th[1] + Th[3] - 2*Th[8])*L[8] + cos(Th[1] - Th[3])*L[9] + cos(Th[1] + Th[3] - 2*Th[9])*L[9] + cos(Th[1] - Th[3])*L[10] + cos(Th[1] + Th[3] - 2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[3])*L[6] - cos(Th[1] + Th[3] - 2*Th[6])*L[6] + cos(Th[1] - Th[3])*L[7] - cos(Th[1] + Th[3] - 2*Th[7])*L[7] + cos(Th[1] - Th[3])*L[8] - cos(Th[1] + Th[3] - 2*Th[8])*L[8] + cos(Th[1] - Th[3])*L[9] - cos(Th[1] + Th[3] - 2*Th[9])*L[9] + cos(Th[1] - Th[3])*L[10] - cos(Th[1] + Th[3] - 2*Th[10])*L[10] + 2*L[4]*sin(Th[1] - Th[4])*sin(Th[3] - Th[4]) + 2*L[5]*sin(Th[1] - Th[5])*sin(Th[3] - Th[5]))))/2.;
 matSys[36] = -(L[1]*L[4]*(Cs*(cos(Th[1] - Th[4])*L[4] + 2*cos(Th[1] - Th[5])*cos(Th[4] - Th[5])*L[5] + cos(Th[1] - Th[4])*L[6] + cos(Th[1] + Th[4] - 2*Th[6])*L[6] + cos(Th[1] - Th[4])*L[7] + cos(Th[1] + Th[4] - 2*Th[7])*L[7] + cos(Th[1] - Th[4])*L[8] + cos(Th[1] + Th[4] - 2*Th[8])*L[8] + cos(Th[1] - Th[4])*L[9] + cos(Th[1] + Th[4] - 2*Th[9])*L[9] + cos(Th[1] - Th[4])*L[10] + cos(Th[1] + Th[4] - 2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[4])*L[7] - cos(Th[1] + Th[4] - 2*Th[7])*L[7] + cos(Th[1] - Th[4])*L[8] - cos(Th[1] + Th[4] - 2*Th[8])*L[8] + cos(Th[1] - Th[4])*L[9] - cos(Th[1] + Th[4] - 2*Th[9])*L[9] + cos(Th[1] - Th[4])*L[10] - cos(Th[1] + Th[4] - 2*Th[10])*L[10] + 2*L[5]*sin(Th[1] - Th[5])*sin(Th[4] - Th[5]) + 2*L[6]*sin(Th[1] - Th[6])*sin(Th[4] - Th[6]))))/2.;
 matSys[48] = -(L[1]*L[5]*(Cs*(cos(Th[1] - Th[5])*L[5] + 2*cos(Th[1] - Th[6])*cos(Th[5] - Th[6])*L[6] + cos(Th[1] - Th[5])*L[7] + cos(Th[1] + Th[5] - 2*Th[7])*L[7] + cos(Th[1] - Th[5])*L[8] + cos(Th[1] + Th[5] - 2*Th[8])*L[8] + cos(Th[1] - Th[5])*L[9] + cos(Th[1] + Th[5] - 2*Th[9])*L[9] + cos(Th[1] - Th[5])*L[10] + cos(Th[1] + Th[5] - 2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[5])*L[8] - cos(Th[1] + Th[5] - 2*Th[8])*L[8] + cos(Th[1] - Th[5])*L[9] - cos(Th[1] + Th[5] - 2*Th[9])*L[9] + cos(Th[1] - Th[5])*L[10] - cos(Th[1] + Th[5] - 2*Th[10])*L[10] + 2*L[6]*sin(Th[1] - Th[6])*sin(Th[5] - Th[6]) + 2*L[7]*sin(Th[1] - Th[7])*sin(Th[5] - Th[7]))))/2.;
 matSys[60] = -(L[1]*L[6]*(Cs*(cos(Th[1] - Th[6])*L[6] + 2*cos(Th[1] - Th[7])*cos(Th[6] - Th[7])*L[7] + cos(Th[1] - Th[6])*L[8] + cos(Th[1] + Th[6] - 2*Th[8])*L[8] + cos(Th[1] - Th[6])*L[9] + cos(Th[1] + Th[6] - 2*Th[9])*L[9] + cos(Th[1] - Th[6])*L[10] + cos(Th[1] + Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[6])*L[9] - cos(Th[1] + Th[6] - 2*Th[9])*L[9] + cos(Th[1] - Th[6])*L[10] - cos(Th[1] + Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[1] - Th[7])*sin(Th[6] - Th[7]) + 2*L[8]*sin(Th[1] - Th[8])*sin(Th[6] - Th[8]))))/2.;
 matSys[72] = -(L[1]*L[7]*(Cs*(cos(Th[1] - Th[7])*L[7] + 2*cos(Th[1] - Th[8])*cos(Th[7] - Th[8])*L[8] + cos(Th[1] - Th[7])*L[9] + cos(Th[1] + Th[7] - 2*Th[9])*L[9] + cos(Th[1] - Th[7])*L[10] + cos(Th[1] + Th[7] - 2*Th[10])*L[10]) + 2*Cv*(L[8]*sin(Th[1] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[1] - Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[1] - Th[10])*sin(Th[7] - Th[10]))))/2.;
 matSys[84] = -(L[1]*L[8]*(Cs*(cos(Th[1] - Th[8])*L[8] + 2*cos(Th[1] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[1] - Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[1] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[1] - Th[10])*sin(Th[8] - Th[10]))))/2.;
 matSys[96] = -(L[1]*L[9]*(Cs*(cos(Th[1] - Th[9])*L[9] + 2*cos(Th[1] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[1] - Th[10])*sin(Th[9] - Th[10])))/2.;
 matSys[108] = -(Cs*cos(Th[1] - Th[10])*L[1]*pow(L[10],2))/2.;
 matSys[120] = (L[1]*(Cs*(L[1]*sin(Th[1]) + L[3]*sin(Th[1]) + L[4]*sin(Th[1]) + L[5]*sin(Th[1]) + L[6]*sin(Th[1]) + L[7]*sin(Th[1]) + L[8]*sin(Th[1]) + L[9]*sin(Th[1]) + L[10]*sin(Th[1]) + 2*cos(Th[1] - Th[2])*L[2]*sin(Th[2]) - L[3]*sin(Th[1] - 2*Th[3]) - L[4]*sin(Th[1] - 2*Th[4]) - L[5]*sin(Th[1] - 2*Th[5]) - L[6]*sin(Th[1] - 2*Th[6]) - L[7]*sin(Th[1] - 2*Th[7]) - L[8]*sin(Th[1] - 2*Th[8]) - L[9]*sin(Th[1] - 2*Th[9]) - L[10]*sin(Th[1] - 2*Th[10])) + Cv*(L[4]*sin(Th[1]) + L[5]*sin(Th[1]) + L[6]*sin(Th[1]) + L[7]*sin(Th[1]) + L[8]*sin(Th[1]) + L[9]*sin(Th[1]) + L[10]*sin(Th[1]) + 2*cos(Th[2])*L[2]*sin(Th[1] - Th[2]) + 2*cos(Th[3])*L[3]*sin(Th[1] - Th[3]) + L[4]*sin(Th[1] - 2*Th[4]) + L[5]*sin(Th[1] - 2*Th[5]) + L[6]*sin(Th[1] - 2*Th[6]) + L[7]*sin(Th[1] - 2*Th[7]) + L[8]*sin(Th[1] - 2*Th[8]) + L[9]*sin(Th[1] - 2*Th[9]) + L[10]*sin(Th[1] - 2*Th[10]))))/2.;
 matSys[132] = -(L[1]*(Cs*(cos(Th[1])*L[1] + 2*cos(Th[1] - Th[2])*cos(Th[2])*L[2] + cos(Th[1])*L[3] + cos(Th[1] - 2*Th[3])*L[3] + cos(Th[1])*L[4] + cos(Th[1] - 2*Th[4])*L[4] + cos(Th[1])*L[5] + cos(Th[1] - 2*Th[5])*L[5] + cos(Th[1])*L[6] + cos(Th[1] - 2*Th[6])*L[6] + cos(Th[1])*L[7] + cos(Th[1] - 2*Th[7])*L[7] + cos(Th[1])*L[8] + cos(Th[1] - 2*Th[8])*L[8] + cos(Th[1])*L[9] + cos(Th[1] - 2*Th[9])*L[9] + cos(Th[1])*L[10] + cos(Th[1] - 2*Th[10])*L[10]) - Cv*(-(cos(Th[1])*L[4]) + cos(Th[1] - 2*Th[4])*L[4] - cos(Th[1])*L[5] + cos(Th[1] - 2*Th[5])*L[5] - cos(Th[1])*L[6] + cos(Th[1] - 2*Th[6])*L[6] - cos(Th[1])*L[7] + cos(Th[1] - 2*Th[7])*L[7] - cos(Th[1])*L[8] + cos(Th[1] - 2*Th[8])*L[8] - cos(Th[1])*L[9] + cos(Th[1] - 2*Th[9])*L[9] - cos(Th[1])*L[10] + cos(Th[1] - 2*Th[10])*L[10] + 2*L[2]*sin(Th[1] - Th[2])*sin(Th[2]) + 2*L[3]*sin(Th[1] - Th[3])*sin(Th[3]))))/2.;
 matSys[144] = 0;
 matSys[156] = 0;
 matSys[168] = -(L[1]*sin(Th[1]));
 matSys[180] = cos(Th[1])*L[1];
 matSys[1] = -(L[1]*L[2]*(Cs*(cos(Th[1] - Th[2])*L[2] + 2*cos(Th[1] - Th[3])*cos(Th[2] - Th[3])*L[3] + cos(Th[1] - Th[2])*L[4] + cos(Th[1] + Th[2] - 2*Th[4])*L[4] + cos(Th[1] - Th[2])*L[5] + cos(Th[1] + Th[2] - 2*Th[5])*L[5] + cos(Th[1] - Th[2])*L[6] + cos(Th[1] + Th[2] - 2*Th[6])*L[6] + cos(Th[1] - Th[2])*L[7] + cos(Th[1] + Th[2] - 2*Th[7])*L[7] + cos(Th[1] - Th[2])*L[8] + cos(Th[1] + Th[2] - 2*Th[8])*L[8] + cos(Th[1] - Th[2])*L[9] + cos(Th[1] + Th[2] - 2*Th[9])*L[9] + cos(Th[1] - Th[2])*L[10] + cos(Th[1] + Th[2] - 2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[2])*L[5] - cos(Th[1] + Th[2] - 2*Th[5])*L[5] + cos(Th[1] - Th[2])*L[6] - cos(Th[1] + Th[2] - 2*Th[6])*L[6] + cos(Th[1] - Th[2])*L[7] - cos(Th[1] + Th[2] - 2*Th[7])*L[7] + cos(Th[1] - Th[2])*L[8] - cos(Th[1] + Th[2] - 2*Th[8])*L[8] + cos(Th[1] - Th[2])*L[9] - cos(Th[1] + Th[2] - 2*Th[9])*L[9] + cos(Th[1] - Th[2])*L[10] - cos(Th[1] + Th[2] - 2*Th[10])*L[10] + 2*L[3]*sin(Th[1] - Th[3])*sin(Th[2] - Th[3]) + 2*L[4]*sin(Th[1] - Th[4])*sin(Th[2] - Th[4]))))/2.;
 matSys[13] = -(pow(L[2],2)*(Cs*(2*L[2] + 3*(2*pow(cos(Th[2] - Th[3]),2)*L[3] + 2*pow(cos(Th[2] - Th[4]),2)*L[4] + L[5] + cos(2*(Th[2] - Th[5]))*L[5] + L[6] + cos(2*(Th[2] - Th[6]))*L[6] + L[7] + cos(2*(Th[2] - Th[7]))*L[7] + L[8] + cos(2*(Th[2] - Th[8]))*L[8] + L[9] + cos(2*(Th[2] - Th[9]))*L[9] + L[10] + cos(2*(Th[2] - Th[10]))*L[10])) + 3*Cv*(L[5] - cos(2*(Th[2] - Th[5]))*L[5] + L[6] - cos(2*(Th[2] - Th[6]))*L[6] + L[7] - cos(2*(Th[2] - Th[7]))*L[7] + L[8] - cos(2*(Th[2] - Th[8]))*L[8] + L[9] - cos(2*(Th[2] - Th[9]))*L[9] + L[10] - cos(2*(Th[2] - Th[10]))*L[10] + 2*L[3]*pow(sin(Th[2] - Th[3]),2) + 2*L[4]*pow(sin(Th[2] - Th[4]),2))))/6.;
 matSys[25] = -(L[2]*L[3]*(Cs*(cos(Th[2] - Th[3])*L[3] + 2*cos(Th[2] - Th[4])*cos(Th[3] - Th[4])*L[4] + cos(Th[2] - Th[3])*L[5] + cos(Th[2] + Th[3] - 2*Th[5])*L[5] + cos(Th[2] - Th[3])*L[6] + cos(Th[2] + Th[3] - 2*Th[6])*L[6] + cos(Th[2] - Th[3])*L[7] + cos(Th[2] + Th[3] - 2*Th[7])*L[7] + cos(Th[2] - Th[3])*L[8] + cos(Th[2] + Th[3] - 2*Th[8])*L[8] + cos(Th[2] - Th[3])*L[9] + cos(Th[2] + Th[3] - 2*Th[9])*L[9] + cos(Th[2] - Th[3])*L[10] + cos(Th[2] + Th[3] - 2*Th[10])*L[10]) + Cv*(cos(Th[2] - Th[3])*L[6] - cos(Th[2] + Th[3] - 2*Th[6])*L[6] + cos(Th[2] - Th[3])*L[7] - cos(Th[2] + Th[3] - 2*Th[7])*L[7] + cos(Th[2] - Th[3])*L[8] - cos(Th[2] + Th[3] - 2*Th[8])*L[8] + cos(Th[2] - Th[3])*L[9] - cos(Th[2] + Th[3] - 2*Th[9])*L[9] + cos(Th[2] - Th[3])*L[10] - cos(Th[2] + Th[3] - 2*Th[10])*L[10] + 2*L[4]*sin(Th[2] - Th[4])*sin(Th[3] - Th[4]) + 2*L[5]*sin(Th[2] - Th[5])*sin(Th[3] - Th[5]))))/2.;
 matSys[37] = -(L[2]*L[4]*(Cs*(cos(Th[2] - Th[4])*L[4] + 2*cos(Th[2] - Th[5])*cos(Th[4] - Th[5])*L[5] + cos(Th[2] - Th[4])*L[6] + cos(Th[2] + Th[4] - 2*Th[6])*L[6] + cos(Th[2] - Th[4])*L[7] + cos(Th[2] + Th[4] - 2*Th[7])*L[7] + cos(Th[2] - Th[4])*L[8] + cos(Th[2] + Th[4] - 2*Th[8])*L[8] + cos(Th[2] - Th[4])*L[9] + cos(Th[2] + Th[4] - 2*Th[9])*L[9] + cos(Th[2] - Th[4])*L[10] + cos(Th[2] + Th[4] - 2*Th[10])*L[10]) + Cv*(cos(Th[2] - Th[4])*L[7] - cos(Th[2] + Th[4] - 2*Th[7])*L[7] + cos(Th[2] - Th[4])*L[8] - cos(Th[2] + Th[4] - 2*Th[8])*L[8] + cos(Th[2] - Th[4])*L[9] - cos(Th[2] + Th[4] - 2*Th[9])*L[9] + cos(Th[2] - Th[4])*L[10] - cos(Th[2] + Th[4] - 2*Th[10])*L[10] + 2*L[5]*sin(Th[2] - Th[5])*sin(Th[4] - Th[5]) + 2*L[6]*sin(Th[2] - Th[6])*sin(Th[4] - Th[6]))))/2.;
 matSys[49] = -(L[2]*L[5]*(Cs*(cos(Th[2] - Th[5])*L[5] + 2*cos(Th[2] - Th[6])*cos(Th[5] - Th[6])*L[6] + cos(Th[2] - Th[5])*L[7] + cos(Th[2] + Th[5] - 2*Th[7])*L[7] + cos(Th[2] - Th[5])*L[8] + cos(Th[2] + Th[5] - 2*Th[8])*L[8] + cos(Th[2] - Th[5])*L[9] + cos(Th[2] + Th[5] - 2*Th[9])*L[9] + cos(Th[2] - Th[5])*L[10] + cos(Th[2] + Th[5] - 2*Th[10])*L[10]) + Cv*(cos(Th[2] - Th[5])*L[8] - cos(Th[2] + Th[5] - 2*Th[8])*L[8] + cos(Th[2] - Th[5])*L[9] - cos(Th[2] + Th[5] - 2*Th[9])*L[9] + cos(Th[2] - Th[5])*L[10] - cos(Th[2] + Th[5] - 2*Th[10])*L[10] + 2*L[6]*sin(Th[2] - Th[6])*sin(Th[5] - Th[6]) + 2*L[7]*sin(Th[2] - Th[7])*sin(Th[5] - Th[7]))))/2.;
 matSys[61] = -(L[2]*L[6]*(Cs*(cos(Th[2] - Th[6])*L[6] + 2*cos(Th[2] - Th[7])*cos(Th[6] - Th[7])*L[7] + cos(Th[2] - Th[6])*L[8] + cos(Th[2] + Th[6] - 2*Th[8])*L[8] + cos(Th[2] - Th[6])*L[9] + cos(Th[2] + Th[6] - 2*Th[9])*L[9] + cos(Th[2] - Th[6])*L[10] + cos(Th[2] + Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[2] - Th[6])*L[9] - cos(Th[2] + Th[6] - 2*Th[9])*L[9] + cos(Th[2] - Th[6])*L[10] - cos(Th[2] + Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[2] - Th[7])*sin(Th[6] - Th[7]) + 2*L[8]*sin(Th[2] - Th[8])*sin(Th[6] - Th[8]))))/2.;
 matSys[73] = -(L[2]*L[7]*(Cs*(cos(Th[2] - Th[7])*L[7] + 2*cos(Th[2] - Th[8])*cos(Th[7] - Th[8])*L[8] + cos(Th[2] - Th[7])*L[9] + cos(Th[2] + Th[7] - 2*Th[9])*L[9] + cos(Th[2] - Th[7])*L[10] + cos(Th[2] + Th[7] - 2*Th[10])*L[10]) + 2*Cv*(L[8]*sin(Th[2] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[2] - Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[2] - Th[10])*sin(Th[7] - Th[10]))))/2.;
 matSys[85] = -(L[2]*L[8]*(Cs*(cos(Th[2] - Th[8])*L[8] + 2*cos(Th[2] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[2] - Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[2] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[2] - Th[10])*sin(Th[8] - Th[10]))))/2.;
 matSys[97] = -(L[2]*L[9]*(Cs*(cos(Th[2] - Th[9])*L[9] + 2*cos(Th[2] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[2] - Th[10])*sin(Th[9] - Th[10])))/2.;
 matSys[109] = -(Cs*cos(Th[2] - Th[10])*L[2]*pow(L[10],2))/2.;
 matSys[121] = (L[2]*(Cs*(L[2]*sin(Th[2]) + L[4]*sin(Th[2]) + L[5]*sin(Th[2]) + L[6]*sin(Th[2]) + L[7]*sin(Th[2]) + L[8]*sin(Th[2]) + L[9]*sin(Th[2]) + L[10]*sin(Th[2]) + 2*cos(Th[2] - Th[3])*L[3]*sin(Th[3]) - L[4]*sin(Th[2] - 2*Th[4]) - L[5]*sin(Th[2] - 2*Th[5]) - L[6]*sin(Th[2] - 2*Th[6]) - L[7]*sin(Th[2] - 2*Th[7]) - L[8]*sin(Th[2] - 2*Th[8]) - L[9]*sin(Th[2] - 2*Th[9]) - L[10]*sin(Th[2] - 2*Th[10])) + Cv*(L[5]*sin(Th[2]) + L[6]*sin(Th[2]) + L[7]*sin(Th[2]) + L[8]*sin(Th[2]) + L[9]*sin(Th[2]) + L[10]*sin(Th[2]) + 2*cos(Th[3])*L[3]*sin(Th[2] - Th[3]) + 2*cos(Th[4])*L[4]*sin(Th[2] - Th[4]) + L[5]*sin(Th[2] - 2*Th[5]) + L[6]*sin(Th[2] - 2*Th[6]) + L[7]*sin(Th[2] - 2*Th[7]) + L[8]*sin(Th[2] - 2*Th[8]) + L[9]*sin(Th[2] - 2*Th[9]) + L[10]*sin(Th[2] - 2*Th[10]))))/2.;
 matSys[133] = -(L[2]*(Cs*(cos(Th[2])*L[2] + 2*cos(Th[2] - Th[3])*cos(Th[3])*L[3] + cos(Th[2])*L[4] + cos(Th[2] - 2*Th[4])*L[4] + cos(Th[2])*L[5] + cos(Th[2] - 2*Th[5])*L[5] + cos(Th[2])*L[6] + cos(Th[2] - 2*Th[6])*L[6] + cos(Th[2])*L[7] + cos(Th[2] - 2*Th[7])*L[7] + cos(Th[2])*L[8] + cos(Th[2] - 2*Th[8])*L[8] + cos(Th[2])*L[9] + cos(Th[2] - 2*Th[9])*L[9] + cos(Th[2])*L[10] + cos(Th[2] - 2*Th[10])*L[10]) - Cv*(-(cos(Th[2])*L[5]) + cos(Th[2] - 2*Th[5])*L[5] - cos(Th[2])*L[6] + cos(Th[2] - 2*Th[6])*L[6] - cos(Th[2])*L[7] + cos(Th[2] - 2*Th[7])*L[7] - cos(Th[2])*L[8] + cos(Th[2] - 2*Th[8])*L[8] - cos(Th[2])*L[9] + cos(Th[2] - 2*Th[9])*L[9] - cos(Th[2])*L[10] + cos(Th[2] - 2*Th[10])*L[10] + 2*L[3]*sin(Th[2] - Th[3])*sin(Th[3]) + 2*L[4]*sin(Th[2] - Th[4])*sin(Th[4]))))/2.;
 matSys[145] = 0;
 matSys[157] = 0;
 matSys[169] = -(L[2]*sin(Th[2]));
 matSys[181] = cos(Th[2])*L[2];
 matSys[2] = -(L[1]*L[3]*(Cs*(cos(Th[1] - Th[3])*L[3] + 2*cos(Th[1] - Th[4])*cos(Th[3] - Th[4])*L[4] + cos(Th[1] - Th[3])*L[5] + cos(Th[1] + Th[3] - 2*Th[5])*L[5] + cos(Th[1] - Th[3])*L[6] + cos(Th[1] + Th[3] - 2*Th[6])*L[6] + cos(Th[1] - Th[3])*L[7] + cos(Th[1] + Th[3] - 2*Th[7])*L[7] + cos(Th[1] - Th[3])*L[8] + cos(Th[1] + Th[3] - 2*Th[8])*L[8] + cos(Th[1] - Th[3])*L[9] + cos(Th[1] + Th[3] - 2*Th[9])*L[9] + cos(Th[1] - Th[3])*L[10] + cos(Th[1] + Th[3] - 2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[3])*L[6] - cos(Th[1] + Th[3] - 2*Th[6])*L[6] + cos(Th[1] - Th[3])*L[7] - cos(Th[1] + Th[3] - 2*Th[7])*L[7] + cos(Th[1] - Th[3])*L[8] - cos(Th[1] + Th[3] - 2*Th[8])*L[8] + cos(Th[1] - Th[3])*L[9] - cos(Th[1] + Th[3] - 2*Th[9])*L[9] + cos(Th[1] - Th[3])*L[10] - cos(Th[1] + Th[3] - 2*Th[10])*L[10] + 2*L[4]*sin(Th[1] - Th[4])*sin(Th[3] - Th[4]) + 2*L[5]*sin(Th[1] - Th[5])*sin(Th[3] - Th[5]))))/2.;
 matSys[14] = -(L[2]*L[3]*(Cs*(cos(Th[2] - Th[3])*L[3] + 2*cos(Th[2] - Th[4])*cos(Th[3] - Th[4])*L[4] + cos(Th[2] - Th[3])*L[5] + cos(Th[2] + Th[3] - 2*Th[5])*L[5] + cos(Th[2] - Th[3])*L[6] + cos(Th[2] + Th[3] - 2*Th[6])*L[6] + cos(Th[2] - Th[3])*L[7] + cos(Th[2] + Th[3] - 2*Th[7])*L[7] + cos(Th[2] - Th[3])*L[8] + cos(Th[2] + Th[3] - 2*Th[8])*L[8] + cos(Th[2] - Th[3])*L[9] + cos(Th[2] + Th[3] - 2*Th[9])*L[9] + cos(Th[2] - Th[3])*L[10] + cos(Th[2] + Th[3] - 2*Th[10])*L[10]) + Cv*(cos(Th[2] - Th[3])*L[6] - cos(Th[2] + Th[3] - 2*Th[6])*L[6] + cos(Th[2] - Th[3])*L[7] - cos(Th[2] + Th[3] - 2*Th[7])*L[7] + cos(Th[2] - Th[3])*L[8] - cos(Th[2] + Th[3] - 2*Th[8])*L[8] + cos(Th[2] - Th[3])*L[9] - cos(Th[2] + Th[3] - 2*Th[9])*L[9] + cos(Th[2] - Th[3])*L[10] - cos(Th[2] + Th[3] - 2*Th[10])*L[10] + 2*L[4]*sin(Th[2] - Th[4])*sin(Th[3] - Th[4]) + 2*L[5]*sin(Th[2] - Th[5])*sin(Th[3] - Th[5]))))/2.;
 matSys[26] = -(pow(L[3],2)*(Cs*(2*L[3] + 3*(2*pow(cos(Th[3] - Th[4]),2)*L[4] + 2*pow(cos(Th[3] - Th[5]),2)*L[5] + L[6] + cos(2*(Th[3] - Th[6]))*L[6] + L[7] + cos(2*(Th[3] - Th[7]))*L[7] + L[8] + cos(2*(Th[3] - Th[8]))*L[8] + L[9] + cos(2*(Th[3] - Th[9]))*L[9] + L[10] + cos(2*(Th[3] - Th[10]))*L[10])) + 3*Cv*(L[6] - cos(2*(Th[3] - Th[6]))*L[6] + L[7] - cos(2*(Th[3] - Th[7]))*L[7] + L[8] - cos(2*(Th[3] - Th[8]))*L[8] + L[9] - cos(2*(Th[3] - Th[9]))*L[9] + L[10] - cos(2*(Th[3] - Th[10]))*L[10] + 2*L[4]*pow(sin(Th[3] - Th[4]),2) + 2*L[5]*pow(sin(Th[3] - Th[5]),2))))/6.;
 matSys[38] = -(L[3]*L[4]*(Cs*(cos(Th[3] - Th[4])*L[4] + 2*cos(Th[3] - Th[5])*cos(Th[4] - Th[5])*L[5] + cos(Th[3] - Th[4])*L[6] + cos(Th[3] + Th[4] - 2*Th[6])*L[6] + cos(Th[3] - Th[4])*L[7] + cos(Th[3] + Th[4] - 2*Th[7])*L[7] + cos(Th[3] - Th[4])*L[8] + cos(Th[3] + Th[4] - 2*Th[8])*L[8] + cos(Th[3] - Th[4])*L[9] + cos(Th[3] + Th[4] - 2*Th[9])*L[9] + cos(Th[3] - Th[4])*L[10] + cos(Th[3] + Th[4] - 2*Th[10])*L[10]) + Cv*(cos(Th[3] - Th[4])*L[7] - cos(Th[3] + Th[4] - 2*Th[7])*L[7] + cos(Th[3] - Th[4])*L[8] - cos(Th[3] + Th[4] - 2*Th[8])*L[8] + cos(Th[3] - Th[4])*L[9] - cos(Th[3] + Th[4] - 2*Th[9])*L[9] + cos(Th[3] - Th[4])*L[10] - cos(Th[3] + Th[4] - 2*Th[10])*L[10] + 2*L[5]*sin(Th[3] - Th[5])*sin(Th[4] - Th[5]) + 2*L[6]*sin(Th[3] - Th[6])*sin(Th[4] - Th[6]))))/2.;
 matSys[50] = -(L[3]*L[5]*(Cs*(cos(Th[3] - Th[5])*L[5] + 2*cos(Th[3] - Th[6])*cos(Th[5] - Th[6])*L[6] + cos(Th[3] - Th[5])*L[7] + cos(Th[3] + Th[5] - 2*Th[7])*L[7] + cos(Th[3] - Th[5])*L[8] + cos(Th[3] + Th[5] - 2*Th[8])*L[8] + cos(Th[3] - Th[5])*L[9] + cos(Th[3] + Th[5] - 2*Th[9])*L[9] + cos(Th[3] - Th[5])*L[10] + cos(Th[3] + Th[5] - 2*Th[10])*L[10]) + Cv*(cos(Th[3] - Th[5])*L[8] - cos(Th[3] + Th[5] - 2*Th[8])*L[8] + cos(Th[3] - Th[5])*L[9] - cos(Th[3] + Th[5] - 2*Th[9])*L[9] + cos(Th[3] - Th[5])*L[10] - cos(Th[3] + Th[5] - 2*Th[10])*L[10] + 2*L[6]*sin(Th[3] - Th[6])*sin(Th[5] - Th[6]) + 2*L[7]*sin(Th[3] - Th[7])*sin(Th[5] - Th[7]))))/2.;
 matSys[62] = -(L[3]*L[6]*(Cs*(cos(Th[3] - Th[6])*L[6] + 2*cos(Th[3] - Th[7])*cos(Th[6] - Th[7])*L[7] + cos(Th[3] - Th[6])*L[8] + cos(Th[3] + Th[6] - 2*Th[8])*L[8] + cos(Th[3] - Th[6])*L[9] + cos(Th[3] + Th[6] - 2*Th[9])*L[9] + cos(Th[3] - Th[6])*L[10] + cos(Th[3] + Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[3] - Th[6])*L[9] - cos(Th[3] + Th[6] - 2*Th[9])*L[9] + cos(Th[3] - Th[6])*L[10] - cos(Th[3] + Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[3] - Th[7])*sin(Th[6] - Th[7]) + 2*L[8]*sin(Th[3] - Th[8])*sin(Th[6] - Th[8]))))/2.;
 matSys[74] = -(L[3]*L[7]*(Cs*(cos(Th[3] - Th[7])*L[7] + 2*cos(Th[3] - Th[8])*cos(Th[7] - Th[8])*L[8] + cos(Th[3] - Th[7])*L[9] + cos(Th[3] + Th[7] - 2*Th[9])*L[9] + cos(Th[3] - Th[7])*L[10] + cos(Th[3] + Th[7] - 2*Th[10])*L[10]) + 2*Cv*(L[8]*sin(Th[3] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[3] - Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[3] - Th[10])*sin(Th[7] - Th[10]))))/2.;
 matSys[86] = -(L[3]*L[8]*(Cs*(cos(Th[3] - Th[8])*L[8] + 2*cos(Th[3] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[3] - Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[3] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[3] - Th[10])*sin(Th[8] - Th[10]))))/2.;
 matSys[98] = -(L[3]*L[9]*(Cs*(cos(Th[3] - Th[9])*L[9] + 2*cos(Th[3] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[3] - Th[10])*sin(Th[9] - Th[10])))/2.;
 matSys[110] = -(Cs*cos(Th[3] - Th[10])*L[3]*pow(L[10],2))/2.;
 matSys[122] = (L[3]*(Cs*(L[3]*sin(Th[3]) + L[5]*sin(Th[3]) + L[6]*sin(Th[3]) + L[7]*sin(Th[3]) + L[8]*sin(Th[3]) + L[9]*sin(Th[3]) + L[10]*sin(Th[3]) + 2*cos(Th[3] - Th[4])*L[4]*sin(Th[4]) - L[5]*sin(Th[3] - 2*Th[5]) - L[6]*sin(Th[3] - 2*Th[6]) - L[7]*sin(Th[3] - 2*Th[7]) - L[8]*sin(Th[3] - 2*Th[8]) - L[9]*sin(Th[3] - 2*Th[9]) - L[10]*sin(Th[3] - 2*Th[10])) + Cv*(L[6]*sin(Th[3]) + L[7]*sin(Th[3]) + L[8]*sin(Th[3]) + L[9]*sin(Th[3]) + L[10]*sin(Th[3]) + 2*cos(Th[4])*L[4]*sin(Th[3] - Th[4]) + 2*cos(Th[5])*L[5]*sin(Th[3] - Th[5]) + L[6]*sin(Th[3] - 2*Th[6]) + L[7]*sin(Th[3] - 2*Th[7]) + L[8]*sin(Th[3] - 2*Th[8]) + L[9]*sin(Th[3] - 2*Th[9]) + L[10]*sin(Th[3] - 2*Th[10]))))/2.;
 matSys[134] = -(L[3]*(Cs*(cos(Th[3])*L[3] + 2*cos(Th[3] - Th[4])*cos(Th[4])*L[4] + cos(Th[3])*L[5] + cos(Th[3] - 2*Th[5])*L[5] + cos(Th[3])*L[6] + cos(Th[3] - 2*Th[6])*L[6] + cos(Th[3])*L[7] + cos(Th[3] - 2*Th[7])*L[7] + cos(Th[3])*L[8] + cos(Th[3] - 2*Th[8])*L[8] + cos(Th[3])*L[9] + cos(Th[3] - 2*Th[9])*L[9] + cos(Th[3])*L[10] + cos(Th[3] - 2*Th[10])*L[10]) - Cv*(-(cos(Th[3])*L[6]) + cos(Th[3] - 2*Th[6])*L[6] - cos(Th[3])*L[7] + cos(Th[3] - 2*Th[7])*L[7] - cos(Th[3])*L[8] + cos(Th[3] - 2*Th[8])*L[8] - cos(Th[3])*L[9] + cos(Th[3] - 2*Th[9])*L[9] - cos(Th[3])*L[10] + cos(Th[3] - 2*Th[10])*L[10] + 2*L[4]*sin(Th[3] - Th[4])*sin(Th[4]) + 2*L[5]*sin(Th[3] - Th[5])*sin(Th[5]))))/2.;
 matSys[146] = 0;
 matSys[158] = 0;
 matSys[170] = -(L[3]*sin(Th[3]));
 matSys[182] = cos(Th[3])*L[3];
 matSys[3] = -(L[1]*L[4]*(Cs*(cos(Th[1] - Th[4])*L[4] + 2*cos(Th[1] - Th[5])*cos(Th[4] - Th[5])*L[5] + cos(Th[1] - Th[4])*L[6] + cos(Th[1] + Th[4] - 2*Th[6])*L[6] + cos(Th[1] - Th[4])*L[7] + cos(Th[1] + Th[4] - 2*Th[7])*L[7] + cos(Th[1] - Th[4])*L[8] + cos(Th[1] + Th[4] - 2*Th[8])*L[8] + cos(Th[1] - Th[4])*L[9] + cos(Th[1] + Th[4] - 2*Th[9])*L[9] + cos(Th[1] - Th[4])*L[10] + cos(Th[1] + Th[4] - 2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[4])*L[7] - cos(Th[1] + Th[4] - 2*Th[7])*L[7] + cos(Th[1] - Th[4])*L[8] - cos(Th[1] + Th[4] - 2*Th[8])*L[8] + cos(Th[1] - Th[4])*L[9] - cos(Th[1] + Th[4] - 2*Th[9])*L[9] + cos(Th[1] - Th[4])*L[10] - cos(Th[1] + Th[4] - 2*Th[10])*L[10] + 2*L[5]*sin(Th[1] - Th[5])*sin(Th[4] - Th[5]) + 2*L[6]*sin(Th[1] - Th[6])*sin(Th[4] - Th[6]))))/2.;
 matSys[15] = -(L[2]*L[4]*(Cs*(cos(Th[2] - Th[4])*L[4] + 2*cos(Th[2] - Th[5])*cos(Th[4] - Th[5])*L[5] + cos(Th[2] - Th[4])*L[6] + cos(Th[2] + Th[4] - 2*Th[6])*L[6] + cos(Th[2] - Th[4])*L[7] + cos(Th[2] + Th[4] - 2*Th[7])*L[7] + cos(Th[2] - Th[4])*L[8] + cos(Th[2] + Th[4] - 2*Th[8])*L[8] + cos(Th[2] - Th[4])*L[9] + cos(Th[2] + Th[4] - 2*Th[9])*L[9] + cos(Th[2] - Th[4])*L[10] + cos(Th[2] + Th[4] - 2*Th[10])*L[10]) + Cv*(cos(Th[2] - Th[4])*L[7] - cos(Th[2] + Th[4] - 2*Th[7])*L[7] + cos(Th[2] - Th[4])*L[8] - cos(Th[2] + Th[4] - 2*Th[8])*L[8] + cos(Th[2] - Th[4])*L[9] - cos(Th[2] + Th[4] - 2*Th[9])*L[9] + cos(Th[2] - Th[4])*L[10] - cos(Th[2] + Th[4] - 2*Th[10])*L[10] + 2*L[5]*sin(Th[2] - Th[5])*sin(Th[4] - Th[5]) + 2*L[6]*sin(Th[2] - Th[6])*sin(Th[4] - Th[6]))))/2.;
 matSys[27] = -(L[3]*L[4]*(Cs*(cos(Th[3] - Th[4])*L[4] + 2*cos(Th[3] - Th[5])*cos(Th[4] - Th[5])*L[5] + cos(Th[3] - Th[4])*L[6] + cos(Th[3] + Th[4] - 2*Th[6])*L[6] + cos(Th[3] - Th[4])*L[7] + cos(Th[3] + Th[4] - 2*Th[7])*L[7] + cos(Th[3] - Th[4])*L[8] + cos(Th[3] + Th[4] - 2*Th[8])*L[8] + cos(Th[3] - Th[4])*L[9] + cos(Th[3] + Th[4] - 2*Th[9])*L[9] + cos(Th[3] - Th[4])*L[10] + cos(Th[3] + Th[4] - 2*Th[10])*L[10]) + Cv*(cos(Th[3] - Th[4])*L[7] - cos(Th[3] + Th[4] - 2*Th[7])*L[7] + cos(Th[3] - Th[4])*L[8] - cos(Th[3] + Th[4] - 2*Th[8])*L[8] + cos(Th[3] - Th[4])*L[9] - cos(Th[3] + Th[4] - 2*Th[9])*L[9] + cos(Th[3] - Th[4])*L[10] - cos(Th[3] + Th[4] - 2*Th[10])*L[10] + 2*L[5]*sin(Th[3] - Th[5])*sin(Th[4] - Th[5]) + 2*L[6]*sin(Th[3] - Th[6])*sin(Th[4] - Th[6]))))/2.;
 matSys[39] = -(pow(L[4],2)*(Cs*(2*L[4] + 3*(2*pow(cos(Th[4] - Th[5]),2)*L[5] + 2*pow(cos(Th[4] - Th[6]),2)*L[6] + L[7] + cos(2*(Th[4] - Th[7]))*L[7] + L[8] + cos(2*(Th[4] - Th[8]))*L[8] + L[9] + cos(2*(Th[4] - Th[9]))*L[9] + L[10] + cos(2*(Th[4] - Th[10]))*L[10])) + 3*Cv*(L[7] - cos(2*(Th[4] - Th[7]))*L[7] + L[8] - cos(2*(Th[4] - Th[8]))*L[8] + L[9] - cos(2*(Th[4] - Th[9]))*L[9] + L[10] - cos(2*(Th[4] - Th[10]))*L[10] + 2*L[5]*pow(sin(Th[4] - Th[5]),2) + 2*L[6]*pow(sin(Th[4] - Th[6]),2))))/6.;
 matSys[51] = -(L[4]*L[5]*(Cs*(cos(Th[4] - Th[5])*L[5] + 2*cos(Th[4] - Th[6])*cos(Th[5] - Th[6])*L[6] + cos(Th[4] - Th[5])*L[7] + cos(Th[4] + Th[5] - 2*Th[7])*L[7] + cos(Th[4] - Th[5])*L[8] + cos(Th[4] + Th[5] - 2*Th[8])*L[8] + cos(Th[4] - Th[5])*L[9] + cos(Th[4] + Th[5] - 2*Th[9])*L[9] + cos(Th[4] - Th[5])*L[10] + cos(Th[4] + Th[5] - 2*Th[10])*L[10]) + Cv*(cos(Th[4] - Th[5])*L[8] - cos(Th[4] + Th[5] - 2*Th[8])*L[8] + cos(Th[4] - Th[5])*L[9] - cos(Th[4] + Th[5] - 2*Th[9])*L[9] + cos(Th[4] - Th[5])*L[10] - cos(Th[4] + Th[5] - 2*Th[10])*L[10] + 2*L[6]*sin(Th[4] - Th[6])*sin(Th[5] - Th[6]) + 2*L[7]*sin(Th[4] - Th[7])*sin(Th[5] - Th[7]))))/2.;
 matSys[63] = -(L[4]*L[6]*(Cs*(cos(Th[4] - Th[6])*L[6] + 2*cos(Th[4] - Th[7])*cos(Th[6] - Th[7])*L[7] + cos(Th[4] - Th[6])*L[8] + cos(Th[4] + Th[6] - 2*Th[8])*L[8] + cos(Th[4] - Th[6])*L[9] + cos(Th[4] + Th[6] - 2*Th[9])*L[9] + cos(Th[4] - Th[6])*L[10] + cos(Th[4] + Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[4] - Th[6])*L[9] - cos(Th[4] + Th[6] - 2*Th[9])*L[9] + cos(Th[4] - Th[6])*L[10] - cos(Th[4] + Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[4] - Th[7])*sin(Th[6] - Th[7]) + 2*L[8]*sin(Th[4] - Th[8])*sin(Th[6] - Th[8]))))/2.;
 matSys[75] = -(L[4]*L[7]*(Cs*(cos(Th[4] - Th[7])*L[7] + 2*cos(Th[4] - Th[8])*cos(Th[7] - Th[8])*L[8] + cos(Th[4] - Th[7])*L[9] + cos(Th[4] + Th[7] - 2*Th[9])*L[9] + cos(Th[4] - Th[7])*L[10] + cos(Th[4] + Th[7] - 2*Th[10])*L[10]) + 2*Cv*(L[8]*sin(Th[4] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[4] - Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[4] - Th[10])*sin(Th[7] - Th[10]))))/2.;
 matSys[87] = -(L[4]*L[8]*(Cs*(cos(Th[4] - Th[8])*L[8] + 2*cos(Th[4] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[4] - Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[4] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[4] - Th[10])*sin(Th[8] - Th[10]))))/2.;
 matSys[99] = -(L[4]*L[9]*(Cs*(cos(Th[4] - Th[9])*L[9] + 2*cos(Th[4] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[4] - Th[10])*sin(Th[9] - Th[10])))/2.;
 matSys[111] = -(Cs*cos(Th[4] - Th[10])*L[4]*pow(L[10],2))/2.;
 matSys[123] = (L[4]*(Cs*(L[4]*sin(Th[4]) + L[6]*sin(Th[4]) + L[7]*sin(Th[4]) + L[8]*sin(Th[4]) + L[9]*sin(Th[4]) + L[10]*sin(Th[4]) + 2*cos(Th[4] - Th[5])*L[5]*sin(Th[5]) - L[6]*sin(Th[4] - 2*Th[6]) - L[7]*sin(Th[4] - 2*Th[7]) - L[8]*sin(Th[4] - 2*Th[8]) - L[9]*sin(Th[4] - 2*Th[9]) - L[10]*sin(Th[4] - 2*Th[10])) + Cv*(L[7]*sin(Th[4]) + L[8]*sin(Th[4]) + L[9]*sin(Th[4]) + L[10]*sin(Th[4]) + 2*cos(Th[5])*L[5]*sin(Th[4] - Th[5]) + 2*cos(Th[6])*L[6]*sin(Th[4] - Th[6]) + L[7]*sin(Th[4] - 2*Th[7]) + L[8]*sin(Th[4] - 2*Th[8]) + L[9]*sin(Th[4] - 2*Th[9]) + L[10]*sin(Th[4] - 2*Th[10]))))/2.;
 matSys[135] = -(L[4]*(Cs*(cos(Th[4])*L[4] + 2*cos(Th[4] - Th[5])*cos(Th[5])*L[5] + cos(Th[4])*L[6] + cos(Th[4] - 2*Th[6])*L[6] + cos(Th[4])*L[7] + cos(Th[4] - 2*Th[7])*L[7] + cos(Th[4])*L[8] + cos(Th[4] - 2*Th[8])*L[8] + cos(Th[4])*L[9] + cos(Th[4] - 2*Th[9])*L[9] + cos(Th[4])*L[10] + cos(Th[4] - 2*Th[10])*L[10]) - Cv*(-(cos(Th[4])*L[7]) + cos(Th[4] - 2*Th[7])*L[7] - cos(Th[4])*L[8] + cos(Th[4] - 2*Th[8])*L[8] - cos(Th[4])*L[9] + cos(Th[4] - 2*Th[9])*L[9] - cos(Th[4])*L[10] + cos(Th[4] - 2*Th[10])*L[10] + 2*L[5]*sin(Th[4] - Th[5])*sin(Th[5]) + 2*L[6]*sin(Th[4] - Th[6])*sin(Th[6]))))/2.;
 matSys[147] = 0;
 matSys[159] = 0;
 matSys[171] = -(L[4]*sin(Th[4]));
 matSys[183] = cos(Th[4])*L[4];
 matSys[4] = -(L[1]*L[5]*(Cs*(cos(Th[1] - Th[5])*L[5] + 2*cos(Th[1] - Th[6])*cos(Th[5] - Th[6])*L[6] + cos(Th[1] - Th[5])*L[7] + cos(Th[1] + Th[5] - 2*Th[7])*L[7] + cos(Th[1] - Th[5])*L[8] + cos(Th[1] + Th[5] - 2*Th[8])*L[8] + cos(Th[1] - Th[5])*L[9] + cos(Th[1] + Th[5] - 2*Th[9])*L[9] + cos(Th[1] - Th[5])*L[10] + cos(Th[1] + Th[5] - 2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[5])*L[8] - cos(Th[1] + Th[5] - 2*Th[8])*L[8] + cos(Th[1] - Th[5])*L[9] - cos(Th[1] + Th[5] - 2*Th[9])*L[9] + cos(Th[1] - Th[5])*L[10] - cos(Th[1] + Th[5] - 2*Th[10])*L[10] + 2*L[6]*sin(Th[1] - Th[6])*sin(Th[5] - Th[6]) + 2*L[7]*sin(Th[1] - Th[7])*sin(Th[5] - Th[7]))))/2.;
 matSys[16] = -(L[2]*L[5]*(Cs*(cos(Th[2] - Th[5])*L[5] + 2*cos(Th[2] - Th[6])*cos(Th[5] - Th[6])*L[6] + cos(Th[2] - Th[5])*L[7] + cos(Th[2] + Th[5] - 2*Th[7])*L[7] + cos(Th[2] - Th[5])*L[8] + cos(Th[2] + Th[5] - 2*Th[8])*L[8] + cos(Th[2] - Th[5])*L[9] + cos(Th[2] + Th[5] - 2*Th[9])*L[9] + cos(Th[2] - Th[5])*L[10] + cos(Th[2] + Th[5] - 2*Th[10])*L[10]) + Cv*(cos(Th[2] - Th[5])*L[8] - cos(Th[2] + Th[5] - 2*Th[8])*L[8] + cos(Th[2] - Th[5])*L[9] - cos(Th[2] + Th[5] - 2*Th[9])*L[9] + cos(Th[2] - Th[5])*L[10] - cos(Th[2] + Th[5] - 2*Th[10])*L[10] + 2*L[6]*sin(Th[2] - Th[6])*sin(Th[5] - Th[6]) + 2*L[7]*sin(Th[2] - Th[7])*sin(Th[5] - Th[7]))))/2.;
 matSys[28] = -(L[3]*L[5]*(Cs*(cos(Th[3] - Th[5])*L[5] + 2*cos(Th[3] - Th[6])*cos(Th[5] - Th[6])*L[6] + cos(Th[3] - Th[5])*L[7] + cos(Th[3] + Th[5] - 2*Th[7])*L[7] + cos(Th[3] - Th[5])*L[8] + cos(Th[3] + Th[5] - 2*Th[8])*L[8] + cos(Th[3] - Th[5])*L[9] + cos(Th[3] + Th[5] - 2*Th[9])*L[9] + cos(Th[3] - Th[5])*L[10] + cos(Th[3] + Th[5] - 2*Th[10])*L[10]) + Cv*(cos(Th[3] - Th[5])*L[8] - cos(Th[3] + Th[5] - 2*Th[8])*L[8] + cos(Th[3] - Th[5])*L[9] - cos(Th[3] + Th[5] - 2*Th[9])*L[9] + cos(Th[3] - Th[5])*L[10] - cos(Th[3] + Th[5] - 2*Th[10])*L[10] + 2*L[6]*sin(Th[3] - Th[6])*sin(Th[5] - Th[6]) + 2*L[7]*sin(Th[3] - Th[7])*sin(Th[5] - Th[7]))))/2.;
 matSys[40] = -(L[4]*L[5]*(Cs*(cos(Th[4] - Th[5])*L[5] + 2*cos(Th[4] - Th[6])*cos(Th[5] - Th[6])*L[6] + cos(Th[4] - Th[5])*L[7] + cos(Th[4] + Th[5] - 2*Th[7])*L[7] + cos(Th[4] - Th[5])*L[8] + cos(Th[4] + Th[5] - 2*Th[8])*L[8] + cos(Th[4] - Th[5])*L[9] + cos(Th[4] + Th[5] - 2*Th[9])*L[9] + cos(Th[4] - Th[5])*L[10] + cos(Th[4] + Th[5] - 2*Th[10])*L[10]) + Cv*(cos(Th[4] - Th[5])*L[8] - cos(Th[4] + Th[5] - 2*Th[8])*L[8] + cos(Th[4] - Th[5])*L[9] - cos(Th[4] + Th[5] - 2*Th[9])*L[9] + cos(Th[4] - Th[5])*L[10] - cos(Th[4] + Th[5] - 2*Th[10])*L[10] + 2*L[6]*sin(Th[4] - Th[6])*sin(Th[5] - Th[6]) + 2*L[7]*sin(Th[4] - Th[7])*sin(Th[5] - Th[7]))))/2.;
 matSys[52] = -(pow(L[5],2)*(Cs*(2*L[5] + 3*(2*pow(cos(Th[5] - Th[6]),2)*L[6] + 2*pow(cos(Th[5] - Th[7]),2)*L[7] + L[8] + cos(2*(Th[5] - Th[8]))*L[8] + L[9] + cos(2*(Th[5] - Th[9]))*L[9] + L[10] + cos(2*(Th[5] - Th[10]))*L[10])) + 3*Cv*(L[8] - cos(2*(Th[5] - Th[8]))*L[8] + L[9] - cos(2*(Th[5] - Th[9]))*L[9] + L[10] - cos(2*(Th[5] - Th[10]))*L[10] + 2*L[6]*pow(sin(Th[5] - Th[6]),2) + 2*L[7]*pow(sin(Th[5] - Th[7]),2))))/6.;
 matSys[64] = -(L[5]*L[6]*(Cs*(cos(Th[5] - Th[6])*L[6] + 2*cos(Th[5] - Th[7])*cos(Th[6] - Th[7])*L[7] + cos(Th[5] - Th[6])*L[8] + cos(Th[5] + Th[6] - 2*Th[8])*L[8] + cos(Th[5] - Th[6])*L[9] + cos(Th[5] + Th[6] - 2*Th[9])*L[9] + cos(Th[5] - Th[6])*L[10] + cos(Th[5] + Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[5] - Th[6])*L[9] - cos(Th[5] + Th[6] - 2*Th[9])*L[9] + cos(Th[5] - Th[6])*L[10] - cos(Th[5] + Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[5] - Th[7])*sin(Th[6] - Th[7]) + 2*L[8]*sin(Th[5] - Th[8])*sin(Th[6] - Th[8]))))/2.;
 matSys[76] = -(L[5]*L[7]*(Cs*(cos(Th[5] - Th[7])*L[7] + 2*cos(Th[5] - Th[8])*cos(Th[7] - Th[8])*L[8] + cos(Th[5] - Th[7])*L[9] + cos(Th[5] + Th[7] - 2*Th[9])*L[9] + cos(Th[5] - Th[7])*L[10] + cos(Th[5] + Th[7] - 2*Th[10])*L[10]) + 2*Cv*(L[8]*sin(Th[5] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[5] - Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[5] - Th[10])*sin(Th[7] - Th[10]))))/2.;
 matSys[88] = -(L[5]*L[8]*(Cs*(cos(Th[5] - Th[8])*L[8] + 2*cos(Th[5] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[5] - Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[5] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[5] - Th[10])*sin(Th[8] - Th[10]))))/2.;
 matSys[100] = -(L[5]*L[9]*(Cs*(cos(Th[5] - Th[9])*L[9] + 2*cos(Th[5] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[5] - Th[10])*sin(Th[9] - Th[10])))/2.;
 matSys[112] = -(Cs*cos(Th[5] - Th[10])*L[5]*pow(L[10],2))/2.;
 matSys[124] = (L[5]*(Cs*(L[5]*sin(Th[5]) + L[7]*sin(Th[5]) + L[8]*sin(Th[5]) + L[9]*sin(Th[5]) + L[10]*sin(Th[5]) + 2*cos(Th[5] - Th[6])*L[6]*sin(Th[6]) - L[7]*sin(Th[5] - 2*Th[7]) - L[8]*sin(Th[5] - 2*Th[8]) - L[9]*sin(Th[5] - 2*Th[9]) - L[10]*sin(Th[5] - 2*Th[10])) + Cv*(L[8]*sin(Th[5]) + L[9]*sin(Th[5]) + L[10]*sin(Th[5]) + 2*cos(Th[6])*L[6]*sin(Th[5] - Th[6]) + 2*cos(Th[7])*L[7]*sin(Th[5] - Th[7]) + L[8]*sin(Th[5] - 2*Th[8]) + L[9]*sin(Th[5] - 2*Th[9]) + L[10]*sin(Th[5] - 2*Th[10]))))/2.;
 matSys[136] = -(L[5]*(Cs*(cos(Th[5])*L[5] + 2*cos(Th[5] - Th[6])*cos(Th[6])*L[6] + cos(Th[5])*L[7] + cos(Th[5] - 2*Th[7])*L[7] + cos(Th[5])*L[8] + cos(Th[5] - 2*Th[8])*L[8] + cos(Th[5])*L[9] + cos(Th[5] - 2*Th[9])*L[9] + cos(Th[5])*L[10] + cos(Th[5] - 2*Th[10])*L[10]) - Cv*(-(cos(Th[5])*L[8]) + cos(Th[5] - 2*Th[8])*L[8] - cos(Th[5])*L[9] + cos(Th[5] - 2*Th[9])*L[9] - cos(Th[5])*L[10] + cos(Th[5] - 2*Th[10])*L[10] + 2*L[6]*sin(Th[5] - Th[6])*sin(Th[6]) + 2*L[7]*sin(Th[5] - Th[7])*sin(Th[7]))))/2.;
 matSys[148] = 0;
 matSys[160] = 0;
 matSys[172] = -(L[5]*sin(Th[5]));
 matSys[184] = cos(Th[5])*L[5];
 matSys[5] = -(L[1]*L[6]*(Cs*(cos(Th[1] - Th[6])*L[6] + 2*cos(Th[1] - Th[7])*cos(Th[6] - Th[7])*L[7] + cos(Th[1] - Th[6])*L[8] + cos(Th[1] + Th[6] - 2*Th[8])*L[8] + cos(Th[1] - Th[6])*L[9] + cos(Th[1] + Th[6] - 2*Th[9])*L[9] + cos(Th[1] - Th[6])*L[10] + cos(Th[1] + Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[6])*L[9] - cos(Th[1] + Th[6] - 2*Th[9])*L[9] + cos(Th[1] - Th[6])*L[10] - cos(Th[1] + Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[1] - Th[7])*sin(Th[6] - Th[7]) + 2*L[8]*sin(Th[1] - Th[8])*sin(Th[6] - Th[8]))))/2.;
 matSys[17] = -(L[2]*L[6]*(Cs*(cos(Th[2] - Th[6])*L[6] + 2*cos(Th[2] - Th[7])*cos(Th[6] - Th[7])*L[7] + cos(Th[2] - Th[6])*L[8] + cos(Th[2] + Th[6] - 2*Th[8])*L[8] + cos(Th[2] - Th[6])*L[9] + cos(Th[2] + Th[6] - 2*Th[9])*L[9] + cos(Th[2] - Th[6])*L[10] + cos(Th[2] + Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[2] - Th[6])*L[9] - cos(Th[2] + Th[6] - 2*Th[9])*L[9] + cos(Th[2] - Th[6])*L[10] - cos(Th[2] + Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[2] - Th[7])*sin(Th[6] - Th[7]) + 2*L[8]*sin(Th[2] - Th[8])*sin(Th[6] - Th[8]))))/2.;
 matSys[29] = -(L[3]*L[6]*(Cs*(cos(Th[3] - Th[6])*L[6] + 2*cos(Th[3] - Th[7])*cos(Th[6] - Th[7])*L[7] + cos(Th[3] - Th[6])*L[8] + cos(Th[3] + Th[6] - 2*Th[8])*L[8] + cos(Th[3] - Th[6])*L[9] + cos(Th[3] + Th[6] - 2*Th[9])*L[9] + cos(Th[3] - Th[6])*L[10] + cos(Th[3] + Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[3] - Th[6])*L[9] - cos(Th[3] + Th[6] - 2*Th[9])*L[9] + cos(Th[3] - Th[6])*L[10] - cos(Th[3] + Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[3] - Th[7])*sin(Th[6] - Th[7]) + 2*L[8]*sin(Th[3] - Th[8])*sin(Th[6] - Th[8]))))/2.;
 matSys[41] = -(L[4]*L[6]*(Cs*(cos(Th[4] - Th[6])*L[6] + 2*cos(Th[4] - Th[7])*cos(Th[6] - Th[7])*L[7] + cos(Th[4] - Th[6])*L[8] + cos(Th[4] + Th[6] - 2*Th[8])*L[8] + cos(Th[4] - Th[6])*L[9] + cos(Th[4] + Th[6] - 2*Th[9])*L[9] + cos(Th[4] - Th[6])*L[10] + cos(Th[4] + Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[4] - Th[6])*L[9] - cos(Th[4] + Th[6] - 2*Th[9])*L[9] + cos(Th[4] - Th[6])*L[10] - cos(Th[4] + Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[4] - Th[7])*sin(Th[6] - Th[7]) + 2*L[8]*sin(Th[4] - Th[8])*sin(Th[6] - Th[8]))))/2.;
 matSys[53] = -(L[5]*L[6]*(Cs*(cos(Th[5] - Th[6])*L[6] + 2*cos(Th[5] - Th[7])*cos(Th[6] - Th[7])*L[7] + cos(Th[5] - Th[6])*L[8] + cos(Th[5] + Th[6] - 2*Th[8])*L[8] + cos(Th[5] - Th[6])*L[9] + cos(Th[5] + Th[6] - 2*Th[9])*L[9] + cos(Th[5] - Th[6])*L[10] + cos(Th[5] + Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[5] - Th[6])*L[9] - cos(Th[5] + Th[6] - 2*Th[9])*L[9] + cos(Th[5] - Th[6])*L[10] - cos(Th[5] + Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[5] - Th[7])*sin(Th[6] - Th[7]) + 2*L[8]*sin(Th[5] - Th[8])*sin(Th[6] - Th[8]))))/2.;
 matSys[65] = -(pow(L[6],2)*(Cs*(2*L[6] + 3*(2*pow(cos(Th[6] - Th[7]),2)*L[7] + 2*pow(cos(Th[6] - Th[8]),2)*L[8] + L[9] + cos(2*(Th[6] - Th[9]))*L[9] + L[10] + cos(2*(Th[6] - Th[10]))*L[10])) + 3*Cv*(L[9] - cos(2*(Th[6] - Th[9]))*L[9] + L[10] - cos(2*(Th[6] - Th[10]))*L[10] + 2*L[7]*pow(sin(Th[6] - Th[7]),2) + 2*L[8]*pow(sin(Th[6] - Th[8]),2))))/6.;
 matSys[77] = -(L[6]*L[7]*(Cs*(cos(Th[6] - Th[7])*L[7] + 2*cos(Th[6] - Th[8])*cos(Th[7] - Th[8])*L[8] + cos(Th[6] - Th[7])*L[9] + cos(Th[6] + Th[7] - 2*Th[9])*L[9] + cos(Th[6] - Th[7])*L[10] + cos(Th[6] + Th[7] - 2*Th[10])*L[10]) + 2*Cv*(L[8]*sin(Th[6] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[6] - Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[6] - Th[10])*sin(Th[7] - Th[10]))))/2.;
 matSys[89] = -(L[6]*L[8]*(Cs*(cos(Th[6] - Th[8])*L[8] + 2*cos(Th[6] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[6] - Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[6] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[6] - Th[10])*sin(Th[8] - Th[10]))))/2.;
 matSys[101] = -(L[6]*L[9]*(Cs*(cos(Th[6] - Th[9])*L[9] + 2*cos(Th[6] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[6] - Th[10])*sin(Th[9] - Th[10])))/2.;
 matSys[113] = -(Cs*cos(Th[6] - Th[10])*L[6]*pow(L[10],2))/2.;
 matSys[125] = (L[6]*(Cs*(L[6]*sin(Th[6]) + L[8]*sin(Th[6]) + L[9]*sin(Th[6]) + L[10]*sin(Th[6]) + 2*cos(Th[6] - Th[7])*L[7]*sin(Th[7]) - L[8]*sin(Th[6] - 2*Th[8]) - L[9]*sin(Th[6] - 2*Th[9]) - L[10]*sin(Th[6] - 2*Th[10])) + Cv*(L[9]*sin(Th[6]) + L[10]*sin(Th[6]) + 2*cos(Th[7])*L[7]*sin(Th[6] - Th[7]) + 2*cos(Th[8])*L[8]*sin(Th[6] - Th[8]) + L[9]*sin(Th[6] - 2*Th[9]) + L[10]*sin(Th[6] - 2*Th[10]))))/2.;
 matSys[137] = -(L[6]*(Cs*(cos(Th[6])*L[6] + 2*cos(Th[6] - Th[7])*cos(Th[7])*L[7] + cos(Th[6])*L[8] + cos(Th[6] - 2*Th[8])*L[8] + cos(Th[6])*L[9] + cos(Th[6] - 2*Th[9])*L[9] + cos(Th[6])*L[10] + cos(Th[6] - 2*Th[10])*L[10]) - Cv*(-(cos(Th[6])*L[9]) + cos(Th[6] - 2*Th[9])*L[9] - cos(Th[6])*L[10] + cos(Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[6] - Th[7])*sin(Th[7]) + 2*L[8]*sin(Th[6] - Th[8])*sin(Th[8]))))/2.;
 matSys[149] = 0;
 matSys[161] = 0;
 matSys[173] = -(L[6]*sin(Th[6]));
 matSys[185] = cos(Th[6])*L[6];
 matSys[6] = -(L[1]*L[7]*(Cs*(cos(Th[1] - Th[7])*L[7] + 2*cos(Th[1] - Th[8])*cos(Th[7] - Th[8])*L[8] + cos(Th[1] - Th[7])*L[9] + cos(Th[1] + Th[7] - 2*Th[9])*L[9] + cos(Th[1] - Th[7])*L[10] + cos(Th[1] + Th[7] - 2*Th[10])*L[10]) + 2*Cv*(L[8]*sin(Th[1] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[1] - Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[1] - Th[10])*sin(Th[7] - Th[10]))))/2.;
 matSys[18] = -(L[2]*L[7]*(Cs*(cos(Th[2] - Th[7])*L[7] + 2*cos(Th[2] - Th[8])*cos(Th[7] - Th[8])*L[8] + cos(Th[2] - Th[7])*L[9] + cos(Th[2] + Th[7] - 2*Th[9])*L[9] + cos(Th[2] - Th[7])*L[10] + cos(Th[2] + Th[7] - 2*Th[10])*L[10]) + 2*Cv*(L[8]*sin(Th[2] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[2] - Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[2] - Th[10])*sin(Th[7] - Th[10]))))/2.;
 matSys[30] = -(L[3]*L[7]*(Cs*(cos(Th[3] - Th[7])*L[7] + 2*cos(Th[3] - Th[8])*cos(Th[7] - Th[8])*L[8] + cos(Th[3] - Th[7])*L[9] + cos(Th[3] + Th[7] - 2*Th[9])*L[9] + cos(Th[3] - Th[7])*L[10] + cos(Th[3] + Th[7] - 2*Th[10])*L[10]) + 2*Cv*(L[8]*sin(Th[3] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[3] - Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[3] - Th[10])*sin(Th[7] - Th[10]))))/2.;
 matSys[42] = -(L[4]*L[7]*(Cs*(cos(Th[4] - Th[7])*L[7] + 2*cos(Th[4] - Th[8])*cos(Th[7] - Th[8])*L[8] + cos(Th[4] - Th[7])*L[9] + cos(Th[4] + Th[7] - 2*Th[9])*L[9] + cos(Th[4] - Th[7])*L[10] + cos(Th[4] + Th[7] - 2*Th[10])*L[10]) + 2*Cv*(L[8]*sin(Th[4] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[4] - Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[4] - Th[10])*sin(Th[7] - Th[10]))))/2.;
 matSys[54] = -(L[5]*L[7]*(Cs*(cos(Th[5] - Th[7])*L[7] + 2*cos(Th[5] - Th[8])*cos(Th[7] - Th[8])*L[8] + cos(Th[5] - Th[7])*L[9] + cos(Th[5] + Th[7] - 2*Th[9])*L[9] + cos(Th[5] - Th[7])*L[10] + cos(Th[5] + Th[7] - 2*Th[10])*L[10]) + 2*Cv*(L[8]*sin(Th[5] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[5] - Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[5] - Th[10])*sin(Th[7] - Th[10]))))/2.;
 matSys[66] = -(L[6]*L[7]*(Cs*(cos(Th[6] - Th[7])*L[7] + 2*cos(Th[6] - Th[8])*cos(Th[7] - Th[8])*L[8] + cos(Th[6] - Th[7])*L[9] + cos(Th[6] + Th[7] - 2*Th[9])*L[9] + cos(Th[6] - Th[7])*L[10] + cos(Th[6] + Th[7] - 2*Th[10])*L[10]) + 2*Cv*(L[8]*sin(Th[6] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[6] - Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[6] - Th[10])*sin(Th[7] - Th[10]))))/2.;
 matSys[78] = -(pow(L[7],2)*(Cs*(L[7] + 3*(pow(cos(Th[7] - Th[8]),2)*L[8] + pow(cos(Th[7] - Th[9]),2)*L[9] + pow(cos(Th[7] - Th[10]),2)*L[10])) + 3*Cv*(L[8]*pow(sin(Th[7] - Th[8]),2) + L[9]*pow(sin(Th[7] - Th[9]),2) + L[10]*pow(sin(Th[7] - Th[10]),2))))/3.;
 matSys[90] = -(L[7]*L[8]*(Cs*(cos(Th[7] - Th[8])*L[8] + 2*cos(Th[7] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[7] - Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[7] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[7] - Th[10])*sin(Th[8] - Th[10]))))/2.;
 matSys[102] = -(L[7]*L[9]*(Cs*(cos(Th[7] - Th[9])*L[9] + 2*cos(Th[7] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[7] - Th[10])*sin(Th[9] - Th[10])))/2.;
 matSys[114] = -(Cs*cos(Th[7] - Th[10])*L[7]*pow(L[10],2))/2.;
 matSys[126] = (L[7]*(Cs*(L[7]*sin(Th[7]) + L[9]*sin(Th[7]) + L[10]*sin(Th[7]) + 2*cos(Th[7] - Th[8])*L[8]*sin(Th[8]) - L[9]*sin(Th[7] - 2*Th[9]) - L[10]*sin(Th[7] - 2*Th[10])) + Cv*(2*cos(Th[8])*L[8]*sin(Th[7] - Th[8]) + 2*cos(Th[9])*L[9]*sin(Th[7] - Th[9]) + L[10]*(sin(Th[7]) + sin(Th[7] - 2*Th[10])))))/2.;
 matSys[138] = -(L[7]*(Cs*(cos(Th[7])*L[7] + 2*cos(Th[7] - Th[8])*cos(Th[8])*L[8] + cos(Th[7])*L[9] + cos(Th[7] - 2*Th[9])*L[9] + cos(Th[7])*L[10] + cos(Th[7] - 2*Th[10])*L[10]) - 2*Cv*(L[8]*sin(Th[7] - Th[8])*sin(Th[8]) + L[9]*sin(Th[7] - Th[9])*sin(Th[9]) + L[10]*sin(Th[7] - Th[10])*sin(Th[10]))))/2.;
 matSys[150] = 0;
 matSys[162] = 0;
 matSys[174] = -(L[7]*sin(Th[7]));
 matSys[186] = cos(Th[7])*L[7];
 matSys[7] = -(L[1]*L[8]*(Cs*(cos(Th[1] - Th[8])*L[8] + 2*cos(Th[1] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[1] - Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[1] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[1] - Th[10])*sin(Th[8] - Th[10]))))/2.;
 matSys[19] = -(L[2]*L[8]*(Cs*(cos(Th[2] - Th[8])*L[8] + 2*cos(Th[2] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[2] - Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[2] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[2] - Th[10])*sin(Th[8] - Th[10]))))/2.;
 matSys[31] = -(L[3]*L[8]*(Cs*(cos(Th[3] - Th[8])*L[8] + 2*cos(Th[3] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[3] - Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[3] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[3] - Th[10])*sin(Th[8] - Th[10]))))/2.;
 matSys[43] = -(L[4]*L[8]*(Cs*(cos(Th[4] - Th[8])*L[8] + 2*cos(Th[4] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[4] - Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[4] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[4] - Th[10])*sin(Th[8] - Th[10]))))/2.;
 matSys[55] = -(L[5]*L[8]*(Cs*(cos(Th[5] - Th[8])*L[8] + 2*cos(Th[5] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[5] - Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[5] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[5] - Th[10])*sin(Th[8] - Th[10]))))/2.;
 matSys[67] = -(L[6]*L[8]*(Cs*(cos(Th[6] - Th[8])*L[8] + 2*cos(Th[6] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[6] - Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[6] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[6] - Th[10])*sin(Th[8] - Th[10]))))/2.;
 matSys[79] = -(L[7]*L[8]*(Cs*(cos(Th[7] - Th[8])*L[8] + 2*cos(Th[7] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[7] - Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[7] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[7] - Th[10])*sin(Th[8] - Th[10]))))/2.;
 matSys[91] = -(pow(L[8],2)*(Cs*(L[8] + 3*pow(cos(Th[8] - Th[9]),2)*L[9] + 3*pow(cos(Th[8] - Th[10]),2)*L[10]) + 3*Cv*(L[9]*pow(sin(Th[8] - Th[9]),2) + L[10]*pow(sin(Th[8] - Th[10]),2))))/3.;
 matSys[103] = -(L[8]*L[9]*(Cs*(cos(Th[8] - Th[9])*L[9] + 2*cos(Th[8] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[8] - Th[10])*sin(Th[9] - Th[10])))/2.;
 matSys[115] = -(Cs*cos(Th[8] - Th[10])*L[8]*pow(L[10],2))/2.;
 matSys[127] = (L[8]*(Cv*(2*cos(Th[9])*L[9]*sin(Th[8] - Th[9]) + L[10]*(sin(Th[8]) + sin(Th[8] - 2*Th[10]))) + Cs*(L[8]*sin(Th[8]) + 2*cos(Th[8] - Th[9])*L[9]*sin(Th[9]) + 2*cos(Th[8] - Th[10])*L[10]*sin(Th[10]))))/2.;
 matSys[139] = -(L[8]*(Cs*(cos(Th[8])*L[8] + 2*cos(Th[8] - Th[9])*cos(Th[9])*L[9] + (cos(Th[8]) + cos(Th[8] - 2*Th[10]))*L[10]) - 2*Cv*(L[9]*sin(Th[8] - Th[9])*sin(Th[9]) + L[10]*sin(Th[8] - Th[10])*sin(Th[10]))))/2.;
 matSys[151] = 0;
 matSys[163] = 0;
 matSys[175] = -(L[8]*sin(Th[8]));
 matSys[187] = cos(Th[8])*L[8];
 matSys[8] = -(L[1]*L[9]*(Cs*(cos(Th[1] - Th[9])*L[9] + 2*cos(Th[1] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[1] - Th[10])*sin(Th[9] - Th[10])))/2.;
 matSys[20] = -(L[2]*L[9]*(Cs*(cos(Th[2] - Th[9])*L[9] + 2*cos(Th[2] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[2] - Th[10])*sin(Th[9] - Th[10])))/2.;
 matSys[32] = -(L[3]*L[9]*(Cs*(cos(Th[3] - Th[9])*L[9] + 2*cos(Th[3] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[3] - Th[10])*sin(Th[9] - Th[10])))/2.;
 matSys[44] = -(L[4]*L[9]*(Cs*(cos(Th[4] - Th[9])*L[9] + 2*cos(Th[4] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[4] - Th[10])*sin(Th[9] - Th[10])))/2.;
 matSys[56] = -(L[5]*L[9]*(Cs*(cos(Th[5] - Th[9])*L[9] + 2*cos(Th[5] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[5] - Th[10])*sin(Th[9] - Th[10])))/2.;
 matSys[68] = -(L[6]*L[9]*(Cs*(cos(Th[6] - Th[9])*L[9] + 2*cos(Th[6] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[6] - Th[10])*sin(Th[9] - Th[10])))/2.;
 matSys[80] = -(L[7]*L[9]*(Cs*(cos(Th[7] - Th[9])*L[9] + 2*cos(Th[7] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[7] - Th[10])*sin(Th[9] - Th[10])))/2.;
 matSys[92] = -(L[8]*L[9]*(Cs*(cos(Th[8] - Th[9])*L[9] + 2*cos(Th[8] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[8] - Th[10])*sin(Th[9] - Th[10])))/2.;
 matSys[104] = -(pow(L[9],2)*(Cs*(L[9] + 3*pow(cos(Th[9] - Th[10]),2)*L[10]) + 3*Cv*L[10]*pow(sin(Th[9] - Th[10]),2)))/3.;
 matSys[116] = -(Cs*cos(Th[9] - Th[10])*L[9]*pow(L[10],2))/2.;
 matSys[128] = (L[9]*(Cv*L[10]*(sin(Th[9]) + sin(Th[9] - 2*Th[10])) + Cs*(L[9]*sin(Th[9]) + 2*cos(Th[9] - Th[10])*L[10]*sin(Th[10]))))/2.;
 matSys[140] = -(L[9]*(Cs*(cos(Th[9])*L[9] + (cos(Th[9]) + cos(Th[9] - 2*Th[10]))*L[10]) - 2*Cv*L[10]*sin(Th[9] - Th[10])*sin(Th[10])))/2.;
 matSys[152] = 0;
 matSys[164] = 0;
 matSys[176] = -(L[9]*sin(Th[9]));
 matSys[188] = cos(Th[9])*L[9];
 matSys[9] = -(Cs*cos(Th[1] - Th[10])*L[1]*pow(L[10],2))/2.;
 matSys[21] = -(Cs*cos(Th[2] - Th[10])*L[2]*pow(L[10],2))/2.;
 matSys[33] = -(Cs*cos(Th[3] - Th[10])*L[3]*pow(L[10],2))/2.;
 matSys[45] = -(Cs*cos(Th[4] - Th[10])*L[4]*pow(L[10],2))/2.;
 matSys[57] = -(Cs*cos(Th[5] - Th[10])*L[5]*pow(L[10],2))/2.;
 matSys[69] = -(Cs*cos(Th[6] - Th[10])*L[6]*pow(L[10],2))/2.;
 matSys[81] = -(Cs*cos(Th[7] - Th[10])*L[7]*pow(L[10],2))/2.;
 matSys[93] = -(Cs*cos(Th[8] - Th[10])*L[8]*pow(L[10],2))/2.;
 matSys[105] = -(Cs*cos(Th[9] - Th[10])*L[9]*pow(L[10],2))/2.;
 matSys[117] = -(Cs*pow(L[10],3))/3.;
 matSys[129] = (Cs*pow(L[10],2)*sin(Th[10]))/2.;
 matSys[141] = -(Cs*cos(Th[10])*pow(L[10],2))/2.;
 matSys[153] = 0;
 matSys[165] = 0;
 matSys[177] = -(L[10]*sin(Th[10]));
 matSys[189] = cos(Th[10])*L[10];
 matSys[10] = L[1]*sin(Th[1]);
 matSys[22] = L[2]*sin(Th[2]);
 matSys[34] = L[3]*sin(Th[3]);
 matSys[46] = L[4]*sin(Th[4]);
 matSys[58] = L[5]*sin(Th[5]);
 matSys[70] = L[6]*sin(Th[6]);
 matSys[82] = L[7]*sin(Th[7]);
 matSys[94] = L[8]*sin(Th[8]);
 matSys[106] = L[9]*sin(Th[9]);
 matSys[118] = L[10]*sin(Th[10]);
 matSys[130] = -1;
 matSys[142] = 0;
 matSys[154] = 1;
 matSys[166] = 0;
 matSys[178] = 0;
 matSys[190] = 0;
 matSys[11] = -(cos(Th[1])*L[1]);
 matSys[23] = -(cos(Th[2])*L[2]);
 matSys[35] = -(cos(Th[3])*L[3]);
 matSys[47] = -(cos(Th[4])*L[4]);
 matSys[59] = -(cos(Th[5])*L[5]);
 matSys[71] = -(cos(Th[6])*L[6]);
 matSys[83] = -(cos(Th[7])*L[7]);
 matSys[95] = -(cos(Th[8])*L[8]);
 matSys[107] = -(cos(Th[9])*L[9]);
 matSys[119] = -(cos(Th[10])*L[10]);
 matSys[131] = 0;
 matSys[143] = -1;
 matSys[155] = 0;
 matSys[167] = 1;
 matSys[179] = 0;
 matSys[191] = 0;
    
 // ===================
    
    
}
