/*
Use: [mainMat, mainVec] = getDs(v, f, M, L, [Cs Cv])
 where,
  v = [xL,yL,th1,th2,...,thn, DxL,DyL,Dth1,Dth2,...,Dthn] is the state vector
  f = [tauL, forceLX, forceLY, tauR, forceRX, forceRY] is the external force
 The main equations of motion are given by
  mainMat * [DDxL,DDyL,DDth1,DDth2,...,DDthn]' = mainVec;
*/

#include "math.h"
#include "stdio.h"
#include "stdlib.h"
#include "mex.h"   //--This one is required

void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
    int np2x2, np2, a;
    double* v0;
    double* v;
    double* fs;
    double* coefMat;
    double* rhsVec;
    double tauL, forceLX, forceLY, tauR, forceRX, forceRY;
    double* M;
    double* L;
    double* fricCoefs;
    double Cv, Cs;
    
    v0 = mxGetPr(prhs[0]);
    np2x2 = mxGetM(prhs[0]);
    np2 = np2x2 / 2;
    v = (double*) malloc((np2x2+1)*sizeof(double));
    for(a=0; a<np2x2; a++)
        v[a+1] = v0[a];
    
    fs = mxGetPr(prhs[1]);
    tauL = fs[0];
    forceLX = fs[1];
    forceLY = fs[2];
    tauR = fs[3];
    forceRX = fs[4];
    forceRY = fs[5];
    
    M = (double*) malloc((np2-1)*sizeof(double));
    L = (double*) malloc((np2-1)*sizeof(double));
    M[a] = mxGetPr(prhs[2]);
    L[a] = mxGetPr(prhs[3]);
    fricCoefs = mxGetPr(prhs[4]);
    Cs = fricCoefs[0];
    Cv = fricCoefs[1];
    
    plhs[0] = mxCreateDoubleMatrix(np2, np2, mxREAL);
    plhs[1] = mxCreateDoubleMatrix(np2, 1, mxREAL);
    coefMat = mxGetPr(plhs[0]);
    rhsVec = mxGetPr(plhs[1]);
    
    // Assignments go here
    // ===================

 coefMat[0] = M[1] + M[2] + M[3] + M[4];
 coefMat[6] = 0;
 coefMat[12] = -(L[1]*(M[1] + 2*(M[2] + M[3] + M[4]))*sin(v[3]))/2.;
 coefMat[18] = -(L[2]*(M[2] + 2*(M[3] + M[4]))*sin(v[4]))/2.;
 coefMat[24] = -(L[3]*(M[3] + 2*M[4])*sin(v[5]))/2.;
 coefMat[30] = -(L[4]*M[4]*sin(v[6]))/2.;
 rhsVec[0] = (2*forceLX + 2*forceRX + cos(v[3])*L[1]*M[1]*pow(v[9],2) + M[2]*(2*cos(v[3])*L[1]*pow(v[9],2) + cos(v[4])*L[2]*pow(v[10],2)) + M[3]*(2*cos(v[3])*L[1]*pow(v[9],2) + 2*cos(v[4])*L[2]*pow(v[10],2) + cos(v[5])*L[3]*pow(v[11],2)) + M[4]*(2*cos(v[3])*L[1]*pow(v[9],2) + 2*cos(v[4])*L[2]*pow(v[10],2) + 2*cos(v[5])*L[3]*pow(v[11],2) + cos(v[6])*L[4]*pow(v[12],2)) + L[1]*(-((Cs + Cv)*v[7]) + (Cs - Cv)*cos(2*v[3])*v[7] + Cs*L[1]*v[9]*sin(v[3]) + (Cs - Cv)*v[8]*sin(2*v[3])) + L[2]*(Cs*sin(v[4])*(2*cos(v[4])*v[8] + 2*cos(v[3] - v[4])*L[1]*v[9] + L[2]*v[10] - 2*v[7]*sin(v[4])) - 2*Cv*cos(v[4])*(cos(v[4])*v[7] - L[1]*v[9]*sin(v[3] - v[4]) + v[8]*sin(v[4]))) + L[3]*(Cs*sin(v[5])*(2*cos(v[5])*v[8] + 2*cos(v[3] - v[5])*L[1]*v[9] + 2*cos(v[4] - v[5])*L[2]*v[10] + L[3]*v[11] - 2*v[7]*sin(v[5])) + 2*Cv*cos(v[5])*(-(cos(v[5])*v[7]) + L[1]*v[9]*sin(v[3] - v[5]) + L[2]*v[10]*sin(v[4] - v[5]) - v[8]*sin(v[5]))) + L[4]*(Cs*sin(v[6])*(2*(cos(v[6])*v[8] + cos(v[3] - v[6])*L[1]*v[9] + cos(v[4] - v[6])*L[2]*v[10] + cos(v[5] - v[6])*L[3]*v[11]) + L[4]*v[12] - 2*v[7]*sin(v[6])) + 2*Cv*cos(v[6])*(-(cos(v[6])*v[7]) + L[1]*v[9]*sin(v[3] - v[6]) + L[2]*v[10]*sin(v[4] - v[6]) + L[3]*v[11]*sin(v[5] - v[6]) - v[8]*sin(v[6]))))/2.;
 coefMat[1] = 0;
 coefMat[7] = M[1] + M[2] + M[3] + M[4];
 coefMat[13] = (cos(v[3])*L[1]*(M[1] + 2*(M[2] + M[3] + M[4])))/2.;
 coefMat[19] = (cos(v[4])*L[2]*(M[2] + 2*(M[3] + M[4])))/2.;
 coefMat[25] = (cos(v[5])*L[3]*(M[3] + 2*M[4]))/2.;
 coefMat[31] = (cos(v[6])*L[4]*M[4])/2.;
 rhsVec[1] = (2*forceLY + 2*forceRY + L[1]*M[1]*pow(v[9],2)*sin(v[3]) - L[1]*(Cs*cos(v[3])*(2*cos(v[3])*v[8] + L[1]*v[9] - 2*v[7]*sin(v[3])) + Cv*(2*v[8]*pow(sin(v[3]),2) + v[7]*sin(2*v[3]))) + M[2]*(2*L[1]*pow(v[9],2)*sin(v[3]) + L[2]*pow(v[10],2)*sin(v[4])) - L[2]*(Cs*cos(v[4])*(2*cos(v[4])*v[8] + 2*cos(v[3] - v[4])*L[1]*v[9] + L[2]*v[10] - 2*v[7]*sin(v[4])) + 2*Cv*sin(v[4])*(cos(v[4])*v[7] - L[1]*v[9]*sin(v[3] - v[4]) + v[8]*sin(v[4]))) + M[3]*(2*L[1]*pow(v[9],2)*sin(v[3]) + 2*L[2]*pow(v[10],2)*sin(v[4]) + L[3]*pow(v[11],2)*sin(v[5])) - L[3]*(Cs*cos(v[5])*(2*cos(v[5])*v[8] + 2*cos(v[3] - v[5])*L[1]*v[9] + 2*cos(v[4] - v[5])*L[2]*v[10] + L[3]*v[11] - 2*v[7]*sin(v[5])) + 2*Cv*sin(v[5])*(cos(v[5])*v[7] - L[1]*v[9]*sin(v[3] - v[5]) - L[2]*v[10]*sin(v[4] - v[5]) + v[8]*sin(v[5]))) + M[4]*(2*L[1]*pow(v[9],2)*sin(v[3]) + 2*L[2]*pow(v[10],2)*sin(v[4]) + 2*L[3]*pow(v[11],2)*sin(v[5]) + L[4]*pow(v[12],2)*sin(v[6])) - L[4]*(Cs*cos(v[6])*(2*(cos(v[6])*v[8] + cos(v[3] - v[6])*L[1]*v[9] + cos(v[4] - v[6])*L[2]*v[10] + cos(v[5] - v[6])*L[3]*v[11]) + L[4]*v[12] - 2*v[7]*sin(v[6])) + 2*Cv*sin(v[6])*(cos(v[6])*v[7] - L[1]*v[9]*sin(v[3] - v[6]) - L[2]*v[10]*sin(v[4] - v[6]) - L[3]*v[11]*sin(v[5] - v[6]) + v[8]*sin(v[6]))))/2.;
 coefMat[2] = -(L[1]*(M[1] + 2*(M[2] + M[3] + M[4]))*sin(v[3]))/2.;
 coefMat[8] = (cos(v[3])*L[1]*(M[1] + 2*(M[2] + M[3] + M[4])))/2.;
 coefMat[14] = (pow(L[1],2)*(M[1] + 3*(M[2] + M[3] + M[4])))/3.;
 coefMat[20] = (cos(v[3] - v[4])*L[1]*L[2]*(M[2] + 2*(M[3] + M[4])))/2.;
 coefMat[26] = (cos(v[3] - v[5])*L[1]*L[3]*(M[3] + 2*M[4]))/2.;
 coefMat[32] = (cos(v[3] - v[6])*L[1]*L[4]*M[4])/2.;
 rhsVec[2] = tauL - (L[1]*(Cs*(2*pow(L[1],2)*v[9] + 3*L[1]*(cos(v[3])*v[8] + 2*(pow(cos(v[3] - v[4]),2)*L[2] + pow(cos(v[3] - v[5]),2)*L[3] + pow(cos(v[3] - v[6]),2)*L[4])*v[9] - v[7]*sin(v[3])) + 3*(cos(v[3] - v[4])*pow(L[2],2)*v[10] + cos(v[3] - v[5])*pow(L[3],2)*v[11] + 2*L[2]*((cos(v[3] - v[5])*cos(v[4] - v[5])*L[3] + cos(v[3] - v[6])*cos(v[4] - v[6])*L[4])*v[10] + cos(v[3] - v[4])*(cos(v[4])*v[8] - v[7]*sin(v[4]))) + 2*L[3]*(cos(v[3] - v[6])*cos(v[5] - v[6])*L[4]*v[11] + cos(v[3] - v[5])*(cos(v[5])*v[8] - v[7]*sin(v[5]))) + cos(v[3] - v[6])*L[4]*(2*cos(v[6])*v[8] + L[4]*v[12] - 2*v[7]*sin(v[6])))) + 3*(-2*forceRY*cos(v[3]) + 2*forceRX*sin(v[3]) + L[2]*M[2]*pow(v[10],2)*sin(v[3] - v[4]) + 2*L[2]*M[3]*pow(v[10],2)*sin(v[3] - v[4]) + 2*L[2]*M[4]*pow(v[10],2)*sin(v[3] - v[4]) + L[3]*M[3]*pow(v[11],2)*sin(v[3] - v[5]) + 2*L[3]*M[4]*pow(v[11],2)*sin(v[3] - v[5]) + L[4]*M[4]*pow(v[12],2)*sin(v[3] - v[6]) - 2*Cv*(L[2]*(sin(v[3] - v[4])*(cos(v[4])*v[7] - L[1]*v[9]*sin(v[3] - v[4]) + v[8]*sin(v[4])) - v[10]*(L[3]*sin(v[3] - v[5])*sin(v[4] - v[5]) + L[4]*sin(v[3] - v[6])*sin(v[4] - v[6]))) + L[3]*(sin(v[3] - v[5])*(cos(v[5])*v[7] - L[1]*v[9]*sin(v[3] - v[5]) + v[8]*sin(v[5])) - L[4]*v[11]*sin(v[3] - v[6])*sin(v[5] - v[6])) + L[4]*sin(v[3] - v[6])*(cos(v[6])*v[7] - L[1]*v[9]*sin(v[3] - v[6]) + v[8]*sin(v[6]))))))/6.;
 coefMat[3] = -(L[2]*(M[2] + 2*(M[3] + M[4]))*sin(v[4]))/2.;
 coefMat[9] = (cos(v[4])*L[2]*(M[2] + 2*(M[3] + M[4])))/2.;
 coefMat[15] = (cos(v[3] - v[4])*L[1]*L[2]*(M[2] + 2*(M[3] + M[4])))/2.;
 coefMat[21] = (pow(L[2],2)*(M[2] + 3*(M[3] + M[4])))/3.;
 coefMat[27] = (cos(v[4] - v[5])*L[2]*L[3]*(M[3] + 2*M[4]))/2.;
 coefMat[33] = (cos(v[4] - v[6])*L[2]*L[4]*M[4])/2.;
 rhsVec[3] = -(L[2]*(-6*forceRY*cos(v[4]) - 3*L[1]*M[2]*pow(v[9],2)*sin(v[3] - v[4]) - 6*L[1]*M[3]*pow(v[9],2)*sin(v[3] - v[4]) - 6*L[1]*M[4]*pow(v[9],2)*sin(v[3] - v[4]) + 6*forceRX*sin(v[4]) + 3*L[3]*M[3]*pow(v[11],2)*sin(v[4] - v[5]) + 6*L[3]*M[4]*pow(v[11],2)*sin(v[4] - v[5]) + 3*L[4]*M[4]*pow(v[12],2)*sin(v[4] - v[6]) + Cs*(2*pow(L[2],2)*v[10] + 3*cos(v[4] - v[5])*pow(L[3],2)*v[11] + 3*L[2]*(cos(v[4])*v[8] + cos(v[3] - v[4])*L[1]*v[9] + 2*(pow(cos(v[4] - v[5]),2)*L[3] + pow(cos(v[4] - v[6]),2)*L[4])*v[10] - v[7]*sin(v[4])) + 6*L[3]*(cos(v[4] - v[6])*cos(v[5] - v[6])*L[4]*v[11] + cos(v[4] - v[5])*(cos(v[5])*v[8] + cos(v[3] - v[5])*L[1]*v[9] - v[7]*sin(v[5]))) + 3*cos(v[4] - v[6])*L[4]*(2*cos(v[6])*v[8] + 2*cos(v[3] - v[6])*L[1]*v[9] + L[4]*v[12] - 2*v[7]*sin(v[6]))) - 6*Cv*(L[3]*(sin(v[4] - v[5])*(cos(v[5])*v[7] - L[1]*v[9]*sin(v[3] - v[5]) - L[2]*v[10]*sin(v[4] - v[5]) + v[8]*sin(v[5])) - L[4]*v[11]*sin(v[4] - v[6])*sin(v[5] - v[6])) + L[4]*sin(v[4] - v[6])*(cos(v[6])*v[7] - L[1]*v[9]*sin(v[3] - v[6]) - L[2]*v[10]*sin(v[4] - v[6]) + v[8]*sin(v[6])))))/6.;
 coefMat[4] = -(L[3]*(M[3] + 2*M[4])*sin(v[5]))/2.;
 coefMat[10] = (cos(v[5])*L[3]*(M[3] + 2*M[4]))/2.;
 coefMat[16] = (cos(v[3] - v[5])*L[1]*L[3]*(M[3] + 2*M[4]))/2.;
 coefMat[22] = (cos(v[4] - v[5])*L[2]*L[3]*(M[3] + 2*M[4]))/2.;
 coefMat[28] = (pow(L[3],2)*(M[3] + 3*M[4]))/3.;
 coefMat[34] = (cos(v[5] - v[6])*L[3]*L[4]*M[4])/2.;
 rhsVec[4] = -(L[3]*(Cs*(2*pow(L[3],2)*v[11] + 3*L[3]*(cos(v[5])*v[8] + cos(v[3] - v[5])*L[1]*v[9] + cos(v[4] - v[5])*L[2]*v[10] + 2*pow(cos(v[5] - v[6]),2)*L[4]*v[11] - v[7]*sin(v[5])) + 3*cos(v[5] - v[6])*L[4]*(2*cos(v[6])*v[8] + 2*cos(v[3] - v[6])*L[1]*v[9] + 2*cos(v[4] - v[6])*L[2]*v[10] + L[4]*v[12] - 2*v[7]*sin(v[6]))) - 3*(2*forceRY*cos(v[5]) + (M[3] + 2*M[4])*(L[1]*pow(v[9],2)*sin(v[3] - v[5]) + L[2]*pow(v[10],2)*sin(v[4] - v[5])) - 2*forceRX*sin(v[5]) - L[4]*M[4]*pow(v[12],2)*sin(v[5] - v[6]) - 2*Cv*L[4]*sin(v[5] - v[6])*(-(cos(v[6])*v[7]) + L[1]*v[9]*sin(v[3] - v[6]) + L[2]*v[10]*sin(v[4] - v[6]) + L[3]*v[11]*sin(v[5] - v[6]) - v[8]*sin(v[6])))))/6.;
 coefMat[5] = -(L[4]*M[4]*sin(v[6]))/2.;
 coefMat[11] = (cos(v[6])*L[4]*M[4])/2.;
 coefMat[17] = (cos(v[3] - v[6])*L[1]*L[4]*M[4])/2.;
 coefMat[23] = (cos(v[4] - v[6])*L[2]*L[4]*M[4])/2.;
 coefMat[29] = (cos(v[5] - v[6])*L[3]*L[4]*M[4])/2.;
 coefMat[35] = (pow(L[4],2)*M[4])/3.;
 rhsVec[5] = (6*tauR + 3*L[4]*(2*forceRY*cos(v[6]) + M[4]*(L[1]*pow(v[9],2)*sin(v[3] - v[6]) + L[2]*pow(v[10],2)*sin(v[4] - v[6]) + L[3]*pow(v[11],2)*sin(v[5] - v[6])) - 2*forceRX*sin(v[6])) - Cs*pow(L[4],2)*(3*(cos(v[6])*v[8] + cos(v[3] - v[6])*L[1]*v[9] + cos(v[4] - v[6])*L[2]*v[10] + cos(v[5] - v[6])*L[3]*v[11]) + 2*L[4]*v[12] - 3*v[7]*sin(v[6])))/6.;
    
    // ===================
    
    
}
