function boomSim
clear all
clear global

global boomParams
global Lhist Rhist
global MaxTime
global ForceSols

boomParams.n = 10;
boomParams.M = (0.8/boomParams.n) * ones(boomParams.n,1);
boomParams.L = (60*0.3048/boomParams.n) * ones(boomParams.n,1);
boomParams.Cs = 0.05; %0.00627552;
boomParams.Cv = 0.05; %0.00628319;

% v = [th1,th2,...,thn, Dth1,Dth2,...,Dthn] : initial velocities should be 0
v0 = [-pi/2, -pi/3, -pi/8, pi/8, pi/12, -pi/12, -pi/8, pi/8, pi/3, pi/2, ...
      zeros(1,boomParams.n)];
pL0 = [10, 0];
MaxTime = 70;
EndTraj('init', pL0, v0);

options = odeset('RelTol',1e-6);
[tt, YY] = ode45(@boomODEs, [0 MaxTime], v0, options);
t = 0:0.1:MaxTime;
Y = interp1(tt, YY, t); % The angles
et = EndTraj(t);
pL = et(:, 1:2);
[ForceSols.t, sortInds] = sort(ForceSols.t);
ForceSols.f = ForceSols.f(sortInds,:);
[repRemoved,ai,bi] = union(ForceSols.t,[]);
ForceSols.t = ForceSols.t(ai);
ForceSols.f = ForceSols.f(ai,:);
Fs = interp1(ForceSols.t, ForceSols.f, t); % The forces

Lhist = [];
Rhist = [];
fCount = 1;
figure;
axis equal;
hold on;
grid on;
set(gca,'XLim',[-1 5]);
for a=1:size(Y, 1)
    cla;
    pts = drawFrame([pL(a,:),Y(a,:)],t(a),Fs(a,:));
    set(gca,'YLim',[mean(pts(2,:))-7.9, mean(pts(2,:))+7.9]);
    set(gca,'XLim',[mean(pts(1,:))-8.5, mean(pts(1,:))+8.5]);
    title(sprintf('t = %f', t(a)));
    drawnow;
    F(fCount) = getframe;
    F(fCount).cdata = F(fCount).cdata(1:339,1:363,1:3);
    fCount = fCount + 1;
    pause(0.01);
end

%% movie(F);
%movie2avi(F,'FullDynamic(70s)_PosControl(circle)_ExptParams.avi', 'compression','Cinepak', 'fps',10);

% =============================================

function pts = drawFrame(y, t, fs)
global boomParams
global Lhist Rhist

xs(1) = y(1);
ys(1) = y(2);
for a=3:(boomParams.n+2)
    pNext = [xs(end),ys(end)] + boomParams.L(a-2)*[cos(y(a)),sin(y(a))];
    xs(end+1) = pNext(1);
    ys(end+1) = pNext(2);
end

Lhist(end+1,:) = [xs(1),ys(1)];
Rhist(end+1,:) = [xs(end),ys(end)];
plot(Lhist(:,1), Lhist(:,2), 'm:', 'LineWidth',2.5);
plot(Rhist(:,1), Rhist(:,2), 'm:', 'LineWidth',2.5);

%f = ForceProfile(t);

plot(xs, ys, 'b.-', 'LineWidth',2.5);
plot(xs(1), ys(1), 'ro', 'LineWidth',2.5);
plot(xs(end), ys(end), 'ro', 'LineWidth',2.5);
plot([xs(1),xs(1)+0.01*fs(1)], [ys(1),ys(1)+0.01*fs(2)], 'r-', 'LineWidth',3);
plot([xs(end),xs(end)+0.01*fs(3)], [ys(end),ys(end)+0.01*fs(4)], 'r-', 'LineWidth',3);

pts = [xs; ys];

