/*
Use: Drag = getDrag_quasistatic(v, dv, p, dp, M, L, [Cs Cv])
 where,
  v = [th1,th2,...,thn] is the state vector
  p = [xL, yL, xR, yR]
 
Drag is a n by 2 matrix.
*/

#include "math.h"
#include "stdio.h"
#include "stdlib.h"
#include "mex.h"   //--This one is required

void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
    int n, a;
    double* v0;
    double* dv0;
    double* Th;
    double* dTh;
    double* endPoses;
    double* dendPoses;
    double* dragForce;
    double xL,yL,xR,yR;
    double dxL,dyL,dxR,dyR;
    double* M0;
    double* L0;
    double* M;
    double* L;
    double* fricCoefs;
    double Cv, Cs;
    
    n = max(mxGetN(prhs[0]), mxGetM(prhs[0]));
    //printf("\n=- %d -=\n", n);

    v0 = mxGetPr(prhs[0]);
    Th = (double*) mxMalloc((n+1)*sizeof(double));
    for(a=0; a<n; a++)
        Th[a+1] = v0[a];
    
    dv0 = mxGetPr(prhs[1]);
    dTh = (double*) mxMalloc((n+1)*sizeof(double));
    for(a=0; a<n; a++)
        dTh[a+1] = dv0[a];
    
    endPoses = mxGetPr(prhs[2]);
    xL = endPoses[0];
    yL = endPoses[1];
    xR = endPoses[2];
    yR = endPoses[3];
    
    dendPoses = mxGetPr(prhs[3]);
    dxL = dendPoses[0];
    dyL = dendPoses[1];
    dxR = dendPoses[2];
    dyR = dendPoses[3];
    
    M0 = (double*) mxMalloc(n*sizeof(double));
    L0 = (double*) mxMalloc(n*sizeof(double));
    M0 = mxGetPr(prhs[4]);
    L0 = mxGetPr(prhs[5]);
    M = (double*) mxMalloc(n*sizeof(double));
    L = (double*) mxMalloc(n*sizeof(double));
    for(a=0; a<n; a++)
    {
        M[a+1] = M0[a];
        L[a+1] = L0[a];
    }
    fricCoefs = mxGetPr(prhs[6]);
    Cs = fricCoefs[0];
    Cv = fricCoefs[1];
    
    plhs[0] = mxCreateDoubleMatrix(n, 2, mxREAL);
    dragForce = mxGetPr(plhs[0]);
    
    // Assignments go here
    // ===================

 dragForce[0] = (L[1]*(-2*Cv*cos(Th[1])*(dxL*cos(Th[1]) + dyL*sin(Th[1])) + Cs*(dTh[1]*L[1]*sin(Th[1]) - 2*dxL*pow(sin(Th[1]),2) + dyL*sin(2*Th[1]))))/2.;
 dragForce[10] = -(L[1]*(Cs*cos(Th[1])*(2*dyL*cos(Th[1]) + dTh[1]*L[1] - 2*dxL*sin(Th[1])) + Cv*(2*dyL*pow(sin(Th[1]),2) + dxL*sin(2*Th[1]))))/2.;
 dragForce[1] = (L[2]*(-(Cs*sin(Th[2])*(-2*dyL*cos(Th[2]) - 2*cos(Th[1] - Th[2])*dTh[1]*L[1] - dTh[2]*L[2] + 2*dxL*sin(Th[2]))) - 2*Cv*cos(Th[2])*(dxL*cos(Th[2]) - dTh[1]*L[1]*sin(Th[1] - Th[2]) + dyL*sin(Th[2]))))/2.;
 dragForce[11] = -(L[2]*(Cs*cos(Th[2])*(2*dyL*cos(Th[2]) + 2*cos(Th[1] - Th[2])*dTh[1]*L[1] + dTh[2]*L[2] - 2*dxL*sin(Th[2])) + 2*Cv*sin(Th[2])*(dxL*cos(Th[2]) - dTh[1]*L[1]*sin(Th[1] - Th[2]) + dyL*sin(Th[2]))))/2.;
 dragForce[2] = (L[3]*(-(Cs*sin(Th[3])*(-2*dyL*cos(Th[3]) - 2*cos(Th[1] - Th[3])*dTh[1]*L[1] - 2*cos(Th[2] - Th[3])*dTh[2]*L[2] - dTh[3]*L[3] + 2*dxL*sin(Th[3]))) + 2*Cv*cos(Th[3])*(-(dxL*cos(Th[3])) + dTh[1]*L[1]*sin(Th[1] - Th[3]) + dTh[2]*L[2]*sin(Th[2] - Th[3]) - dyL*sin(Th[3]))))/2.;
 dragForce[12] = -(L[3]*(Cs*cos(Th[3])*(2*dyL*cos(Th[3]) + 2*cos(Th[1] - Th[3])*dTh[1]*L[1] + 2*cos(Th[2] - Th[3])*dTh[2]*L[2] + dTh[3]*L[3] - 2*dxL*sin(Th[3])) + 2*Cv*sin(Th[3])*(dxL*cos(Th[3]) - dTh[1]*L[1]*sin(Th[1] - Th[3]) - dTh[2]*L[2]*sin(Th[2] - Th[3]) + dyL*sin(Th[3]))))/2.;
 dragForce[3] = (L[4]*(-(Cs*sin(Th[4])*(-2*dyL*cos(Th[4]) - 2*cos(Th[1] - Th[4])*dTh[1]*L[1] - 2*cos(Th[2] - Th[4])*dTh[2]*L[2] - 2*cos(Th[3] - Th[4])*dTh[3]*L[3] - dTh[4]*L[4] + 2*dxL*sin(Th[4]))) + 2*Cv*cos(Th[4])*(-(dxL*cos(Th[4])) + dTh[1]*L[1]*sin(Th[1] - Th[4]) + dTh[2]*L[2]*sin(Th[2] - Th[4]) + dTh[3]*L[3]*sin(Th[3] - Th[4]) - dyL*sin(Th[4]))))/2.;
 dragForce[13] = -(L[4]*(Cs*cos(Th[4])*(2*dyL*cos(Th[4]) + 2*cos(Th[1] - Th[4])*dTh[1]*L[1] + 2*cos(Th[2] - Th[4])*dTh[2]*L[2] + 2*cos(Th[3] - Th[4])*dTh[3]*L[3] + dTh[4]*L[4] - 2*dxL*sin(Th[4])) + 2*Cv*sin(Th[4])*(dxL*cos(Th[4]) - dTh[1]*L[1]*sin(Th[1] - Th[4]) - dTh[2]*L[2]*sin(Th[2] - Th[4]) - dTh[3]*L[3]*sin(Th[3] - Th[4]) + dyL*sin(Th[4]))))/2.;
 dragForce[4] = (L[5]*(-(Cs*sin(Th[5])*(-2*dyL*cos(Th[5]) - 2*cos(Th[1] - Th[5])*dTh[1]*L[1] - 2*cos(Th[2] - Th[5])*dTh[2]*L[2] - 2*cos(Th[3] - Th[5])*dTh[3]*L[3] - 2*cos(Th[4] - Th[5])*dTh[4]*L[4] - dTh[5]*L[5] + 2*dxL*sin(Th[5]))) + 2*Cv*cos(Th[5])*(-(dxL*cos(Th[5])) + dTh[1]*L[1]*sin(Th[1] - Th[5]) + dTh[2]*L[2]*sin(Th[2] - Th[5]) + dTh[3]*L[3]*sin(Th[3] - Th[5]) + dTh[4]*L[4]*sin(Th[4] - Th[5]) - dyL*sin(Th[5]))))/2.;
 dragForce[14] = -(L[5]*(Cs*cos(Th[5])*(2*dyL*cos(Th[5]) + 2*cos(Th[1] - Th[5])*dTh[1]*L[1] + 2*cos(Th[2] - Th[5])*dTh[2]*L[2] + 2*cos(Th[3] - Th[5])*dTh[3]*L[3] + 2*cos(Th[4] - Th[5])*dTh[4]*L[4] + dTh[5]*L[5] - 2*dxL*sin(Th[5])) + 2*Cv*sin(Th[5])*(dxL*cos(Th[5]) - dTh[1]*L[1]*sin(Th[1] - Th[5]) - dTh[2]*L[2]*sin(Th[2] - Th[5]) - dTh[3]*L[3]*sin(Th[3] - Th[5]) - dTh[4]*L[4]*sin(Th[4] - Th[5]) + dyL*sin(Th[5]))))/2.;
 dragForce[5] = (L[6]*(-(Cs*sin(Th[6])*(-2*dyL*cos(Th[6]) - 2*cos(Th[1] - Th[6])*dTh[1]*L[1] - 2*cos(Th[2] - Th[6])*dTh[2]*L[2] - 2*cos(Th[3] - Th[6])*dTh[3]*L[3] - 2*cos(Th[4] - Th[6])*dTh[4]*L[4] - 2*cos(Th[5] - Th[6])*dTh[5]*L[5] - dTh[6]*L[6] + 2*dxL*sin(Th[6]))) + 2*Cv*cos(Th[6])*(-(dxL*cos(Th[6])) + dTh[1]*L[1]*sin(Th[1] - Th[6]) + dTh[2]*L[2]*sin(Th[2] - Th[6]) + dTh[3]*L[3]*sin(Th[3] - Th[6]) + dTh[4]*L[4]*sin(Th[4] - Th[6]) + dTh[5]*L[5]*sin(Th[5] - Th[6]) - dyL*sin(Th[6]))))/2.;
 dragForce[15] = (L[6]*(-(Cs*cos(Th[6])*(2*dyL*cos(Th[6]) + 2*cos(Th[1] - Th[6])*dTh[1]*L[1] + 2*cos(Th[2] - Th[6])*dTh[2]*L[2] + 2*cos(Th[3] - Th[6])*dTh[3]*L[3] + 2*cos(Th[4] - Th[6])*dTh[4]*L[4] + 2*cos(Th[5] - Th[6])*dTh[5]*L[5] + dTh[6]*L[6] - 2*dxL*sin(Th[6]))) + 2*Cv*sin(Th[6])*(-(dxL*cos(Th[6])) + dTh[1]*L[1]*sin(Th[1] - Th[6]) + dTh[2]*L[2]*sin(Th[2] - Th[6]) + dTh[3]*L[3]*sin(Th[3] - Th[6]) + dTh[4]*L[4]*sin(Th[4] - Th[6]) + dTh[5]*L[5]*sin(Th[5] - Th[6]) - dyL*sin(Th[6]))))/2.;
 dragForce[6] = (L[7]*(-(Cs*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + 2*dxL*sin(Th[7]))) + 2*Cv*cos(Th[7])*(-(dxL*cos(Th[7])) + dTh[1]*L[1]*sin(Th[1] - Th[7]) + dTh[2]*L[2]*sin(Th[2] - Th[7]) + dTh[3]*L[3]*sin(Th[3] - Th[7]) + dTh[4]*L[4]*sin(Th[4] - Th[7]) + dTh[5]*L[5]*sin(Th[5] - Th[7]) + dTh[6]*L[6]*sin(Th[6] - Th[7]) - dyL*sin(Th[7]))))/2.;
 dragForce[16] = -(L[7]*(Cs*cos(Th[7])*(2*dyL*cos(Th[7]) + 2*cos(Th[1] - Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + 2*cos(Th[3] - Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + 2*cos(Th[5] - Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + dTh[7]*L[7] - 2*dxL*sin(Th[7])) + 2*Cv*sin(Th[7])*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7]))))/2.;
 dragForce[7] = (L[8]*(-(Cs*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8]))) + 2*Cv*cos(Th[8])*(-(dxL*cos(Th[8])) + dTh[1]*L[1]*sin(Th[1] - Th[8]) + dTh[2]*L[2]*sin(Th[2] - Th[8]) + dTh[3]*L[3]*sin(Th[3] - Th[8]) + dTh[4]*L[4]*sin(Th[4] - Th[8]) + dTh[5]*L[5]*sin(Th[5] - Th[8]) + dTh[6]*L[6]*sin(Th[6] - Th[8]) + dTh[7]*L[7]*sin(Th[7] - Th[8]) - dyL*sin(Th[8]))))/2.;
 dragForce[17] = -(L[8]*(Cs*cos(Th[8])*(2*dyL*cos(Th[8]) + 2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + 2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + 2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + 2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])) + 2*Cv*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))))/2.;
 dragForce[8] = (L[9]*(-(Cs*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + 2*dxL*sin(Th[9]))) + 2*Cv*cos(Th[9])*(-(dxL*cos(Th[9])) + dTh[1]*L[1]*sin(Th[1] - Th[9]) + dTh[2]*L[2]*sin(Th[2] - Th[9]) + dTh[3]*L[3]*sin(Th[3] - Th[9]) + dTh[4]*L[4]*sin(Th[4] - Th[9]) + dTh[5]*L[5]*sin(Th[5] - Th[9]) + dTh[6]*L[6]*sin(Th[6] - Th[9]) + dTh[7]*L[7]*sin(Th[7] - Th[9]) + dTh[8]*L[8]*sin(Th[8] - Th[9]) - dyL*sin(Th[9]))))/2.;
 dragForce[18] = -(L[9]*(Cs*cos(Th[9])*(2*dyL*cos(Th[9]) + 2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + 2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + 2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + 2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + dTh[9]*L[9] - 2*dxL*sin(Th[9])) + 2*Cv*sin(Th[9])*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))))/2.;
 dragForce[9] = (L[10]*(-(Cs*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10]))) + 2*Cv*cos(Th[10])*(-(dxL*cos(Th[10])) + dTh[1]*L[1]*sin(Th[1] - Th[10]) + dTh[2]*L[2]*sin(Th[2] - Th[10]) + dTh[3]*L[3]*sin(Th[3] - Th[10]) + dTh[4]*L[4]*sin(Th[4] - Th[10]) + dTh[5]*L[5]*sin(Th[5] - Th[10]) + dTh[6]*L[6]*sin(Th[6] - Th[10]) + dTh[7]*L[7]*sin(Th[7] - Th[10]) + dTh[8]*L[8]*sin(Th[8] - Th[10]) + dTh[9]*L[9]*sin(Th[9] - Th[10]) - dyL*sin(Th[10]))))/2.;
 dragForce[19] = -(L[10]*(Cs*cos(Th[10])*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])) + 2*Cv*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))))/2.;
    
 // ===================
    
    
}
