/*
Use: matSys = getMat_quasistatic(v, p, M, L, [Cs Cv])
 where,
  v = [th1,th2,...,thn] is the state vector
  p = [xL, yL, xR, yR]
 The main equations of motion are given by
  matSys * [Dth1,Dth2,...,Dthn, DxL,DyL,DxR,DyR, fRX,fRY]' = 0;
 matSys is a (n+2) by (n+6) matrix.
*/

#include "math.h"
#include "stdio.h"
#include "stdlib.h"
#include "mex.h"   //--This one is required

void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
    int n, a;
    double* v0;
    double* Th;
    double* dTh;
    double* endPoses;
    double* matSys;
    double* rhsVec;
    double xL,yL,xR,yR;
    double* M0;
    double* L0;
    double* M;
    double* L;
    double* fricCoefs;
    double Cv, Cs;
    
    v0 = mxGetPr(prhs[0]);
    n = mxGetM(prhs[0]);
    Th = (double*) mxMalloc((n+1)*sizeof(double));
    for(a=0; a<n; a++)
        Th[a+1] = v0[a];
    
    endPoses = mxGetPr(prhs[1]);
    xL = endPoses[0];
    yL = endPoses[1];
    xR = endPoses[2];
    yR = endPoses[3];
    
    M0 = (double*) mxMalloc(n*sizeof(double));
    L0 = (double*) mxMalloc(n*sizeof(double));
    M0 = mxGetPr(prhs[2]);
    L0 = mxGetPr(prhs[3]);
    M = (double*) mxMalloc((n+1)*sizeof(double));
    L = (double*) mxMalloc((n+1)*sizeof(double));
    for(a=0; a<n; a++)
    {
        M[a+1] = M0[a];
        L[a+1] = L0[a];
    }
    fricCoefs = mxGetPr(prhs[4]);
    Cs = fricCoefs[0];
    Cv = fricCoefs[1];
    
    plhs[0] = mxCreateDoubleMatrix(n+2, n+6, mxREAL);
    matSys = mxGetPr(plhs[0]);
    
    // Assignments go here
    // ===================

 matSys[0] = -(pow(L[1],2)*(Cs*(L[1] + 3*(pow(cos(Th[1] - Th[2]),2)*L[2] + pow(cos(Th[1] - Th[3]),2)*L[3] + pow(cos(Th[1] - Th[4]),2)*L[4])) + 3*Cv*(L[2]*pow(sin(Th[1] - Th[2]),2) + L[3]*pow(sin(Th[1] - Th[3]),2) + L[4]*pow(sin(Th[1] - Th[4]),2))))/3.;
 matSys[6] = -(L[1]*L[2]*(Cs*(cos(Th[1] - Th[2])*L[2] + 2*cos(Th[1] - Th[3])*cos(Th[2] - Th[3])*L[3] + 2*cos(Th[1] - Th[4])*cos(Th[2] - Th[4])*L[4]) + 2*Cv*(L[3]*sin(Th[1] - Th[3])*sin(Th[2] - Th[3]) + L[4]*sin(Th[1] - Th[4])*sin(Th[2] - Th[4]))))/2.;
 matSys[12] = -(L[1]*L[3]*(Cs*(cos(Th[1] - Th[3])*L[3] + 2*cos(Th[1] - Th[4])*cos(Th[3] - Th[4])*L[4]) + 2*Cv*L[4]*sin(Th[1] - Th[4])*sin(Th[3] - Th[4])))/2.;
 matSys[18] = -(Cs*cos(Th[1] - Th[4])*L[1]*pow(L[4],2))/2.;
 matSys[24] = (L[1]*(Cs*(L[1]*sin(Th[1]) + L[3]*sin(Th[1]) + L[4]*sin(Th[1]) + 2*cos(Th[1] - Th[2])*L[2]*sin(Th[2]) - L[3]*sin(Th[1] - 2*Th[3]) - L[4]*sin(Th[1] - 2*Th[4])) + 2*Cv*(cos(Th[2])*L[2]*sin(Th[1] - Th[2]) + cos(Th[3])*L[3]*sin(Th[1] - Th[3]) + cos(Th[4])*L[4]*sin(Th[1] - Th[4]))))/2.;
 matSys[30] = -(L[1]*(Cs*(cos(Th[1])*L[1] + 2*cos(Th[1] - Th[2])*cos(Th[2])*L[2] + cos(Th[1])*L[3] + cos(Th[1] - 2*Th[3])*L[3] + cos(Th[1])*L[4] + cos(Th[1] - 2*Th[4])*L[4]) - 2*Cv*(L[2]*sin(Th[1] - Th[2])*sin(Th[2]) + L[3]*sin(Th[1] - Th[3])*sin(Th[3]) + L[4]*sin(Th[1] - Th[4])*sin(Th[4]))))/2.;
 matSys[36] = 0;
 matSys[42] = 0;
 matSys[48] = -(L[1]*sin(Th[1]));
 matSys[54] = cos(Th[1])*L[1];
 matSys[1] = -(L[1]*L[2]*(Cs*(cos(Th[1] - Th[2])*L[2] + 2*cos(Th[1] - Th[3])*cos(Th[2] - Th[3])*L[3] + 2*cos(Th[1] - Th[4])*cos(Th[2] - Th[4])*L[4]) + 2*Cv*(L[3]*sin(Th[1] - Th[3])*sin(Th[2] - Th[3]) + L[4]*sin(Th[1] - Th[4])*sin(Th[2] - Th[4]))))/2.;
 matSys[7] = -(pow(L[2],2)*(Cs*(L[2] + 3*pow(cos(Th[2] - Th[3]),2)*L[3] + 3*pow(cos(Th[2] - Th[4]),2)*L[4]) + 3*Cv*(L[3]*pow(sin(Th[2] - Th[3]),2) + L[4]*pow(sin(Th[2] - Th[4]),2))))/3.;
 matSys[13] = -(L[2]*L[3]*(Cs*(cos(Th[2] - Th[3])*L[3] + 2*cos(Th[2] - Th[4])*cos(Th[3] - Th[4])*L[4]) + 2*Cv*L[4]*sin(Th[2] - Th[4])*sin(Th[3] - Th[4])))/2.;
 matSys[19] = -(Cs*cos(Th[2] - Th[4])*L[2]*pow(L[4],2))/2.;
 matSys[25] = (L[2]*(2*Cv*(cos(Th[3])*L[3]*sin(Th[2] - Th[3]) + cos(Th[4])*L[4]*sin(Th[2] - Th[4])) + Cs*(L[2]*sin(Th[2]) + 2*cos(Th[2] - Th[3])*L[3]*sin(Th[3]) + 2*cos(Th[2] - Th[4])*L[4]*sin(Th[4]))))/2.;
 matSys[31] = -(L[2]*(Cs*(cos(Th[2])*L[2] + 2*cos(Th[2] - Th[3])*cos(Th[3])*L[3] + 2*cos(Th[2] - Th[4])*cos(Th[4])*L[4]) - 2*Cv*(L[3]*sin(Th[2] - Th[3])*sin(Th[3]) + L[4]*sin(Th[2] - Th[4])*sin(Th[4]))))/2.;
 matSys[37] = 0;
 matSys[43] = 0;
 matSys[49] = -(L[2]*sin(Th[2]));
 matSys[55] = cos(Th[2])*L[2];
 matSys[2] = -(L[1]*L[3]*(Cs*(cos(Th[1] - Th[3])*L[3] + 2*cos(Th[1] - Th[4])*cos(Th[3] - Th[4])*L[4]) + 2*Cv*L[4]*sin(Th[1] - Th[4])*sin(Th[3] - Th[4])))/2.;
 matSys[8] = -(L[2]*L[3]*(Cs*(cos(Th[2] - Th[3])*L[3] + 2*cos(Th[2] - Th[4])*cos(Th[3] - Th[4])*L[4]) + 2*Cv*L[4]*sin(Th[2] - Th[4])*sin(Th[3] - Th[4])))/2.;
 matSys[14] = -(pow(L[3],2)*(Cs*(L[3] + 3*pow(cos(Th[3] - Th[4]),2)*L[4]) + 3*Cv*L[4]*pow(sin(Th[3] - Th[4]),2)))/3.;
 matSys[20] = -(Cs*cos(Th[3] - Th[4])*L[3]*pow(L[4],2))/2.;
 matSys[26] = (L[3]*(2*Cv*cos(Th[4])*L[4]*sin(Th[3] - Th[4]) + Cs*(L[3]*sin(Th[3]) + 2*cos(Th[3] - Th[4])*L[4]*sin(Th[4]))))/2.;
 matSys[32] = -(L[3]*(Cs*(cos(Th[3])*L[3] + 2*cos(Th[3] - Th[4])*cos(Th[4])*L[4]) - 2*Cv*L[4]*sin(Th[3] - Th[4])*sin(Th[4])))/2.;
 matSys[38] = 0;
 matSys[44] = 0;
 matSys[50] = -(L[3]*sin(Th[3]));
 matSys[56] = cos(Th[3])*L[3];
 matSys[3] = -(Cs*cos(Th[1] - Th[4])*L[1]*pow(L[4],2))/2.;
 matSys[9] = -(Cs*cos(Th[2] - Th[4])*L[2]*pow(L[4],2))/2.;
 matSys[15] = -(Cs*cos(Th[3] - Th[4])*L[3]*pow(L[4],2))/2.;
 matSys[21] = -(Cs*pow(L[4],3))/3.;
 matSys[27] = (Cs*pow(L[4],2)*sin(Th[4]))/2.;
 matSys[33] = -(Cs*cos(Th[4])*pow(L[4],2))/2.;
 matSys[39] = 0;
 matSys[45] = 0;
 matSys[51] = -(L[4]*sin(Th[4]));
 matSys[57] = cos(Th[4])*L[4];
 matSys[4] = L[1]*sin(Th[1]);
 matSys[10] = L[2]*sin(Th[2]);
 matSys[16] = L[3]*sin(Th[3]);
 matSys[22] = L[4]*sin(Th[4]);
 matSys[28] = -1;
 matSys[34] = 0;
 matSys[40] = 1;
 matSys[46] = 0;
 matSys[52] = 0;
 matSys[58] = 0;
 matSys[5] = -(cos(Th[1])*L[1]);
 matSys[11] = -(cos(Th[2])*L[2]);
 matSys[17] = -(cos(Th[3])*L[3]);
 matSys[23] = -(cos(Th[4])*L[4]);
 matSys[29] = 0;
 matSys[35] = -1;
 matSys[41] = 0;
 matSys[47] = 1;
 matSys[53] = 0;
 matSys[59] = 0;
    
 // ===================
    
    
}
