(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    919651,      14235]*)
(*NotebookOutlinePosition[    920296,      14257]*)
(*  CellTagsIndexPosition[    920252,      14253]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[{\(mySimplify[expr_] := Chop[expr];\), "\[IndentingNewLine]", 
    StyleBox[\(Print["\<Generalized coordinates and drag forces ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(n = 10;\), "\[IndentingNewLine]", 
    StyleBox[\(\[Mu] = 10\^\(-3\);\),
      FontColor->GrayLevel[0.666667]], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[\(reNo = 1.0;\),
        FontColor->GrayLevel[0.666667]], "\[IndentingNewLine]", 
      StyleBox[
        RowBox[{"(*", " ", 
          RowBox[{
            
            StyleBox[\(c\_S = \(4\ \[Pi]\ \[Mu]\)\/\(1\/2 - 0.577 - \
Log[reNo\/8]\)\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[";",
              FontColor->GrayLevel[0.666667]], "\[IndentingNewLine]", 
            StyleBox[\(c\_V\  = \(\[Mu]\ 2\ \[Pi]\ 0.1\)\/0.1\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[";",
              FontColor->GrayLevel[0.666667]]}], " ", "*)"}],
        FontColor->GrayLevel[
        0.666667]]}], "\[IndentingNewLine]", \(w\_0 = {x\_L[t], 
          y\_L[t]};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"For", "[", 
        RowBox[{\(a = 1\), ",", \(a \[LessEqual] n\), ",", 
          "\[IndentingNewLine]", 
          RowBox[{\(Print[a]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ \[Lambda]\_a = 1.0; \[IndentingNewLine]m\_a = 
                  1.0;\ *) \),
              FontColor->GrayLevel[0.666667]], 
            "\[IndentingNewLine]", \(th\_a = \[Theta]\_a[t]\), ";", 
            "\[IndentingNewLine]", \(vec\_a = {Cos[th\_a], Sin[th\_a]}\), ";",
             "\[IndentingNewLine]", \(p\_a = 
              w\_\(a - 1\) + \[Lambda]\_a\/2\ vec\_a\), ";", 
            "\[IndentingNewLine]", \(w\_a = 
              w\_\(a - 1\) + \[Lambda]\_a\ vec\_a\), ";", 
            "\[IndentingNewLine]", \(v\_a = D[p\_a, t]\), ";", 
            "\[IndentingNewLine]", \(rotMat\_a = {{Cos[th\_a], 
                  Sin[th\_a]}, {\(-Sin[th\_a]\), Cos[th\_a]}}\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ 
                For\ an\ infinidecimal\ point\ on\ segment\ a\ *) \),
              Background->GrayLevel[0.900008]], 
            "\[IndentingNewLine]", \(pPt\_a = 
              p\_a + s\ {Cos[th\_a], Sin[th\_a]}\), ";", 
            "\[IndentingNewLine]", \(vPt\_a = D[pPt\_a, t]\), ";", 
            "\[IndentingNewLine]", \(vPtLocal\_a = rotMat\_a . vPt\_a\), ";", 
            "\[IndentingNewLine]", \(fPtDrag\_a = 
              Inverse[rotMat\_a] . {\(-c\_V\)\ vPtLocal\_a[\([1]\)], \
\(-c\_S\)\ vPtLocal\_a[\([2]\)]}\), ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ Integrating\ *) \),
              Background->GrayLevel[0.900008]], 
            "\[IndentingNewLine]", \(fDrag\_a = 
              mySimplify[
                Integrate[
                  fPtDrag\_a, {s, \(-\(\[Lambda]\_a\/2\)\), \
\[Lambda]\_a\/2}]]\), ";", 
            "\[IndentingNewLine]", \(tauDrag\_a = 
              mySimplify[
                Integrate[
                  s\ \((fPtDrag\_a[\([2]\)]\ Cos[th\_a] - 
                        fPtDrag\_a[\([1]\)]\ Sin[
                            th\_a])\), {s, \(-\(\[Lambda]\_a\/2\)\), \
\[Lambda]\_a\/2}]]\), ";", "\[IndentingNewLine]", \(a++\)}]}], "]"}], 
      ";"}], "\[IndentingNewLine]", 
    StyleBox[\(Print["\<Kinetic Energy ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(ke = 
        mySimplify[\[Sum]\+\(k = 1\)\%n\((1\/2\ m\_k\ \((v\_k . v\_k)\) + 
                1\/2\ \(m\_k\ \[Lambda]\_k\^2\)\/12\ \((D[th\_k, \
t])\)\^2)\)];\), "\[IndentingNewLine]", 
    StyleBox[\(Print["\<Generalized forces ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(q\_XL = {f\_LX[t], f\_LY[t]} . 
            D[w\_0, x\_L[t]] + \[Sum]\+\(k = 1\)\%n\((fDrag\_k . 
                D[p\_k, x\_L[t]])\) + {f\_RX[t], f\_RY[t]} . 
            D[w\_n, x\_L[t]];\), "\[IndentingNewLine]", \(q\_YL = {f\_LX[t], 
              f\_LY[t]} . 
            D[w\_0, y\_L[t]] + \[Sum]\+\(k = 1\)\%n\((fDrag\_k . 
                D[p\_k, y\_L[t]])\) + {f\_RX[t], f\_RY[t]} . 
            D[w\_n, y\_L[t]];\), "\[IndentingNewLine]", \(For[a = 1, 
      a \[LessEqual] 
        n, \[IndentingNewLine]q\_a = {f\_LX[t], f\_LY[t]} . 
            D[w\_0, \[Theta]\_a[t]] + \[Sum]\+\(k = 1\)\%n\((fDrag\_k . 
                D[p\_k, \[Theta]\_a[t]])\) + {f\_RX[t], f\_RY[t]} . 
            D[w\_n, \[Theta]\_a[t]] + 
          tauDrag\_a; \[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", \
\(q\_1 = q\_1 + \[Tau]\_L[t];\), "\[IndentingNewLine]", \(q\_n = 
        q\_n + \[Tau]\_R[t];\), "\[IndentingNewLine]", 
    StyleBox[\(Print["\<The LHS of the equations ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(Print[
        1];\), "\[IndentingNewLine]", \(eqLHS\_XL = 
        mySimplify[
          D[D[ke, \(x\_L'\)[t]], t] - D[ke, x\_L[t]] - 
            q\_XL];\), "\[IndentingNewLine]", \(Print[
        2];\), "\[IndentingNewLine]", \(eqLHS\_YL = 
        mySimplify[
          D[D[ke, \(y\_L'\)[t]], t] - D[ke, y\_L[t]] - 
            q\_YL];\), "\[IndentingNewLine]", \(For[a = 1, 
      a \[LessEqual] n, \[IndentingNewLine]Print[
        a + 2]; \[IndentingNewLine]eqLHS\_a = 
        mySimplify[
          D[D[ke, \(\[Theta]\_a'\)[t]], t] - D[ke, \[Theta]\_a[t]] - 
            q\_a]; \[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", 
    StyleBox[\(Print["\<The ODEs ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(varReplacement = 
        Table[Null, {n + 2}];\), "\n", \(varReplacement[\([1]\)] = \(x\_L'\)[
            t] \[Rule] 
          dx\_L[t];\), "\n", \(varReplacement[\([2]\)] = \(y\_L'\)[t] \[Rule] 
          dy\_L[t];\), "\n", \(For[a = 1, a \[LessEqual] n, 
        varReplacement[\([a + 2]\)] = \(\[Theta]\_a'\)[t] \[Rule] 
            d\[Theta]\_a[t]; \(a++\)];\), "\[IndentingNewLine]", \(varList = 
        Table[Null, {n + 2}];\), "\[IndentingNewLine]", \(varList[\([1]\)] = 
        x\_L[t];\), "\n", \(varList[\([2]\)] = y\_L[t];\), "\n", \(For[a = 1, 
        a \[LessEqual] n, 
        varList[\([a + 2]\)] = \[Theta]\_a[
            t]; \(a++\)];\), "\[IndentingNewLine]", \(mainEqns = 
        Table[Null, {n + 2}];\), "\[IndentingNewLine]", \(mainEqns[\([1]\)] = 
        eqLHS\_XL;\), "\[IndentingNewLine]", \(mainEqns[\([2]\)] = 
        eqLHS\_YL;\), "\[IndentingNewLine]", \(For[a = 1, a \[LessEqual] n, 
        mainEqns[\([a + 2]\)] = 
          eqLHS\_a; \(a++\)];\), "\[IndentingNewLine]", \(mainEqnsReplaced = 
        mainEqns\  /. \ 
          Join[D[varReplacement, t], 
            varReplacement];\), "\[IndentingNewLine]", \(mainDVars = 
        D[varList, t] /. 
          varReplacement;\), "\[IndentingNewLine]", \(primesZeroReplace = 
        Table[Null, {n + 2}];\), "\[IndentingNewLine]", 
    RowBox[{\(For[a = 1, 
        a \[LessEqual] n + 2, \[IndentingNewLine]primesZeroReplace[\([a]\)] = 
          D[mainDVars[\([a]\)], t] \[Rule] 0; \[IndentingNewLine]\(a++\)]\), 
      "\[IndentingNewLine]", 
      StyleBox[\( (*\ Computing\ the\ LHS\ matrix\ and\ the\ RHS\ *) \),
        Background->GrayLevel[0.900008]]}], "\[IndentingNewLine]", \(matLHS = 
        Table[Null, {n + 2}, {n + 2}];\), "\[IndentingNewLine]", \(vecRHS = 
        Table[Null, {n + 2}];\), "\[IndentingNewLine]", \(For[a = 1, 
      a \[LessEqual] n + 2, \[IndentingNewLine]Print[
        a]; \[IndentingNewLine]For[b = 1, 
        b \[LessEqual] n + 2, \[IndentingNewLine]matLHS[\([a, b]\)] = 
          Chop[mySimplify[
              D[mainEqnsReplaced[\([a]\)], 
                D[mainDVars[\([b]\)], 
                  t]]]]; \[IndentingNewLine]\(b++\)]; \
\[IndentingNewLine]vecRHS[\([a]\)] = \(-Chop[
            mySimplify[
              mainEqnsReplaced[\([a]\)]\  /. \ 
                primesZeroReplace]]\); \[IndentingNewLine]\(a++\)]\)}], \
"Input"],

Cell[BoxData[
    \("Generalized coordinates and drag forces ..."\)], "Print"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"],

Cell[BoxData[
    \(7\)], "Print"],

Cell[BoxData[
    \(8\)], "Print"],

Cell[BoxData[
    \(9\)], "Print"],

Cell[BoxData[
    \(10\)], "Print"],

Cell[BoxData[
    \("Kinetic Energy ..."\)], "Print"],

Cell[BoxData[
    \("Generalized forces ..."\)], "Print"],

Cell[BoxData[
    \("The LHS of the equations ..."\)], "Print"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"],

Cell[BoxData[
    \(7\)], "Print"],

Cell[BoxData[
    \(8\)], "Print"],

Cell[BoxData[
    \(9\)], "Print"],

Cell[BoxData[
    \(10\)], "Print"],

Cell[BoxData[
    \(11\)], "Print"],

Cell[BoxData[
    \(12\)], "Print"],

Cell[BoxData[
    \("The ODEs ..."\)], "Print"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"],

Cell[BoxData[
    \(7\)], "Print"],

Cell[BoxData[
    \(8\)], "Print"],

Cell[BoxData[
    \(9\)], "Print"],

Cell[BoxData[
    \(10\)], "Print"],

Cell[BoxData[
    \(11\)], "Print"],

Cell[BoxData[
    \(12\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cformVarReplace = 
        Table[Null, {4\ \((n + 2)\) + 2\ n + 
              8}];\)\), "\[IndentingNewLine]", 
    \(\(For[a = 1, 
        a \[LessEqual] n + 2, \[IndentingNewLine]cformVarReplace[\([a]\)] = 
          varList[\([a]\)] \[Rule] 
            v[\([a]\)]; \[IndentingNewLine]cformVarReplace[\([a + n + 
                2]\)] = \((D[varList[\([a]\)], t] /. 
                varReplacement)\) \[Rule] 
            v[\([a + n + 2]\)]; \[IndentingNewLine]cformVarReplace[\([a + 
                2\ \((n + 2)\)]\)] = 
          D[varList[\([a]\)], t] \[Rule] 
            dv[\([a]\)]; \[IndentingNewLine]cformVarReplace[\([a + 
                3\ \((n + 2)\)]\)] = 
          D[\((D[varList[\([a]\)], t] /. varReplacement)\), t] \[Rule] 
            dv[\([a + n + 
                  2]\)]; \[IndentingNewLine]\(a++\)];\)\), "\
\[IndentingNewLine]", 
    \(For[a = 1, 
      a \[LessEqual] 
        n, \[IndentingNewLine]cformVarReplace[\([a + 4\ \((n + 2)\)]\)] = 
        m\_a \[Rule] 
          M[\([a]\)]; \[IndentingNewLine]cformVarReplace[\([a + 
              4\ \((n + 2)\) + n]\)] = \[Lambda]\_a \[Rule] 
          L[\([a]\)]; \[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ \((n + 2)\) + 2\ n + 1]\)] = 
        c\_V \[Rule] Cv;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ \((n + 2)\) + 2\ n + 2]\)] = 
        c\_S \[Rule] Cs;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ \((n + 2)\) + 2\ n + 3]\)] = \[Tau]\_L[
            t] \[Rule] tauL;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ \((n + 2)\) + 2\ n + 4]\)] = 
        f\_LX[t] \[Rule] forceLX;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ \((n + 2)\) + 2\ n + 5]\)] = 
        f\_LY[t] \[Rule] forceLY;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ \((n + 2)\) + 2\ n + 6]\)] = \[Tau]\_R[
            t] \[Rule] tauR;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ \((n + 2)\) + 2\ n + 7]\)] = 
        f\_RX[t] \[Rule] forceRX;\)\), "\n", 
    \(\(cformVarReplace[\([4\ \((n + 2)\) + 2\ n + 8]\)] = 
        f\_RY[t] \[Rule] forceRY;\)\), "\[IndentingNewLine]", 
    \(matLHS\  // \ MatrixForm\), "\n", 
    \(vecRHS\  // \ MatrixForm\), "\[IndentingNewLine]", 
    \(cformVarReplace\), "\[IndentingNewLine]", 
    \(\(outCString = "\<\>";\)\), "\[IndentingNewLine]", 
    \(For[a = 1, 
      a \[LessEqual] n + 2, \[IndentingNewLine]For[b = 1, 
        b \[LessEqual] n + 2, \[IndentingNewLine]outCString = 
          outCString <> "\<\n coefMat[\>" <> 
            ToString[CForm[\((b - 1)\)\ \((n + 2)\) + a - 1]] <> "\<] = \>" <> 
            ToString[
              CForm[matLHS[\([a, b]\)]\  /. \ 
                  cformVarReplace]] <> "\<;\>"; \[IndentingNewLine]\(b++\)]; \
\[IndentingNewLine]outCString = 
        outCString <> "\<\n rhsVec[\>" <> 
          ToString[CForm[a - 1]] <> "\<] = \>" <> 
          ToString[
            CForm[vecRHS[\([a]\)]\  /. \ 
                cformVarReplace]] <> "\<;\>"; \[IndentingNewLine]\(a++\)]\), \
"\[IndentingNewLine]", 
    \(\(outCString = 
        StringReplace[
          outCString, {"\<Cos\>" \[Rule] "\<cos\>", "\<Sin\>" \[Rule] \
"\<sin\>", "\<Tan\>" \[Rule] "\<tan\>", "\<Power\>" \[Rule] "\<pow\>"}];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[outCString];\)\), "\[IndentingNewLine]", 
    \(\(SetSystemOptions["\<BinaryFormat\>" -> True];\)\), "\n", 
    \(\(BinaryWrite["\<boom10.txt\>", 
        outCString];\)\), "\[IndentingNewLine]", 
    \(\(Close["\<boom10.txt\>"];\)\)}], "Input"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(v \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(v \[LeftDoubleBracket] 13 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(dv \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Part :: \\\"partd\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(M \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(L \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(M \[LeftDoubleBracket] 2 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Part :: \\\"partd\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(m\_1 + m\_2 + m\_3 + m\_4 + m\_5 + m\_6 + m\_7 + m\_8 + m\_9 + 
                m\_10\), 
              "0", \(\(-\(1\/2\)\)\ Sin[\[Theta]\_1[t]]\ m\_1\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_2\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_3\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_4\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_5\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_6\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_7\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_8\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_9\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[
                      t]]\ m\_10\ \[Lambda]\_1\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_2[t]]\ m\_2\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_3\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_4\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_5\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_6\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_7\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_8\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_9\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[
                      t]]\ m\_10\ \[Lambda]\_2\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_3[t]]\ m\_3\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_4\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_5\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_6\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_7\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_8\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_9\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[
                      t]]\ m\_10\ \[Lambda]\_3\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_4[t]]\ m\_4\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[t]]\ m\_5\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[t]]\ m\_6\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[t]]\ m\_7\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[t]]\ m\_8\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[t]]\ m\_9\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[
                      t]]\ m\_10\ \[Lambda]\_4\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_5[t]]\ m\_5\ \[Lambda]\_5 - 
                Sin[\[Theta]\_5[t]]\ m\_6\ \[Lambda]\_5 - 
                Sin[\[Theta]\_5[t]]\ m\_7\ \[Lambda]\_5 - 
                Sin[\[Theta]\_5[t]]\ m\_8\ \[Lambda]\_5 - 
                Sin[\[Theta]\_5[t]]\ m\_9\ \[Lambda]\_5 - 
                Sin[\[Theta]\_5[
                      t]]\ m\_10\ \[Lambda]\_5\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_6[t]]\ m\_6\ \[Lambda]\_6 - 
                Sin[\[Theta]\_6[t]]\ m\_7\ \[Lambda]\_6 - 
                Sin[\[Theta]\_6[t]]\ m\_8\ \[Lambda]\_6 - 
                Sin[\[Theta]\_6[t]]\ m\_9\ \[Lambda]\_6 - 
                Sin[\[Theta]\_6[
                      t]]\ m\_10\ \[Lambda]\_6\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_7[t]]\ m\_7\ \[Lambda]\_7 - 
                Sin[\[Theta]\_7[t]]\ m\_8\ \[Lambda]\_7 - 
                Sin[\[Theta]\_7[t]]\ m\_9\ \[Lambda]\_7 - 
                Sin[\[Theta]\_7[
                      t]]\ m\_10\ \[Lambda]\_7\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_8[t]]\ m\_8\ \[Lambda]\_8 - 
                Sin[\[Theta]\_8[t]]\ m\_9\ \[Lambda]\_8 - 
                Sin[\[Theta]\_8[
                      t]]\ m\_10\ \[Lambda]\_8\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_9[t]]\ m\_9\ \[Lambda]\_9 - 
                Sin[\[Theta]\_9[
                      t]]\ m\_10\ \[Lambda]\_9\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_10[t]]\ m\_10\ \[Lambda]\_10\)},
            {
              "0", \(m\_1 + m\_2 + m\_3 + m\_4 + m\_5 + m\_6 + m\_7 + m\_8 + 
                m\_9 + m\_10\), \(1\/2\ Cos[\[Theta]\_1[
                      t]]\ m\_1\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_2\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_3\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_4\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_5\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_6\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_7\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_8\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_9\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[
                      t]]\ m\_10\ \[Lambda]\_1\), \(1\/2\ Cos[\[Theta]\_2[
                      t]]\ m\_2\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_3\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_4\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_5\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_6\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_7\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_8\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_9\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[
                      t]]\ m\_10\ \[Lambda]\_2\), \(1\/2\ Cos[\[Theta]\_3[
                      t]]\ m\_3\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_4\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_5\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_6\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_7\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_8\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_9\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[
                      t]]\ m\_10\ \[Lambda]\_3\), \(1\/2\ Cos[\[Theta]\_4[
                      t]]\ m\_4\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[t]]\ m\_5\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[t]]\ m\_6\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[t]]\ m\_7\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[t]]\ m\_8\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[t]]\ m\_9\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[
                      t]]\ m\_10\ \[Lambda]\_4\), \(1\/2\ Cos[\[Theta]\_5[
                      t]]\ m\_5\ \[Lambda]\_5 + 
                Cos[\[Theta]\_5[t]]\ m\_6\ \[Lambda]\_5 + 
                Cos[\[Theta]\_5[t]]\ m\_7\ \[Lambda]\_5 + 
                Cos[\[Theta]\_5[t]]\ m\_8\ \[Lambda]\_5 + 
                Cos[\[Theta]\_5[t]]\ m\_9\ \[Lambda]\_5 + 
                Cos[\[Theta]\_5[
                      t]]\ m\_10\ \[Lambda]\_5\), \(1\/2\ Cos[\[Theta]\_6[
                      t]]\ m\_6\ \[Lambda]\_6 + 
                Cos[\[Theta]\_6[t]]\ m\_7\ \[Lambda]\_6 + 
                Cos[\[Theta]\_6[t]]\ m\_8\ \[Lambda]\_6 + 
                Cos[\[Theta]\_6[t]]\ m\_9\ \[Lambda]\_6 + 
                Cos[\[Theta]\_6[
                      t]]\ m\_10\ \[Lambda]\_6\), \(1\/2\ Cos[\[Theta]\_7[
                      t]]\ m\_7\ \[Lambda]\_7 + 
                Cos[\[Theta]\_7[t]]\ m\_8\ \[Lambda]\_7 + 
                Cos[\[Theta]\_7[t]]\ m\_9\ \[Lambda]\_7 + 
                Cos[\[Theta]\_7[
                      t]]\ m\_10\ \[Lambda]\_7\), \(1\/2\ Cos[\[Theta]\_8[
                      t]]\ m\_8\ \[Lambda]\_8 + 
                Cos[\[Theta]\_8[t]]\ m\_9\ \[Lambda]\_8 + 
                Cos[\[Theta]\_8[
                      t]]\ m\_10\ \[Lambda]\_8\), \(1\/2\ Cos[\[Theta]\_9[
                      t]]\ m\_9\ \[Lambda]\_9 + 
                Cos[\[Theta]\_9[
                      t]]\ m\_10\ \[Lambda]\_9\), \(1\/2\ Cos[\[Theta]\_10[
                    t]]\ m\_10\ \[Lambda]\_10\)},
            {\(\(-\(1\/2\)\)\ Sin[\[Theta]\_1[t]]\ m\_1\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_2\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_3\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_4\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_5\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_6\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_7\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_8\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_9\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[
                      t]]\ m\_10\ \[Lambda]\_1\), \(1\/2\ Cos[\[Theta]\_1[
                      t]]\ m\_1\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_2\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_3\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_4\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_5\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_6\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_7\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_8\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_9\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[
                      t]]\ m\_10\ \[Lambda]\_1\), \(1\/12\ m\_1\ \[Lambda]\_1\
\%2 + 1\/2\ m\_1\ \((1\/2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      1\/2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_2\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_3\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\)\), \(1\/2\
\ m\_2\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_3\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\)\), \(1\/2\ \
m\_3\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\)\), \(1\/2\ \
m\_4\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\)\), \(1\/2\ \
m\_5\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\)\), \(1\/2\ \
m\_6\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_1\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_1\ \[Lambda]\_10)\)\)},
            {\(\(-\(1\/2\)\)\ Sin[\[Theta]\_2[t]]\ m\_2\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_3\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_4\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_5\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_6\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_7\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_8\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_9\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[
                      t]]\ m\_10\ \[Lambda]\_2\), \(1\/2\ Cos[\[Theta]\_2[
                      t]]\ m\_2\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_3\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_4\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_5\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_6\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_7\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_8\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_9\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[
                      t]]\ m\_10\ \[Lambda]\_2\), \(1\/2\ m\_2\ \((Cos[\
\[Theta]\_1[t]]\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_3\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\)\), \(1\/12\ \
m\_2\ \[Lambda]\_2\%2 + 
                1\/2\ m\_2\ \((1\/2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 \
+ 1\/2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\) + 
                1\/2\ m\_3\ \((2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 + 
                      2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 + 
                      2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 + 
                      2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 + 
                      2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 + 
                      2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 + 
                      2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 + 
                      2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 + 
                      2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\)\), \(1\/2\
\ m\_3\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\)\), \(1\/2\ \
m\_4\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\)\), \(1\/2\ \
m\_5\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\)\), \(1\/2\ \
m\_6\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_2\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_2\ \[Lambda]\_10)\)\)},
            {\(\(-\(1\/2\)\)\ Sin[\[Theta]\_3[t]]\ m\_3\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_4\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_5\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_6\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_7\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_8\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_9\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[
                      t]]\ m\_10\ \[Lambda]\_3\), \(1\/2\ Cos[\[Theta]\_3[
                      t]]\ m\_3\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_4\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_5\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_6\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_7\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_8\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_9\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[
                      t]]\ m\_10\ \[Lambda]\_3\), \(1\/2\ m\_3\ \((Cos[\
\[Theta]\_1[t]]\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\)\), \(1\/2\ \
m\_3\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\)\), \(1\/12\ \
m\_3\ \[Lambda]\_3\%2 + 
                1\/2\ m\_3\ \((1\/2\ Cos[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2 \
+ 1\/2\ Sin[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2 + 
                      2\ Sin[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2 + 
                      2\ Sin[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2 + 
                      2\ Sin[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2 + 
                      2\ Sin[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2 + 
                      2\ Sin[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2 + 
                      2\ Sin[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2 + 
                      2\ Sin[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2)\)\), \(1\/2\
\ m\_4\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\)\), \(1\/2\ \
m\_5\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\)\), \(1\/2\ \
m\_6\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_3\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_3\ \[Lambda]\_10)\)\)},
            {\(\(-\(1\/2\)\)\ Sin[\[Theta]\_4[t]]\ m\_4\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[t]]\ m\_5\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[t]]\ m\_6\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[t]]\ m\_7\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[t]]\ m\_8\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[t]]\ m\_9\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[
                      t]]\ m\_10\ \[Lambda]\_4\), \(1\/2\ Cos[\[Theta]\_4[
                      t]]\ m\_4\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[t]]\ m\_5\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[t]]\ m\_6\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[t]]\ m\_7\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[t]]\ m\_8\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[t]]\ m\_9\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[
                      t]]\ m\_10\ \[Lambda]\_4\), \(1\/2\ m\_4\ \((Cos[\
\[Theta]\_1[t]]\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\)\), \(1\/2\ \
m\_4\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\)\), \(1\/2\ \
m\_4\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\)\), \(1\/12\ \
m\_4\ \[Lambda]\_4\%2 + 
                1\/2\ m\_4\ \((1\/2\ Cos[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2 \
+ 1\/2\ Sin[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2 + 
                      2\ Sin[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2 + 
                      2\ Sin[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2 + 
                      2\ Sin[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2 + 
                      2\ Sin[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2 + 
                      2\ Sin[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2 + 
                      2\ Sin[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2)\)\), \(1\/2\
\ m\_5\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\)\), \(1\/2\ \
m\_6\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_4\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_4\ \[Lambda]\_10)\)\)},
            {\(\(-\(1\/2\)\)\ Sin[\[Theta]\_5[t]]\ m\_5\ \[Lambda]\_5 - 
                Sin[\[Theta]\_5[t]]\ m\_6\ \[Lambda]\_5 - 
                Sin[\[Theta]\_5[t]]\ m\_7\ \[Lambda]\_5 - 
                Sin[\[Theta]\_5[t]]\ m\_8\ \[Lambda]\_5 - 
                Sin[\[Theta]\_5[t]]\ m\_9\ \[Lambda]\_5 - 
                Sin[\[Theta]\_5[
                      t]]\ m\_10\ \[Lambda]\_5\), \(1\/2\ Cos[\[Theta]\_5[
                      t]]\ m\_5\ \[Lambda]\_5 + 
                Cos[\[Theta]\_5[t]]\ m\_6\ \[Lambda]\_5 + 
                Cos[\[Theta]\_5[t]]\ m\_7\ \[Lambda]\_5 + 
                Cos[\[Theta]\_5[t]]\ m\_8\ \[Lambda]\_5 + 
                Cos[\[Theta]\_5[t]]\ m\_9\ \[Lambda]\_5 + 
                Cos[\[Theta]\_5[
                      t]]\ m\_10\ \[Lambda]\_5\), \(1\/2\ m\_5\ \((Cos[\
\[Theta]\_1[t]]\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\)\), \(1\/2\ \
m\_5\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\)\), \(1\/2\ \
m\_5\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\)\), \(1\/2\ \
m\_5\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\)\), \(1\/12\ \
m\_5\ \[Lambda]\_5\%2 + 
                1\/2\ m\_5\ \((1\/2\ Cos[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2 \
+ 1\/2\ Sin[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2 + 
                      2\ Sin[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2 + 
                      2\ Sin[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2 + 
                      2\ Sin[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2 + 
                      2\ Sin[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2 + 
                      2\ Sin[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2)\)\), \(1\/2\
\ m\_6\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_5\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_5\ \[Lambda]\_10)\)\)},
            {\(\(-\(1\/2\)\)\ Sin[\[Theta]\_6[t]]\ m\_6\ \[Lambda]\_6 - 
                Sin[\[Theta]\_6[t]]\ m\_7\ \[Lambda]\_6 - 
                Sin[\[Theta]\_6[t]]\ m\_8\ \[Lambda]\_6 - 
                Sin[\[Theta]\_6[t]]\ m\_9\ \[Lambda]\_6 - 
                Sin[\[Theta]\_6[
                      t]]\ m\_10\ \[Lambda]\_6\), \(1\/2\ Cos[\[Theta]\_6[
                      t]]\ m\_6\ \[Lambda]\_6 + 
                Cos[\[Theta]\_6[t]]\ m\_7\ \[Lambda]\_6 + 
                Cos[\[Theta]\_6[t]]\ m\_8\ \[Lambda]\_6 + 
                Cos[\[Theta]\_6[t]]\ m\_9\ \[Lambda]\_6 + 
                Cos[\[Theta]\_6[
                      t]]\ m\_10\ \[Lambda]\_6\), \(1\/2\ m\_6\ \((Cos[\
\[Theta]\_1[t]]\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_6\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_6\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_6\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_6\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\)\), \(1\/12\ \
m\_6\ \[Lambda]\_6\%2 + 
                1\/2\ m\_6\ \((1\/2\ Cos[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2 \
+ 1\/2\ Sin[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2 + 
                      2\ Sin[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2 + 
                      2\ Sin[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2 + 
                      2\ Sin[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2 + 
                      2\ Sin[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2)\)\), \(1\/2\
\ m\_7\ \((Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_6\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_6\ \[Lambda]\_10)\)\)},
            {\(\(-\(1\/2\)\)\ Sin[\[Theta]\_7[t]]\ m\_7\ \[Lambda]\_7 - 
                Sin[\[Theta]\_7[t]]\ m\_8\ \[Lambda]\_7 - 
                Sin[\[Theta]\_7[t]]\ m\_9\ \[Lambda]\_7 - 
                Sin[\[Theta]\_7[
                      t]]\ m\_10\ \[Lambda]\_7\), \(1\/2\ Cos[\[Theta]\_7[
                      t]]\ m\_7\ \[Lambda]\_7 + 
                Cos[\[Theta]\_7[t]]\ m\_8\ \[Lambda]\_7 + 
                Cos[\[Theta]\_7[t]]\ m\_9\ \[Lambda]\_7 + 
                Cos[\[Theta]\_7[
                      t]]\ m\_10\ \[Lambda]\_7\), \(1\/2\ m\_7\ \((Cos[\
\[Theta]\_1[t]]\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_1\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7)\)\), \(1\/12\ \
m\_7\ \[Lambda]\_7\%2 + 
                1\/2\ m\_7\ \((1\/2\ Cos[\[Theta]\_7[t]]\^2\ \[Lambda]\_7\%2 \
+ 1\/2\ Sin[\[Theta]\_7[t]]\^2\ \[Lambda]\_7\%2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_7[t]]\^2\ \[Lambda]\_7\%2 + 
                      2\ Sin[\[Theta]\_7[t]]\^2\ \[Lambda]\_7\%2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_7[t]]\^2\ \[Lambda]\_7\%2 + 
                      2\ Sin[\[Theta]\_7[t]]\^2\ \[Lambda]\_7\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_7[t]]\^2\ \[Lambda]\_7\%2 + 
                      2\ Sin[\[Theta]\_7[t]]\^2\ \[Lambda]\_7\%2)\)\), \(1\/2\
\ m\_8\ \((Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_7\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_7\ \[Lambda]\_10)\)\)},
            {\(\(-\(1\/2\)\)\ Sin[\[Theta]\_8[t]]\ m\_8\ \[Lambda]\_8 - 
                Sin[\[Theta]\_8[t]]\ m\_9\ \[Lambda]\_8 - 
                Sin[\[Theta]\_8[
                      t]]\ m\_10\ \[Lambda]\_8\), \(1\/2\ Cos[\[Theta]\_8[
                      t]]\ m\_8\ \[Lambda]\_8 + 
                Cos[\[Theta]\_8[t]]\ m\_9\ \[Lambda]\_8 + 
                Cos[\[Theta]\_8[
                      t]]\ m\_10\ \[Lambda]\_8\), \(1\/2\ m\_8\ \((Cos[\
\[Theta]\_1[t]]\ Cos[\[Theta]\_8[t]]\ \[Lambda]\_1\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8)\)\), \(1\/12\ \
m\_8\ \[Lambda]\_8\%2 + 
                1\/2\ m\_8\ \((1\/2\ Cos[\[Theta]\_8[t]]\^2\ \[Lambda]\_8\%2 \
+ 1\/2\ Sin[\[Theta]\_8[t]]\^2\ \[Lambda]\_8\%2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_8[t]]\^2\ \[Lambda]\_8\%2 + 
                      2\ Sin[\[Theta]\_8[t]]\^2\ \[Lambda]\_8\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_8[t]]\^2\ \[Lambda]\_8\%2 + 
                      2\ Sin[\[Theta]\_8[t]]\^2\ \[Lambda]\_8\%2)\)\), \(1\/2\
\ m\_9\ \((Cos[\[Theta]\_8[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_8\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_8[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_8\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_8[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_8\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_8[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_8\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_8[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_8\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_8[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_8\ \[Lambda]\_10)\)\)},
            {\(\(-\(1\/2\)\)\ Sin[\[Theta]\_9[t]]\ m\_9\ \[Lambda]\_9 - 
                Sin[\[Theta]\_9[
                      t]]\ m\_10\ \[Lambda]\_9\), \(1\/2\ Cos[\[Theta]\_9[
                      t]]\ m\_9\ \[Lambda]\_9 + 
                Cos[\[Theta]\_9[
                      t]]\ m\_10\ \[Lambda]\_9\), \(1\/2\ m\_9\ \((Cos[\
\[Theta]\_1[t]]\ Cos[\[Theta]\_9[t]]\ \[Lambda]\_1\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_9[
                            
                            t]]\ \[Lambda]\_3\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_8[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_8\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_8[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_8\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_8[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_8\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_8[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_8\ \[Lambda]\_9)\)\), \(1\/12\ \
m\_9\ \[Lambda]\_9\%2 + 
                1\/2\ m\_9\ \((1\/2\ Cos[\[Theta]\_9[t]]\^2\ \[Lambda]\_9\%2 \
+ 1\/2\ Sin[\[Theta]\_9[t]]\^2\ \[Lambda]\_9\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_9[t]]\^2\ \[Lambda]\_9\%2 + 
                      
                      2\ Sin[\[Theta]\_9[t]]\^2\ \[Lambda]\_9\%2)\)\), \(1\/2\
\ m\_10\ \((Cos[\[Theta]\_9[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_9\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_9[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_9\ \[Lambda]\_10)\)\)},
            {\(\(-\(1\/2\)\)\ Sin[\[Theta]\_10[
                    t]]\ m\_10\ \[Lambda]\_10\), \(1\/2\ Cos[\[Theta]\_10[
                    t]]\ m\_10\ \[Lambda]\_10\), \(1\/2\ m\_10\ \((Cos[\
\[Theta]\_1[t]]\ Cos[\[Theta]\_10[t]]\ \[Lambda]\_1\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_1\ \[Lambda]\_10)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_2\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_2\ \[Lambda]\_10)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_3\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_3\ \[Lambda]\_10)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_4\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_4\ \[Lambda]\_10)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_5\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_5\ \[Lambda]\_10)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_6\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_6\ \[Lambda]\_10)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_7\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_7\ \[Lambda]\_10)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_8[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_8\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_8[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_8\ \[Lambda]\_10)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_9[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_9\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_9[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_9\ \[Lambda]\_10)\)\), \(1\/12\ \
m\_10\ \[Lambda]\_10\%2 + 
                1\/2\ m\_10\ \((1\/2\ Cos[\[Theta]\_10[t]]\^2\ \
\[Lambda]\_10\%2 + 1\/2\ Sin[\[Theta]\_10[t]]\^2\ \[Lambda]\_10\%2)\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", 
        TagBox[GridBox[{
              {\(\(-Sin[\[Theta]\_1[t]]\^2\)\ c\_S\ \[Lambda]\_1\ dx\_L[t] - 
                  Cos[\[Theta]\_1[t]]\^2\ c\_V\ \[Lambda]\_1\ dx\_L[t] - 
                  Sin[\[Theta]\_2[t]]\^2\ c\_S\ \[Lambda]\_2\ dx\_L[t] - 
                  Cos[\[Theta]\_2[t]]\^2\ c\_V\ \[Lambda]\_2\ dx\_L[t] - 
                  Sin[\[Theta]\_3[t]]\^2\ c\_S\ \[Lambda]\_3\ dx\_L[t] - 
                  Cos[\[Theta]\_3[t]]\^2\ c\_V\ \[Lambda]\_3\ dx\_L[t] - 
                  Sin[\[Theta]\_4[t]]\^2\ c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                  Cos[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ dx\_L[t] + 
                  Cos[\[Theta]\_1[t]]\ Sin[\[Theta]\_1[
                        t]]\ c\_S\ \[Lambda]\_1\ dy\_L[t] - 
                  Cos[\[Theta]\_1[t]]\ Sin[\[Theta]\_1[
                        t]]\ c\_V\ \[Lambda]\_1\ dy\_L[t] + 
                  Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                        t]]\ c\_S\ \[Lambda]\_2\ dy\_L[t] - 
                  Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                        t]]\ c\_V\ \[Lambda]\_2\ dy\_L[t] + 
                  Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                        t]]\ c\_S\ \[Lambda]\_3\ dy\_L[t] - 
                  Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                        t]]\ c\_V\ \[Lambda]\_3\ dy\_L[t] + 
                  Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_4\ dy\_L[t] - 
                  Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_V\ \[Lambda]\_4\ dy\_L[t] + 
                  1\/2\ Sin[\[Theta]\_1[
                        t]]\ c\_S\ \[Lambda]\_1\%2\ d\[Theta]\_1[t] + 
                  Cos[\[Theta]\_1[t] - \[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                        t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_2\ d\[Theta]\_1[
                      t] + Cos[\[Theta]\_2[
                        t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_2[
                          t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_2\ d\[Theta]\_1[
                      t] + Cos[\[Theta]\_1[t] - \[Theta]\_3[
                          t]]\ Sin[\[Theta]\_3[
                        t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_3\ d\[Theta]\_1[
                      t] + Cos[\[Theta]\_3[
                        t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_3[
                          t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_3\ d\[Theta]\_1[
                      t] + Cos[\[Theta]\_1[t] - \[Theta]\_4[
                          t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ d\[Theta]\_1[
                      t] + Cos[\[Theta]\_4[
                        t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_4[
                          t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ d\[Theta]\_1[
                      t] + 1\/2\ Cos[\[Theta]\_1[
                        t]]\ m\_1\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 + 
                  1\/2\ Sin[\[Theta]\_2[
                        t]]\ c\_S\ \[Lambda]\_2\%2\ d\[Theta]\_2[t] + 
                  Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                        t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_3\ d\[Theta]\_2[
                      t] + Cos[\[Theta]\_3[
                        t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_3[
                          t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_3\ d\[Theta]\_2[
                      t] + Cos[\[Theta]\_2[t] - \[Theta]\_4[
                          t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ d\[Theta]\_2[
                      t] + Cos[\[Theta]\_4[
                        t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                          t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ d\[Theta]\_2[
                      t] - m\_2\ \((\(-Cos[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2)\) + 
                  1\/2\ Sin[\[Theta]\_3[
                        t]]\ c\_S\ \[Lambda]\_3\%2\ d\[Theta]\_3[t] + 
                  Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ d\[Theta]\_3[
                      t] + Cos[\[Theta]\_4[
                        t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                          t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ d\[Theta]\_3[
                      t] - m\_3\ \((\(-Cos[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\) + 
                  1\/2\ Sin[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[t] - 
                  m\_4\ \((\(-Cos[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\) - 
                  m\_5\ \((\(-Cos[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Cos[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\) + 
                  1\/2\ \[Lambda]\_5\ \((2\ Cos[\[Theta]\_5[
                              t]]\ c\_V\ \((\(-Cos[\[Theta]\_5[t]]\)\ dx\_L[
                                  t] - Sin[\[Theta]\_5[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Sin[\[Theta]\_5[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_5[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - \[Lambda]\_5\ d\[Theta]\_5[t])\))\) - 
                  Cos[\[Theta]\_7[
                        t]]\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                              t]]\ dx\_L[t] + Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                  m\_6\ \((\(-Cos[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Cos[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Cos[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\) + 
                  1\/2\ \[Lambda]\_6\ \((2\ Cos[\[Theta]\_6[
                              t]]\ c\_V\ \((\(-Cos[\[Theta]\_6[t]]\)\ dx\_L[
                                  t] - Sin[\[Theta]\_6[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Sin[\[Theta]\_6[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_6[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - \[Lambda]\_6\ d\[Theta]\_6[t])\))\) - 
                  1\/2\ Sin[\[Theta]\_7[
                        t]]\ c\_S\ \[Lambda]\_7\ \((2\ Sin[\[Theta]\_7[
                              t]]\ dx\_L[t] - 
                        2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] - 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t] - \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                  Cos[\[Theta]\_8[
                        t]]\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                              t]]\ dx\_L[t] + Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                  m\_7\ \((\(-Cos[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Cos[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Cos[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        Cos[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) - 
                  1\/2\ Sin[\[Theta]\_8[
                        t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                              t]]\ dx\_L[t] - 
                        2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t] - \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                  Cos[\[Theta]\_9[
                        t]]\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                              t]]\ dx\_L[t] + Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                        Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                  m\_8\ \((\(-Cos[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Cos[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Cos[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        Cos[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                        Cos[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) - 
                  1\/2\ Sin[\[Theta]\_9[
                        t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                              t]]\ dx\_L[t] - 
                        2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                        2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t] - \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                  Cos[\[Theta]\_10[
                        t]]\ c\_V\ \[Lambda]\_10\ \((Cos[\[Theta]\_10[
                              t]]\ dx\_L[t] + 
                        Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                        Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                        Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                  m\_9\ \((\(-Cos[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Cos[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Cos[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        Cos[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                        Cos[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                        Cos[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) - 
                  1\/2\ Sin[\[Theta]\_10[
                        t]]\ c\_S\ \[Lambda]\_10\ \((2\ Sin[\[Theta]\_10[
                              t]]\ dx\_L[t] - 
                        2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                        2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                        2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                            t] - \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                  m\_10\ \((\(-Cos[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Cos[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Cos[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        Cos[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                        Cos[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                        Cos[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                        Cos[\[Theta]\_9[
                              t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ \[Lambda]\_10\ d\[Theta]\_10[t]\^2)\) + 
                  f\_LX[t] + f\_RX[t]\)},
              {\(Cos[\[Theta]\_1[t]]\ Sin[\[Theta]\_1[
                        t]]\ c\_S\ \[Lambda]\_1\ dx\_L[t] - 
                  Cos[\[Theta]\_1[t]]\ Sin[\[Theta]\_1[
                        t]]\ c\_V\ \[Lambda]\_1\ dx\_L[t] + 
                  Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                        t]]\ c\_S\ \[Lambda]\_2\ dx\_L[t] - 
                  Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                        t]]\ c\_V\ \[Lambda]\_2\ dx\_L[t] + 
                  Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                        t]]\ c\_S\ \[Lambda]\_3\ dx\_L[t] - 
                  Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                        t]]\ c\_V\ \[Lambda]\_3\ dx\_L[t] + 
                  Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                  Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_V\ \[Lambda]\_4\ dx\_L[t] - 
                  Cos[\[Theta]\_1[t]]\^2\ c\_S\ \[Lambda]\_1\ dy\_L[t] - 
                  Sin[\[Theta]\_1[t]]\^2\ c\_V\ \[Lambda]\_1\ dy\_L[t] - 
                  Cos[\[Theta]\_2[t]]\^2\ c\_S\ \[Lambda]\_2\ dy\_L[t] - 
                  Sin[\[Theta]\_2[t]]\^2\ c\_V\ \[Lambda]\_2\ dy\_L[t] - 
                  Cos[\[Theta]\_3[t]]\^2\ c\_S\ \[Lambda]\_3\ dy\_L[t] - 
                  Sin[\[Theta]\_3[t]]\^2\ c\_V\ \[Lambda]\_3\ dy\_L[t] - 
                  Cos[\[Theta]\_4[t]]\^2\ c\_S\ \[Lambda]\_4\ dy\_L[t] - 
                  Sin[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ dy\_L[t] - 
                  1\/2\ Cos[\[Theta]\_1[
                        t]]\ c\_S\ \[Lambda]\_1\%2\ d\[Theta]\_1[t] - 
                  Cos[\[Theta]\_1[t] - \[Theta]\_2[t]]\ Cos[\[Theta]\_2[
                        t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_2\ d\[Theta]\_1[
                      t] + Sin[\[Theta]\_1[t] - \[Theta]\_2[
                          t]]\ Sin[\[Theta]\_2[
                        t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_2\ d\[Theta]\_1[
                      t] - Cos[\[Theta]\_1[t] - \[Theta]\_3[
                          t]]\ Cos[\[Theta]\_3[
                        t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_3\ d\[Theta]\_1[
                      t] + Sin[\[Theta]\_1[t] - \[Theta]\_3[
                          t]]\ Sin[\[Theta]\_3[
                        t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_3\ d\[Theta]\_1[
                      t] - Cos[\[Theta]\_1[t] - \[Theta]\_4[
                          t]]\ Cos[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ d\[Theta]\_1[
                      t] + Sin[\[Theta]\_1[t] - \[Theta]\_4[
                          t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ d\[Theta]\_1[
                      t] + 
                  1\/2\ Sin[\[Theta]\_1[
                        t]]\ m\_1\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                  1\/2\ Cos[\[Theta]\_2[
                        t]]\ c\_S\ \[Lambda]\_2\%2\ d\[Theta]\_2[t] - 
                  Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Cos[\[Theta]\_3[
                        t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_3\ d\[Theta]\_2[
                      t] + Sin[\[Theta]\_2[t] - \[Theta]\_3[
                          t]]\ Sin[\[Theta]\_3[
                        t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_3\ d\[Theta]\_2[
                      t] - Cos[\[Theta]\_2[t] - \[Theta]\_4[
                          t]]\ Cos[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ d\[Theta]\_2[
                      t] + Sin[\[Theta]\_2[t] - \[Theta]\_4[
                          t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ d\[Theta]\_2[
                      t] - m\_2\ \((\(-Sin[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2)\) - 
                  1\/2\ Cos[\[Theta]\_3[
                        t]]\ c\_S\ \[Lambda]\_3\%2\ d\[Theta]\_3[t] - 
                  Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ d\[Theta]\_3[
                      t] + Sin[\[Theta]\_3[t] - \[Theta]\_4[
                          t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ d\[Theta]\_3[
                      t] - m\_3\ \((\(-Sin[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\) - 
                  1\/2\ Cos[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[t] - 
                  m\_4\ \((\(-Sin[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\) - 
                  Sin[\[Theta]\_6[
                        t]]\ c\_V\ \[Lambda]\_6\ \((Cos[\[Theta]\_6[
                              t]]\ dx\_L[t] + Sin[\[Theta]\_6[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                  m\_5\ \((\(-Sin[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\) - 
                  1\/2\ \[Lambda]\_5\ \((2\ Sin[\[Theta]\_5[
                              t]]\ c\_V\ \((Cos[\[Theta]\_5[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) + 
                        Cos[\[Theta]\_5[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_5[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + \[Lambda]\_5\ d\[Theta]\_5[t])\))\) - 
                  1\/2\ Cos[\[Theta]\_6[
                        t]]\ c\_S\ \[Lambda]\_6\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ dx\_L[t] + 
                        2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] + 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t] + \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                  Sin[\[Theta]\_7[
                        t]]\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                              t]]\ dx\_L[t] + Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                  m\_6\ \((\(-Sin[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\) - 
                  1\/2\ Cos[\[Theta]\_7[
                        t]]\ c\_S\ \[Lambda]\_7\ \((\(-2\)\ Sin[\[Theta]\_7[
                              t]]\ dx\_L[t] + 
                        2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] + 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                        2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t] + \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                  Sin[\[Theta]\_8[
                        t]]\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                              t]]\ dx\_L[t] + Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                  m\_7\ \((\(-Sin[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) - 
                  1\/2\ Cos[\[Theta]\_8[
                        t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ Sin[\[Theta]\_8[
                              t]]\ dx\_L[t] + 
                        2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                        2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                        2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t] + \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                  Sin[\[Theta]\_9[
                        t]]\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                              t]]\ dx\_L[t] + Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                        Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                  m\_8\ \((\(-Sin[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                        Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) - 
                  1\/2\ Cos[\[Theta]\_9[
                        t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ Sin[\[Theta]\_9[
                              t]]\ dx\_L[t] + 
                        2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                        2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                        2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                        2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t] + \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                  Sin[\[Theta]\_10[
                        t]]\ c\_V\ \[Lambda]\_10\ \((Cos[\[Theta]\_10[
                              t]]\ dx\_L[t] + 
                        Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                        Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                        Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                  m\_9\ \((\(-Sin[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                        Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                        Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) - 
                  1\/2\ Cos[\[Theta]\_10[
                        t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\[Theta]\_10[
                              t]]\ dx\_L[t] + 
                        2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                        2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                        2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                        2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                        2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                            t] + \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                  m\_10\ \((\(-Sin[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                        Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                        Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                        Sin[\[Theta]\_9[
                              t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ \[Lambda]\_10\ d\[Theta]\_10[t]\^2)\) + 
                  f\_LY[t] + f\_RY[t]\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_1\%3\ d\[Theta]\_1[t] + 
                  1\/2\ Cos[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((Cos[\[Theta]\_1[
                              t]]\ Sin[\[Theta]\_1[
                              t]]\ c\_S\ \[Lambda]\_1\ dx\_L[t] - 
                        Cos[\[Theta]\_1[t]]\ Sin[\[Theta]\_1[
                              t]]\ c\_V\ \[Lambda]\_1\ dx\_L[t] - 
                        Cos[\[Theta]\_1[t]]\^2\ c\_S\ \[Lambda]\_1\ dy\_L[
                            t] - Sin[\[Theta]\_1[t]]\^2\ c\_V\ \[Lambda]\_1\ \
dy\_L[t] - 1\/2\ Cos[\[Theta]\_1[t]]\ c\_S\ \[Lambda]\_1\%2\ d\[Theta]\_1[
                            t])\) - 
                  1\/2\ Sin[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_1[t]]\^2\)\ \
c\_S\ \[Lambda]\_1\ dx\_L[t] - 
                        Cos[\[Theta]\_1[t]]\^2\ c\_V\ \[Lambda]\_1\ dx\_L[
                            t] + Cos[\[Theta]\_1[t]]\ Sin[\[Theta]\_1[
                              t]]\ c\_S\ \[Lambda]\_1\ dy\_L[t] - 
                        Cos[\[Theta]\_1[t]]\ Sin[\[Theta]\_1[
                              t]]\ c\_V\ \[Lambda]\_1\ dy\_L[t] + 
                        1\/2\ Sin[\[Theta]\_1[
                              t]]\ c\_S\ \[Lambda]\_1\%2\ d\[Theta]\_1[
                            t])\) + 
                  Cos[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((Cos[\[Theta]\_2[
                              t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_2\ dx\_L[t] - 
                        Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_V\ \[Lambda]\_2\ dx\_L[t] - 
                        Cos[\[Theta]\_2[t]]\^2\ c\_S\ \[Lambda]\_2\ dy\_L[
                            t] - Sin[\[Theta]\_2[t]]\^2\ c\_V\ \[Lambda]\_2\ \
dy\_L[t] - Cos[\[Theta]\_1[t] - \[Theta]\_2[t]]\ Cos[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_2\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_2\ \
d\[Theta]\_1[t] - 1\/2\ Cos[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_2\%2\ d\[Theta]\_2[
                            t])\) - 
                  Sin[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_2[t]]\^2\)\ \
c\_S\ \[Lambda]\_2\ dx\_L[t] - 
                        Cos[\[Theta]\_2[t]]\^2\ c\_V\ \[Lambda]\_2\ dx\_L[
                            t] + Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_2\ dy\_L[t] - 
                        Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_V\ \[Lambda]\_2\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_2\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_2[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_2[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_2\ d\
\[Theta]\_1[t] + 1\/2\ Sin[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_2\%2\ d\[Theta]\_2[
                            t])\) + 
                  1\/2\ m\_2\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + 1\/2\ Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - 1\/2\ Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                  t])\))\) - 
                  1\/2\ m\_2\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + 1\/2\ Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - 1\/2\ Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t])\) - 
                        2\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- 1\/2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2)\) + 
                        2\ Cos[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- 1\/2\ Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2)\))\) + 
                  Cos[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\^2\ c\_S\ \[Lambda]\_3\ dy\_L[
                            t] - Sin[\[Theta]\_3[t]]\^2\ c\_V\ \[Lambda]\_3\ \
dy\_L[t] - Cos[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] - Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] + Sin[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] - 1\/2\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\%2\ d\[Theta]\_3[
                            t])\) - 
                  Sin[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_3[t]]\^2\)\ \
c\_S\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\^2\ c\_V\ \[Lambda]\_3\ dx\_L[
                            t] + Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\ dy\_L[t] - 
                        Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_3\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_3\ d\
\[Theta]\_1[t] + Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] + Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_3[
                                t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_3\ d\
\[Theta]\_2[t] + 1\/2\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\%2\ d\[Theta]\_3[
                            t])\) + 
                  1\/2\ m\_3\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t])\))\) - 
                  1\/2\ m\_3\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        2\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\) \
+ 2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\))\
\) + Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\^2\ c\_S\ \[Lambda]\_4\ dy\_L[
                            t] - Sin[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ \
dy\_L[t] - Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] - Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] + Sin[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] - Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] + Sin[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] - 1\/2\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[
                            t])\) - 
                  Sin[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_4[t]]\^2\)\ \
c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ dx\_L[
                            t] + Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\ dy\_L[t] - 
                        Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_4\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ d\
\[Theta]\_1[t] + Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ d\
\[Theta]\_2[t] + Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ d\
\[Theta]\_3[t] + 1\/2\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[
                            t])\) + 
                  1\/2\ m\_4\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t])\))\) - 
                  1\/2\ m\_4\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\) \
+ 2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \[Lambda]\_5\ \((2\ \
Cos[\[Theta]\_5[t]]\ c\_V\ \((\(-Cos[\[Theta]\_5[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Sin[\[Theta]\_5[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_5[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - \[Lambda]\_5\ d\[Theta]\_5[t])\))\) - 
                  1\/2\ Cos[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \[Lambda]\_5\ \((2\ \
Sin[\[Theta]\_5[t]]\ c\_V\ \((Cos[\[Theta]\_5[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) + 
                        Cos[\[Theta]\_5[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_5[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + \[Lambda]\_5\ d\[Theta]\_5[t])\))\) + 
                  1\/2\ m\_5\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t])\))\) - 
                  1\/2\ m\_5\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\) \
+ 2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \[Lambda]\_6\ \((2\ \
Cos[\[Theta]\_6[t]]\ c\_V\ \((\(-Cos[\[Theta]\_6[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Sin[\[Theta]\_6[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_6[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  Cos[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_6[
                                t]]\)\ c\_V\ \[Lambda]\_6\ \((Cos[\[Theta]\_6[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        1\/2\ Cos[\[Theta]\_6[
                              t]]\ c\_S\ \[Lambda]\_6\ \((\(-2\)\ \
Sin[\[Theta]\_6[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 
                              1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t])\))\) - 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\) \
+ 2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\))\
\) - Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Sin[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((2\ Sin[\[Theta]\_7[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  Cos[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Cos[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((\(-2\)\ \
Sin[\[Theta]\_7[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t])\))\) - 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 
                              Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - 1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) \
+ 2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\))\
\) - Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  Cos[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ \
Sin[\[Theta]\_8[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t])\))\) - 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) \
+ 2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\))\
\) - Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  Cos[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 
                              Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + 1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ 2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        2\ Cos[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\) - Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ f\_RX[t] + 
                  Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ f\_RY[t] + \[Tau]\_L[
                    t]\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_2\%3\ d\[Theta]\_2[t] + 
                  1\/2\ Cos[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((Cos[\[Theta]\_2[
                              t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_2\ dx\_L[t] - 
                        Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_V\ \[Lambda]\_2\ dx\_L[t] - 
                        Cos[\[Theta]\_2[t]]\^2\ c\_S\ \[Lambda]\_2\ dy\_L[
                            t] - 
                        Sin[\[Theta]\_2[t]]\^2\ c\_V\ \[Lambda]\_2\ dy\_L[
                            t] - Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                t]]\ Cos[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_2\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_2\ \
d\[Theta]\_1[t] - 1\/2\ Cos[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_2\%2\ d\[Theta]\_2[
                            t])\) - 
                  1\/2\ Sin[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_2[t]]\^2\)\ \
c\_S\ \[Lambda]\_2\ dx\_L[t] - 
                        Cos[\[Theta]\_2[t]]\^2\ c\_V\ \[Lambda]\_2\ dx\_L[
                            t] + Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_2\ dy\_L[t] - 
                        Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_V\ \[Lambda]\_2\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_2\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_2[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_2[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_2\ d\
\[Theta]\_1[t] + 1\/2\ Sin[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_2\%2\ d\[Theta]\_2[
                            t])\) + 
                  1\/2\ m\_2\ \((\(-Sin[\[Theta]\_2[
                                t]]\)\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + 1\/2\ Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t])\) - 
                        Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - 1\/2\ Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                  t])\))\) - 
                  1\/2\ m\_2\ \((\(-Sin[\[Theta]\_2[
                                t]]\)\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + 1\/2\ Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t])\) - 
                        Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - 1\/2\ Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t])\) - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- 1\/2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2)\) + 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- 1\/2\ Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2)\))\) + 
                  Cos[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\^2\ c\_S\ \[Lambda]\_3\ dy\_L[
                            t] - Sin[\[Theta]\_3[t]]\^2\ c\_V\ \[Lambda]\_3\ \
dy\_L[t] - Cos[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] - Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] + Sin[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] - 1\/2\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\%2\ d\[Theta]\_3[
                            t])\) - 
                  Sin[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_3[t]]\^2\)\ \
c\_S\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\^2\ c\_V\ \[Lambda]\_3\ dx\_L[
                            t] + Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\ dy\_L[t] - 
                        Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_3\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_3\ d\
\[Theta]\_1[t] + Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] + Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_3[
                                t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_3\ d\
\[Theta]\_2[t] + 1\/2\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\%2\ d\[Theta]\_3[
                            t])\) + 
                  1\/2\ m\_3\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t])\))\) - 
                  1\/2\ m\_3\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        2\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\) \
+ 2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\))\
\) + Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\^2\ c\_S\ \[Lambda]\_4\ dy\_L[
                            t] - Sin[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ \
dy\_L[t] - Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] - Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] + Sin[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] - Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] + Sin[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] - 1\/2\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[
                            t])\) - 
                  Sin[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_4[t]]\^2\)\ \
c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ dx\_L[
                            t] + Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\ dy\_L[t] - 
                        Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_4\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ d\
\[Theta]\_1[t] + Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ d\
\[Theta]\_2[t] + Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ d\
\[Theta]\_3[t] + 1\/2\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[
                            t])\) + 
                  1\/2\ m\_4\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t])\))\) - 
                  1\/2\ m\_4\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\) \
+ 2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \[Lambda]\_5\ \((2\ \
Cos[\[Theta]\_5[t]]\ c\_V\ \((\(-Cos[\[Theta]\_5[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Sin[\[Theta]\_5[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_5[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - \[Lambda]\_5\ d\[Theta]\_5[t])\))\) - 
                  1\/2\ Cos[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \[Lambda]\_5\ \((2\ \
Sin[\[Theta]\_5[t]]\ c\_V\ \((Cos[\[Theta]\_5[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) + 
                        Cos[\[Theta]\_5[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_5[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + \[Lambda]\_5\ d\[Theta]\_5[t])\))\) + 
                  1\/2\ m\_5\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 
                              Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - 1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t])\))\) - 
                  1\/2\ m\_5\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\) \
+ 2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \[Lambda]\_6\ \((2\ \
Cos[\[Theta]\_6[t]]\ c\_V\ \((\(-Cos[\[Theta]\_6[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Sin[\[Theta]\_6[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_6[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  Cos[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_6[
                                t]]\)\ c\_V\ \[Lambda]\_6\ \((Cos[\[Theta]\_6[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        1\/2\ Cos[\[Theta]\_6[
                              t]]\ c\_S\ \[Lambda]\_6\ \((\(-2\)\ \
Sin[\[Theta]\_6[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t])\))\) - 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\) \
+ 2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\))\
\) - Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Sin[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((2\ Sin[\[Theta]\_7[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  Cos[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Cos[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((\(-2\)\ \
Sin[\[Theta]\_7[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t])\))\) - 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) \
+ 2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\))\
\) - Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  Cos[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Cos[\[Theta]\_8[
                              
                              t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ \
Sin[\[Theta]\_8[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t])\))\) - 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) \
+ 2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\))\
\) - Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  Cos[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ 2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 
                              Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t] + 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        2\ Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\) - Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ f\_RX[t] + 
                  Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ f\_RY[t]\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_3\%3\ d\[Theta]\_3[t] + 
                  1\/2\ Cos[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \((Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\^2\ c\_S\ \[Lambda]\_3\ dy\_L[
                            t] - Sin[\[Theta]\_3[t]]\^2\ c\_V\ \[Lambda]\_3\ \
dy\_L[t] - Cos[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] - Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] + Sin[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] - 1\/2\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\%2\ d\[Theta]\_3[
                            t])\) - 
                  1\/2\ Sin[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_3[t]]\^2\)\ \
c\_S\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\^2\ c\_V\ \[Lambda]\_3\ dx\_L[
                            t] + Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\ dy\_L[t] - 
                        Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_3\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_3\ d\
\[Theta]\_1[t] + Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] + Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_3[
                                t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_3\ d\
\[Theta]\_2[t] + 1\/2\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\%2\ d\[Theta]\_3[
                            t])\) + 
                  1\/2\ m\_3\ \((\(-Sin[\[Theta]\_3[
                                t]]\)\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t])\))\) - 
                  1\/2\ m\_3\ \((\(-Sin[\[Theta]\_3[
                                t]]\)\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\) \
+ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\))\
\) + Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\^2\ c\_S\ \[Lambda]\_4\ dy\_L[
                            t] - Sin[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ \
dy\_L[t] - Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] - Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] + Sin[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] - Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] + Sin[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] - 1\/2\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[
                            t])\) - 
                  Sin[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_4[t]]\^2\)\ \
c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ dx\_L[
                            t] + Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\ dy\_L[t] - 
                        Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_4\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ d\
\[Theta]\_1[t] + Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ d\
\[Theta]\_2[t] + Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ d\
\[Theta]\_3[t] + 1\/2\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[
                            t])\) + 
                  1\/2\ m\_4\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 
                              1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t])\))\) - 
                  1\/2\ m\_4\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\) \
+ 2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \[Lambda]\_5\ \((2\ \
Cos[\[Theta]\_5[t]]\ c\_V\ \((\(-Cos[\[Theta]\_5[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Sin[\[Theta]\_5[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_5[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - \[Lambda]\_5\ d\[Theta]\_5[t])\))\) - 
                  1\/2\ Cos[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \[Lambda]\_5\ \((2\ \
Sin[\[Theta]\_5[t]]\ c\_V\ \((Cos[\[Theta]\_5[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) + 
                        Cos[\[Theta]\_5[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_5[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + \[Lambda]\_5\ d\[Theta]\_5[t])\))\) + 
                  1\/2\ m\_5\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t])\))\) - 
                  1\/2\ m\_5\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\) \
+ 2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \[Lambda]\_6\ \((2\ \
Cos[\[Theta]\_6[t]]\ c\_V\ \((\(-Cos[\[Theta]\_6[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Sin[\[Theta]\_6[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_6[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  Cos[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_6[
                                t]]\)\ c\_V\ \[Lambda]\_6\ \((Cos[\[Theta]\_6[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        1\/2\ Cos[\[Theta]\_6[
                              t]]\ c\_S\ \[Lambda]\_6\ \((\(-2\)\ \
Sin[\[Theta]\_6[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t])\))\) - 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\) \
+ 2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\))\
\) - Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((\(-Cos[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Sin[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((2\ Sin[\[Theta]\_7[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  Cos[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Cos[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((\(-2\)\ \
Sin[\[Theta]\_7[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t])\))\) - 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) \
+ 2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\))\
\) - Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((\(-Cos[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  Cos[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ \
Sin[\[Theta]\_8[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t])\))\) - 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) \
+ 2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\))\
\) - Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  Cos[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ 2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        2\ Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\) - Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ f\_RX[t] + 
                  Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ f\_RY[t]\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_4\%3\ d\[Theta]\_4[t] + 
                  1\/2\ Cos[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \((Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\^2\ c\_S\ \[Lambda]\_4\ dy\_L[
                            t] - Sin[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ \
dy\_L[t] - Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] - Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] + Sin[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] - Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] + Sin[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] - 1\/2\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[
                            t])\) - 
                  1\/2\ Sin[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_4[t]]\^2\)\ \
c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ dx\_L[
                            t] + Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\ dy\_L[t] - 
                        Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_4\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ d\
\[Theta]\_1[t] + Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ d\
\[Theta]\_2[t] + Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ d\
\[Theta]\_3[t] + 1\/2\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[
                            t])\) + 
                  1\/2\ m\_4\ \((\(-Sin[\[Theta]\_4[
                                t]]\)\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t])\))\) - 
                  1\/2\ m\_4\ \((\(-Sin[\[Theta]\_4[
                                t]]\)\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\) \
+ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \[Lambda]\_5\ \((2\ \
Cos[\[Theta]\_5[t]]\ c\_V\ \((\(-Cos[\[Theta]\_5[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Sin[\[Theta]\_5[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_5[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - \[Lambda]\_5\ d\[Theta]\_5[t])\))\) - 
                  1\/2\ Cos[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \[Lambda]\_5\ \((2\ \
Sin[\[Theta]\_5[t]]\ c\_V\ \((Cos[\[Theta]\_5[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) + 
                        Cos[\[Theta]\_5[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_5[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + \[Lambda]\_5\ d\[Theta]\_5[t])\))\) + 
                  1\/2\ m\_5\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t])\))\) - 
                  1\/2\ m\_5\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\) \
+ 2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \[Lambda]\_6\ \((2\ \
Cos[\[Theta]\_6[t]]\ c\_V\ \((\(-Cos[\[Theta]\_6[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Sin[\[Theta]\_6[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_6[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  Cos[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_6[
                                t]]\)\ c\_V\ \[Lambda]\_6\ \((Cos[\[Theta]\_6[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        1\/2\ Cos[\[Theta]\_6[
                              t]]\ c\_S\ \[Lambda]\_6\ \((\(-2\)\ \
Sin[\[Theta]\_6[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t])\))\) - 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 
                              Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\) \
+ 2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\))\
\) - Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((\(-Cos[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Sin[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((2\ Sin[\[Theta]\_7[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  Cos[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Cos[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((\(-2\)\ \
Sin[\[Theta]\_7[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t])\))\) - 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ \((\(-Cos[\[Theta]\_1[
                                      
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) \
+ 2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\))\
\) - Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((\(-Cos[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  Cos[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ \
Sin[\[Theta]\_8[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 
                              Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t])\))\) - 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ \((\(-Cos[\[Theta]\_1[
                                      
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) \
+ 2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\))\
\) - Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  Cos[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ 2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ \((\(-Cos[\[Theta]\_1[
                                      
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        2\ Cos[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\) - Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ f\_RX[t] + 
                  Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ f\_RY[t]\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_5\%3\ d\[Theta]\_5[t] - 
                  1\/4\ Sin[\[Theta]\_5[
                        t]]\ \[Lambda]\_5\%2\ \((2\ Cos[\[Theta]\_5[
                              t]]\ c\_V\ \((\(-Cos[\[Theta]\_5[t]]\)\ dx\_L[
                                  t] - Sin[\[Theta]\_5[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Sin[\[Theta]\_5[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_5[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - \[Lambda]\_5\ d\[Theta]\_5[t])\))\) - 
                  1\/4\ Cos[\[Theta]\_5[
                        t]]\ \[Lambda]\_5\%2\ \((2\ Sin[\[Theta]\_5[
                              t]]\ c\_V\ \((Cos[\[Theta]\_5[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) + 
                        Cos[\[Theta]\_5[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_5[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + \[Lambda]\_5\ d\[Theta]\_5[t])\))\) + 
                  1\/2\ m\_5\ \((\(-Sin[\[Theta]\_5[
                                t]]\)\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t])\))\) - 
                  1\/2\ m\_5\ \((\(-Sin[\[Theta]\_5[
                                t]]\)\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\) \
+ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_5[
                        t]]\ \[Lambda]\_5\ \[Lambda]\_6\ \((2\ \
Cos[\[Theta]\_6[t]]\ c\_V\ \((\(-Cos[\[Theta]\_6[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Sin[\[Theta]\_6[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_6[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  Cos[\[Theta]\_5[
                        t]]\ \[Lambda]\_5\ \((\(-Sin[\[Theta]\_6[
                                t]]\)\ c\_V\ \[Lambda]\_6\ \((Cos[\[Theta]\_6[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        1\/2\ Cos[\[Theta]\_6[
                              t]]\ c\_S\ \[Lambda]\_6\ \((\(-2\)\ \
Sin[\[Theta]\_6[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 
                              1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t])\))\) - 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\) \
+ 2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\))\
\) - Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((\(-Cos[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Sin[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((2\ Sin[\[Theta]\_7[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  Cos[\[Theta]\_5[
                        t]]\ \[Lambda]\_5\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Cos[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((\(-2\)\ \
Sin[\[Theta]\_7[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t])\))\) - 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) \
+ 2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\))\
\) - Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((\(-Cos[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  Cos[\[Theta]\_5[
                        t]]\ \[Lambda]\_5\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ \
Sin[\[Theta]\_8[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t])\))\) - 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) \
+ 2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\))\
\) - Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  Cos[\[Theta]\_5[
                        t]]\ \[Lambda]\_5\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ 2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_5[
                        t]]\ \[Lambda]\_5\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        2\ Cos[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\) - Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ f\_RX[t] + 
                  Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ f\_RY[t]\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_6\%3\ d\[Theta]\_6[t] - 
                  1\/4\ Sin[\[Theta]\_6[
                        t]]\ \[Lambda]\_6\%2\ \((2\ Cos[\[Theta]\_6[
                              t]]\ c\_V\ \((\(-Cos[\[Theta]\_6[t]]\)\ dx\_L[
                                  t] - Sin[\[Theta]\_6[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Sin[\[Theta]\_6[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_6[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  1\/2\ Cos[\[Theta]\_6[
                        t]]\ \[Lambda]\_6\ \((\(-Sin[\[Theta]\_6[
                                t]]\)\ c\_V\ \[Lambda]\_6\ \((Cos[\[Theta]\_6[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        1\/2\ Cos[\[Theta]\_6[
                              t]]\ c\_S\ \[Lambda]\_6\ \((\(-2\)\ \
Sin[\[Theta]\_6[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  1\/2\ m\_6\ \((\(-Sin[\[Theta]\_6[
                                t]]\)\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t])\))\) - 
                  1\/2\ m\_6\ \((\(-Sin[\[Theta]\_6[
                                t]]\)\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\) \
+ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\))\
\) - Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((\(-Cos[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Sin[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((2\ Sin[\[Theta]\_7[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  Cos[\[Theta]\_6[
                        t]]\ \[Lambda]\_6\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Cos[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((\(-2\)\ \
Sin[\[Theta]\_7[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t])\))\) - 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) \
+ 2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\))\
\) - Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((\(-Cos[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  Cos[\[Theta]\_6[
                        t]]\ \[Lambda]\_6\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ \
Sin[\[Theta]\_8[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 
                              Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t])\))\) - 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) \
+ 2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\))\
\) - Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  Cos[\[Theta]\_6[
                        t]]\ \[Lambda]\_6\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 
                              Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + 1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ \((\(-Cos[\[Theta]\_1[
                                      
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ 2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_6[
                        t]]\ \[Lambda]\_6\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 2\ Cos[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\) - Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ f\_RX[t] + 
                  Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ f\_RY[t]\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_7\%3\ d\[Theta]\_7[t] - 
                  1\/2\ Sin[\[Theta]\_7[
                        t]]\ \[Lambda]\_7\ \((\(-Cos[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Sin[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((2\ Sin[\[Theta]\_7[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  1\/2\ Cos[\[Theta]\_7[
                        t]]\ \[Lambda]\_7\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Cos[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((\(-2\)\ \
Sin[\[Theta]\_7[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  1\/2\ m\_7\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t])\))\) - 
                  1\/2\ m\_7\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) \
+ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\))\
\) - Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((\(-Cos[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  Cos[\[Theta]\_7[
                        t]]\ \[Lambda]\_7\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ \
Sin[\[Theta]\_8[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t])\))\) - 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) \
+ 2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\))\
\) - Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  Cos[\[Theta]\_7[
                        t]]\ \[Lambda]\_7\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 
                              Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + 1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ \((\(-Cos[\[Theta]\_1[
                                      
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ 2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_7[
                        t]]\ \[Lambda]\_7\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 2\ Cos[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\) - Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ f\_RX[t] + 
                  Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ f\_RY[t]\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_8\%3\ d\[Theta]\_8[t] - 
                  1\/2\ Sin[\[Theta]\_8[
                        t]]\ \[Lambda]\_8\ \((\(-Cos[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ Cos[\[Theta]\_8[
                        t]]\ \[Lambda]\_8\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ \
Sin[\[Theta]\_8[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ m\_8\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t])\))\) - 
                  1\/2\ m\_8\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) \
+ Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\))\
\) - Sin[\[Theta]\_8[t]]\ \[Lambda]\_8\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  Cos[\[Theta]\_8[
                        t]]\ \[Lambda]\_8\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ 2\ Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_8[t]]\ \[Lambda]\_8\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_8[
                        t]]\ \[Lambda]\_8\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - 
                              Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                  t] - Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t] - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        2\ Cos[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\) - Sin[\[Theta]\_8[t]]\ \[Lambda]\_8\ f\_RX[t] + 
                  Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ f\_RY[t]\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_9\%3\ d\[Theta]\_9[t] - 
                  1\/2\ Sin[\[Theta]\_9[
                        t]]\ \[Lambda]\_9\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ Cos[\[Theta]\_9[
                        t]]\ \[Lambda]\_9\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ \[Lambda]\_9\ d\[Theta]\_9[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ \[Lambda]\_9\ d\[Theta]\_9[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        Sin[\[Theta]\_9[
                              t]]\ \[Lambda]\_9\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_9[
                        t]]\ \[Lambda]\_9\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_9[
                              t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 
                              Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t] + 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_9[
                              t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 
                              Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t] - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_9[
                              t]]\ \[Lambda]\_9\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        2\ Cos[\[Theta]\_9[
                              t]]\ \[Lambda]\_9\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\) - Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ f\_RX[t] + 
                  Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ f\_RY[t]\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_10\%3\ d\[Theta]\_10[t] - 
                  1\/2\ Sin[\[Theta]\_10[
                        t]]\ \[Lambda]\_10\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ Cos[\[Theta]\_10[
                        t]]\ \[Lambda]\_10\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ \[Lambda]\_10\ d\[Theta]\_10[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        Cos[\[Theta]\_10[t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ \[Lambda]\_10\ d\[Theta]\_10[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        Cos[\[Theta]\_10[t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        Sin[\[Theta]\_10[
                              t]]\ \[Lambda]\_10\ \((\(-Cos[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        Cos[\[Theta]\_10[
                              t]]\ \[Lambda]\_10\ \((\(-Sin[\[Theta]\_1[
                                      t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
- Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\) - Sin[\[Theta]\_10[t]]\ \[Lambda]\_10\ f\_RX[t] + 
                  Cos[\[Theta]\_10[t]]\ \[Lambda]\_10\ f\_RY[t] + \[Tau]\_R[
                    t]\)}
              },
            RowSpacings->1,
            ColumnAlignments->{Left}],
          Column], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(x\_L[t] \[Rule] v\[LeftDoubleBracket]1\[RightDoubleBracket]\),
         ",", \(y\_L[t] \[Rule] v\[LeftDoubleBracket]2\[RightDoubleBracket]\),
         ",", \(\[Theta]\_1[t] \[Rule] 
          v\[LeftDoubleBracket]3\[RightDoubleBracket]\), 
        ",", \(\[Theta]\_2[t] \[Rule] 
          v\[LeftDoubleBracket]4\[RightDoubleBracket]\), 
        ",", \(\[Theta]\_3[t] \[Rule] 
          v\[LeftDoubleBracket]5\[RightDoubleBracket]\), 
        ",", \(\[Theta]\_4[t] \[Rule] 
          v\[LeftDoubleBracket]6\[RightDoubleBracket]\), 
        ",", \(\[Theta]\_5[t] \[Rule] 
          v\[LeftDoubleBracket]7\[RightDoubleBracket]\), 
        ",", \(\[Theta]\_6[t] \[Rule] 
          v\[LeftDoubleBracket]8\[RightDoubleBracket]\), 
        ",", \(\[Theta]\_7[t] \[Rule] 
          v\[LeftDoubleBracket]9\[RightDoubleBracket]\), 
        ",", \(\[Theta]\_8[t] \[Rule] 
          v\[LeftDoubleBracket]10\[RightDoubleBracket]\), 
        ",", \(\[Theta]\_9[t] \[Rule] 
          v\[LeftDoubleBracket]11\[RightDoubleBracket]\), 
        ",", \(\[Theta]\_10[t] \[Rule] 
          v\[LeftDoubleBracket]12\[RightDoubleBracket]\), 
        ",", \(dx\_L[t] \[Rule] 
          v\[LeftDoubleBracket]13\[RightDoubleBracket]\), 
        ",", \(dy\_L[t] \[Rule] 
          v\[LeftDoubleBracket]14\[RightDoubleBracket]\), 
        ",", \(d\[Theta]\_1[t] \[Rule] 
          v\[LeftDoubleBracket]15\[RightDoubleBracket]\), 
        ",", \(d\[Theta]\_2[t] \[Rule] 
          v\[LeftDoubleBracket]16\[RightDoubleBracket]\), 
        ",", \(d\[Theta]\_3[t] \[Rule] 
          v\[LeftDoubleBracket]17\[RightDoubleBracket]\), 
        ",", \(d\[Theta]\_4[t] \[Rule] 
          v\[LeftDoubleBracket]18\[RightDoubleBracket]\), 
        ",", \(d\[Theta]\_5[t] \[Rule] 
          v\[LeftDoubleBracket]19\[RightDoubleBracket]\), 
        ",", \(d\[Theta]\_6[t] \[Rule] 
          v\[LeftDoubleBracket]20\[RightDoubleBracket]\), 
        ",", \(d\[Theta]\_7[t] \[Rule] 
          v\[LeftDoubleBracket]21\[RightDoubleBracket]\), 
        ",", \(d\[Theta]\_8[t] \[Rule] 
          v\[LeftDoubleBracket]22\[RightDoubleBracket]\), 
        ",", \(d\[Theta]\_9[t] \[Rule] 
          v\[LeftDoubleBracket]23\[RightDoubleBracket]\), 
        ",", \(d\[Theta]\_10[t] \[Rule] 
          v\[LeftDoubleBracket]24\[RightDoubleBracket]\), ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox[\(x\_L\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]1\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(y\_L\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]2\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_1\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]3\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_2\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]4\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_3\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]5\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_4\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]6\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_5\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]7\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_6\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]8\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_7\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]9\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_8\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]10\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_9\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]11\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_10\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]12\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(dx\_L\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]13\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(dy\_L\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]14\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(d\[Theta]\_1\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]15\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(d\[Theta]\_2\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]16\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(d\[Theta]\_3\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]17\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(d\[Theta]\_4\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]18\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(d\[Theta]\_5\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]19\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(d\[Theta]\_6\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]20\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(d\[Theta]\_7\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]21\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(d\[Theta]\_8\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]22\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(d\[Theta]\_9\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]23\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(d\[Theta]\_10\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]24\[RightDoubleBracket]\)}], 
        ",", \(m\_1 \[Rule] M\[LeftDoubleBracket]1\[RightDoubleBracket]\), 
        ",", \(m\_2 \[Rule] M\[LeftDoubleBracket]2\[RightDoubleBracket]\), 
        ",", \(m\_3 \[Rule] M\[LeftDoubleBracket]3\[RightDoubleBracket]\), 
        ",", \(m\_4 \[Rule] M\[LeftDoubleBracket]4\[RightDoubleBracket]\), 
        ",", \(m\_5 \[Rule] M\[LeftDoubleBracket]5\[RightDoubleBracket]\), 
        ",", \(m\_6 \[Rule] M\[LeftDoubleBracket]6\[RightDoubleBracket]\), 
        ",", \(m\_7 \[Rule] M\[LeftDoubleBracket]7\[RightDoubleBracket]\), 
        ",", \(m\_8 \[Rule] M\[LeftDoubleBracket]8\[RightDoubleBracket]\), 
        ",", \(m\_9 \[Rule] M\[LeftDoubleBracket]9\[RightDoubleBracket]\), 
        ",", \(m\_10 \[Rule] M\[LeftDoubleBracket]10\[RightDoubleBracket]\), 
        ",", \(\[Lambda]\_1 \[Rule] 
          L\[LeftDoubleBracket]1\[RightDoubleBracket]\), 
        ",", \(\[Lambda]\_2 \[Rule] 
          L\[LeftDoubleBracket]2\[RightDoubleBracket]\), 
        ",", \(\[Lambda]\_3 \[Rule] 
          L\[LeftDoubleBracket]3\[RightDoubleBracket]\), 
        ",", \(\[Lambda]\_4 \[Rule] 
          L\[LeftDoubleBracket]4\[RightDoubleBracket]\), 
        ",", \(\[Lambda]\_5 \[Rule] 
          L\[LeftDoubleBracket]5\[RightDoubleBracket]\), 
        ",", \(\[Lambda]\_6 \[Rule] 
          L\[LeftDoubleBracket]6\[RightDoubleBracket]\), 
        ",", \(\[Lambda]\_7 \[Rule] 
          L\[LeftDoubleBracket]7\[RightDoubleBracket]\), 
        ",", \(\[Lambda]\_8 \[Rule] 
          L\[LeftDoubleBracket]8\[RightDoubleBracket]\), 
        ",", \(\[Lambda]\_9 \[Rule] 
          L\[LeftDoubleBracket]9\[RightDoubleBracket]\), 
        ",", \(\[Lambda]\_10 \[Rule] 
          L\[LeftDoubleBracket]10\[RightDoubleBracket]\), 
        ",", \(c\_V \[Rule] Cv\), ",", \(c\_S \[Rule] Cs\), 
        ",", \(\[Tau]\_L[t] \[Rule] tauL\), ",", \(f\_LX[t] \[Rule] forceLX\),
         ",", \(f\_LY[t] \[Rule] forceLY\), 
        ",", \(\[Tau]\_R[t] \[Rule] tauR\), ",", \(f\_RX[t] \[Rule] forceRX\),
         ",", \(f\_RY[t] \[Rule] forceRY\)}], "}"}]], "Output"],

Cell[BoxData[
    \("\n coefMat[0] = M[1] + M[2] + M[3] + M[4] + M[5] + M[6] + M[7] + M[8] \
+ M[9] + M[10];\n coefMat[12] = 0;\n coefMat[24] = -(L[1]*M[1]*sin(v[3]))/2. \
- L[1]*M[2]*sin(v[3]) - L[1]*M[3]*sin(v[3]) - L[1]*M[4]*sin(v[3]) - \
L[1]*M[5]*sin(v[3]) - L[1]*M[6]*sin(v[3]) - L[1]*M[7]*sin(v[3]) - \
L[1]*M[8]*sin(v[3]) - L[1]*M[9]*sin(v[3]) - L[1]*M[10]*sin(v[3]);\n \
coefMat[36] = -(L[2]*M[2]*sin(v[4]))/2. - L[2]*M[3]*sin(v[4]) - \
L[2]*M[4]*sin(v[4]) - L[2]*M[5]*sin(v[4]) - L[2]*M[6]*sin(v[4]) - \
L[2]*M[7]*sin(v[4]) - L[2]*M[8]*sin(v[4]) - L[2]*M[9]*sin(v[4]) - \
L[2]*M[10]*sin(v[4]);\n coefMat[48] = -(L[3]*M[3]*sin(v[5]))/2. - \
L[3]*M[4]*sin(v[5]) - L[3]*M[5]*sin(v[5]) - L[3]*M[6]*sin(v[5]) - \
L[3]*M[7]*sin(v[5]) - L[3]*M[8]*sin(v[5]) - L[3]*M[9]*sin(v[5]) - \
L[3]*M[10]*sin(v[5]);\n coefMat[60] = -(L[4]*M[4]*sin(v[6]))/2. - \
L[4]*M[5]*sin(v[6]) - L[4]*M[6]*sin(v[6]) - L[4]*M[7]*sin(v[6]) - \
L[4]*M[8]*sin(v[6]) - L[4]*M[9]*sin(v[6]) - L[4]*M[10]*sin(v[6]);\n \
coefMat[72] = -(L[5]*M[5]*sin(v[7]))/2. - L[5]*M[6]*sin(v[7]) - \
L[5]*M[7]*sin(v[7]) - L[5]*M[8]*sin(v[7]) - L[5]*M[9]*sin(v[7]) - \
L[5]*M[10]*sin(v[7]);\n coefMat[84] = -(L[6]*M[6]*sin(v[8]))/2. - \
L[6]*M[7]*sin(v[8]) - L[6]*M[8]*sin(v[8]) - L[6]*M[9]*sin(v[8]) - \
L[6]*M[10]*sin(v[8]);\n coefMat[96] = -(L[7]*M[7]*sin(v[9]))/2. - \
L[7]*M[8]*sin(v[9]) - L[7]*M[9]*sin(v[9]) - L[7]*M[10]*sin(v[9]);\n \
coefMat[108] = -(L[8]*M[8]*sin(v[10]))/2. - L[8]*M[9]*sin(v[10]) - \
L[8]*M[10]*sin(v[10]);\n coefMat[120] = -(L[9]*M[9]*sin(v[11]))/2. - \
L[9]*M[10]*sin(v[11]);\n coefMat[132] = -(L[10]*M[10]*sin(v[12]))/2.;\n \
rhsVec[0] = forceLX + forceRX - Cv*pow(cos(v[3]),2)*L[1]*v[13] - \
Cv*pow(cos(v[4]),2)*L[2]*v[13] - Cv*pow(cos(v[5]),2)*L[3]*v[13] - \
Cv*pow(cos(v[6]),2)*L[4]*v[13] + (cos(v[3])*L[1]*M[1]*pow(v[15],2))/2. - \
M[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) - (cos(v[4])*L[2]*pow(v[16],2))/2.) - \
M[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
(cos(v[5])*L[3]*pow(v[17],2))/2.) - M[4]*(-(cos(v[3])*L[1]*pow(v[15],2)) - \
cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
(cos(v[6])*L[4]*pow(v[18],2))/2.) - M[5]*(-(cos(v[3])*L[1]*pow(v[15],2)) - \
cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
cos(v[6])*L[4]*pow(v[18],2) - (cos(v[7])*L[5]*pow(v[19],2))/2.) - \
M[6]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - (cos(v[8])*L[6]*pow(v[20],2))/2.) - \
M[7]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
(cos(v[9])*L[7]*pow(v[21],2))/2.) - M[8]*(-(cos(v[3])*L[1]*pow(v[15],2)) - \
cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - \
cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - \
(cos(v[10])*L[8]*pow(v[22],2))/2.) - M[9]*(-(cos(v[3])*L[1]*pow(v[15],2)) - \
cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - \
cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - \
cos(v[10])*L[8]*pow(v[22],2) - (cos(v[11])*L[9]*pow(v[23],2))/2.) - \
M[10]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.) + \
Cs*cos(v[3])*L[1]*v[14]*sin(v[3]) - Cv*cos(v[3])*L[1]*v[14]*sin(v[3]) + \
(Cs*pow(L[1],2)*v[15]*sin(v[3]))/2. - Cs*L[1]*v[13]*pow(sin(v[3]),2) + \
Cv*cos(v[4])*L[1]*L[2]*v[15]*sin(v[3] - v[4]) + \
Cs*cos(v[4])*L[2]*v[14]*sin(v[4]) - Cv*cos(v[4])*L[2]*v[14]*sin(v[4]) + \
Cs*cos(v[3] - v[4])*L[1]*L[2]*v[15]*sin(v[4]) + \
(Cs*pow(L[2],2)*v[16]*sin(v[4]))/2. - Cs*L[2]*v[13]*pow(sin(v[4]),2) + \
Cv*cos(v[5])*L[1]*L[3]*v[15]*sin(v[3] - v[5]) + \
Cv*cos(v[5])*L[2]*L[3]*v[16]*sin(v[4] - v[5]) + \
Cs*cos(v[5])*L[3]*v[14]*sin(v[5]) - Cv*cos(v[5])*L[3]*v[14]*sin(v[5]) + \
Cs*cos(v[3] - v[5])*L[1]*L[3]*v[15]*sin(v[5]) + Cs*cos(v[4] - \
v[5])*L[2]*L[3]*v[16]*sin(v[5]) + (Cs*pow(L[3],2)*v[17]*sin(v[5]))/2. - \
Cs*L[3]*v[13]*pow(sin(v[5]),2) + Cv*cos(v[6])*L[1]*L[4]*v[15]*sin(v[3] - \
v[6]) + Cv*cos(v[6])*L[2]*L[4]*v[16]*sin(v[4] - v[6]) + \
Cv*cos(v[6])*L[3]*L[4]*v[17]*sin(v[5] - v[6]) + \
Cs*cos(v[6])*L[4]*v[14]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[14]*sin(v[6]) + \
Cs*cos(v[3] - v[6])*L[1]*L[4]*v[15]*sin(v[6]) + Cs*cos(v[4] - \
v[6])*L[2]*L[4]*v[16]*sin(v[6]) + Cs*cos(v[5] - \
v[6])*L[3]*L[4]*v[17]*sin(v[6]) + (Cs*pow(L[4],2)*v[18]*sin(v[6]))/2. - \
Cs*L[4]*v[13]*pow(sin(v[6]),2) + (L[5]*(-(Cs*sin(v[7])*(-2*cos(v[7])*v[14] - \
2*cos(v[3] - v[7])*L[1]*v[15] - 2*cos(v[4] - v[7])*L[2]*v[16] - 2*cos(v[5] - \
v[7])*L[3]*v[17] - 2*cos(v[6] - v[7])*L[4]*v[18] - L[5]*v[19] + \
2*v[13]*sin(v[7]))) + 2*Cv*cos(v[7])*(-(cos(v[7])*v[13]) + \
L[1]*v[15]*sin(v[3] - v[7]) + L[2]*v[16]*sin(v[4] - v[7]) + \
L[3]*v[17]*sin(v[5] - v[7]) + L[4]*v[18]*sin(v[6] - v[7]) - \
v[14]*sin(v[7]))))/2. + (L[6]*(-(Cs*sin(v[8])*(-2*cos(v[8])*v[14] - \
2*cos(v[3] - v[8])*L[1]*v[15] - 2*cos(v[4] - v[8])*L[2]*v[16] - 2*cos(v[5] - \
v[8])*L[3]*v[17] - 2*cos(v[6] - v[8])*L[4]*v[18] - 2*cos(v[7] - \
v[8])*L[5]*v[19] - L[6]*v[20] + 2*v[13]*sin(v[8]))) + \
2*Cv*cos(v[8])*(-(cos(v[8])*v[13]) + L[1]*v[15]*sin(v[3] - v[8]) + \
L[2]*v[16]*sin(v[4] - v[8]) + L[3]*v[17]*sin(v[5] - v[8]) + \
L[4]*v[18]*sin(v[6] - v[8]) + L[5]*v[19]*sin(v[7] - v[8]) - \
v[14]*sin(v[8]))))/2. - (Cs*L[7]*sin(v[9])*(-2*cos(v[9])*v[14] - 2*cos(v[3] - \
v[9])*L[1]*v[15] - 2*cos(v[4] - v[9])*L[2]*v[16] - 2*cos(v[5] - \
v[9])*L[3]*v[17] - 2*cos(v[6] - v[9])*L[4]*v[18] - 2*cos(v[7] - \
v[9])*L[5]*v[19] - 2*cos(v[8] - v[9])*L[6]*v[20] - L[7]*v[21] + \
2*v[13]*sin(v[9])))/2. - Cv*cos(v[9])*L[7]*(cos(v[9])*v[13] - \
L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - \
L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - \
L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9])) \
- (Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - v[10])*L[1]*v[15] - \
2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - v[10])*L[3]*v[17] - 2*cos(v[6] \
- v[10])*L[4]*v[18] - 2*cos(v[7] - v[10])*L[5]*v[19] - 2*cos(v[8] - \
v[10])*L[6]*v[20] - 2*cos(v[9] - v[10])*L[7]*v[21] - L[8]*v[22] + \
2*v[13]*sin(v[10])))/2. - Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - \
L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - \
L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - \
L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - \
L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10])) - \
(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - v[11])*L[1]*v[15] - \
2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - v[11])*L[3]*v[17] - 2*cos(v[6] \
- v[11])*L[4]*v[18] - 2*cos(v[7] - v[11])*L[5]*v[19] - 2*cos(v[8] - \
v[11])*L[6]*v[20] - 2*cos(v[9] - v[11])*L[7]*v[21] - 2*cos(v[10] - \
v[11])*L[8]*v[22] - L[9]*v[23] + 2*v[13]*sin(v[11])))/2. - \
Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - \
L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - \
L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - \
L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - \
L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11])) - \
(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - v[12])*L[1]*v[15] - \
2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - v[12])*L[3]*v[17] - 2*cos(v[6] \
- v[12])*L[4]*v[18] - 2*cos(v[7] - v[12])*L[5]*v[19] - 2*cos(v[8] - \
v[12])*L[6]*v[20] - 2*cos(v[9] - v[12])*L[7]*v[21] - 2*cos(v[10] - \
v[12])*L[8]*v[22] - 2*cos(v[11] - v[12])*L[9]*v[23] - L[10]*v[24] + \
2*v[13]*sin(v[12])))/2. - Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - \
L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - \
L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - \
L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - \
L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - \
L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]));\n coefMat[1] = 0;\n \
coefMat[13] = M[1] + M[2] + M[3] + M[4] + M[5] + M[6] + M[7] + M[8] + M[9] + \
M[10];\n coefMat[25] = (cos(v[3])*L[1]*M[1])/2. + cos(v[3])*L[1]*M[2] + \
cos(v[3])*L[1]*M[3] + cos(v[3])*L[1]*M[4] + cos(v[3])*L[1]*M[5] + \
cos(v[3])*L[1]*M[6] + cos(v[3])*L[1]*M[7] + cos(v[3])*L[1]*M[8] + \
cos(v[3])*L[1]*M[9] + cos(v[3])*L[1]*M[10];\n coefMat[37] = \
(cos(v[4])*L[2]*M[2])/2. + cos(v[4])*L[2]*M[3] + cos(v[4])*L[2]*M[4] + \
cos(v[4])*L[2]*M[5] + cos(v[4])*L[2]*M[6] + cos(v[4])*L[2]*M[7] + \
cos(v[4])*L[2]*M[8] + cos(v[4])*L[2]*M[9] + cos(v[4])*L[2]*M[10];\n \
coefMat[49] = (cos(v[5])*L[3]*M[3])/2. + cos(v[5])*L[3]*M[4] + \
cos(v[5])*L[3]*M[5] + cos(v[5])*L[3]*M[6] + cos(v[5])*L[3]*M[7] + \
cos(v[5])*L[3]*M[8] + cos(v[5])*L[3]*M[9] + cos(v[5])*L[3]*M[10];\n \
coefMat[61] = (cos(v[6])*L[4]*M[4])/2. + cos(v[6])*L[4]*M[5] + \
cos(v[6])*L[4]*M[6] + cos(v[6])*L[4]*M[7] + cos(v[6])*L[4]*M[8] + \
cos(v[6])*L[4]*M[9] + cos(v[6])*L[4]*M[10];\n coefMat[73] = \
(cos(v[7])*L[5]*M[5])/2. + cos(v[7])*L[5]*M[6] + cos(v[7])*L[5]*M[7] + \
cos(v[7])*L[5]*M[8] + cos(v[7])*L[5]*M[9] + cos(v[7])*L[5]*M[10];\n \
coefMat[85] = (cos(v[8])*L[6]*M[6])/2. + cos(v[8])*L[6]*M[7] + \
cos(v[8])*L[6]*M[8] + cos(v[8])*L[6]*M[9] + cos(v[8])*L[6]*M[10];\n \
coefMat[97] = (cos(v[9])*L[7]*M[7])/2. + cos(v[9])*L[7]*M[8] + \
cos(v[9])*L[7]*M[9] + cos(v[9])*L[7]*M[10];\n coefMat[109] = \
(cos(v[10])*L[8]*M[8])/2. + cos(v[10])*L[8]*M[9] + cos(v[10])*L[8]*M[10];\n \
coefMat[121] = (cos(v[11])*L[9]*M[9])/2. + cos(v[11])*L[9]*M[10];\n \
coefMat[133] = (cos(v[12])*L[10]*M[10])/2.;\n rhsVec[1] = forceLY + forceRY - \
Cs*pow(cos(v[3]),2)*L[1]*v[14] - Cs*pow(cos(v[4]),2)*L[2]*v[14] - \
Cs*pow(cos(v[5]),2)*L[3]*v[14] - Cs*pow(cos(v[6]),2)*L[4]*v[14] - \
(Cs*cos(v[3])*pow(L[1],2)*v[15])/2. - Cs*cos(v[3] - \
v[4])*cos(v[4])*L[1]*L[2]*v[15] - Cs*cos(v[3] - \
v[5])*cos(v[5])*L[1]*L[3]*v[15] - Cs*cos(v[3] - \
v[6])*cos(v[6])*L[1]*L[4]*v[15] - (Cs*cos(v[4])*pow(L[2],2)*v[16])/2. - \
Cs*cos(v[4] - v[5])*cos(v[5])*L[2]*L[3]*v[16] - Cs*cos(v[4] - \
v[6])*cos(v[6])*L[2]*L[4]*v[16] - (Cs*cos(v[5])*pow(L[3],2)*v[17])/2. - \
Cs*cos(v[5] - v[6])*cos(v[6])*L[3]*L[4]*v[17] - \
(Cs*cos(v[6])*pow(L[4],2)*v[18])/2. + Cs*cos(v[3])*L[1]*v[13]*sin(v[3]) - \
Cv*cos(v[3])*L[1]*v[13]*sin(v[3]) + (L[1]*M[1]*pow(v[15],2)*sin(v[3]))/2. - \
Cv*L[1]*v[14]*pow(sin(v[3]),2) + Cs*cos(v[4])*L[2]*v[13]*sin(v[4]) - \
Cv*cos(v[4])*L[2]*v[13]*sin(v[4]) + Cv*L[1]*L[2]*v[15]*sin(v[3] - \
v[4])*sin(v[4]) - Cv*L[2]*v[14]*pow(sin(v[4]),2) - \
M[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - (L[2]*pow(v[16],2)*sin(v[4]))/2.) + \
Cs*cos(v[5])*L[3]*v[13]*sin(v[5]) - Cv*cos(v[5])*L[3]*v[13]*sin(v[5]) + \
Cv*L[1]*L[3]*v[15]*sin(v[3] - v[5])*sin(v[5]) + Cv*L[2]*L[3]*v[16]*sin(v[4] - \
v[5])*sin(v[5]) - Cv*L[3]*v[14]*pow(sin(v[5]),2) - \
M[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - \
(L[3]*pow(v[17],2)*sin(v[5]))/2.) + Cs*cos(v[6])*L[4]*v[13]*sin(v[6]) - \
Cv*cos(v[6])*L[4]*v[13]*sin(v[6]) + Cv*L[1]*L[4]*v[15]*sin(v[3] - \
v[6])*sin(v[6]) + Cv*L[2]*L[4]*v[16]*sin(v[4] - v[6])*sin(v[6]) + \
Cv*L[3]*L[4]*v[17]*sin(v[5] - v[6])*sin(v[6]) - \
Cv*L[4]*v[14]*pow(sin(v[6]),2) - M[4]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
(L[4]*pow(v[18],2)*sin(v[6]))/2.) - M[5]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - (L[5]*pow(v[19],2)*sin(v[7]))/2.) - \
(L[5]*(Cs*cos(v[7])*(2*cos(v[7])*v[14] + 2*cos(v[3] - v[7])*L[1]*v[15] + \
2*cos(v[4] - v[7])*L[2]*v[16] + 2*cos(v[5] - v[7])*L[3]*v[17] + 2*cos(v[6] - \
v[7])*L[4]*v[18] + L[5]*v[19] - 2*v[13]*sin(v[7])) + \
2*Cv*sin(v[7])*(cos(v[7])*v[13] - L[1]*v[15]*sin(v[3] - v[7]) - \
L[2]*v[16]*sin(v[4] - v[7]) - L[3]*v[17]*sin(v[5] - v[7]) - \
L[4]*v[18]*sin(v[6] - v[7]) + v[14]*sin(v[7]))))/2. - \
(Cs*cos(v[8])*L[6]*(2*cos(v[8])*v[14] + 2*cos(v[3] - v[8])*L[1]*v[15] + \
2*cos(v[4] - v[8])*L[2]*v[16] + 2*cos(v[5] - v[8])*L[3]*v[17] + 2*cos(v[6] - \
v[8])*L[4]*v[18] + 2*cos(v[7] - v[8])*L[5]*v[19] + L[6]*v[20] - \
2*v[13]*sin(v[8])))/2. - Cv*L[6]*sin(v[8])*(cos(v[8])*v[13] - \
L[1]*v[15]*sin(v[3] - v[8]) - L[2]*v[16]*sin(v[4] - v[8]) - \
L[3]*v[17]*sin(v[5] - v[8]) - L[4]*v[18]*sin(v[6] - v[8]) - \
L[5]*v[19]*sin(v[7] - v[8]) + v[14]*sin(v[8])) - \
M[6]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - \
L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - \
L[5]*pow(v[19],2)*sin(v[7]) - (L[6]*pow(v[20],2)*sin(v[8]))/2.) - \
(Cs*cos(v[9])*L[7]*(2*cos(v[9])*v[14] + 2*cos(v[3] - v[9])*L[1]*v[15] + \
2*cos(v[4] - v[9])*L[2]*v[16] + 2*cos(v[5] - v[9])*L[3]*v[17] + 2*cos(v[6] - \
v[9])*L[4]*v[18] + 2*cos(v[7] - v[9])*L[5]*v[19] + 2*cos(v[8] - \
v[9])*L[6]*v[20] + L[7]*v[21] - 2*v[13]*sin(v[9])))/2. - \
Cv*L[7]*sin(v[9])*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - \
L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - \
L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - \
L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9])) - \
M[7]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - \
L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - \
L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - \
(L[7]*pow(v[21],2)*sin(v[9]))/2.) - (Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] + \
2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + 2*cos(v[5] \
- v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] - \
v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - \
v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - \
Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10])) - M[8]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
(L[8]*pow(v[22],2)*sin(v[10]))/2.) - (Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] \
+ 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + \
2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] \
- v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - \
v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - \
2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11])) - M[9]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.) - \
(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - v[12])*L[1]*v[15] + \
2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - v[12])*L[3]*v[17] + 2*cos(v[6] \
- v[12])*L[4]*v[18] + 2*cos(v[7] - v[12])*L[5]*v[19] + 2*cos(v[8] - \
v[12])*L[6]*v[20] + 2*cos(v[9] - v[12])*L[7]*v[21] + 2*cos(v[10] - \
v[12])*L[8]*v[22] + 2*cos(v[11] - v[12])*L[9]*v[23] + L[10]*v[24] - \
2*v[13]*sin(v[12])))/2. - Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - \
L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - \
L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - \
L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - \
L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - \
L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12])) - \
M[10]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - \
L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - \
L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - \
L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - \
L[9]*pow(v[23],2)*sin(v[11]) - (L[10]*pow(v[24],2)*sin(v[12]))/2.);\n \
coefMat[2] = -(L[1]*M[1]*sin(v[3]))/2. - L[1]*M[2]*sin(v[3]) - \
L[1]*M[3]*sin(v[3]) - L[1]*M[4]*sin(v[3]) - L[1]*M[5]*sin(v[3]) - \
L[1]*M[6]*sin(v[3]) - L[1]*M[7]*sin(v[3]) - L[1]*M[8]*sin(v[3]) - \
L[1]*M[9]*sin(v[3]) - L[1]*M[10]*sin(v[3]);\n coefMat[14] = \
(cos(v[3])*L[1]*M[1])/2. + cos(v[3])*L[1]*M[2] + cos(v[3])*L[1]*M[3] + \
cos(v[3])*L[1]*M[4] + cos(v[3])*L[1]*M[5] + cos(v[3])*L[1]*M[6] + \
cos(v[3])*L[1]*M[7] + cos(v[3])*L[1]*M[8] + cos(v[3])*L[1]*M[9] + \
cos(v[3])*L[1]*M[10];\n coefMat[26] = (pow(L[1],2)*M[1])/12. + \
(M[1]*((pow(cos(v[3]),2)*pow(L[1],2))/2. + \
(pow(L[1],2)*pow(sin(v[3]),2))/2.))/2. + \
(M[2]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2. + \
(M[3]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2. + \
(M[4]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2. + \
(M[5]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2. + \
(M[6]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2. + \
(M[7]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2. + \
(M[8]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2. + \
(M[9]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2. + \
(M[10]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2.;\
\n coefMat[38] = (M[2]*(cos(v[3])*cos(v[4])*L[1]*L[2] + \
L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[3]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + \
2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[4]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] \
+ 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + \
(M[5]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. \
+ (M[6]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + \
2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[7]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] \
+ 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + \
(M[8]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. \
+ (M[9]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + \
2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + \
(M[10]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + \
2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2.;\n coefMat[50] = \
(M[3]*(cos(v[3])*cos(v[5])*L[1]*L[3] + L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + \
(M[4]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. \
+ (M[5]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + \
2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[6]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] \
+ 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + \
(M[7]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. \
+ (M[8]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + \
2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[9]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] \
+ 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + \
(M[10]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + \
2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2.;\n coefMat[62] = \
(M[4]*(cos(v[3])*cos(v[6])*L[1]*L[4] + L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + \
(M[5]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. \
+ (M[6]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + \
2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + (M[7]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] \
+ 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + \
(M[8]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. \
+ (M[9]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + \
2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + \
(M[10]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + \
2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2.;\n coefMat[74] = \
(M[5]*(cos(v[3])*cos(v[7])*L[1]*L[5] + L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + \
(M[6]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + 2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2. \
+ (M[7]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + \
2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + (M[8]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] \
+ 2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + \
(M[9]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + 2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2. \
+ (M[10]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + \
2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2.;\n coefMat[86] = \
(M[6]*(cos(v[3])*cos(v[8])*L[1]*L[6] + L[1]*L[6]*sin(v[3])*sin(v[8])))/2. + \
(M[7]*(2*cos(v[3])*cos(v[8])*L[1]*L[6] + 2*L[1]*L[6]*sin(v[3])*sin(v[8])))/2. \
+ (M[8]*(2*cos(v[3])*cos(v[8])*L[1]*L[6] + \
2*L[1]*L[6]*sin(v[3])*sin(v[8])))/2. + (M[9]*(2*cos(v[3])*cos(v[8])*L[1]*L[6] \
+ 2*L[1]*L[6]*sin(v[3])*sin(v[8])))/2. + \
(M[10]*(2*cos(v[3])*cos(v[8])*L[1]*L[6] + \
2*L[1]*L[6]*sin(v[3])*sin(v[8])))/2.;\n coefMat[98] = \
(M[7]*(cos(v[3])*cos(v[9])*L[1]*L[7] + L[1]*L[7]*sin(v[3])*sin(v[9])))/2. + \
(M[8]*(2*cos(v[3])*cos(v[9])*L[1]*L[7] + 2*L[1]*L[7]*sin(v[3])*sin(v[9])))/2. \
+ (M[9]*(2*cos(v[3])*cos(v[9])*L[1]*L[7] + \
2*L[1]*L[7]*sin(v[3])*sin(v[9])))/2. + \
(M[10]*(2*cos(v[3])*cos(v[9])*L[1]*L[7] + \
2*L[1]*L[7]*sin(v[3])*sin(v[9])))/2.;\n coefMat[110] = \
(M[8]*(cos(v[3])*cos(v[10])*L[1]*L[8] + L[1]*L[8]*sin(v[3])*sin(v[10])))/2. + \
(M[9]*(2*cos(v[3])*cos(v[10])*L[1]*L[8] + \
2*L[1]*L[8]*sin(v[3])*sin(v[10])))/2. + \
(M[10]*(2*cos(v[3])*cos(v[10])*L[1]*L[8] + \
2*L[1]*L[8]*sin(v[3])*sin(v[10])))/2.;\n coefMat[122] = \
(M[9]*(cos(v[3])*cos(v[11])*L[1]*L[9] + L[1]*L[9]*sin(v[3])*sin(v[11])))/2. + \
(M[10]*(2*cos(v[3])*cos(v[11])*L[1]*L[9] + \
2*L[1]*L[9]*sin(v[3])*sin(v[11])))/2.;\n coefMat[134] = \
(M[10]*(cos(v[3])*cos(v[12])*L[1]*L[10] + \
L[1]*L[10]*sin(v[3])*sin(v[12])))/2.;\n rhsVec[2] = tauL + \
forceRY*cos(v[3])*L[1] - (Cs*pow(L[1],3)*v[15])/12. - forceRX*L[1]*sin(v[3]) \
- (L[1]*sin(v[3])*(-(Cv*pow(cos(v[3]),2)*L[1]*v[13]) + \
Cs*cos(v[3])*L[1]*v[14]*sin(v[3]) - Cv*cos(v[3])*L[1]*v[14]*sin(v[3]) + \
(Cs*pow(L[1],2)*v[15]*sin(v[3]))/2. - Cs*L[1]*v[13]*pow(sin(v[3]),2)))/2. + \
(cos(v[3])*L[1]*(-(Cs*pow(cos(v[3]),2)*L[1]*v[14]) - \
(Cs*cos(v[3])*pow(L[1],2)*v[15])/2. + Cs*cos(v[3])*L[1]*v[13]*sin(v[3]) - \
Cv*cos(v[3])*L[1]*v[13]*sin(v[3]) - Cv*L[1]*v[14]*pow(sin(v[3]),2)))/2. - \
L[1]*sin(v[3])*(-(Cv*pow(cos(v[4]),2)*L[2]*v[13]) + \
Cv*cos(v[4])*L[1]*L[2]*v[15]*sin(v[3] - v[4]) + \
Cs*cos(v[4])*L[2]*v[14]*sin(v[4]) - Cv*cos(v[4])*L[2]*v[14]*sin(v[4]) + \
Cs*cos(v[3] - v[4])*L[1]*L[2]*v[15]*sin(v[4]) + \
(Cs*pow(L[2],2)*v[16]*sin(v[4]))/2. - Cs*L[2]*v[13]*pow(sin(v[4]),2)) + \
cos(v[3])*L[1]*(-(Cs*pow(cos(v[4]),2)*L[2]*v[14]) - Cs*cos(v[3] - \
v[4])*cos(v[4])*L[1]*L[2]*v[15] - (Cs*cos(v[4])*pow(L[2],2)*v[16])/2. + \
Cs*cos(v[4])*L[2]*v[13]*sin(v[4]) - Cv*cos(v[4])*L[2]*v[13]*sin(v[4]) + \
Cv*L[1]*L[2]*v[15]*sin(v[3] - v[4])*sin(v[4]) - \
Cv*L[2]*v[14]*pow(sin(v[4]),2)) + (M[2]*(-2*L[1]*v[15]*(v[14] + \
cos(v[3])*L[1]*v[15] + (cos(v[4])*L[2]*v[16])/2.)*sin(v[3]) - \
2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - \
(L[2]*v[16]*sin(v[4]))/2.)))/2. - (M[2]*(-2*L[1]*v[15]*(v[14] + \
cos(v[3])*L[1]*v[15] + (cos(v[4])*L[2]*v[16])/2.)*sin(v[3]) - \
2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) - \
(cos(v[4])*L[2]*pow(v[16],2))/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - \
L[1]*v[15]*sin(v[3]) - (L[2]*v[16]*sin(v[4]))/2.) + \
2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
(L[2]*pow(v[16],2)*sin(v[4]))/2.)))/2. - \
L[1]*sin(v[3])*(-(Cv*pow(cos(v[5]),2)*L[3]*v[13]) + \
Cv*cos(v[5])*L[1]*L[3]*v[15]*sin(v[3] - v[5]) + \
Cv*cos(v[5])*L[2]*L[3]*v[16]*sin(v[4] - v[5]) + \
Cs*cos(v[5])*L[3]*v[14]*sin(v[5]) - Cv*cos(v[5])*L[3]*v[14]*sin(v[5]) + \
Cs*cos(v[3] - v[5])*L[1]*L[3]*v[15]*sin(v[5]) + Cs*cos(v[4] - \
v[5])*L[2]*L[3]*v[16]*sin(v[5]) + (Cs*pow(L[3],2)*v[17]*sin(v[5]))/2. - \
Cs*L[3]*v[13]*pow(sin(v[5]),2)) + \
cos(v[3])*L[1]*(-(Cs*pow(cos(v[5]),2)*L[3]*v[14]) - Cs*cos(v[3] - \
v[5])*cos(v[5])*L[1]*L[3]*v[15] - Cs*cos(v[4] - \
v[5])*cos(v[5])*L[2]*L[3]*v[16] - (Cs*cos(v[5])*pow(L[3],2)*v[17])/2. + \
Cs*cos(v[5])*L[3]*v[13]*sin(v[5]) - Cv*cos(v[5])*L[3]*v[13]*sin(v[5]) + \
Cv*L[1]*L[3]*v[15]*sin(v[3] - v[5])*sin(v[5]) + Cv*L[2]*L[3]*v[16]*sin(v[4] - \
v[5])*sin(v[5]) - Cv*L[3]*v[14]*pow(sin(v[5]),2)) + \
(M[3]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
(cos(v[5])*L[3]*v[17])/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - (L[3]*v[17]*sin(v[5]))/2.)))/2. \
- (M[3]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
(cos(v[5])*L[3]*v[17])/2.)*sin(v[3]) - 2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - (cos(v[5])*L[3]*pow(v[17],2))/2.)*sin(v[3]) - \
2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
(L[3]*v[17]*sin(v[5]))/2.) + 2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) \
- L[2]*pow(v[16],2)*sin(v[4]) - (L[3]*pow(v[17],2)*sin(v[5]))/2.)))/2. - \
L[1]*sin(v[3])*(-(Cv*pow(cos(v[6]),2)*L[4]*v[13]) + \
Cv*cos(v[6])*L[1]*L[4]*v[15]*sin(v[3] - v[6]) + \
Cv*cos(v[6])*L[2]*L[4]*v[16]*sin(v[4] - v[6]) + \
Cv*cos(v[6])*L[3]*L[4]*v[17]*sin(v[5] - v[6]) + \
Cs*cos(v[6])*L[4]*v[14]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[14]*sin(v[6]) + \
Cs*cos(v[3] - v[6])*L[1]*L[4]*v[15]*sin(v[6]) + Cs*cos(v[4] - \
v[6])*L[2]*L[4]*v[16]*sin(v[6]) + Cs*cos(v[5] - \
v[6])*L[3]*L[4]*v[17]*sin(v[6]) + (Cs*pow(L[4],2)*v[18]*sin(v[6]))/2. - \
Cs*L[4]*v[13]*pow(sin(v[6]),2)) + \
cos(v[3])*L[1]*(-(Cs*pow(cos(v[6]),2)*L[4]*v[14]) - Cs*cos(v[3] - \
v[6])*cos(v[6])*L[1]*L[4]*v[15] - Cs*cos(v[4] - \
v[6])*cos(v[6])*L[2]*L[4]*v[16] - Cs*cos(v[5] - \
v[6])*cos(v[6])*L[3]*L[4]*v[17] - (Cs*cos(v[6])*pow(L[4],2)*v[18])/2. + \
Cs*cos(v[6])*L[4]*v[13]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[13]*sin(v[6]) + \
Cv*L[1]*L[4]*v[15]*sin(v[3] - v[6])*sin(v[6]) + Cv*L[2]*L[4]*v[16]*sin(v[4] - \
v[6])*sin(v[6]) + Cv*L[3]*L[4]*v[17]*sin(v[5] - v[6])*sin(v[6]) - \
Cv*L[4]*v[14]*pow(sin(v[6]),2)) + (M[4]*(-2*L[1]*v[15]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
(cos(v[6])*L[4]*v[18])/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
(L[4]*v[18]*sin(v[6]))/2.)))/2. - (M[4]*(-2*L[1]*v[15]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
(cos(v[6])*L[4]*v[18])/2.)*sin(v[3]) - 2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
(cos(v[6])*L[4]*pow(v[18],2))/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
(L[4]*v[18]*sin(v[6]))/2.) + 2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) \
- L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
(L[4]*pow(v[18],2)*sin(v[6]))/2.)))/2. - \
(L[1]*L[5]*sin(v[3])*(-(Cs*sin(v[7])*(-2*cos(v[7])*v[14] - 2*cos(v[3] - \
v[7])*L[1]*v[15] - 2*cos(v[4] - v[7])*L[2]*v[16] - 2*cos(v[5] - \
v[7])*L[3]*v[17] - 2*cos(v[6] - v[7])*L[4]*v[18] - L[5]*v[19] + \
2*v[13]*sin(v[7]))) + 2*Cv*cos(v[7])*(-(cos(v[7])*v[13]) + \
L[1]*v[15]*sin(v[3] - v[7]) + L[2]*v[16]*sin(v[4] - v[7]) + \
L[3]*v[17]*sin(v[5] - v[7]) + L[4]*v[18]*sin(v[6] - v[7]) - \
v[14]*sin(v[7]))))/2. - (cos(v[3])*L[1]*L[5]*(Cs*cos(v[7])*(2*cos(v[7])*v[14] \
+ 2*cos(v[3] - v[7])*L[1]*v[15] + 2*cos(v[4] - v[7])*L[2]*v[16] + 2*cos(v[5] \
- v[7])*L[3]*v[17] + 2*cos(v[6] - v[7])*L[4]*v[18] + L[5]*v[19] - \
2*v[13]*sin(v[7])) + 2*Cv*sin(v[7])*(cos(v[7])*v[13] - L[1]*v[15]*sin(v[3] - \
v[7]) - L[2]*v[16]*sin(v[4] - v[7]) - L[3]*v[17]*sin(v[5] - v[7]) - \
L[4]*v[18]*sin(v[6] - v[7]) + v[14]*sin(v[7]))))/2. + \
(M[5]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
(cos(v[7])*L[5]*v[19])/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.)))/2. - \
(M[5]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
(cos(v[7])*L[5]*v[19])/2.)*sin(v[3]) - 2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
cos(v[6])*L[4]*pow(v[18],2) - (cos(v[7])*L[5]*pow(v[19],2))/2.)*sin(v[3]) - \
2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.) + \
2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - (L[5]*pow(v[19],2)*sin(v[7]))/2.)))/2. - \
(L[1]*L[6]*sin(v[3])*(-(Cs*sin(v[8])*(-2*cos(v[8])*v[14] - 2*cos(v[3] - \
v[8])*L[1]*v[15] - 2*cos(v[4] - v[8])*L[2]*v[16] - 2*cos(v[5] - \
v[8])*L[3]*v[17] - 2*cos(v[6] - v[8])*L[4]*v[18] - 2*cos(v[7] - \
v[8])*L[5]*v[19] - L[6]*v[20] + 2*v[13]*sin(v[8]))) + \
2*Cv*cos(v[8])*(-(cos(v[8])*v[13]) + L[1]*v[15]*sin(v[3] - v[8]) + \
L[2]*v[16]*sin(v[4] - v[8]) + L[3]*v[17]*sin(v[5] - v[8]) + \
L[4]*v[18]*sin(v[6] - v[8]) + L[5]*v[19]*sin(v[7] - v[8]) - \
v[14]*sin(v[8]))))/2. + \
cos(v[3])*L[1]*(-(Cs*cos(v[8])*L[6]*(2*cos(v[8])*v[14] + 2*cos(v[3] - \
v[8])*L[1]*v[15] + 2*cos(v[4] - v[8])*L[2]*v[16] + 2*cos(v[5] - \
v[8])*L[3]*v[17] + 2*cos(v[6] - v[8])*L[4]*v[18] + 2*cos(v[7] - \
v[8])*L[5]*v[19] + L[6]*v[20] - 2*v[13]*sin(v[8])))/2. - \
Cv*L[6]*sin(v[8])*(cos(v[8])*v[13] - L[1]*v[15]*sin(v[3] - v[8]) - \
L[2]*v[16]*sin(v[4] - v[8]) - L[3]*v[17]*sin(v[5] - v[8]) - \
L[4]*v[18]*sin(v[6] - v[8]) - L[5]*v[19]*sin(v[7] - v[8]) + v[14]*sin(v[8]))) \
+ (M[6]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
(cos(v[8])*L[6]*v[20])/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.)))/2. \
- (M[6]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
(cos(v[8])*L[6]*v[20])/2.)*sin(v[3]) - 2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - \
(cos(v[8])*L[6]*pow(v[20],2))/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.) + \
2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
(L[6]*pow(v[20],2)*sin(v[8]))/2.)))/2. - \
L[1]*sin(v[3])*(-(Cs*L[7]*sin(v[9])*(-2*cos(v[9])*v[14] - 2*cos(v[3] - \
v[9])*L[1]*v[15] - 2*cos(v[4] - v[9])*L[2]*v[16] - 2*cos(v[5] - \
v[9])*L[3]*v[17] - 2*cos(v[6] - v[9])*L[4]*v[18] - 2*cos(v[7] - \
v[9])*L[5]*v[19] - 2*cos(v[8] - v[9])*L[6]*v[20] - L[7]*v[21] + \
2*v[13]*sin(v[9])))/2. - Cv*cos(v[9])*L[7]*(cos(v[9])*v[13] - \
L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - \
L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - \
L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) \
+ cos(v[3])*L[1]*(-(Cs*cos(v[9])*L[7]*(2*cos(v[9])*v[14] + 2*cos(v[3] - \
v[9])*L[1]*v[15] + 2*cos(v[4] - v[9])*L[2]*v[16] + 2*cos(v[5] - \
v[9])*L[3]*v[17] + 2*cos(v[6] - v[9])*L[4]*v[18] + 2*cos(v[7] - \
v[9])*L[5]*v[19] + 2*cos(v[8] - v[9])*L[6]*v[20] + L[7]*v[21] - \
2*v[13]*sin(v[9])))/2. - Cv*L[7]*sin(v[9])*(cos(v[9])*v[13] - \
L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - \
L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - \
L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) \
+ (M[7]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[3]) - \
2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.)))/2. - \
(M[7]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[3]) - \
2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
(cos(v[9])*L[7]*pow(v[21],2))/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
(L[7]*v[21]*sin(v[9]))/2.) + 2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) \
- L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - (L[7]*pow(v[21],2)*sin(v[9]))/2.)))/2. - \
L[1]*sin(v[3])*(-(Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - \
v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - \
v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - \
v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - \
v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - \
Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10]))) + cos(v[3])*L[1]*(-(Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] \
+ 2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + \
2*cos(v[5] - v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] \
- v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - \
v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - \
Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10]))) + (M[8]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
(cos(v[10])*L[8]*v[22])/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.)))/2. - \
(M[8]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
(cos(v[10])*L[8]*v[22])/2.)*sin(v[3]) - \
2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.)*sin(v[3]) - \
2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.) + \
2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
(L[8]*pow(v[22],2)*sin(v[10]))/2.)))/2. - \
L[1]*sin(v[3])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - \
v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - \
v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - \
v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - \
v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + \
2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))) + cos(v[3])*L[1]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] \
+ 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + \
2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] \
- v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - \
v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - \
2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))) + (M[9]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[3]) - \
2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
(L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-2*L[1]*v[15]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + \
(cos(v[11])*L[9]*v[23])/2.)*sin(v[3]) - \
2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
(cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] \
- L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + \
2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - \
L[1]*sin(v[3])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - \
v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - \
v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - \
v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - \
v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - \
v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - \
Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + \
cos(v[3])*L[1]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - \
v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - \
v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - \
v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - \
v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - \
v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - \
Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + (M[10]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - \
(L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[1]*v[15]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[3]) - \
2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[3]) \
- 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) \
- L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + \
2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - \
(L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;\n coefMat[3] = \
-(L[2]*M[2]*sin(v[4]))/2. - L[2]*M[3]*sin(v[4]) - L[2]*M[4]*sin(v[4]) - \
L[2]*M[5]*sin(v[4]) - L[2]*M[6]*sin(v[4]) - L[2]*M[7]*sin(v[4]) - \
L[2]*M[8]*sin(v[4]) - L[2]*M[9]*sin(v[4]) - L[2]*M[10]*sin(v[4]);\n \
coefMat[15] = (cos(v[4])*L[2]*M[2])/2. + cos(v[4])*L[2]*M[3] + \
cos(v[4])*L[2]*M[4] + cos(v[4])*L[2]*M[5] + cos(v[4])*L[2]*M[6] + \
cos(v[4])*L[2]*M[7] + cos(v[4])*L[2]*M[8] + cos(v[4])*L[2]*M[9] + \
cos(v[4])*L[2]*M[10];\n coefMat[27] = (M[2]*(cos(v[3])*cos(v[4])*L[1]*L[2] + \
L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[3]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + \
2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[4]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] \
+ 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + \
(M[5]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. \
+ (M[6]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + \
2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[7]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] \
+ 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + \
(M[8]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. \
+ (M[9]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + \
2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + \
(M[10]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + \
2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2.;\n coefMat[39] = (pow(L[2],2)*M[2])/12. \
+ (M[2]*((pow(cos(v[4]),2)*pow(L[2],2))/2. + \
(pow(L[2],2)*pow(sin(v[4]),2))/2.))/2. + \
(M[3]*(2*pow(cos(v[4]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(v[4]),2)))/2. + \
(M[4]*(2*pow(cos(v[4]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(v[4]),2)))/2. + \
(M[5]*(2*pow(cos(v[4]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(v[4]),2)))/2. + \
(M[6]*(2*pow(cos(v[4]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(v[4]),2)))/2. + \
(M[7]*(2*pow(cos(v[4]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(v[4]),2)))/2. + \
(M[8]*(2*pow(cos(v[4]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(v[4]),2)))/2. + \
(M[9]*(2*pow(cos(v[4]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(v[4]),2)))/2. + \
(M[10]*(2*pow(cos(v[4]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(v[4]),2)))/2.;\
\n coefMat[51] = (M[3]*(cos(v[4])*cos(v[5])*L[2]*L[3] + \
L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[4]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + \
2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[5]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] \
+ 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + \
(M[6]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. \
+ (M[7]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + \
2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[8]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] \
+ 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + \
(M[9]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. \
+ (M[10]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + \
2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2.;\n coefMat[63] = \
(M[4]*(cos(v[4])*cos(v[6])*L[2]*L[4] + L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + \
(M[5]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. \
+ (M[6]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + \
2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + (M[7]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] \
+ 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + \
(M[8]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. \
+ (M[9]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + \
2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + \
(M[10]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + \
2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2.;\n coefMat[75] = \
(M[5]*(cos(v[4])*cos(v[7])*L[2]*L[5] + L[2]*L[5]*sin(v[4])*sin(v[7])))/2. + \
(M[6]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + 2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2. \
+ (M[7]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + \
2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2. + (M[8]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] \
+ 2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2. + \
(M[9]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + 2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2. \
+ (M[10]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + \
2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2.;\n coefMat[87] = \
(M[6]*(cos(v[4])*cos(v[8])*L[2]*L[6] + L[2]*L[6]*sin(v[4])*sin(v[8])))/2. + \
(M[7]*(2*cos(v[4])*cos(v[8])*L[2]*L[6] + 2*L[2]*L[6]*sin(v[4])*sin(v[8])))/2. \
+ (M[8]*(2*cos(v[4])*cos(v[8])*L[2]*L[6] + \
2*L[2]*L[6]*sin(v[4])*sin(v[8])))/2. + (M[9]*(2*cos(v[4])*cos(v[8])*L[2]*L[6] \
+ 2*L[2]*L[6]*sin(v[4])*sin(v[8])))/2. + \
(M[10]*(2*cos(v[4])*cos(v[8])*L[2]*L[6] + \
2*L[2]*L[6]*sin(v[4])*sin(v[8])))/2.;\n coefMat[99] = \
(M[7]*(cos(v[4])*cos(v[9])*L[2]*L[7] + L[2]*L[7]*sin(v[4])*sin(v[9])))/2. + \
(M[8]*(2*cos(v[4])*cos(v[9])*L[2]*L[7] + 2*L[2]*L[7]*sin(v[4])*sin(v[9])))/2. \
+ (M[9]*(2*cos(v[4])*cos(v[9])*L[2]*L[7] + \
2*L[2]*L[7]*sin(v[4])*sin(v[9])))/2. + \
(M[10]*(2*cos(v[4])*cos(v[9])*L[2]*L[7] + \
2*L[2]*L[7]*sin(v[4])*sin(v[9])))/2.;\n coefMat[111] = \
(M[8]*(cos(v[4])*cos(v[10])*L[2]*L[8] + L[2]*L[8]*sin(v[4])*sin(v[10])))/2. + \
(M[9]*(2*cos(v[4])*cos(v[10])*L[2]*L[8] + \
2*L[2]*L[8]*sin(v[4])*sin(v[10])))/2. + \
(M[10]*(2*cos(v[4])*cos(v[10])*L[2]*L[8] + \
2*L[2]*L[8]*sin(v[4])*sin(v[10])))/2.;\n coefMat[123] = \
(M[9]*(cos(v[4])*cos(v[11])*L[2]*L[9] + L[2]*L[9]*sin(v[4])*sin(v[11])))/2. + \
(M[10]*(2*cos(v[4])*cos(v[11])*L[2]*L[9] + \
2*L[2]*L[9]*sin(v[4])*sin(v[11])))/2.;\n coefMat[135] = \
(M[10]*(cos(v[4])*cos(v[12])*L[2]*L[10] + \
L[2]*L[10]*sin(v[4])*sin(v[12])))/2.;\n rhsVec[3] = forceRY*cos(v[4])*L[2] - \
(Cs*pow(L[2],3)*v[16])/12. - forceRX*L[2]*sin(v[4]) - \
(L[2]*sin(v[4])*(-(Cv*pow(cos(v[4]),2)*L[2]*v[13]) + \
Cv*cos(v[4])*L[1]*L[2]*v[15]*sin(v[3] - v[4]) + \
Cs*cos(v[4])*L[2]*v[14]*sin(v[4]) - Cv*cos(v[4])*L[2]*v[14]*sin(v[4]) + \
Cs*cos(v[3] - v[4])*L[1]*L[2]*v[15]*sin(v[4]) + \
(Cs*pow(L[2],2)*v[16]*sin(v[4]))/2. - Cs*L[2]*v[13]*pow(sin(v[4]),2)))/2. + \
(cos(v[4])*L[2]*(-(Cs*pow(cos(v[4]),2)*L[2]*v[14]) - Cs*cos(v[3] - \
v[4])*cos(v[4])*L[1]*L[2]*v[15] - (Cs*cos(v[4])*pow(L[2],2)*v[16])/2. + \
Cs*cos(v[4])*L[2]*v[13]*sin(v[4]) - Cv*cos(v[4])*L[2]*v[13]*sin(v[4]) + \
Cv*L[1]*L[2]*v[15]*sin(v[3] - v[4])*sin(v[4]) - \
Cv*L[2]*v[14]*pow(sin(v[4]),2)))/2. + (M[2]*(-(L[2]*v[16]*(v[14] + \
cos(v[3])*L[1]*v[15] + (cos(v[4])*L[2]*v[16])/2.)*sin(v[4])) - \
cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - \
(L[2]*v[16]*sin(v[4]))/2.)))/2. - (M[2]*(-(L[2]*v[16]*(v[14] + \
cos(v[3])*L[1]*v[15] + (cos(v[4])*L[2]*v[16])/2.)*sin(v[4])) - \
L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) - \
(cos(v[4])*L[2]*pow(v[16],2))/2.)*sin(v[4]) - cos(v[4])*L[2]*v[16]*(v[13] - \
L[1]*v[15]*sin(v[3]) - (L[2]*v[16]*sin(v[4]))/2.) + \
cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
(L[2]*pow(v[16],2)*sin(v[4]))/2.)))/2. - \
L[2]*sin(v[4])*(-(Cv*pow(cos(v[5]),2)*L[3]*v[13]) + \
Cv*cos(v[5])*L[1]*L[3]*v[15]*sin(v[3] - v[5]) + \
Cv*cos(v[5])*L[2]*L[3]*v[16]*sin(v[4] - v[5]) + \
Cs*cos(v[5])*L[3]*v[14]*sin(v[5]) - Cv*cos(v[5])*L[3]*v[14]*sin(v[5]) + \
Cs*cos(v[3] - v[5])*L[1]*L[3]*v[15]*sin(v[5]) + Cs*cos(v[4] - \
v[5])*L[2]*L[3]*v[16]*sin(v[5]) + (Cs*pow(L[3],2)*v[17]*sin(v[5]))/2. - \
Cs*L[3]*v[13]*pow(sin(v[5]),2)) + \
cos(v[4])*L[2]*(-(Cs*pow(cos(v[5]),2)*L[3]*v[14]) - Cs*cos(v[3] - \
v[5])*cos(v[5])*L[1]*L[3]*v[15] - Cs*cos(v[4] - \
v[5])*cos(v[5])*L[2]*L[3]*v[16] - (Cs*cos(v[5])*pow(L[3],2)*v[17])/2. + \
Cs*cos(v[5])*L[3]*v[13]*sin(v[5]) - Cv*cos(v[5])*L[3]*v[13]*sin(v[5]) + \
Cv*L[1]*L[3]*v[15]*sin(v[3] - v[5])*sin(v[5]) + Cv*L[2]*L[3]*v[16]*sin(v[4] - \
v[5])*sin(v[5]) - Cv*L[3]*v[14]*pow(sin(v[5]),2)) + \
(M[3]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
(cos(v[5])*L[3]*v[17])/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - (L[3]*v[17]*sin(v[5]))/2.)))/2. \
- (M[3]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
(cos(v[5])*L[3]*v[17])/2.)*sin(v[4]) - 2*L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - (cos(v[5])*L[3]*pow(v[17],2))/2.)*sin(v[4]) - \
2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
(L[3]*v[17]*sin(v[5]))/2.) + 2*cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) \
- L[2]*pow(v[16],2)*sin(v[4]) - (L[3]*pow(v[17],2)*sin(v[5]))/2.)))/2. - \
L[2]*sin(v[4])*(-(Cv*pow(cos(v[6]),2)*L[4]*v[13]) + \
Cv*cos(v[6])*L[1]*L[4]*v[15]*sin(v[3] - v[6]) + \
Cv*cos(v[6])*L[2]*L[4]*v[16]*sin(v[4] - v[6]) + \
Cv*cos(v[6])*L[3]*L[4]*v[17]*sin(v[5] - v[6]) + \
Cs*cos(v[6])*L[4]*v[14]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[14]*sin(v[6]) + \
Cs*cos(v[3] - v[6])*L[1]*L[4]*v[15]*sin(v[6]) + Cs*cos(v[4] - \
v[6])*L[2]*L[4]*v[16]*sin(v[6]) + Cs*cos(v[5] - \
v[6])*L[3]*L[4]*v[17]*sin(v[6]) + (Cs*pow(L[4],2)*v[18]*sin(v[6]))/2. - \
Cs*L[4]*v[13]*pow(sin(v[6]),2)) + \
cos(v[4])*L[2]*(-(Cs*pow(cos(v[6]),2)*L[4]*v[14]) - Cs*cos(v[3] - \
v[6])*cos(v[6])*L[1]*L[4]*v[15] - Cs*cos(v[4] - \
v[6])*cos(v[6])*L[2]*L[4]*v[16] - Cs*cos(v[5] - \
v[6])*cos(v[6])*L[3]*L[4]*v[17] - (Cs*cos(v[6])*pow(L[4],2)*v[18])/2. + \
Cs*cos(v[6])*L[4]*v[13]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[13]*sin(v[6]) + \
Cv*L[1]*L[4]*v[15]*sin(v[3] - v[6])*sin(v[6]) + Cv*L[2]*L[4]*v[16]*sin(v[4] - \
v[6])*sin(v[6]) + Cv*L[3]*L[4]*v[17]*sin(v[5] - v[6])*sin(v[6]) - \
Cv*L[4]*v[14]*pow(sin(v[6]),2)) + (M[4]*(-2*L[2]*v[16]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
(cos(v[6])*L[4]*v[18])/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
(L[4]*v[18]*sin(v[6]))/2.)))/2. - (M[4]*(-2*L[2]*v[16]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
(cos(v[6])*L[4]*v[18])/2.)*sin(v[4]) - 2*L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
(cos(v[6])*L[4]*pow(v[18],2))/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
(L[4]*v[18]*sin(v[6]))/2.) + 2*cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) \
- L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
(L[4]*pow(v[18],2)*sin(v[6]))/2.)))/2. - \
(L[2]*L[5]*sin(v[4])*(-(Cs*sin(v[7])*(-2*cos(v[7])*v[14] - 2*cos(v[3] - \
v[7])*L[1]*v[15] - 2*cos(v[4] - v[7])*L[2]*v[16] - 2*cos(v[5] - \
v[7])*L[3]*v[17] - 2*cos(v[6] - v[7])*L[4]*v[18] - L[5]*v[19] + \
2*v[13]*sin(v[7]))) + 2*Cv*cos(v[7])*(-(cos(v[7])*v[13]) + \
L[1]*v[15]*sin(v[3] - v[7]) + L[2]*v[16]*sin(v[4] - v[7]) + \
L[3]*v[17]*sin(v[5] - v[7]) + L[4]*v[18]*sin(v[6] - v[7]) - \
v[14]*sin(v[7]))))/2. - (cos(v[4])*L[2]*L[5]*(Cs*cos(v[7])*(2*cos(v[7])*v[14] \
+ 2*cos(v[3] - v[7])*L[1]*v[15] + 2*cos(v[4] - v[7])*L[2]*v[16] + 2*cos(v[5] \
- v[7])*L[3]*v[17] + 2*cos(v[6] - v[7])*L[4]*v[18] + L[5]*v[19] - \
2*v[13]*sin(v[7])) + 2*Cv*sin(v[7])*(cos(v[7])*v[13] - L[1]*v[15]*sin(v[3] - \
v[7]) - L[2]*v[16]*sin(v[4] - v[7]) - L[3]*v[17]*sin(v[5] - v[7]) - \
L[4]*v[18]*sin(v[6] - v[7]) + v[14]*sin(v[7]))))/2. + \
(M[5]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
(cos(v[7])*L[5]*v[19])/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.)))/2. - \
(M[5]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
(cos(v[7])*L[5]*v[19])/2.)*sin(v[4]) - 2*L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
cos(v[6])*L[4]*pow(v[18],2) - (cos(v[7])*L[5]*pow(v[19],2))/2.)*sin(v[4]) - \
2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.) + \
2*cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - (L[5]*pow(v[19],2)*sin(v[7]))/2.)))/2. - \
(L[2]*L[6]*sin(v[4])*(-(Cs*sin(v[8])*(-2*cos(v[8])*v[14] - 2*cos(v[3] - \
v[8])*L[1]*v[15] - 2*cos(v[4] - v[8])*L[2]*v[16] - 2*cos(v[5] - \
v[8])*L[3]*v[17] - 2*cos(v[6] - v[8])*L[4]*v[18] - 2*cos(v[7] - \
v[8])*L[5]*v[19] - L[6]*v[20] + 2*v[13]*sin(v[8]))) + \
2*Cv*cos(v[8])*(-(cos(v[8])*v[13]) + L[1]*v[15]*sin(v[3] - v[8]) + \
L[2]*v[16]*sin(v[4] - v[8]) + L[3]*v[17]*sin(v[5] - v[8]) + \
L[4]*v[18]*sin(v[6] - v[8]) + L[5]*v[19]*sin(v[7] - v[8]) - \
v[14]*sin(v[8]))))/2. + \
cos(v[4])*L[2]*(-(Cs*cos(v[8])*L[6]*(2*cos(v[8])*v[14] + 2*cos(v[3] - \
v[8])*L[1]*v[15] + 2*cos(v[4] - v[8])*L[2]*v[16] + 2*cos(v[5] - \
v[8])*L[3]*v[17] + 2*cos(v[6] - v[8])*L[4]*v[18] + 2*cos(v[7] - \
v[8])*L[5]*v[19] + L[6]*v[20] - 2*v[13]*sin(v[8])))/2. - \
Cv*L[6]*sin(v[8])*(cos(v[8])*v[13] - L[1]*v[15]*sin(v[3] - v[8]) - \
L[2]*v[16]*sin(v[4] - v[8]) - L[3]*v[17]*sin(v[5] - v[8]) - \
L[4]*v[18]*sin(v[6] - v[8]) - L[5]*v[19]*sin(v[7] - v[8]) + v[14]*sin(v[8]))) \
+ (M[6]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
(cos(v[8])*L[6]*v[20])/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.)))/2. \
- (M[6]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
(cos(v[8])*L[6]*v[20])/2.)*sin(v[4]) - 2*L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - \
(cos(v[8])*L[6]*pow(v[20],2))/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.) + \
2*cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
(L[6]*pow(v[20],2)*sin(v[8]))/2.)))/2. - \
L[2]*sin(v[4])*(-(Cs*L[7]*sin(v[9])*(-2*cos(v[9])*v[14] - 2*cos(v[3] - \
v[9])*L[1]*v[15] - 2*cos(v[4] - v[9])*L[2]*v[16] - 2*cos(v[5] - \
v[9])*L[3]*v[17] - 2*cos(v[6] - v[9])*L[4]*v[18] - 2*cos(v[7] - \
v[9])*L[5]*v[19] - 2*cos(v[8] - v[9])*L[6]*v[20] - L[7]*v[21] + \
2*v[13]*sin(v[9])))/2. - Cv*cos(v[9])*L[7]*(cos(v[9])*v[13] - \
L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - \
L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - \
L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) \
+ cos(v[4])*L[2]*(-(Cs*cos(v[9])*L[7]*(2*cos(v[9])*v[14] + 2*cos(v[3] - \
v[9])*L[1]*v[15] + 2*cos(v[4] - v[9])*L[2]*v[16] + 2*cos(v[5] - \
v[9])*L[3]*v[17] + 2*cos(v[6] - v[9])*L[4]*v[18] + 2*cos(v[7] - \
v[9])*L[5]*v[19] + 2*cos(v[8] - v[9])*L[6]*v[20] + L[7]*v[21] - \
2*v[13]*sin(v[9])))/2. - Cv*L[7]*sin(v[9])*(cos(v[9])*v[13] - \
L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - \
L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - \
L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) \
+ (M[7]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[4]) - \
2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.)))/2. - \
(M[7]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[4]) - \
2*L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
(cos(v[9])*L[7]*pow(v[21],2))/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
(L[7]*v[21]*sin(v[9]))/2.) + 2*cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) \
- L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - (L[7]*pow(v[21],2)*sin(v[9]))/2.)))/2. - \
L[2]*sin(v[4])*(-(Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - \
v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - \
v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - \
v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - \
v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - \
Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10]))) + cos(v[4])*L[2]*(-(Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] \
+ 2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + \
2*cos(v[5] - v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] \
- v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - \
v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - \
Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10]))) + (M[8]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
(cos(v[10])*L[8]*v[22])/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.)))/2. - \
(M[8]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
(cos(v[10])*L[8]*v[22])/2.)*sin(v[4]) - \
2*L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.)*sin(v[4]) - \
2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.) + \
2*cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
(L[8]*pow(v[22],2)*sin(v[10]))/2.)))/2. - \
L[2]*sin(v[4])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - \
v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - \
v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - \
v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - \
v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + \
2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))) + cos(v[4])*L[2]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] \
+ 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + \
2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] \
- v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - \
v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - \
2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))) + (M[9]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[4]) - \
2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
(L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-2*L[2]*v[16]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + \
(cos(v[11])*L[9]*v[23])/2.)*sin(v[4]) - \
2*L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
(cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] \
- L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + \
2*cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - \
L[2]*sin(v[4])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - \
v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - \
v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - \
v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - \
v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - \
v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - \
Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + \
cos(v[4])*L[2]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - \
v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - \
v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - \
v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - \
v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - \
v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - \
Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + (M[10]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - \
(L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[2]*v[16]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[4]) - \
2*L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[4]) \
- 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) \
- L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + \
2*cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - \
(L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;\n coefMat[4] = \
-(L[3]*M[3]*sin(v[5]))/2. - L[3]*M[4]*sin(v[5]) - L[3]*M[5]*sin(v[5]) - \
L[3]*M[6]*sin(v[5]) - L[3]*M[7]*sin(v[5]) - L[3]*M[8]*sin(v[5]) - \
L[3]*M[9]*sin(v[5]) - L[3]*M[10]*sin(v[5]);\n coefMat[16] = \
(cos(v[5])*L[3]*M[3])/2. + cos(v[5])*L[3]*M[4] + cos(v[5])*L[3]*M[5] + \
cos(v[5])*L[3]*M[6] + cos(v[5])*L[3]*M[7] + cos(v[5])*L[3]*M[8] + \
cos(v[5])*L[3]*M[9] + cos(v[5])*L[3]*M[10];\n coefMat[28] = \
(M[3]*(cos(v[3])*cos(v[5])*L[1]*L[3] + L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + \
(M[4]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. \
+ (M[5]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + \
2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[6]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] \
+ 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + \
(M[7]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. \
+ (M[8]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + \
2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[9]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] \
+ 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + \
(M[10]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + \
2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2.;\n coefMat[40] = \
(M[3]*(cos(v[4])*cos(v[5])*L[2]*L[3] + L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + \
(M[4]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. \
+ (M[5]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + \
2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[6]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] \
+ 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + \
(M[7]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. \
+ (M[8]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + \
2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[9]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] \
+ 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + \
(M[10]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + \
2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2.;\n coefMat[52] = (pow(L[3],2)*M[3])/12. \
+ (M[3]*((pow(cos(v[5]),2)*pow(L[3],2))/2. + \
(pow(L[3],2)*pow(sin(v[5]),2))/2.))/2. + \
(M[4]*(2*pow(cos(v[5]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(v[5]),2)))/2. + \
(M[5]*(2*pow(cos(v[5]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(v[5]),2)))/2. + \
(M[6]*(2*pow(cos(v[5]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(v[5]),2)))/2. + \
(M[7]*(2*pow(cos(v[5]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(v[5]),2)))/2. + \
(M[8]*(2*pow(cos(v[5]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(v[5]),2)))/2. + \
(M[9]*(2*pow(cos(v[5]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(v[5]),2)))/2. + \
(M[10]*(2*pow(cos(v[5]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(v[5]),2)))/2.;\
\n coefMat[64] = (M[4]*(cos(v[5])*cos(v[6])*L[3]*L[4] + \
L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + (M[5]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + \
2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + (M[6]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] \
+ 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + \
(M[7]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. \
+ (M[8]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + \
2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + (M[9]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] \
+ 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + \
(M[10]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + \
2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2.;\n coefMat[76] = \
(M[5]*(cos(v[5])*cos(v[7])*L[3]*L[5] + L[3]*L[5]*sin(v[5])*sin(v[7])))/2. + \
(M[6]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + 2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2. \
+ (M[7]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + \
2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2. + (M[8]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] \
+ 2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2. + \
(M[9]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + 2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2. \
+ (M[10]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + \
2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2.;\n coefMat[88] = \
(M[6]*(cos(v[5])*cos(v[8])*L[3]*L[6] + L[3]*L[6]*sin(v[5])*sin(v[8])))/2. + \
(M[7]*(2*cos(v[5])*cos(v[8])*L[3]*L[6] + 2*L[3]*L[6]*sin(v[5])*sin(v[8])))/2. \
+ (M[8]*(2*cos(v[5])*cos(v[8])*L[3]*L[6] + \
2*L[3]*L[6]*sin(v[5])*sin(v[8])))/2. + (M[9]*(2*cos(v[5])*cos(v[8])*L[3]*L[6] \
+ 2*L[3]*L[6]*sin(v[5])*sin(v[8])))/2. + \
(M[10]*(2*cos(v[5])*cos(v[8])*L[3]*L[6] + \
2*L[3]*L[6]*sin(v[5])*sin(v[8])))/2.;\n coefMat[100] = \
(M[7]*(cos(v[5])*cos(v[9])*L[3]*L[7] + L[3]*L[7]*sin(v[5])*sin(v[9])))/2. + \
(M[8]*(2*cos(v[5])*cos(v[9])*L[3]*L[7] + 2*L[3]*L[7]*sin(v[5])*sin(v[9])))/2. \
+ (M[9]*(2*cos(v[5])*cos(v[9])*L[3]*L[7] + \
2*L[3]*L[7]*sin(v[5])*sin(v[9])))/2. + \
(M[10]*(2*cos(v[5])*cos(v[9])*L[3]*L[7] + \
2*L[3]*L[7]*sin(v[5])*sin(v[9])))/2.;\n coefMat[112] = \
(M[8]*(cos(v[5])*cos(v[10])*L[3]*L[8] + L[3]*L[8]*sin(v[5])*sin(v[10])))/2. + \
(M[9]*(2*cos(v[5])*cos(v[10])*L[3]*L[8] + \
2*L[3]*L[8]*sin(v[5])*sin(v[10])))/2. + \
(M[10]*(2*cos(v[5])*cos(v[10])*L[3]*L[8] + \
2*L[3]*L[8]*sin(v[5])*sin(v[10])))/2.;\n coefMat[124] = \
(M[9]*(cos(v[5])*cos(v[11])*L[3]*L[9] + L[3]*L[9]*sin(v[5])*sin(v[11])))/2. + \
(M[10]*(2*cos(v[5])*cos(v[11])*L[3]*L[9] + \
2*L[3]*L[9]*sin(v[5])*sin(v[11])))/2.;\n coefMat[136] = \
(M[10]*(cos(v[5])*cos(v[12])*L[3]*L[10] + \
L[3]*L[10]*sin(v[5])*sin(v[12])))/2.;\n rhsVec[4] = forceRY*cos(v[5])*L[3] - \
(Cs*pow(L[3],3)*v[17])/12. - forceRX*L[3]*sin(v[5]) - \
(L[3]*sin(v[5])*(-(Cv*pow(cos(v[5]),2)*L[3]*v[13]) + \
Cv*cos(v[5])*L[1]*L[3]*v[15]*sin(v[3] - v[5]) + \
Cv*cos(v[5])*L[2]*L[3]*v[16]*sin(v[4] - v[5]) + \
Cs*cos(v[5])*L[3]*v[14]*sin(v[5]) - Cv*cos(v[5])*L[3]*v[14]*sin(v[5]) + \
Cs*cos(v[3] - v[5])*L[1]*L[3]*v[15]*sin(v[5]) + Cs*cos(v[4] - \
v[5])*L[2]*L[3]*v[16]*sin(v[5]) + (Cs*pow(L[3],2)*v[17]*sin(v[5]))/2. - \
Cs*L[3]*v[13]*pow(sin(v[5]),2)))/2. + \
(cos(v[5])*L[3]*(-(Cs*pow(cos(v[5]),2)*L[3]*v[14]) - Cs*cos(v[3] - \
v[5])*cos(v[5])*L[1]*L[3]*v[15] - Cs*cos(v[4] - \
v[5])*cos(v[5])*L[2]*L[3]*v[16] - (Cs*cos(v[5])*pow(L[3],2)*v[17])/2. + \
Cs*cos(v[5])*L[3]*v[13]*sin(v[5]) - Cv*cos(v[5])*L[3]*v[13]*sin(v[5]) + \
Cv*L[1]*L[3]*v[15]*sin(v[3] - v[5])*sin(v[5]) + Cv*L[2]*L[3]*v[16]*sin(v[4] - \
v[5])*sin(v[5]) - Cv*L[3]*v[14]*pow(sin(v[5]),2)))/2. + \
(M[3]*(-(L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
(cos(v[5])*L[3]*v[17])/2.)*sin(v[5])) - cos(v[5])*L[3]*v[17]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - (L[3]*v[17]*sin(v[5]))/2.)))/2. \
- (M[3]*(-(L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
(cos(v[5])*L[3]*v[17])/2.)*sin(v[5])) - L[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - (cos(v[5])*L[3]*pow(v[17],2))/2.)*sin(v[5]) - \
cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
(L[3]*v[17]*sin(v[5]))/2.) + cos(v[5])*L[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - (L[3]*pow(v[17],2)*sin(v[5]))/2.)))/2. - \
L[3]*sin(v[5])*(-(Cv*pow(cos(v[6]),2)*L[4]*v[13]) + \
Cv*cos(v[6])*L[1]*L[4]*v[15]*sin(v[3] - v[6]) + \
Cv*cos(v[6])*L[2]*L[4]*v[16]*sin(v[4] - v[6]) + \
Cv*cos(v[6])*L[3]*L[4]*v[17]*sin(v[5] - v[6]) + \
Cs*cos(v[6])*L[4]*v[14]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[14]*sin(v[6]) + \
Cs*cos(v[3] - v[6])*L[1]*L[4]*v[15]*sin(v[6]) + Cs*cos(v[4] - \
v[6])*L[2]*L[4]*v[16]*sin(v[6]) + Cs*cos(v[5] - \
v[6])*L[3]*L[4]*v[17]*sin(v[6]) + (Cs*pow(L[4],2)*v[18]*sin(v[6]))/2. - \
Cs*L[4]*v[13]*pow(sin(v[6]),2)) + \
cos(v[5])*L[3]*(-(Cs*pow(cos(v[6]),2)*L[4]*v[14]) - Cs*cos(v[3] - \
v[6])*cos(v[6])*L[1]*L[4]*v[15] - Cs*cos(v[4] - \
v[6])*cos(v[6])*L[2]*L[4]*v[16] - Cs*cos(v[5] - \
v[6])*cos(v[6])*L[3]*L[4]*v[17] - (Cs*cos(v[6])*pow(L[4],2)*v[18])/2. + \
Cs*cos(v[6])*L[4]*v[13]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[13]*sin(v[6]) + \
Cv*L[1]*L[4]*v[15]*sin(v[3] - v[6])*sin(v[6]) + Cv*L[2]*L[4]*v[16]*sin(v[4] - \
v[6])*sin(v[6]) + Cv*L[3]*L[4]*v[17]*sin(v[5] - v[6])*sin(v[6]) - \
Cv*L[4]*v[14]*pow(sin(v[6]),2)) + (M[4]*(-2*L[3]*v[17]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
(cos(v[6])*L[4]*v[18])/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
(L[4]*v[18]*sin(v[6]))/2.)))/2. - (M[4]*(-2*L[3]*v[17]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
(cos(v[6])*L[4]*v[18])/2.)*sin(v[5]) - 2*L[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
(cos(v[6])*L[4]*pow(v[18],2))/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
(L[4]*v[18]*sin(v[6]))/2.) + 2*cos(v[5])*L[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) \
- L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
(L[4]*pow(v[18],2)*sin(v[6]))/2.)))/2. - \
(L[3]*L[5]*sin(v[5])*(-(Cs*sin(v[7])*(-2*cos(v[7])*v[14] - 2*cos(v[3] - \
v[7])*L[1]*v[15] - 2*cos(v[4] - v[7])*L[2]*v[16] - 2*cos(v[5] - \
v[7])*L[3]*v[17] - 2*cos(v[6] - v[7])*L[4]*v[18] - L[5]*v[19] + \
2*v[13]*sin(v[7]))) + 2*Cv*cos(v[7])*(-(cos(v[7])*v[13]) + \
L[1]*v[15]*sin(v[3] - v[7]) + L[2]*v[16]*sin(v[4] - v[7]) + \
L[3]*v[17]*sin(v[5] - v[7]) + L[4]*v[18]*sin(v[6] - v[7]) - \
v[14]*sin(v[7]))))/2. - (cos(v[5])*L[3]*L[5]*(Cs*cos(v[7])*(2*cos(v[7])*v[14] \
+ 2*cos(v[3] - v[7])*L[1]*v[15] + 2*cos(v[4] - v[7])*L[2]*v[16] + 2*cos(v[5] \
- v[7])*L[3]*v[17] + 2*cos(v[6] - v[7])*L[4]*v[18] + L[5]*v[19] - \
2*v[13]*sin(v[7])) + 2*Cv*sin(v[7])*(cos(v[7])*v[13] - L[1]*v[15]*sin(v[3] - \
v[7]) - L[2]*v[16]*sin(v[4] - v[7]) - L[3]*v[17]*sin(v[5] - v[7]) - \
L[4]*v[18]*sin(v[6] - v[7]) + v[14]*sin(v[7]))))/2. + \
(M[5]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
(cos(v[7])*L[5]*v[19])/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.)))/2. - \
(M[5]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
(cos(v[7])*L[5]*v[19])/2.)*sin(v[5]) - 2*L[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
cos(v[6])*L[4]*pow(v[18],2) - (cos(v[7])*L[5]*pow(v[19],2))/2.)*sin(v[5]) - \
2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.) + \
2*cos(v[5])*L[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - (L[5]*pow(v[19],2)*sin(v[7]))/2.)))/2. - \
(L[3]*L[6]*sin(v[5])*(-(Cs*sin(v[8])*(-2*cos(v[8])*v[14] - 2*cos(v[3] - \
v[8])*L[1]*v[15] - 2*cos(v[4] - v[8])*L[2]*v[16] - 2*cos(v[5] - \
v[8])*L[3]*v[17] - 2*cos(v[6] - v[8])*L[4]*v[18] - 2*cos(v[7] - \
v[8])*L[5]*v[19] - L[6]*v[20] + 2*v[13]*sin(v[8]))) + \
2*Cv*cos(v[8])*(-(cos(v[8])*v[13]) + L[1]*v[15]*sin(v[3] - v[8]) + \
L[2]*v[16]*sin(v[4] - v[8]) + L[3]*v[17]*sin(v[5] - v[8]) + \
L[4]*v[18]*sin(v[6] - v[8]) + L[5]*v[19]*sin(v[7] - v[8]) - \
v[14]*sin(v[8]))))/2. + \
cos(v[5])*L[3]*(-(Cs*cos(v[8])*L[6]*(2*cos(v[8])*v[14] + 2*cos(v[3] - \
v[8])*L[1]*v[15] + 2*cos(v[4] - v[8])*L[2]*v[16] + 2*cos(v[5] - \
v[8])*L[3]*v[17] + 2*cos(v[6] - v[8])*L[4]*v[18] + 2*cos(v[7] - \
v[8])*L[5]*v[19] + L[6]*v[20] - 2*v[13]*sin(v[8])))/2. - \
Cv*L[6]*sin(v[8])*(cos(v[8])*v[13] - L[1]*v[15]*sin(v[3] - v[8]) - \
L[2]*v[16]*sin(v[4] - v[8]) - L[3]*v[17]*sin(v[5] - v[8]) - \
L[4]*v[18]*sin(v[6] - v[8]) - L[5]*v[19]*sin(v[7] - v[8]) + v[14]*sin(v[8]))) \
+ (M[6]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
(cos(v[8])*L[6]*v[20])/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.)))/2. \
- (M[6]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
(cos(v[8])*L[6]*v[20])/2.)*sin(v[5]) - 2*L[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - \
(cos(v[8])*L[6]*pow(v[20],2))/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.) + \
2*cos(v[5])*L[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
(L[6]*pow(v[20],2)*sin(v[8]))/2.)))/2. - \
L[3]*sin(v[5])*(-(Cs*L[7]*sin(v[9])*(-2*cos(v[9])*v[14] - 2*cos(v[3] - \
v[9])*L[1]*v[15] - 2*cos(v[4] - v[9])*L[2]*v[16] - 2*cos(v[5] - \
v[9])*L[3]*v[17] - 2*cos(v[6] - v[9])*L[4]*v[18] - 2*cos(v[7] - \
v[9])*L[5]*v[19] - 2*cos(v[8] - v[9])*L[6]*v[20] - L[7]*v[21] + \
2*v[13]*sin(v[9])))/2. - Cv*cos(v[9])*L[7]*(cos(v[9])*v[13] - \
L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - \
L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - \
L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) \
+ cos(v[5])*L[3]*(-(Cs*cos(v[9])*L[7]*(2*cos(v[9])*v[14] + 2*cos(v[3] - \
v[9])*L[1]*v[15] + 2*cos(v[4] - v[9])*L[2]*v[16] + 2*cos(v[5] - \
v[9])*L[3]*v[17] + 2*cos(v[6] - v[9])*L[4]*v[18] + 2*cos(v[7] - \
v[9])*L[5]*v[19] + 2*cos(v[8] - v[9])*L[6]*v[20] + L[7]*v[21] - \
2*v[13]*sin(v[9])))/2. - Cv*L[7]*sin(v[9])*(cos(v[9])*v[13] - \
L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - \
L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - \
L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) \
+ (M[7]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[5]) - \
2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.)))/2. - \
(M[7]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[5]) - \
2*L[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
(cos(v[9])*L[7]*pow(v[21],2))/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
(L[7]*v[21]*sin(v[9]))/2.) + 2*cos(v[5])*L[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) \
- L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - (L[7]*pow(v[21],2)*sin(v[9]))/2.)))/2. - \
L[3]*sin(v[5])*(-(Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - \
v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - \
v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - \
v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - \
v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - \
Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10]))) + cos(v[5])*L[3]*(-(Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] \
+ 2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + \
2*cos(v[5] - v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] \
- v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - \
v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - \
Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10]))) + (M[8]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
(cos(v[10])*L[8]*v[22])/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.)))/2. - \
(M[8]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
(cos(v[10])*L[8]*v[22])/2.)*sin(v[5]) - \
2*L[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.)*sin(v[5]) - \
2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.) + \
2*cos(v[5])*L[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
(L[8]*pow(v[22],2)*sin(v[10]))/2.)))/2. - \
L[3]*sin(v[5])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - \
v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - \
v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - \
v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - \
v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + \
2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))) + cos(v[5])*L[3]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] \
+ 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + \
2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] \
- v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - \
v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - \
2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))) + (M[9]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[5]) - \
2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
(L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-2*L[3]*v[17]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + \
(cos(v[11])*L[9]*v[23])/2.)*sin(v[5]) - \
2*L[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
(cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] \
- L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + \
2*cos(v[5])*L[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - \
L[3]*sin(v[5])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - \
v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - \
v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - \
v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - \
v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - \
v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - \
Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + \
cos(v[5])*L[3]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - \
v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - \
v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - \
v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - \
v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - \
v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - \
Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + (M[10]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - \
(L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[3]*v[17]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[5]) - \
2*L[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[5]) \
- 2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) \
- L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + \
2*cos(v[5])*L[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - \
(L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;\n coefMat[5] = \
-(L[4]*M[4]*sin(v[6]))/2. - L[4]*M[5]*sin(v[6]) - L[4]*M[6]*sin(v[6]) - \
L[4]*M[7]*sin(v[6]) - L[4]*M[8]*sin(v[6]) - L[4]*M[9]*sin(v[6]) - \
L[4]*M[10]*sin(v[6]);\n coefMat[17] = (cos(v[6])*L[4]*M[4])/2. + \
cos(v[6])*L[4]*M[5] + cos(v[6])*L[4]*M[6] + cos(v[6])*L[4]*M[7] + \
cos(v[6])*L[4]*M[8] + cos(v[6])*L[4]*M[9] + cos(v[6])*L[4]*M[10];\n \
coefMat[29] = (M[4]*(cos(v[3])*cos(v[6])*L[1]*L[4] + \
L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + (M[5]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + \
2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + (M[6]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] \
+ 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + \
(M[7]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. \
+ (M[8]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + \
2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + (M[9]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] \
+ 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + \
(M[10]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + \
2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2.;\n coefMat[41] = \
(M[4]*(cos(v[4])*cos(v[6])*L[2]*L[4] + L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + \
(M[5]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. \
+ (M[6]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + \
2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + (M[7]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] \
+ 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + \
(M[8]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. \
+ (M[9]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + \
2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + \
(M[10]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + \
2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2.;\n coefMat[53] = \
(M[4]*(cos(v[5])*cos(v[6])*L[3]*L[4] + L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + \
(M[5]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. \
+ (M[6]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + \
2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + (M[7]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] \
+ 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + \
(M[8]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. \
+ (M[9]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + \
2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + \
(M[10]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + \
2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2.;\n coefMat[65] = (pow(L[4],2)*M[4])/12. \
+ (M[4]*((pow(cos(v[6]),2)*pow(L[4],2))/2. + \
(pow(L[4],2)*pow(sin(v[6]),2))/2.))/2. + \
(M[5]*(2*pow(cos(v[6]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(v[6]),2)))/2. + \
(M[6]*(2*pow(cos(v[6]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(v[6]),2)))/2. + \
(M[7]*(2*pow(cos(v[6]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(v[6]),2)))/2. + \
(M[8]*(2*pow(cos(v[6]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(v[6]),2)))/2. + \
(M[9]*(2*pow(cos(v[6]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(v[6]),2)))/2. + \
(M[10]*(2*pow(cos(v[6]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(v[6]),2)))/2.;\
\n coefMat[77] = (M[5]*(cos(v[6])*cos(v[7])*L[4]*L[5] + \
L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + (M[6]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + \
2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + (M[7]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] \
+ 2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + \
(M[8]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + 2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2. \
+ (M[9]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + \
2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + \
(M[10]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + \
2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2.;\n coefMat[89] = \
(M[6]*(cos(v[6])*cos(v[8])*L[4]*L[6] + L[4]*L[6]*sin(v[6])*sin(v[8])))/2. + \
(M[7]*(2*cos(v[6])*cos(v[8])*L[4]*L[6] + 2*L[4]*L[6]*sin(v[6])*sin(v[8])))/2. \
+ (M[8]*(2*cos(v[6])*cos(v[8])*L[4]*L[6] + \
2*L[4]*L[6]*sin(v[6])*sin(v[8])))/2. + (M[9]*(2*cos(v[6])*cos(v[8])*L[4]*L[6] \
+ 2*L[4]*L[6]*sin(v[6])*sin(v[8])))/2. + \
(M[10]*(2*cos(v[6])*cos(v[8])*L[4]*L[6] + \
2*L[4]*L[6]*sin(v[6])*sin(v[8])))/2.;\n coefMat[101] = \
(M[7]*(cos(v[6])*cos(v[9])*L[4]*L[7] + L[4]*L[7]*sin(v[6])*sin(v[9])))/2. + \
(M[8]*(2*cos(v[6])*cos(v[9])*L[4]*L[7] + 2*L[4]*L[7]*sin(v[6])*sin(v[9])))/2. \
+ (M[9]*(2*cos(v[6])*cos(v[9])*L[4]*L[7] + \
2*L[4]*L[7]*sin(v[6])*sin(v[9])))/2. + \
(M[10]*(2*cos(v[6])*cos(v[9])*L[4]*L[7] + \
2*L[4]*L[7]*sin(v[6])*sin(v[9])))/2.;\n coefMat[113] = \
(M[8]*(cos(v[6])*cos(v[10])*L[4]*L[8] + L[4]*L[8]*sin(v[6])*sin(v[10])))/2. + \
(M[9]*(2*cos(v[6])*cos(v[10])*L[4]*L[8] + \
2*L[4]*L[8]*sin(v[6])*sin(v[10])))/2. + \
(M[10]*(2*cos(v[6])*cos(v[10])*L[4]*L[8] + \
2*L[4]*L[8]*sin(v[6])*sin(v[10])))/2.;\n coefMat[125] = \
(M[9]*(cos(v[6])*cos(v[11])*L[4]*L[9] + L[4]*L[9]*sin(v[6])*sin(v[11])))/2. + \
(M[10]*(2*cos(v[6])*cos(v[11])*L[4]*L[9] + \
2*L[4]*L[9]*sin(v[6])*sin(v[11])))/2.;\n coefMat[137] = \
(M[10]*(cos(v[6])*cos(v[12])*L[4]*L[10] + \
L[4]*L[10]*sin(v[6])*sin(v[12])))/2.;\n rhsVec[5] = forceRY*cos(v[6])*L[4] - \
(Cs*pow(L[4],3)*v[18])/12. - forceRX*L[4]*sin(v[6]) - \
(L[4]*sin(v[6])*(-(Cv*pow(cos(v[6]),2)*L[4]*v[13]) + \
Cv*cos(v[6])*L[1]*L[4]*v[15]*sin(v[3] - v[6]) + \
Cv*cos(v[6])*L[2]*L[4]*v[16]*sin(v[4] - v[6]) + \
Cv*cos(v[6])*L[3]*L[4]*v[17]*sin(v[5] - v[6]) + \
Cs*cos(v[6])*L[4]*v[14]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[14]*sin(v[6]) + \
Cs*cos(v[3] - v[6])*L[1]*L[4]*v[15]*sin(v[6]) + Cs*cos(v[4] - \
v[6])*L[2]*L[4]*v[16]*sin(v[6]) + Cs*cos(v[5] - \
v[6])*L[3]*L[4]*v[17]*sin(v[6]) + (Cs*pow(L[4],2)*v[18]*sin(v[6]))/2. - \
Cs*L[4]*v[13]*pow(sin(v[6]),2)))/2. + \
(cos(v[6])*L[4]*(-(Cs*pow(cos(v[6]),2)*L[4]*v[14]) - Cs*cos(v[3] - \
v[6])*cos(v[6])*L[1]*L[4]*v[15] - Cs*cos(v[4] - \
v[6])*cos(v[6])*L[2]*L[4]*v[16] - Cs*cos(v[5] - \
v[6])*cos(v[6])*L[3]*L[4]*v[17] - (Cs*cos(v[6])*pow(L[4],2)*v[18])/2. + \
Cs*cos(v[6])*L[4]*v[13]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[13]*sin(v[6]) + \
Cv*L[1]*L[4]*v[15]*sin(v[3] - v[6])*sin(v[6]) + Cv*L[2]*L[4]*v[16]*sin(v[4] - \
v[6])*sin(v[6]) + Cv*L[3]*L[4]*v[17]*sin(v[5] - v[6])*sin(v[6]) - \
Cv*L[4]*v[14]*pow(sin(v[6]),2)))/2. + (M[4]*(-(L[4]*v[18]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
(cos(v[6])*L[4]*v[18])/2.)*sin(v[6])) - cos(v[6])*L[4]*v[18]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
(L[4]*v[18]*sin(v[6]))/2.)))/2. - (M[4]*(-(L[4]*v[18]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
(cos(v[6])*L[4]*v[18])/2.)*sin(v[6])) - L[4]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
(cos(v[6])*L[4]*pow(v[18],2))/2.)*sin(v[6]) - cos(v[6])*L[4]*v[18]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
(L[4]*v[18]*sin(v[6]))/2.) + cos(v[6])*L[4]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
(L[4]*pow(v[18],2)*sin(v[6]))/2.)))/2. - \
(L[4]*L[5]*sin(v[6])*(-(Cs*sin(v[7])*(-2*cos(v[7])*v[14] - 2*cos(v[3] - \
v[7])*L[1]*v[15] - 2*cos(v[4] - v[7])*L[2]*v[16] - 2*cos(v[5] - \
v[7])*L[3]*v[17] - 2*cos(v[6] - v[7])*L[4]*v[18] - L[5]*v[19] + \
2*v[13]*sin(v[7]))) + 2*Cv*cos(v[7])*(-(cos(v[7])*v[13]) + \
L[1]*v[15]*sin(v[3] - v[7]) + L[2]*v[16]*sin(v[4] - v[7]) + \
L[3]*v[17]*sin(v[5] - v[7]) + L[4]*v[18]*sin(v[6] - v[7]) - \
v[14]*sin(v[7]))))/2. - (cos(v[6])*L[4]*L[5]*(Cs*cos(v[7])*(2*cos(v[7])*v[14] \
+ 2*cos(v[3] - v[7])*L[1]*v[15] + 2*cos(v[4] - v[7])*L[2]*v[16] + 2*cos(v[5] \
- v[7])*L[3]*v[17] + 2*cos(v[6] - v[7])*L[4]*v[18] + L[5]*v[19] - \
2*v[13]*sin(v[7])) + 2*Cv*sin(v[7])*(cos(v[7])*v[13] - L[1]*v[15]*sin(v[3] - \
v[7]) - L[2]*v[16]*sin(v[4] - v[7]) - L[3]*v[17]*sin(v[5] - v[7]) - \
L[4]*v[18]*sin(v[6] - v[7]) + v[14]*sin(v[7]))))/2. + \
(M[5]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
(cos(v[7])*L[5]*v[19])/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.)))/2. - \
(M[5]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
(cos(v[7])*L[5]*v[19])/2.)*sin(v[6]) - 2*L[4]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
cos(v[6])*L[4]*pow(v[18],2) - (cos(v[7])*L[5]*pow(v[19],2))/2.)*sin(v[6]) - \
2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.) + \
2*cos(v[6])*L[4]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - (L[5]*pow(v[19],2)*sin(v[7]))/2.)))/2. - \
(L[4]*L[6]*sin(v[6])*(-(Cs*sin(v[8])*(-2*cos(v[8])*v[14] - 2*cos(v[3] - \
v[8])*L[1]*v[15] - 2*cos(v[4] - v[8])*L[2]*v[16] - 2*cos(v[5] - \
v[8])*L[3]*v[17] - 2*cos(v[6] - v[8])*L[4]*v[18] - 2*cos(v[7] - \
v[8])*L[5]*v[19] - L[6]*v[20] + 2*v[13]*sin(v[8]))) + \
2*Cv*cos(v[8])*(-(cos(v[8])*v[13]) + L[1]*v[15]*sin(v[3] - v[8]) + \
L[2]*v[16]*sin(v[4] - v[8]) + L[3]*v[17]*sin(v[5] - v[8]) + \
L[4]*v[18]*sin(v[6] - v[8]) + L[5]*v[19]*sin(v[7] - v[8]) - \
v[14]*sin(v[8]))))/2. + \
cos(v[6])*L[4]*(-(Cs*cos(v[8])*L[6]*(2*cos(v[8])*v[14] + 2*cos(v[3] - \
v[8])*L[1]*v[15] + 2*cos(v[4] - v[8])*L[2]*v[16] + 2*cos(v[5] - \
v[8])*L[3]*v[17] + 2*cos(v[6] - v[8])*L[4]*v[18] + 2*cos(v[7] - \
v[8])*L[5]*v[19] + L[6]*v[20] - 2*v[13]*sin(v[8])))/2. - \
Cv*L[6]*sin(v[8])*(cos(v[8])*v[13] - L[1]*v[15]*sin(v[3] - v[8]) - \
L[2]*v[16]*sin(v[4] - v[8]) - L[3]*v[17]*sin(v[5] - v[8]) - \
L[4]*v[18]*sin(v[6] - v[8]) - L[5]*v[19]*sin(v[7] - v[8]) + v[14]*sin(v[8]))) \
+ (M[6]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
(cos(v[8])*L[6]*v[20])/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.)))/2. \
- (M[6]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
(cos(v[8])*L[6]*v[20])/2.)*sin(v[6]) - 2*L[4]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - \
(cos(v[8])*L[6]*pow(v[20],2))/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.) + \
2*cos(v[6])*L[4]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
(L[6]*pow(v[20],2)*sin(v[8]))/2.)))/2. - \
L[4]*sin(v[6])*(-(Cs*L[7]*sin(v[9])*(-2*cos(v[9])*v[14] - 2*cos(v[3] - \
v[9])*L[1]*v[15] - 2*cos(v[4] - v[9])*L[2]*v[16] - 2*cos(v[5] - \
v[9])*L[3]*v[17] - 2*cos(v[6] - v[9])*L[4]*v[18] - 2*cos(v[7] - \
v[9])*L[5]*v[19] - 2*cos(v[8] - v[9])*L[6]*v[20] - L[7]*v[21] + \
2*v[13]*sin(v[9])))/2. - Cv*cos(v[9])*L[7]*(cos(v[9])*v[13] - \
L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - \
L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - \
L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) \
+ cos(v[6])*L[4]*(-(Cs*cos(v[9])*L[7]*(2*cos(v[9])*v[14] + 2*cos(v[3] - \
v[9])*L[1]*v[15] + 2*cos(v[4] - v[9])*L[2]*v[16] + 2*cos(v[5] - \
v[9])*L[3]*v[17] + 2*cos(v[6] - v[9])*L[4]*v[18] + 2*cos(v[7] - \
v[9])*L[5]*v[19] + 2*cos(v[8] - v[9])*L[6]*v[20] + L[7]*v[21] - \
2*v[13]*sin(v[9])))/2. - Cv*L[7]*sin(v[9])*(cos(v[9])*v[13] - \
L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - \
L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - \
L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) \
+ (M[7]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[6]) - \
2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.)))/2. - \
(M[7]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[6]) - \
2*L[4]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
(cos(v[9])*L[7]*pow(v[21],2))/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
(L[7]*v[21]*sin(v[9]))/2.) + 2*cos(v[6])*L[4]*(-(L[1]*pow(v[15],2)*sin(v[3])) \
- L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - (L[7]*pow(v[21],2)*sin(v[9]))/2.)))/2. - \
L[4]*sin(v[6])*(-(Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - \
v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - \
v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - \
v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - \
v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - \
Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10]))) + cos(v[6])*L[4]*(-(Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] \
+ 2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + \
2*cos(v[5] - v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] \
- v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - \
v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - \
Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10]))) + (M[8]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
(cos(v[10])*L[8]*v[22])/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.)))/2. - \
(M[8]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
(cos(v[10])*L[8]*v[22])/2.)*sin(v[6]) - \
2*L[4]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.)*sin(v[6]) - \
2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.) + \
2*cos(v[6])*L[4]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
(L[8]*pow(v[22],2)*sin(v[10]))/2.)))/2. - \
L[4]*sin(v[6])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - \
v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - \
v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - \
v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - \
v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + \
2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))) + cos(v[6])*L[4]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] \
+ 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + \
2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] \
- v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - \
v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - \
2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))) + (M[9]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[6]) - \
2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
(L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-2*L[4]*v[18]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + \
(cos(v[11])*L[9]*v[23])/2.)*sin(v[6]) - \
2*L[4]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
(cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] \
- L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + \
2*cos(v[6])*L[4]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - \
L[4]*sin(v[6])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - \
v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - \
v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - \
v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - \
v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - \
v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - \
Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + \
cos(v[6])*L[4]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - \
v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - \
v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - \
v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - \
v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - \
v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - \
Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + (M[10]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - \
(L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[4]*v[18]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[6]) - \
2*L[4]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[6]) \
- 2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) \
- L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + \
2*cos(v[6])*L[4]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - \
(L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;\n coefMat[6] = \
-(L[5]*M[5]*sin(v[7]))/2. - L[5]*M[6]*sin(v[7]) - L[5]*M[7]*sin(v[7]) - \
L[5]*M[8]*sin(v[7]) - L[5]*M[9]*sin(v[7]) - L[5]*M[10]*sin(v[7]);\n \
coefMat[18] = (cos(v[7])*L[5]*M[5])/2. + cos(v[7])*L[5]*M[6] + \
cos(v[7])*L[5]*M[7] + cos(v[7])*L[5]*M[8] + cos(v[7])*L[5]*M[9] + \
cos(v[7])*L[5]*M[10];\n coefMat[30] = (M[5]*(cos(v[3])*cos(v[7])*L[1]*L[5] + \
L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + (M[6]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + \
2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + (M[7]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] \
+ 2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + \
(M[8]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + 2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2. \
+ (M[9]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + \
2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + \
(M[10]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + \
2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2.;\n coefMat[42] = \
(M[5]*(cos(v[4])*cos(v[7])*L[2]*L[5] + L[2]*L[5]*sin(v[4])*sin(v[7])))/2. + \
(M[6]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + 2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2. \
+ (M[7]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + \
2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2. + (M[8]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] \
+ 2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2. + \
(M[9]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + 2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2. \
+ (M[10]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + \
2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2.;\n coefMat[54] = \
(M[5]*(cos(v[5])*cos(v[7])*L[3]*L[5] + L[3]*L[5]*sin(v[5])*sin(v[7])))/2. + \
(M[6]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + 2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2. \
+ (M[7]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + \
2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2. + (M[8]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] \
+ 2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2. + \
(M[9]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + 2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2. \
+ (M[10]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + \
2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2.;\n coefMat[66] = \
(M[5]*(cos(v[6])*cos(v[7])*L[4]*L[5] + L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + \
(M[6]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + 2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2. \
+ (M[7]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + \
2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + (M[8]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] \
+ 2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + \
(M[9]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + 2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2. \
+ (M[10]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + \
2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2.;\n coefMat[78] = (pow(L[5],2)*M[5])/12. \
+ (M[5]*((pow(cos(v[7]),2)*pow(L[5],2))/2. + \
(pow(L[5],2)*pow(sin(v[7]),2))/2.))/2. + \
(M[6]*(2*pow(cos(v[7]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(v[7]),2)))/2. + \
(M[7]*(2*pow(cos(v[7]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(v[7]),2)))/2. + \
(M[8]*(2*pow(cos(v[7]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(v[7]),2)))/2. + \
(M[9]*(2*pow(cos(v[7]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(v[7]),2)))/2. + \
(M[10]*(2*pow(cos(v[7]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(v[7]),2)))/2.;\
\n coefMat[90] = (M[6]*(cos(v[7])*cos(v[8])*L[5]*L[6] + \
L[5]*L[6]*sin(v[7])*sin(v[8])))/2. + (M[7]*(2*cos(v[7])*cos(v[8])*L[5]*L[6] + \
2*L[5]*L[6]*sin(v[7])*sin(v[8])))/2. + (M[8]*(2*cos(v[7])*cos(v[8])*L[5]*L[6] \
+ 2*L[5]*L[6]*sin(v[7])*sin(v[8])))/2. + \
(M[9]*(2*cos(v[7])*cos(v[8])*L[5]*L[6] + 2*L[5]*L[6]*sin(v[7])*sin(v[8])))/2. \
+ (M[10]*(2*cos(v[7])*cos(v[8])*L[5]*L[6] + \
2*L[5]*L[6]*sin(v[7])*sin(v[8])))/2.;\n coefMat[102] = \
(M[7]*(cos(v[7])*cos(v[9])*L[5]*L[7] + L[5]*L[7]*sin(v[7])*sin(v[9])))/2. + \
(M[8]*(2*cos(v[7])*cos(v[9])*L[5]*L[7] + 2*L[5]*L[7]*sin(v[7])*sin(v[9])))/2. \
+ (M[9]*(2*cos(v[7])*cos(v[9])*L[5]*L[7] + \
2*L[5]*L[7]*sin(v[7])*sin(v[9])))/2. + \
(M[10]*(2*cos(v[7])*cos(v[9])*L[5]*L[7] + \
2*L[5]*L[7]*sin(v[7])*sin(v[9])))/2.;\n coefMat[114] = \
(M[8]*(cos(v[7])*cos(v[10])*L[5]*L[8] + L[5]*L[8]*sin(v[7])*sin(v[10])))/2. + \
(M[9]*(2*cos(v[7])*cos(v[10])*L[5]*L[8] + \
2*L[5]*L[8]*sin(v[7])*sin(v[10])))/2. + \
(M[10]*(2*cos(v[7])*cos(v[10])*L[5]*L[8] + \
2*L[5]*L[8]*sin(v[7])*sin(v[10])))/2.;\n coefMat[126] = \
(M[9]*(cos(v[7])*cos(v[11])*L[5]*L[9] + L[5]*L[9]*sin(v[7])*sin(v[11])))/2. + \
(M[10]*(2*cos(v[7])*cos(v[11])*L[5]*L[9] + \
2*L[5]*L[9]*sin(v[7])*sin(v[11])))/2.;\n coefMat[138] = \
(M[10]*(cos(v[7])*cos(v[12])*L[5]*L[10] + \
L[5]*L[10]*sin(v[7])*sin(v[12])))/2.;\n rhsVec[6] = forceRY*cos(v[7])*L[5] - \
(Cs*pow(L[5],3)*v[19])/12. - forceRX*L[5]*sin(v[7]) - \
(pow(L[5],2)*sin(v[7])*(-(Cs*sin(v[7])*(-2*cos(v[7])*v[14] - 2*cos(v[3] - \
v[7])*L[1]*v[15] - 2*cos(v[4] - v[7])*L[2]*v[16] - 2*cos(v[5] - \
v[7])*L[3]*v[17] - 2*cos(v[6] - v[7])*L[4]*v[18] - L[5]*v[19] + \
2*v[13]*sin(v[7]))) + 2*Cv*cos(v[7])*(-(cos(v[7])*v[13]) + \
L[1]*v[15]*sin(v[3] - v[7]) + L[2]*v[16]*sin(v[4] - v[7]) + \
L[3]*v[17]*sin(v[5] - v[7]) + L[4]*v[18]*sin(v[6] - v[7]) - \
v[14]*sin(v[7]))))/4. - \
(cos(v[7])*pow(L[5],2)*(Cs*cos(v[7])*(2*cos(v[7])*v[14] + 2*cos(v[3] - \
v[7])*L[1]*v[15] + 2*cos(v[4] - v[7])*L[2]*v[16] + 2*cos(v[5] - \
v[7])*L[3]*v[17] + 2*cos(v[6] - v[7])*L[4]*v[18] + L[5]*v[19] - \
2*v[13]*sin(v[7])) + 2*Cv*sin(v[7])*(cos(v[7])*v[13] - L[1]*v[15]*sin(v[3] - \
v[7]) - L[2]*v[16]*sin(v[4] - v[7]) - L[3]*v[17]*sin(v[5] - v[7]) - \
L[4]*v[18]*sin(v[6] - v[7]) + v[14]*sin(v[7]))))/4. + \
(M[5]*(-(L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
(cos(v[7])*L[5]*v[19])/2.)*sin(v[7])) - cos(v[7])*L[5]*v[19]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.)))/2. - \
(M[5]*(-(L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
(cos(v[7])*L[5]*v[19])/2.)*sin(v[7])) - L[5]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
cos(v[6])*L[4]*pow(v[18],2) - (cos(v[7])*L[5]*pow(v[19],2))/2.)*sin(v[7]) - \
cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.) + \
cos(v[7])*L[5]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) \
- L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - \
(L[5]*pow(v[19],2)*sin(v[7]))/2.)))/2. - \
(L[5]*L[6]*sin(v[7])*(-(Cs*sin(v[8])*(-2*cos(v[8])*v[14] - 2*cos(v[3] - \
v[8])*L[1]*v[15] - 2*cos(v[4] - v[8])*L[2]*v[16] - 2*cos(v[5] - \
v[8])*L[3]*v[17] - 2*cos(v[6] - v[8])*L[4]*v[18] - 2*cos(v[7] - \
v[8])*L[5]*v[19] - L[6]*v[20] + 2*v[13]*sin(v[8]))) + \
2*Cv*cos(v[8])*(-(cos(v[8])*v[13]) + L[1]*v[15]*sin(v[3] - v[8]) + \
L[2]*v[16]*sin(v[4] - v[8]) + L[3]*v[17]*sin(v[5] - v[8]) + \
L[4]*v[18]*sin(v[6] - v[8]) + L[5]*v[19]*sin(v[7] - v[8]) - \
v[14]*sin(v[8]))))/2. + \
cos(v[7])*L[5]*(-(Cs*cos(v[8])*L[6]*(2*cos(v[8])*v[14] + 2*cos(v[3] - \
v[8])*L[1]*v[15] + 2*cos(v[4] - v[8])*L[2]*v[16] + 2*cos(v[5] - \
v[8])*L[3]*v[17] + 2*cos(v[6] - v[8])*L[4]*v[18] + 2*cos(v[7] - \
v[8])*L[5]*v[19] + L[6]*v[20] - 2*v[13]*sin(v[8])))/2. - \
Cv*L[6]*sin(v[8])*(cos(v[8])*v[13] - L[1]*v[15]*sin(v[3] - v[8]) - \
L[2]*v[16]*sin(v[4] - v[8]) - L[3]*v[17]*sin(v[5] - v[8]) - \
L[4]*v[18]*sin(v[6] - v[8]) - L[5]*v[19]*sin(v[7] - v[8]) + v[14]*sin(v[8]))) \
+ (M[6]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
(cos(v[8])*L[6]*v[20])/2.)*sin(v[7]) - 2*cos(v[7])*L[5]*v[19]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.)))/2. \
- (M[6]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
(cos(v[8])*L[6]*v[20])/2.)*sin(v[7]) - 2*L[5]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - \
(cos(v[8])*L[6]*pow(v[20],2))/2.)*sin(v[7]) - 2*cos(v[7])*L[5]*v[19]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.) + \
2*cos(v[7])*L[5]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
(L[6]*pow(v[20],2)*sin(v[8]))/2.)))/2. - \
L[5]*sin(v[7])*(-(Cs*L[7]*sin(v[9])*(-2*cos(v[9])*v[14] - 2*cos(v[3] - \
v[9])*L[1]*v[15] - 2*cos(v[4] - v[9])*L[2]*v[16] - 2*cos(v[5] - \
v[9])*L[3]*v[17] - 2*cos(v[6] - v[9])*L[4]*v[18] - 2*cos(v[7] - \
v[9])*L[5]*v[19] - 2*cos(v[8] - v[9])*L[6]*v[20] - L[7]*v[21] + \
2*v[13]*sin(v[9])))/2. - Cv*cos(v[9])*L[7]*(cos(v[9])*v[13] - \
L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - \
L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - \
L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) \
+ cos(v[7])*L[5]*(-(Cs*cos(v[9])*L[7]*(2*cos(v[9])*v[14] + 2*cos(v[3] - \
v[9])*L[1]*v[15] + 2*cos(v[4] - v[9])*L[2]*v[16] + 2*cos(v[5] - \
v[9])*L[3]*v[17] + 2*cos(v[6] - v[9])*L[4]*v[18] + 2*cos(v[7] - \
v[9])*L[5]*v[19] + 2*cos(v[8] - v[9])*L[6]*v[20] + L[7]*v[21] - \
2*v[13]*sin(v[9])))/2. - Cv*L[7]*sin(v[9])*(cos(v[9])*v[13] - \
L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - \
L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - \
L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) \
+ (M[7]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[7]) - \
2*cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.)))/2. - \
(M[7]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[7]) - \
2*L[5]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
(cos(v[9])*L[7]*pow(v[21],2))/2.)*sin(v[7]) - 2*cos(v[7])*L[5]*v[19]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
(L[7]*v[21]*sin(v[9]))/2.) + 2*cos(v[7])*L[5]*(-(L[1]*pow(v[15],2)*sin(v[3])) \
- L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - (L[7]*pow(v[21],2)*sin(v[9]))/2.)))/2. - \
L[5]*sin(v[7])*(-(Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - \
v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - \
v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - \
v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - \
v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - \
Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10]))) + cos(v[7])*L[5]*(-(Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] \
+ 2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + \
2*cos(v[5] - v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] \
- v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - \
v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - \
Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10]))) + (M[8]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
(cos(v[10])*L[8]*v[22])/2.)*sin(v[7]) - 2*cos(v[7])*L[5]*v[19]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.)))/2. - \
(M[8]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
(cos(v[10])*L[8]*v[22])/2.)*sin(v[7]) - \
2*L[5]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.)*sin(v[7]) - \
2*cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.) + \
2*cos(v[7])*L[5]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
(L[8]*pow(v[22],2)*sin(v[10]))/2.)))/2. - \
L[5]*sin(v[7])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - \
v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - \
v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - \
v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - \
v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + \
2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))) + cos(v[7])*L[5]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] \
+ 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + \
2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] \
- v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - \
v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - \
2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))) + (M[9]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[7]) - \
2*cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
(L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-2*L[5]*v[19]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + \
(cos(v[11])*L[9]*v[23])/2.)*sin(v[7]) - \
2*L[5]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
(cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[7]) - 2*cos(v[7])*L[5]*v[19]*(v[13] \
- L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + \
2*cos(v[7])*L[5]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - \
L[5]*sin(v[7])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - \
v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - \
v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - \
v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - \
v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - \
v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - \
Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + \
cos(v[7])*L[5]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - \
v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - \
v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - \
v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - \
v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - \
v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - \
Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + (M[10]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[7]) - 2*cos(v[7])*L[5]*v[19]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - \
(L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[5]*v[19]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[7]) - \
2*L[5]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[7]) \
- 2*cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) \
- L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + \
2*cos(v[7])*L[5]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - \
(L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;\n coefMat[7] = \
-(L[6]*M[6]*sin(v[8]))/2. - L[6]*M[7]*sin(v[8]) - L[6]*M[8]*sin(v[8]) - \
L[6]*M[9]*sin(v[8]) - L[6]*M[10]*sin(v[8]);\n coefMat[19] = \
(cos(v[8])*L[6]*M[6])/2. + cos(v[8])*L[6]*M[7] + cos(v[8])*L[6]*M[8] + \
cos(v[8])*L[6]*M[9] + cos(v[8])*L[6]*M[10];\n coefMat[31] = \
(M[6]*(cos(v[3])*cos(v[8])*L[1]*L[6] + L[1]*L[6]*sin(v[3])*sin(v[8])))/2. + \
(M[7]*(2*cos(v[3])*cos(v[8])*L[1]*L[6] + 2*L[1]*L[6]*sin(v[3])*sin(v[8])))/2. \
+ (M[8]*(2*cos(v[3])*cos(v[8])*L[1]*L[6] + \
2*L[1]*L[6]*sin(v[3])*sin(v[8])))/2. + (M[9]*(2*cos(v[3])*cos(v[8])*L[1]*L[6] \
+ 2*L[1]*L[6]*sin(v[3])*sin(v[8])))/2. + \
(M[10]*(2*cos(v[3])*cos(v[8])*L[1]*L[6] + \
2*L[1]*L[6]*sin(v[3])*sin(v[8])))/2.;\n coefMat[43] = \
(M[6]*(cos(v[4])*cos(v[8])*L[2]*L[6] + L[2]*L[6]*sin(v[4])*sin(v[8])))/2. + \
(M[7]*(2*cos(v[4])*cos(v[8])*L[2]*L[6] + 2*L[2]*L[6]*sin(v[4])*sin(v[8])))/2. \
+ (M[8]*(2*cos(v[4])*cos(v[8])*L[2]*L[6] + \
2*L[2]*L[6]*sin(v[4])*sin(v[8])))/2. + (M[9]*(2*cos(v[4])*cos(v[8])*L[2]*L[6] \
+ 2*L[2]*L[6]*sin(v[4])*sin(v[8])))/2. + \
(M[10]*(2*cos(v[4])*cos(v[8])*L[2]*L[6] + \
2*L[2]*L[6]*sin(v[4])*sin(v[8])))/2.;\n coefMat[55] = \
(M[6]*(cos(v[5])*cos(v[8])*L[3]*L[6] + L[3]*L[6]*sin(v[5])*sin(v[8])))/2. + \
(M[7]*(2*cos(v[5])*cos(v[8])*L[3]*L[6] + 2*L[3]*L[6]*sin(v[5])*sin(v[8])))/2. \
+ (M[8]*(2*cos(v[5])*cos(v[8])*L[3]*L[6] + \
2*L[3]*L[6]*sin(v[5])*sin(v[8])))/2. + (M[9]*(2*cos(v[5])*cos(v[8])*L[3]*L[6] \
+ 2*L[3]*L[6]*sin(v[5])*sin(v[8])))/2. + \
(M[10]*(2*cos(v[5])*cos(v[8])*L[3]*L[6] + \
2*L[3]*L[6]*sin(v[5])*sin(v[8])))/2.;\n coefMat[67] = \
(M[6]*(cos(v[6])*cos(v[8])*L[4]*L[6] + L[4]*L[6]*sin(v[6])*sin(v[8])))/2. + \
(M[7]*(2*cos(v[6])*cos(v[8])*L[4]*L[6] + 2*L[4]*L[6]*sin(v[6])*sin(v[8])))/2. \
+ (M[8]*(2*cos(v[6])*cos(v[8])*L[4]*L[6] + \
2*L[4]*L[6]*sin(v[6])*sin(v[8])))/2. + (M[9]*(2*cos(v[6])*cos(v[8])*L[4]*L[6] \
+ 2*L[4]*L[6]*sin(v[6])*sin(v[8])))/2. + \
(M[10]*(2*cos(v[6])*cos(v[8])*L[4]*L[6] + \
2*L[4]*L[6]*sin(v[6])*sin(v[8])))/2.;\n coefMat[79] = \
(M[6]*(cos(v[7])*cos(v[8])*L[5]*L[6] + L[5]*L[6]*sin(v[7])*sin(v[8])))/2. + \
(M[7]*(2*cos(v[7])*cos(v[8])*L[5]*L[6] + 2*L[5]*L[6]*sin(v[7])*sin(v[8])))/2. \
+ (M[8]*(2*cos(v[7])*cos(v[8])*L[5]*L[6] + \
2*L[5]*L[6]*sin(v[7])*sin(v[8])))/2. + (M[9]*(2*cos(v[7])*cos(v[8])*L[5]*L[6] \
+ 2*L[5]*L[6]*sin(v[7])*sin(v[8])))/2. + \
(M[10]*(2*cos(v[7])*cos(v[8])*L[5]*L[6] + \
2*L[5]*L[6]*sin(v[7])*sin(v[8])))/2.;\n coefMat[91] = (pow(L[6],2)*M[6])/12. \
+ (M[6]*((pow(cos(v[8]),2)*pow(L[6],2))/2. + \
(pow(L[6],2)*pow(sin(v[8]),2))/2.))/2. + \
(M[7]*(2*pow(cos(v[8]),2)*pow(L[6],2) + 2*pow(L[6],2)*pow(sin(v[8]),2)))/2. + \
(M[8]*(2*pow(cos(v[8]),2)*pow(L[6],2) + 2*pow(L[6],2)*pow(sin(v[8]),2)))/2. + \
(M[9]*(2*pow(cos(v[8]),2)*pow(L[6],2) + 2*pow(L[6],2)*pow(sin(v[8]),2)))/2. + \
(M[10]*(2*pow(cos(v[8]),2)*pow(L[6],2) + 2*pow(L[6],2)*pow(sin(v[8]),2)))/2.;\
\n coefMat[103] = (M[7]*(cos(v[8])*cos(v[9])*L[6]*L[7] + \
L[6]*L[7]*sin(v[8])*sin(v[9])))/2. + (M[8]*(2*cos(v[8])*cos(v[9])*L[6]*L[7] + \
2*L[6]*L[7]*sin(v[8])*sin(v[9])))/2. + (M[9]*(2*cos(v[8])*cos(v[9])*L[6]*L[7] \
+ 2*L[6]*L[7]*sin(v[8])*sin(v[9])))/2. + \
(M[10]*(2*cos(v[8])*cos(v[9])*L[6]*L[7] + \
2*L[6]*L[7]*sin(v[8])*sin(v[9])))/2.;\n coefMat[115] = \
(M[8]*(cos(v[8])*cos(v[10])*L[6]*L[8] + L[6]*L[8]*sin(v[8])*sin(v[10])))/2. + \
(M[9]*(2*cos(v[8])*cos(v[10])*L[6]*L[8] + \
2*L[6]*L[8]*sin(v[8])*sin(v[10])))/2. + \
(M[10]*(2*cos(v[8])*cos(v[10])*L[6]*L[8] + \
2*L[6]*L[8]*sin(v[8])*sin(v[10])))/2.;\n coefMat[127] = \
(M[9]*(cos(v[8])*cos(v[11])*L[6]*L[9] + L[6]*L[9]*sin(v[8])*sin(v[11])))/2. + \
(M[10]*(2*cos(v[8])*cos(v[11])*L[6]*L[9] + \
2*L[6]*L[9]*sin(v[8])*sin(v[11])))/2.;\n coefMat[139] = \
(M[10]*(cos(v[8])*cos(v[12])*L[6]*L[10] + \
L[6]*L[10]*sin(v[8])*sin(v[12])))/2.;\n rhsVec[7] = forceRY*cos(v[8])*L[6] - \
(Cs*pow(L[6],3)*v[20])/12. - forceRX*L[6]*sin(v[8]) - \
(pow(L[6],2)*sin(v[8])*(-(Cs*sin(v[8])*(-2*cos(v[8])*v[14] - 2*cos(v[3] - \
v[8])*L[1]*v[15] - 2*cos(v[4] - v[8])*L[2]*v[16] - 2*cos(v[5] - \
v[8])*L[3]*v[17] - 2*cos(v[6] - v[8])*L[4]*v[18] - 2*cos(v[7] - \
v[8])*L[5]*v[19] - L[6]*v[20] + 2*v[13]*sin(v[8]))) + \
2*Cv*cos(v[8])*(-(cos(v[8])*v[13]) + L[1]*v[15]*sin(v[3] - v[8]) + \
L[2]*v[16]*sin(v[4] - v[8]) + L[3]*v[17]*sin(v[5] - v[8]) + \
L[4]*v[18]*sin(v[6] - v[8]) + L[5]*v[19]*sin(v[7] - v[8]) - \
v[14]*sin(v[8]))))/4. + \
(cos(v[8])*L[6]*(-(Cs*cos(v[8])*L[6]*(2*cos(v[8])*v[14] + 2*cos(v[3] - \
v[8])*L[1]*v[15] + 2*cos(v[4] - v[8])*L[2]*v[16] + 2*cos(v[5] - \
v[8])*L[3]*v[17] + 2*cos(v[6] - v[8])*L[4]*v[18] + 2*cos(v[7] - \
v[8])*L[5]*v[19] + L[6]*v[20] - 2*v[13]*sin(v[8])))/2. - \
Cv*L[6]*sin(v[8])*(cos(v[8])*v[13] - L[1]*v[15]*sin(v[3] - v[8]) - \
L[2]*v[16]*sin(v[4] - v[8]) - L[3]*v[17]*sin(v[5] - v[8]) - \
L[4]*v[18]*sin(v[6] - v[8]) - L[5]*v[19]*sin(v[7] - v[8]) + \
v[14]*sin(v[8]))))/2. + (M[6]*(-(L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + (cos(v[8])*L[6]*v[20])/2.)*sin(v[8])) - \
cos(v[8])*L[6]*v[20]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
(L[6]*v[20]*sin(v[8]))/2.)))/2. - (M[6]*(-(L[6]*v[20]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
(cos(v[8])*L[6]*v[20])/2.)*sin(v[8])) - L[6]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - \
(cos(v[8])*L[6]*pow(v[20],2))/2.)*sin(v[8]) - cos(v[8])*L[6]*v[20]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.) + \
cos(v[8])*L[6]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) \
- L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - \
L[5]*pow(v[19],2)*sin(v[7]) - (L[6]*pow(v[20],2)*sin(v[8]))/2.)))/2. - \
L[6]*sin(v[8])*(-(Cs*L[7]*sin(v[9])*(-2*cos(v[9])*v[14] - 2*cos(v[3] - \
v[9])*L[1]*v[15] - 2*cos(v[4] - v[9])*L[2]*v[16] - 2*cos(v[5] - \
v[9])*L[3]*v[17] - 2*cos(v[6] - v[9])*L[4]*v[18] - 2*cos(v[7] - \
v[9])*L[5]*v[19] - 2*cos(v[8] - v[9])*L[6]*v[20] - L[7]*v[21] + \
2*v[13]*sin(v[9])))/2. - Cv*cos(v[9])*L[7]*(cos(v[9])*v[13] - \
L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - \
L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - \
L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) \
+ cos(v[8])*L[6]*(-(Cs*cos(v[9])*L[7]*(2*cos(v[9])*v[14] + 2*cos(v[3] - \
v[9])*L[1]*v[15] + 2*cos(v[4] - v[9])*L[2]*v[16] + 2*cos(v[5] - \
v[9])*L[3]*v[17] + 2*cos(v[6] - v[9])*L[4]*v[18] + 2*cos(v[7] - \
v[9])*L[5]*v[19] + 2*cos(v[8] - v[9])*L[6]*v[20] + L[7]*v[21] - \
2*v[13]*sin(v[9])))/2. - Cv*L[7]*sin(v[9])*(cos(v[9])*v[13] - \
L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - \
L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - \
L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) \
+ (M[7]*(-2*L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[8]) - \
2*cos(v[8])*L[6]*v[20]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.)))/2. - \
(M[7]*(-2*L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[8]) - \
2*L[6]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
(cos(v[9])*L[7]*pow(v[21],2))/2.)*sin(v[8]) - 2*cos(v[8])*L[6]*v[20]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
(L[7]*v[21]*sin(v[9]))/2.) + 2*cos(v[8])*L[6]*(-(L[1]*pow(v[15],2)*sin(v[3])) \
- L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - (L[7]*pow(v[21],2)*sin(v[9]))/2.)))/2. - \
L[6]*sin(v[8])*(-(Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - \
v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - \
v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - \
v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - \
v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - \
Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10]))) + cos(v[8])*L[6]*(-(Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] \
+ 2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + \
2*cos(v[5] - v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] \
- v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - \
v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - \
Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10]))) + (M[8]*(-2*L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
(cos(v[10])*L[8]*v[22])/2.)*sin(v[8]) - 2*cos(v[8])*L[6]*v[20]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.)))/2. - \
(M[8]*(-2*L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
(cos(v[10])*L[8]*v[22])/2.)*sin(v[8]) - \
2*L[6]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.)*sin(v[8]) - \
2*cos(v[8])*L[6]*v[20]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.) + \
2*cos(v[8])*L[6]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
(L[8]*pow(v[22],2)*sin(v[10]))/2.)))/2. - \
L[6]*sin(v[8])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - \
v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - \
v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - \
v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - \
v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + \
2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))) + cos(v[8])*L[6]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] \
+ 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + \
2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] \
- v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - \
v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - \
2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))) + (M[9]*(-2*L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[8]) - \
2*cos(v[8])*L[6]*v[20]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
(L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-2*L[6]*v[20]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + \
(cos(v[11])*L[9]*v[23])/2.)*sin(v[8]) - \
2*L[6]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
(cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[8]) - 2*cos(v[8])*L[6]*v[20]*(v[13] \
- L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + \
2*cos(v[8])*L[6]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - \
L[6]*sin(v[8])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - \
v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - \
v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - \
v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - \
v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - \
v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - \
Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + \
cos(v[8])*L[6]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - \
v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - \
v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - \
v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - \
v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - \
v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - \
Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + (M[10]*(-2*L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[8]) - 2*cos(v[8])*L[6]*v[20]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - \
(L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[6]*v[20]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[8]) - \
2*L[6]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[8]) \
- 2*cos(v[8])*L[6]*v[20]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) \
- L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + \
2*cos(v[8])*L[6]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - \
(L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;\n coefMat[8] = \
-(L[7]*M[7]*sin(v[9]))/2. - L[7]*M[8]*sin(v[9]) - L[7]*M[9]*sin(v[9]) - \
L[7]*M[10]*sin(v[9]);\n coefMat[20] = (cos(v[9])*L[7]*M[7])/2. + \
cos(v[9])*L[7]*M[8] + cos(v[9])*L[7]*M[9] + cos(v[9])*L[7]*M[10];\n \
coefMat[32] = (M[7]*(cos(v[3])*cos(v[9])*L[1]*L[7] + \
L[1]*L[7]*sin(v[3])*sin(v[9])))/2. + (M[8]*(2*cos(v[3])*cos(v[9])*L[1]*L[7] + \
2*L[1]*L[7]*sin(v[3])*sin(v[9])))/2. + (M[9]*(2*cos(v[3])*cos(v[9])*L[1]*L[7] \
+ 2*L[1]*L[7]*sin(v[3])*sin(v[9])))/2. + \
(M[10]*(2*cos(v[3])*cos(v[9])*L[1]*L[7] + \
2*L[1]*L[7]*sin(v[3])*sin(v[9])))/2.;\n coefMat[44] = \
(M[7]*(cos(v[4])*cos(v[9])*L[2]*L[7] + L[2]*L[7]*sin(v[4])*sin(v[9])))/2. + \
(M[8]*(2*cos(v[4])*cos(v[9])*L[2]*L[7] + 2*L[2]*L[7]*sin(v[4])*sin(v[9])))/2. \
+ (M[9]*(2*cos(v[4])*cos(v[9])*L[2]*L[7] + \
2*L[2]*L[7]*sin(v[4])*sin(v[9])))/2. + \
(M[10]*(2*cos(v[4])*cos(v[9])*L[2]*L[7] + \
2*L[2]*L[7]*sin(v[4])*sin(v[9])))/2.;\n coefMat[56] = \
(M[7]*(cos(v[5])*cos(v[9])*L[3]*L[7] + L[3]*L[7]*sin(v[5])*sin(v[9])))/2. + \
(M[8]*(2*cos(v[5])*cos(v[9])*L[3]*L[7] + 2*L[3]*L[7]*sin(v[5])*sin(v[9])))/2. \
+ (M[9]*(2*cos(v[5])*cos(v[9])*L[3]*L[7] + \
2*L[3]*L[7]*sin(v[5])*sin(v[9])))/2. + \
(M[10]*(2*cos(v[5])*cos(v[9])*L[3]*L[7] + \
2*L[3]*L[7]*sin(v[5])*sin(v[9])))/2.;\n coefMat[68] = \
(M[7]*(cos(v[6])*cos(v[9])*L[4]*L[7] + L[4]*L[7]*sin(v[6])*sin(v[9])))/2. + \
(M[8]*(2*cos(v[6])*cos(v[9])*L[4]*L[7] + 2*L[4]*L[7]*sin(v[6])*sin(v[9])))/2. \
+ (M[9]*(2*cos(v[6])*cos(v[9])*L[4]*L[7] + \
2*L[4]*L[7]*sin(v[6])*sin(v[9])))/2. + \
(M[10]*(2*cos(v[6])*cos(v[9])*L[4]*L[7] + \
2*L[4]*L[7]*sin(v[6])*sin(v[9])))/2.;\n coefMat[80] = \
(M[7]*(cos(v[7])*cos(v[9])*L[5]*L[7] + L[5]*L[7]*sin(v[7])*sin(v[9])))/2. + \
(M[8]*(2*cos(v[7])*cos(v[9])*L[5]*L[7] + 2*L[5]*L[7]*sin(v[7])*sin(v[9])))/2. \
+ (M[9]*(2*cos(v[7])*cos(v[9])*L[5]*L[7] + \
2*L[5]*L[7]*sin(v[7])*sin(v[9])))/2. + \
(M[10]*(2*cos(v[7])*cos(v[9])*L[5]*L[7] + \
2*L[5]*L[7]*sin(v[7])*sin(v[9])))/2.;\n coefMat[92] = \
(M[7]*(cos(v[8])*cos(v[9])*L[6]*L[7] + L[6]*L[7]*sin(v[8])*sin(v[9])))/2. + \
(M[8]*(2*cos(v[8])*cos(v[9])*L[6]*L[7] + 2*L[6]*L[7]*sin(v[8])*sin(v[9])))/2. \
+ (M[9]*(2*cos(v[8])*cos(v[9])*L[6]*L[7] + \
2*L[6]*L[7]*sin(v[8])*sin(v[9])))/2. + \
(M[10]*(2*cos(v[8])*cos(v[9])*L[6]*L[7] + \
2*L[6]*L[7]*sin(v[8])*sin(v[9])))/2.;\n coefMat[104] = (pow(L[7],2)*M[7])/12. \
+ (M[7]*((pow(cos(v[9]),2)*pow(L[7],2))/2. + \
(pow(L[7],2)*pow(sin(v[9]),2))/2.))/2. + \
(M[8]*(2*pow(cos(v[9]),2)*pow(L[7],2) + 2*pow(L[7],2)*pow(sin(v[9]),2)))/2. + \
(M[9]*(2*pow(cos(v[9]),2)*pow(L[7],2) + 2*pow(L[7],2)*pow(sin(v[9]),2)))/2. + \
(M[10]*(2*pow(cos(v[9]),2)*pow(L[7],2) + 2*pow(L[7],2)*pow(sin(v[9]),2)))/2.;\
\n coefMat[116] = (M[8]*(cos(v[9])*cos(v[10])*L[7]*L[8] + \
L[7]*L[8]*sin(v[9])*sin(v[10])))/2. + (M[9]*(2*cos(v[9])*cos(v[10])*L[7]*L[8] \
+ 2*L[7]*L[8]*sin(v[9])*sin(v[10])))/2. + \
(M[10]*(2*cos(v[9])*cos(v[10])*L[7]*L[8] + \
2*L[7]*L[8]*sin(v[9])*sin(v[10])))/2.;\n coefMat[128] = \
(M[9]*(cos(v[9])*cos(v[11])*L[7]*L[9] + L[7]*L[9]*sin(v[9])*sin(v[11])))/2. + \
(M[10]*(2*cos(v[9])*cos(v[11])*L[7]*L[9] + \
2*L[7]*L[9]*sin(v[9])*sin(v[11])))/2.;\n coefMat[140] = \
(M[10]*(cos(v[9])*cos(v[12])*L[7]*L[10] + \
L[7]*L[10]*sin(v[9])*sin(v[12])))/2.;\n rhsVec[8] = forceRY*cos(v[9])*L[7] - \
(Cs*pow(L[7],3)*v[21])/12. - forceRX*L[7]*sin(v[9]) - \
(L[7]*sin(v[9])*(-(Cs*L[7]*sin(v[9])*(-2*cos(v[9])*v[14] - 2*cos(v[3] - \
v[9])*L[1]*v[15] - 2*cos(v[4] - v[9])*L[2]*v[16] - 2*cos(v[5] - \
v[9])*L[3]*v[17] - 2*cos(v[6] - v[9])*L[4]*v[18] - 2*cos(v[7] - \
v[9])*L[5]*v[19] - 2*cos(v[8] - v[9])*L[6]*v[20] - L[7]*v[21] + \
2*v[13]*sin(v[9])))/2. - Cv*cos(v[9])*L[7]*(cos(v[9])*v[13] - \
L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - \
L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - \
L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + \
v[14]*sin(v[9]))))/2. + \
(cos(v[9])*L[7]*(-(Cs*cos(v[9])*L[7]*(2*cos(v[9])*v[14] + 2*cos(v[3] - \
v[9])*L[1]*v[15] + 2*cos(v[4] - v[9])*L[2]*v[16] + 2*cos(v[5] - \
v[9])*L[3]*v[17] + 2*cos(v[6] - v[9])*L[4]*v[18] + 2*cos(v[7] - \
v[9])*L[5]*v[19] + 2*cos(v[8] - v[9])*L[6]*v[20] + L[7]*v[21] - \
2*v[13]*sin(v[9])))/2. - Cv*L[7]*sin(v[9])*(cos(v[9])*v[13] - \
L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - \
L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - \
L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + \
v[14]*sin(v[9]))))/2. + (M[7]*(-(L[7]*v[21]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
(cos(v[9])*L[7]*v[21])/2.)*sin(v[9])) - cos(v[9])*L[7]*v[21]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
(L[7]*v[21]*sin(v[9]))/2.)))/2. - (M[7]*(-(L[7]*v[21]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
(cos(v[9])*L[7]*v[21])/2.)*sin(v[9])) - L[7]*(-(cos(v[3])*L[1]*pow(v[15],2)) \
- cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - \
cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - \
cos(v[8])*L[6]*pow(v[20],2) - (cos(v[9])*L[7]*pow(v[21],2))/2.)*sin(v[9]) - \
cos(v[9])*L[7]*v[21]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.) + \
cos(v[9])*L[7]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) \
- L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - \
L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - \
(L[7]*pow(v[21],2)*sin(v[9]))/2.)))/2. - \
L[7]*sin(v[9])*(-(Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - \
v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - \
v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - \
v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - \
v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - \
Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10]))) + cos(v[9])*L[7]*(-(Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] \
+ 2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + \
2*cos(v[5] - v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] \
- v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - \
v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - \
Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10]))) + (M[8]*(-2*L[7]*v[21]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
(cos(v[10])*L[8]*v[22])/2.)*sin(v[9]) - 2*cos(v[9])*L[7]*v[21]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.)))/2. - \
(M[8]*(-2*L[7]*v[21]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
(cos(v[10])*L[8]*v[22])/2.)*sin(v[9]) - \
2*L[7]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.)*sin(v[9]) - \
2*cos(v[9])*L[7]*v[21]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.) + \
2*cos(v[9])*L[7]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
(L[8]*pow(v[22],2)*sin(v[10]))/2.)))/2. - \
L[7]*sin(v[9])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - \
v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - \
v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - \
v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - \
v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + \
2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))) + cos(v[9])*L[7]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] \
+ 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + \
2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] \
- v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - \
v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - \
2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))) + (M[9]*(-2*L[7]*v[21]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[9]) - \
2*cos(v[9])*L[7]*v[21]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
(L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-2*L[7]*v[21]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + \
(cos(v[11])*L[9]*v[23])/2.)*sin(v[9]) - \
2*L[7]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
(cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[9]) - 2*cos(v[9])*L[7]*v[21]*(v[13] \
- L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + \
2*cos(v[9])*L[7]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - \
L[7]*sin(v[9])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - \
v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - \
v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - \
v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - \
v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - \
v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - \
Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + \
cos(v[9])*L[7]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - \
v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - \
v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - \
v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - \
v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - \
v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - \
Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + (M[10]*(-2*L[7]*v[21]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[9]) - 2*cos(v[9])*L[7]*v[21]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - \
(L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[7]*v[21]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[9]) - \
2*L[7]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[9]) \
- 2*cos(v[9])*L[7]*v[21]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) \
- L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + \
2*cos(v[9])*L[7]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - \
(L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;\n coefMat[9] = \
-(L[8]*M[8]*sin(v[10]))/2. - L[8]*M[9]*sin(v[10]) - L[8]*M[10]*sin(v[10]);\n \
coefMat[21] = (cos(v[10])*L[8]*M[8])/2. + cos(v[10])*L[8]*M[9] + \
cos(v[10])*L[8]*M[10];\n coefMat[33] = (M[8]*(cos(v[3])*cos(v[10])*L[1]*L[8] \
+ L[1]*L[8]*sin(v[3])*sin(v[10])))/2. + \
(M[9]*(2*cos(v[3])*cos(v[10])*L[1]*L[8] + \
2*L[1]*L[8]*sin(v[3])*sin(v[10])))/2. + \
(M[10]*(2*cos(v[3])*cos(v[10])*L[1]*L[8] + \
2*L[1]*L[8]*sin(v[3])*sin(v[10])))/2.;\n coefMat[45] = \
(M[8]*(cos(v[4])*cos(v[10])*L[2]*L[8] + L[2]*L[8]*sin(v[4])*sin(v[10])))/2. + \
(M[9]*(2*cos(v[4])*cos(v[10])*L[2]*L[8] + \
2*L[2]*L[8]*sin(v[4])*sin(v[10])))/2. + \
(M[10]*(2*cos(v[4])*cos(v[10])*L[2]*L[8] + \
2*L[2]*L[8]*sin(v[4])*sin(v[10])))/2.;\n coefMat[57] = \
(M[8]*(cos(v[5])*cos(v[10])*L[3]*L[8] + L[3]*L[8]*sin(v[5])*sin(v[10])))/2. + \
(M[9]*(2*cos(v[5])*cos(v[10])*L[3]*L[8] + \
2*L[3]*L[8]*sin(v[5])*sin(v[10])))/2. + \
(M[10]*(2*cos(v[5])*cos(v[10])*L[3]*L[8] + \
2*L[3]*L[8]*sin(v[5])*sin(v[10])))/2.;\n coefMat[69] = \
(M[8]*(cos(v[6])*cos(v[10])*L[4]*L[8] + L[4]*L[8]*sin(v[6])*sin(v[10])))/2. + \
(M[9]*(2*cos(v[6])*cos(v[10])*L[4]*L[8] + \
2*L[4]*L[8]*sin(v[6])*sin(v[10])))/2. + \
(M[10]*(2*cos(v[6])*cos(v[10])*L[4]*L[8] + \
2*L[4]*L[8]*sin(v[6])*sin(v[10])))/2.;\n coefMat[81] = \
(M[8]*(cos(v[7])*cos(v[10])*L[5]*L[8] + L[5]*L[8]*sin(v[7])*sin(v[10])))/2. + \
(M[9]*(2*cos(v[7])*cos(v[10])*L[5]*L[8] + \
2*L[5]*L[8]*sin(v[7])*sin(v[10])))/2. + \
(M[10]*(2*cos(v[7])*cos(v[10])*L[5]*L[8] + \
2*L[5]*L[8]*sin(v[7])*sin(v[10])))/2.;\n coefMat[93] = \
(M[8]*(cos(v[8])*cos(v[10])*L[6]*L[8] + L[6]*L[8]*sin(v[8])*sin(v[10])))/2. + \
(M[9]*(2*cos(v[8])*cos(v[10])*L[6]*L[8] + \
2*L[6]*L[8]*sin(v[8])*sin(v[10])))/2. + \
(M[10]*(2*cos(v[8])*cos(v[10])*L[6]*L[8] + \
2*L[6]*L[8]*sin(v[8])*sin(v[10])))/2.;\n coefMat[105] = \
(M[8]*(cos(v[9])*cos(v[10])*L[7]*L[8] + L[7]*L[8]*sin(v[9])*sin(v[10])))/2. + \
(M[9]*(2*cos(v[9])*cos(v[10])*L[7]*L[8] + \
2*L[7]*L[8]*sin(v[9])*sin(v[10])))/2. + \
(M[10]*(2*cos(v[9])*cos(v[10])*L[7]*L[8] + \
2*L[7]*L[8]*sin(v[9])*sin(v[10])))/2.;\n coefMat[117] = \
(pow(L[8],2)*M[8])/12. + (M[8]*((pow(cos(v[10]),2)*pow(L[8],2))/2. + \
(pow(L[8],2)*pow(sin(v[10]),2))/2.))/2. + \
(M[9]*(2*pow(cos(v[10]),2)*pow(L[8],2) + 2*pow(L[8],2)*pow(sin(v[10]),2)))/2. \
+ (M[10]*(2*pow(cos(v[10]),2)*pow(L[8],2) + \
2*pow(L[8],2)*pow(sin(v[10]),2)))/2.;\n coefMat[129] = \
(M[9]*(cos(v[10])*cos(v[11])*L[8]*L[9] + L[8]*L[9]*sin(v[10])*sin(v[11])))/2. \
+ (M[10]*(2*cos(v[10])*cos(v[11])*L[8]*L[9] + \
2*L[8]*L[9]*sin(v[10])*sin(v[11])))/2.;\n coefMat[141] = \
(M[10]*(cos(v[10])*cos(v[12])*L[8]*L[10] + \
L[8]*L[10]*sin(v[10])*sin(v[12])))/2.;\n rhsVec[9] = forceRY*cos(v[10])*L[8] \
- (Cs*pow(L[8],3)*v[22])/12. - forceRX*L[8]*sin(v[10]) - \
(L[8]*sin(v[10])*(-(Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - \
v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - \
v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - \
v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - \
v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - \
Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10]))))/2. + \
(cos(v[10])*L[8]*(-(Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] + 2*cos(v[3] - \
v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + 2*cos(v[5] - \
v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] - \
v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - \
v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - \
Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - \
L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - \
L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - \
L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + \
v[14]*sin(v[10]))))/2. + (M[8]*(-(L[8]*v[22]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
(cos(v[10])*L[8]*v[22])/2.)*sin(v[10])) - cos(v[10])*L[8]*v[22]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.)))/2. - \
(M[8]*(-(L[8]*v[22]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + \
cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + \
cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
(cos(v[10])*L[8]*v[22])/2.)*sin(v[10])) - \
L[8]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.)*sin(v[10]) - \
cos(v[10])*L[8]*v[22]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.) + \
cos(v[10])*L[8]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) \
- L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - \
L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - \
L[7]*pow(v[21],2)*sin(v[9]) - (L[8]*pow(v[22],2)*sin(v[10]))/2.)))/2. - \
L[8]*sin(v[10])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - \
v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - \
v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - \
v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - \
v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + \
2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))) + \
cos(v[10])*L[8]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] + 2*cos(v[3] - \
v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + 2*cos(v[5] - \
v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] - \
v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - \
v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - \
2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))) + (M[9]*(-2*L[8]*v[22]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[10]) - \
2*cos(v[10])*L[8]*v[22]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) \
- L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
(L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-2*L[8]*v[22]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + \
(cos(v[11])*L[9]*v[23])/2.)*sin(v[10]) - \
2*L[8]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
(cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[10]) - \
2*cos(v[10])*L[8]*v[22]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) \
- L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
(L[9]*v[23]*sin(v[11]))/2.) + \
2*cos(v[10])*L[8]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - \
L[8]*sin(v[10])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - \
v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - \
v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - \
v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - \
v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - \
v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - \
Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + \
cos(v[10])*L[8]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - \
v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - \
v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - \
v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - \
v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - \
v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - \
Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + (M[10]*(-2*L[8]*v[22]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[10]) - 2*cos(v[10])*L[8]*v[22]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - \
(L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[8]*v[22]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[10]) - \
2*L[8]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[10]) \
- 2*cos(v[10])*L[8]*v[22]*(v[13] - L[1]*v[15]*sin(v[3]) - \
L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - \
L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - \
L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) \
+ 2*cos(v[10])*L[8]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - \
(L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;\n coefMat[10] = \
-(L[9]*M[9]*sin(v[11]))/2. - L[9]*M[10]*sin(v[11]);\n coefMat[22] = \
(cos(v[11])*L[9]*M[9])/2. + cos(v[11])*L[9]*M[10];\n coefMat[34] = \
(M[9]*(cos(v[3])*cos(v[11])*L[1]*L[9] + L[1]*L[9]*sin(v[3])*sin(v[11])))/2. + \
(M[10]*(2*cos(v[3])*cos(v[11])*L[1]*L[9] + \
2*L[1]*L[9]*sin(v[3])*sin(v[11])))/2.;\n coefMat[46] = \
(M[9]*(cos(v[4])*cos(v[11])*L[2]*L[9] + L[2]*L[9]*sin(v[4])*sin(v[11])))/2. + \
(M[10]*(2*cos(v[4])*cos(v[11])*L[2]*L[9] + \
2*L[2]*L[9]*sin(v[4])*sin(v[11])))/2.;\n coefMat[58] = \
(M[9]*(cos(v[5])*cos(v[11])*L[3]*L[9] + L[3]*L[9]*sin(v[5])*sin(v[11])))/2. + \
(M[10]*(2*cos(v[5])*cos(v[11])*L[3]*L[9] + \
2*L[3]*L[9]*sin(v[5])*sin(v[11])))/2.;\n coefMat[70] = \
(M[9]*(cos(v[6])*cos(v[11])*L[4]*L[9] + L[4]*L[9]*sin(v[6])*sin(v[11])))/2. + \
(M[10]*(2*cos(v[6])*cos(v[11])*L[4]*L[9] + \
2*L[4]*L[9]*sin(v[6])*sin(v[11])))/2.;\n coefMat[82] = \
(M[9]*(cos(v[7])*cos(v[11])*L[5]*L[9] + L[5]*L[9]*sin(v[7])*sin(v[11])))/2. + \
(M[10]*(2*cos(v[7])*cos(v[11])*L[5]*L[9] + \
2*L[5]*L[9]*sin(v[7])*sin(v[11])))/2.;\n coefMat[94] = \
(M[9]*(cos(v[8])*cos(v[11])*L[6]*L[9] + L[6]*L[9]*sin(v[8])*sin(v[11])))/2. + \
(M[10]*(2*cos(v[8])*cos(v[11])*L[6]*L[9] + \
2*L[6]*L[9]*sin(v[8])*sin(v[11])))/2.;\n coefMat[106] = \
(M[9]*(cos(v[9])*cos(v[11])*L[7]*L[9] + L[7]*L[9]*sin(v[9])*sin(v[11])))/2. + \
(M[10]*(2*cos(v[9])*cos(v[11])*L[7]*L[9] + \
2*L[7]*L[9]*sin(v[9])*sin(v[11])))/2.;\n coefMat[118] = \
(M[9]*(cos(v[10])*cos(v[11])*L[8]*L[9] + L[8]*L[9]*sin(v[10])*sin(v[11])))/2. \
+ (M[10]*(2*cos(v[10])*cos(v[11])*L[8]*L[9] + \
2*L[8]*L[9]*sin(v[10])*sin(v[11])))/2.;\n coefMat[130] = \
(pow(L[9],2)*M[9])/12. + (M[9]*((pow(cos(v[11]),2)*pow(L[9],2))/2. + \
(pow(L[9],2)*pow(sin(v[11]),2))/2.))/2. + \
(M[10]*(2*pow(cos(v[11]),2)*pow(L[9],2) + \
2*pow(L[9],2)*pow(sin(v[11]),2)))/2.;\n coefMat[142] = \
(M[10]*(cos(v[11])*cos(v[12])*L[9]*L[10] + \
L[9]*L[10]*sin(v[11])*sin(v[12])))/2.;\n rhsVec[10] = forceRY*cos(v[11])*L[9] \
- (Cs*pow(L[9],3)*v[23])/12. - forceRX*L[9]*sin(v[11]) - \
(L[9]*sin(v[11])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - \
v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - \
v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - \
v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - \
v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + \
2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))))/2. + \
(cos(v[11])*L[9]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] + 2*cos(v[3] - \
v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + 2*cos(v[5] - \
v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] - \
v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - \
v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - \
2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - \
L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - \
L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - \
L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - \
L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + \
v[14]*sin(v[11]))))/2. + (M[9]*(-(L[9]*v[23]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[11])) - \
cos(v[11])*L[9]*v[23]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - \
L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
(L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-(L[9]*v[23]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + \
(cos(v[11])*L[9]*v[23])/2.)*sin(v[11])) - \
L[9]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
(cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[11]) - cos(v[11])*L[9]*v[23]*(v[13] \
- L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + \
cos(v[11])*L[9]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) \
- L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - \
L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - \
L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - \
(L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - \
L[9]*sin(v[11])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - \
v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - \
v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - \
v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - \
v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - \
v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - \
Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + \
cos(v[11])*L[9]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - \
v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - \
v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - \
v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - \
v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - \
v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - \
Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))) + (M[10]*(-2*L[9]*v[23]*(v[14] + cos(v[3])*L[1]*v[15] + \
cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[11]) - 2*cos(v[11])*L[9]*v[23]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - \
(L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[9]*v[23]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[11]) - \
2*L[9]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[11]) \
- 2*cos(v[11])*L[9]*v[23]*(v[13] - L[1]*v[15]*sin(v[3]) - \
L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - \
L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - \
L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) \
+ 2*cos(v[11])*L[9]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - \
(L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;\n coefMat[11] = \
-(L[10]*M[10]*sin(v[12]))/2.;\n coefMat[23] = (cos(v[12])*L[10]*M[10])/2.;\n \
coefMat[35] = (M[10]*(cos(v[3])*cos(v[12])*L[1]*L[10] + \
L[1]*L[10]*sin(v[3])*sin(v[12])))/2.;\n coefMat[47] = \
(M[10]*(cos(v[4])*cos(v[12])*L[2]*L[10] + \
L[2]*L[10]*sin(v[4])*sin(v[12])))/2.;\n coefMat[59] = \
(M[10]*(cos(v[5])*cos(v[12])*L[3]*L[10] + \
L[3]*L[10]*sin(v[5])*sin(v[12])))/2.;\n coefMat[71] = \
(M[10]*(cos(v[6])*cos(v[12])*L[4]*L[10] + \
L[4]*L[10]*sin(v[6])*sin(v[12])))/2.;\n coefMat[83] = \
(M[10]*(cos(v[7])*cos(v[12])*L[5]*L[10] + \
L[5]*L[10]*sin(v[7])*sin(v[12])))/2.;\n coefMat[95] = \
(M[10]*(cos(v[8])*cos(v[12])*L[6]*L[10] + \
L[6]*L[10]*sin(v[8])*sin(v[12])))/2.;\n coefMat[107] = \
(M[10]*(cos(v[9])*cos(v[12])*L[7]*L[10] + \
L[7]*L[10]*sin(v[9])*sin(v[12])))/2.;\n coefMat[119] = \
(M[10]*(cos(v[10])*cos(v[12])*L[8]*L[10] + \
L[8]*L[10]*sin(v[10])*sin(v[12])))/2.;\n coefMat[131] = \
(M[10]*(cos(v[11])*cos(v[12])*L[9]*L[10] + \
L[9]*L[10]*sin(v[11])*sin(v[12])))/2.;\n coefMat[143] = \
(pow(L[10],2)*M[10])/12. + (M[10]*((pow(cos(v[12]),2)*pow(L[10],2))/2. + \
(pow(L[10],2)*pow(sin(v[12]),2))/2.))/2.;\n rhsVec[11] = tauR + \
forceRY*cos(v[12])*L[10] - (Cs*pow(L[10],3)*v[24])/12. - \
forceRX*L[10]*sin(v[12]) - \
(L[10]*sin(v[12])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - \
v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - \
v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - \
v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - \
v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - \
v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - \
Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))))/2. + \
(cos(v[12])*L[10]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - \
v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - \
v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - \
v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - \
v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - \
v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - \
Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - \
L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - \
L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - \
L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - \
L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + \
v[14]*sin(v[12]))))/2. + (M[10]*(-(L[10]*v[24]*(v[14] + cos(v[3])*L[1]*v[15] \
+ cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + \
cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + \
cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[12])) - cos(v[12])*L[10]*v[24]*(v[13] - \
L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - \
L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - \
L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - \
(L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-(L[10]*v[24]*(v[14] + \
cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + \
cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + \
cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + \
(cos(v[12])*L[10]*v[24])/2.)*sin(v[12])) - \
L[10]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - \
cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - \
cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - \
cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - \
cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[12]) \
- cos(v[12])*L[10]*v[24]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) \
- L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - \
L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - \
L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + \
cos(v[12])*L[10]*(-(L[1]*pow(v[15],2)*sin(v[3])) - \
L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - \
L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - \
L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - \
L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - \
(L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;"\)], "Print"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1352}, {0, 560}},
WindowSize->{1204, 510},
WindowMargins->{{46, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 7975, 153, 1678, "Input"],
Cell[9754, 208, 78, 1, 25, "Print"],
Cell[9835, 211, 34, 1, 25, "Print"],
Cell[9872, 214, 34, 1, 25, "Print"],
Cell[9909, 217, 34, 1, 25, "Print"],
Cell[9946, 220, 34, 1, 25, "Print"],
Cell[9983, 223, 34, 1, 25, "Print"],
Cell[10020, 226, 34, 1, 25, "Print"],
Cell[10057, 229, 34, 1, 25, "Print"],
Cell[10094, 232, 34, 1, 25, "Print"],
Cell[10131, 235, 34, 1, 25, "Print"],
Cell[10168, 238, 35, 1, 25, "Print"],
Cell[10206, 241, 53, 1, 25, "Print"],
Cell[10262, 244, 57, 1, 25, "Print"],
Cell[10322, 247, 63, 1, 25, "Print"],
Cell[10388, 250, 34, 1, 25, "Print"],
Cell[10425, 253, 34, 1, 25, "Print"],
Cell[10462, 256, 34, 1, 25, "Print"],
Cell[10499, 259, 34, 1, 25, "Print"],
Cell[10536, 262, 34, 1, 25, "Print"],
Cell[10573, 265, 34, 1, 25, "Print"],
Cell[10610, 268, 34, 1, 25, "Print"],
Cell[10647, 271, 34, 1, 25, "Print"],
Cell[10684, 274, 34, 1, 25, "Print"],
Cell[10721, 277, 35, 1, 25, "Print"],
Cell[10759, 280, 35, 1, 25, "Print"],
Cell[10797, 283, 35, 1, 25, "Print"],
Cell[10835, 286, 47, 1, 25, "Print"],
Cell[10885, 289, 34, 1, 25, "Print"],
Cell[10922, 292, 34, 1, 25, "Print"],
Cell[10959, 295, 34, 1, 25, "Print"],
Cell[10996, 298, 34, 1, 25, "Print"],
Cell[11033, 301, 34, 1, 25, "Print"],
Cell[11070, 304, 34, 1, 25, "Print"],
Cell[11107, 307, 34, 1, 25, "Print"],
Cell[11144, 310, 34, 1, 25, "Print"],
Cell[11181, 313, 34, 1, 25, "Print"],
Cell[11218, 316, 35, 1, 25, "Print"],
Cell[11256, 319, 35, 1, 25, "Print"],
Cell[11294, 322, 35, 1, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11366, 328, 3573, 70, 690, "Input"],
Cell[14942, 400, 342, 5, 22, "Message"],
Cell[15287, 407, 343, 5, 22, "Message"],
Cell[15633, 414, 343, 5, 22, "Message"],
Cell[15979, 421, 329, 5, 22, "Message"],
Cell[16311, 428, 342, 5, 22, "Message"],
Cell[16656, 435, 342, 5, 22, "Message"],
Cell[17001, 442, 342, 5, 22, "Message"],
Cell[17346, 449, 329, 5, 22, "Message"],
Cell[17678, 456, 108588, 1702, 323, "Output"],
Cell[126269, 2160, 592500, 8940, 323, "Output"],
Cell[718772, 11102, 10085, 225, 143, "Output"],
Cell[728860, 11329, 190775, 2903, 26055, "Print"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

