/*
Use: [mainMat, mainVec] = getDs(v, f, M, L, [Cs Cv])
 where,
  v = [xL,yL,th1,th2,...,thn, DxL,DyL,Dth1,Dth2,...,Dthn] is the state vector
  f = [tauL, forceLX, forceLY, tauR, forceRX, forceRY] is the external force
 The main equations of motion are given by
  mainMat * [DDxL,DDyL,DDth1,DDth2,...,DDthn]' = mainVec;
*/

#include "math.h"
#include "stdio.h"
#include "stdlib.h"
#include "mex.h"   //--This one is required

void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
    int np2x2, np2, a;
    double* v0;
    double* v;
    double* fs;
    double* coefMat;
    double* rhsVec;
    double tauL, forceLX, forceLY, tauR, forceRX, forceRY;
    double* M0;
    double* L0;
    double* M;
    double* L;
    double* fricCoefs;
    double Cv, Cs;
    
    v0 = mxGetPr(prhs[0]);
    np2x2 = mxGetM(prhs[0]);
    np2 = np2x2 / 2;
    v = (double*) malloc((np2x2+1)*sizeof(double));
    for(a=0; a<np2x2; a++)
        v[a+1] = v0[a];
    
    fs = mxGetPr(prhs[1]);
    tauL = fs[0];
    forceLX = fs[1];
    forceLY = fs[2];
    tauR = fs[3];
    forceRX = fs[4];
    forceRY = fs[5];
    
    M0 = (double*) malloc((np2-2)*sizeof(double));
    L0 = (double*) malloc((np2-2)*sizeof(double));
    M0 = mxGetPr(prhs[2]);
    L0 = mxGetPr(prhs[3]);
    M = (double*) malloc((np2-1)*sizeof(double));
    L = (double*) malloc((np2-1)*sizeof(double));
    for(a=0; a<np2-2; a++)
    {
        M[a+1] = M0[a];
        L[a+1] = L0[a];
    }
    fricCoefs = mxGetPr(prhs[4]);
    Cs = fricCoefs[0];
    Cv = fricCoefs[1];
    
    plhs[0] = mxCreateDoubleMatrix(np2, np2, mxREAL);
    plhs[1] = mxCreateDoubleMatrix(np2, 1, mxREAL);
    coefMat = mxGetPr(plhs[0]);
    rhsVec = mxGetPr(plhs[1]);
    
    // Assignments go here
    // ===================

 coefMat[0] = M[1] + M[2] + M[3] + M[4] + M[5] + M[6] + M[7] + M[8] + M[9] + M[10];
 coefMat[12] = 0;
 coefMat[24] = -(L[1]*M[1]*sin(v[3]))/2. - L[1]*M[2]*sin(v[3]) - L[1]*M[3]*sin(v[3]) - L[1]*M[4]*sin(v[3]) - L[1]*M[5]*sin(v[3]) - L[1]*M[6]*sin(v[3]) - L[1]*M[7]*sin(v[3]) - L[1]*M[8]*sin(v[3]) - L[1]*M[9]*sin(v[3]) - L[1]*M[10]*sin(v[3]);
 coefMat[36] = -(L[2]*M[2]*sin(v[4]))/2. - L[2]*M[3]*sin(v[4]) - L[2]*M[4]*sin(v[4]) - L[2]*M[5]*sin(v[4]) - L[2]*M[6]*sin(v[4]) - L[2]*M[7]*sin(v[4]) - L[2]*M[8]*sin(v[4]) - L[2]*M[9]*sin(v[4]) - L[2]*M[10]*sin(v[4]);
 coefMat[48] = -(L[3]*M[3]*sin(v[5]))/2. - L[3]*M[4]*sin(v[5]) - L[3]*M[5]*sin(v[5]) - L[3]*M[6]*sin(v[5]) - L[3]*M[7]*sin(v[5]) - L[3]*M[8]*sin(v[5]) - L[3]*M[9]*sin(v[5]) - L[3]*M[10]*sin(v[5]);
 coefMat[60] = -(L[4]*M[4]*sin(v[6]))/2. - L[4]*M[5]*sin(v[6]) - L[4]*M[6]*sin(v[6]) - L[4]*M[7]*sin(v[6]) - L[4]*M[8]*sin(v[6]) - L[4]*M[9]*sin(v[6]) - L[4]*M[10]*sin(v[6]);
 coefMat[72] = -(L[5]*M[5]*sin(v[7]))/2. - L[5]*M[6]*sin(v[7]) - L[5]*M[7]*sin(v[7]) - L[5]*M[8]*sin(v[7]) - L[5]*M[9]*sin(v[7]) - L[5]*M[10]*sin(v[7]);
 coefMat[84] = -(L[6]*M[6]*sin(v[8]))/2. - L[6]*M[7]*sin(v[8]) - L[6]*M[8]*sin(v[8]) - L[6]*M[9]*sin(v[8]) - L[6]*M[10]*sin(v[8]);
 coefMat[96] = -(L[7]*M[7]*sin(v[9]))/2. - L[7]*M[8]*sin(v[9]) - L[7]*M[9]*sin(v[9]) - L[7]*M[10]*sin(v[9]);
 coefMat[108] = -(L[8]*M[8]*sin(v[10]))/2. - L[8]*M[9]*sin(v[10]) - L[8]*M[10]*sin(v[10]);
 coefMat[120] = -(L[9]*M[9]*sin(v[11]))/2. - L[9]*M[10]*sin(v[11]);
 coefMat[132] = -(L[10]*M[10]*sin(v[12]))/2.;
 rhsVec[0] = forceLX + forceRX - Cv*pow(cos(v[3]),2)*L[1]*v[13] - Cv*pow(cos(v[4]),2)*L[2]*v[13] - Cv*pow(cos(v[5]),2)*L[3]*v[13] - Cv*pow(cos(v[6]),2)*L[4]*v[13] + (cos(v[3])*L[1]*M[1]*pow(v[15],2))/2. - M[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) - (cos(v[4])*L[2]*pow(v[16],2))/2.) - M[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - (cos(v[5])*L[3]*pow(v[17],2))/2.) - M[4]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - (cos(v[6])*L[4]*pow(v[18],2))/2.) - M[5]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - (cos(v[7])*L[5]*pow(v[19],2))/2.) - M[6]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - (cos(v[8])*L[6]*pow(v[20],2))/2.) - M[7]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - (cos(v[9])*L[7]*pow(v[21],2))/2.) - M[8]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.) - M[9]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - (cos(v[11])*L[9]*pow(v[23],2))/2.) - M[10]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.) + Cs*cos(v[3])*L[1]*v[14]*sin(v[3]) - Cv*cos(v[3])*L[1]*v[14]*sin(v[3]) + (Cs*pow(L[1],2)*v[15]*sin(v[3]))/2. - Cs*L[1]*v[13]*pow(sin(v[3]),2) + Cv*cos(v[4])*L[1]*L[2]*v[15]*sin(v[3] - v[4]) + Cs*cos(v[4])*L[2]*v[14]*sin(v[4]) - Cv*cos(v[4])*L[2]*v[14]*sin(v[4]) + Cs*cos(v[3] - v[4])*L[1]*L[2]*v[15]*sin(v[4]) + (Cs*pow(L[2],2)*v[16]*sin(v[4]))/2. - Cs*L[2]*v[13]*pow(sin(v[4]),2) + Cv*cos(v[5])*L[1]*L[3]*v[15]*sin(v[3] - v[5]) + Cv*cos(v[5])*L[2]*L[3]*v[16]*sin(v[4] - v[5]) + Cs*cos(v[5])*L[3]*v[14]*sin(v[5]) - Cv*cos(v[5])*L[3]*v[14]*sin(v[5]) + Cs*cos(v[3] - v[5])*L[1]*L[3]*v[15]*sin(v[5]) + Cs*cos(v[4] - v[5])*L[2]*L[3]*v[16]*sin(v[5]) + (Cs*pow(L[3],2)*v[17]*sin(v[5]))/2. - Cs*L[3]*v[13]*pow(sin(v[5]),2) + Cv*cos(v[6])*L[1]*L[4]*v[15]*sin(v[3] - v[6]) + Cv*cos(v[6])*L[2]*L[4]*v[16]*sin(v[4] - v[6]) + Cv*cos(v[6])*L[3]*L[4]*v[17]*sin(v[5] - v[6]) + Cs*cos(v[6])*L[4]*v[14]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[14]*sin(v[6]) + Cs*cos(v[3] - v[6])*L[1]*L[4]*v[15]*sin(v[6]) + Cs*cos(v[4] - v[6])*L[2]*L[4]*v[16]*sin(v[6]) + Cs*cos(v[5] - v[6])*L[3]*L[4]*v[17]*sin(v[6]) + (Cs*pow(L[4],2)*v[18]*sin(v[6]))/2. - Cs*L[4]*v[13]*pow(sin(v[6]),2) + (L[5]*(-(Cs*sin(v[7])*(-2*cos(v[7])*v[14] - 2*cos(v[3] - v[7])*L[1]*v[15] - 2*cos(v[4] - v[7])*L[2]*v[16] - 2*cos(v[5] - v[7])*L[3]*v[17] - 2*cos(v[6] - v[7])*L[4]*v[18] - L[5]*v[19] + 2*v[13]*sin(v[7]))) + 2*Cv*cos(v[7])*(-(cos(v[7])*v[13]) + L[1]*v[15]*sin(v[3] - v[7]) + L[2]*v[16]*sin(v[4] - v[7]) + L[3]*v[17]*sin(v[5] - v[7]) + L[4]*v[18]*sin(v[6] - v[7]) - v[14]*sin(v[7]))))/2. + (L[6]*(-(Cs*sin(v[8])*(-2*cos(v[8])*v[14] - 2*cos(v[3] - v[8])*L[1]*v[15] - 2*cos(v[4] - v[8])*L[2]*v[16] - 2*cos(v[5] - v[8])*L[3]*v[17] - 2*cos(v[6] - v[8])*L[4]*v[18] - 2*cos(v[7] - v[8])*L[5]*v[19] - L[6]*v[20] + 2*v[13]*sin(v[8]))) + 2*Cv*cos(v[8])*(-(cos(v[8])*v[13]) + L[1]*v[15]*sin(v[3] - v[8]) + L[2]*v[16]*sin(v[4] - v[8]) + L[3]*v[17]*sin(v[5] - v[8]) + L[4]*v[18]*sin(v[6] - v[8]) + L[5]*v[19]*sin(v[7] - v[8]) - v[14]*sin(v[8]))))/2. - (Cs*L[7]*sin(v[9])*(-2*cos(v[9])*v[14] - 2*cos(v[3] - v[9])*L[1]*v[15] - 2*cos(v[4] - v[9])*L[2]*v[16] - 2*cos(v[5] - v[9])*L[3]*v[17] - 2*cos(v[6] - v[9])*L[4]*v[18] - 2*cos(v[7] - v[9])*L[5]*v[19] - 2*cos(v[8] - v[9])*L[6]*v[20] - L[7]*v[21] + 2*v[13]*sin(v[9])))/2. - Cv*cos(v[9])*L[7]*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9])) - (Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10])) - (Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + 2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11])) - (Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]));
 coefMat[1] = 0;
 coefMat[13] = M[1] + M[2] + M[3] + M[4] + M[5] + M[6] + M[7] + M[8] + M[9] + M[10];
 coefMat[25] = (cos(v[3])*L[1]*M[1])/2. + cos(v[3])*L[1]*M[2] + cos(v[3])*L[1]*M[3] + cos(v[3])*L[1]*M[4] + cos(v[3])*L[1]*M[5] + cos(v[3])*L[1]*M[6] + cos(v[3])*L[1]*M[7] + cos(v[3])*L[1]*M[8] + cos(v[3])*L[1]*M[9] + cos(v[3])*L[1]*M[10];
 coefMat[37] = (cos(v[4])*L[2]*M[2])/2. + cos(v[4])*L[2]*M[3] + cos(v[4])*L[2]*M[4] + cos(v[4])*L[2]*M[5] + cos(v[4])*L[2]*M[6] + cos(v[4])*L[2]*M[7] + cos(v[4])*L[2]*M[8] + cos(v[4])*L[2]*M[9] + cos(v[4])*L[2]*M[10];
 coefMat[49] = (cos(v[5])*L[3]*M[3])/2. + cos(v[5])*L[3]*M[4] + cos(v[5])*L[3]*M[5] + cos(v[5])*L[3]*M[6] + cos(v[5])*L[3]*M[7] + cos(v[5])*L[3]*M[8] + cos(v[5])*L[3]*M[9] + cos(v[5])*L[3]*M[10];
 coefMat[61] = (cos(v[6])*L[4]*M[4])/2. + cos(v[6])*L[4]*M[5] + cos(v[6])*L[4]*M[6] + cos(v[6])*L[4]*M[7] + cos(v[6])*L[4]*M[8] + cos(v[6])*L[4]*M[9] + cos(v[6])*L[4]*M[10];
 coefMat[73] = (cos(v[7])*L[5]*M[5])/2. + cos(v[7])*L[5]*M[6] + cos(v[7])*L[5]*M[7] + cos(v[7])*L[5]*M[8] + cos(v[7])*L[5]*M[9] + cos(v[7])*L[5]*M[10];
 coefMat[85] = (cos(v[8])*L[6]*M[6])/2. + cos(v[8])*L[6]*M[7] + cos(v[8])*L[6]*M[8] + cos(v[8])*L[6]*M[9] + cos(v[8])*L[6]*M[10];
 coefMat[97] = (cos(v[9])*L[7]*M[7])/2. + cos(v[9])*L[7]*M[8] + cos(v[9])*L[7]*M[9] + cos(v[9])*L[7]*M[10];
 coefMat[109] = (cos(v[10])*L[8]*M[8])/2. + cos(v[10])*L[8]*M[9] + cos(v[10])*L[8]*M[10];
 coefMat[121] = (cos(v[11])*L[9]*M[9])/2. + cos(v[11])*L[9]*M[10];
 coefMat[133] = (cos(v[12])*L[10]*M[10])/2.;
 rhsVec[1] = forceLY + forceRY - Cs*pow(cos(v[3]),2)*L[1]*v[14] - Cs*pow(cos(v[4]),2)*L[2]*v[14] - Cs*pow(cos(v[5]),2)*L[3]*v[14] - Cs*pow(cos(v[6]),2)*L[4]*v[14] - (Cs*cos(v[3])*pow(L[1],2)*v[15])/2. - Cs*cos(v[3] - v[4])*cos(v[4])*L[1]*L[2]*v[15] - Cs*cos(v[3] - v[5])*cos(v[5])*L[1]*L[3]*v[15] - Cs*cos(v[3] - v[6])*cos(v[6])*L[1]*L[4]*v[15] - (Cs*cos(v[4])*pow(L[2],2)*v[16])/2. - Cs*cos(v[4] - v[5])*cos(v[5])*L[2]*L[3]*v[16] - Cs*cos(v[4] - v[6])*cos(v[6])*L[2]*L[4]*v[16] - (Cs*cos(v[5])*pow(L[3],2)*v[17])/2. - Cs*cos(v[5] - v[6])*cos(v[6])*L[3]*L[4]*v[17] - (Cs*cos(v[6])*pow(L[4],2)*v[18])/2. + Cs*cos(v[3])*L[1]*v[13]*sin(v[3]) - Cv*cos(v[3])*L[1]*v[13]*sin(v[3]) + (L[1]*M[1]*pow(v[15],2)*sin(v[3]))/2. - Cv*L[1]*v[14]*pow(sin(v[3]),2) + Cs*cos(v[4])*L[2]*v[13]*sin(v[4]) - Cv*cos(v[4])*L[2]*v[13]*sin(v[4]) + Cv*L[1]*L[2]*v[15]*sin(v[3] - v[4])*sin(v[4]) - Cv*L[2]*v[14]*pow(sin(v[4]),2) - M[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - (L[2]*pow(v[16],2)*sin(v[4]))/2.) + Cs*cos(v[5])*L[3]*v[13]*sin(v[5]) - Cv*cos(v[5])*L[3]*v[13]*sin(v[5]) + Cv*L[1]*L[3]*v[15]*sin(v[3] - v[5])*sin(v[5]) + Cv*L[2]*L[3]*v[16]*sin(v[4] - v[5])*sin(v[5]) - Cv*L[3]*v[14]*pow(sin(v[5]),2) - M[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - (L[3]*pow(v[17],2)*sin(v[5]))/2.) + Cs*cos(v[6])*L[4]*v[13]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[13]*sin(v[6]) + Cv*L[1]*L[4]*v[15]*sin(v[3] - v[6])*sin(v[6]) + Cv*L[2]*L[4]*v[16]*sin(v[4] - v[6])*sin(v[6]) + Cv*L[3]*L[4]*v[17]*sin(v[5] - v[6])*sin(v[6]) - Cv*L[4]*v[14]*pow(sin(v[6]),2) - M[4]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - (L[4]*pow(v[18],2)*sin(v[6]))/2.) - M[5]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - (L[5]*pow(v[19],2)*sin(v[7]))/2.) - (L[5]*(Cs*cos(v[7])*(2*cos(v[7])*v[14] + 2*cos(v[3] - v[7])*L[1]*v[15] + 2*cos(v[4] - v[7])*L[2]*v[16] + 2*cos(v[5] - v[7])*L[3]*v[17] + 2*cos(v[6] - v[7])*L[4]*v[18] + L[5]*v[19] - 2*v[13]*sin(v[7])) + 2*Cv*sin(v[7])*(cos(v[7])*v[13] - L[1]*v[15]*sin(v[3] - v[7]) - L[2]*v[16]*sin(v[4] - v[7]) - L[3]*v[17]*sin(v[5] - v[7]) - L[4]*v[18]*sin(v[6] - v[7]) + v[14]*sin(v[7]))))/2. - (Cs*cos(v[8])*L[6]*(2*cos(v[8])*v[14] + 2*cos(v[3] - v[8])*L[1]*v[15] + 2*cos(v[4] - v[8])*L[2]*v[16] + 2*cos(v[5] - v[8])*L[3]*v[17] + 2*cos(v[6] - v[8])*L[4]*v[18] + 2*cos(v[7] - v[8])*L[5]*v[19] + L[6]*v[20] - 2*v[13]*sin(v[8])))/2. - Cv*L[6]*sin(v[8])*(cos(v[8])*v[13] - L[1]*v[15]*sin(v[3] - v[8]) - L[2]*v[16]*sin(v[4] - v[8]) - L[3]*v[17]*sin(v[5] - v[8]) - L[4]*v[18]*sin(v[6] - v[8]) - L[5]*v[19]*sin(v[7] - v[8]) + v[14]*sin(v[8])) - M[6]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - (L[6]*pow(v[20],2)*sin(v[8]))/2.) - (Cs*cos(v[9])*L[7]*(2*cos(v[9])*v[14] + 2*cos(v[3] - v[9])*L[1]*v[15] + 2*cos(v[4] - v[9])*L[2]*v[16] + 2*cos(v[5] - v[9])*L[3]*v[17] + 2*cos(v[6] - v[9])*L[4]*v[18] + 2*cos(v[7] - v[9])*L[5]*v[19] + 2*cos(v[8] - v[9])*L[6]*v[20] + L[7]*v[21] - 2*v[13]*sin(v[9])))/2. - Cv*L[7]*sin(v[9])*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9])) - M[7]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - (L[7]*pow(v[21],2)*sin(v[9]))/2.) - (Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] + 2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + 2*cos(v[5] - v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] - v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10])) - M[8]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - (L[8]*pow(v[22],2)*sin(v[10]))/2.) - (Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] + 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + 2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] - v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - 2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11])) - M[9]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.) - (Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12])) - M[10]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - (L[10]*pow(v[24],2)*sin(v[12]))/2.);
 coefMat[2] = -(L[1]*M[1]*sin(v[3]))/2. - L[1]*M[2]*sin(v[3]) - L[1]*M[3]*sin(v[3]) - L[1]*M[4]*sin(v[3]) - L[1]*M[5]*sin(v[3]) - L[1]*M[6]*sin(v[3]) - L[1]*M[7]*sin(v[3]) - L[1]*M[8]*sin(v[3]) - L[1]*M[9]*sin(v[3]) - L[1]*M[10]*sin(v[3]);
 coefMat[14] = (cos(v[3])*L[1]*M[1])/2. + cos(v[3])*L[1]*M[2] + cos(v[3])*L[1]*M[3] + cos(v[3])*L[1]*M[4] + cos(v[3])*L[1]*M[5] + cos(v[3])*L[1]*M[6] + cos(v[3])*L[1]*M[7] + cos(v[3])*L[1]*M[8] + cos(v[3])*L[1]*M[9] + cos(v[3])*L[1]*M[10];
 coefMat[26] = (pow(L[1],2)*M[1])/12. + (M[1]*((pow(cos(v[3]),2)*pow(L[1],2))/2. + (pow(L[1],2)*pow(sin(v[3]),2))/2.))/2. + (M[2]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2. + (M[3]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2. + (M[4]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2. + (M[5]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2. + (M[6]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2. + (M[7]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2. + (M[8]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2. + (M[9]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2. + (M[10]*(2*pow(cos(v[3]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(v[3]),2)))/2.;
 coefMat[38] = (M[2]*(cos(v[3])*cos(v[4])*L[1]*L[2] + L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[3]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[4]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[5]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[6]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[7]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[8]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[9]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[10]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2.;
 coefMat[50] = (M[3]*(cos(v[3])*cos(v[5])*L[1]*L[3] + L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[4]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[5]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[6]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[7]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[8]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[9]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[10]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2.;
 coefMat[62] = (M[4]*(cos(v[3])*cos(v[6])*L[1]*L[4] + L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + (M[5]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + (M[6]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + (M[7]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + (M[8]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + (M[9]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + (M[10]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2.;
 coefMat[74] = (M[5]*(cos(v[3])*cos(v[7])*L[1]*L[5] + L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + (M[6]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + 2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + (M[7]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + 2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + (M[8]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + 2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + (M[9]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + 2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + (M[10]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + 2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2.;
 coefMat[86] = (M[6]*(cos(v[3])*cos(v[8])*L[1]*L[6] + L[1]*L[6]*sin(v[3])*sin(v[8])))/2. + (M[7]*(2*cos(v[3])*cos(v[8])*L[1]*L[6] + 2*L[1]*L[6]*sin(v[3])*sin(v[8])))/2. + (M[8]*(2*cos(v[3])*cos(v[8])*L[1]*L[6] + 2*L[1]*L[6]*sin(v[3])*sin(v[8])))/2. + (M[9]*(2*cos(v[3])*cos(v[8])*L[1]*L[6] + 2*L[1]*L[6]*sin(v[3])*sin(v[8])))/2. + (M[10]*(2*cos(v[3])*cos(v[8])*L[1]*L[6] + 2*L[1]*L[6]*sin(v[3])*sin(v[8])))/2.;
 coefMat[98] = (M[7]*(cos(v[3])*cos(v[9])*L[1]*L[7] + L[1]*L[7]*sin(v[3])*sin(v[9])))/2. + (M[8]*(2*cos(v[3])*cos(v[9])*L[1]*L[7] + 2*L[1]*L[7]*sin(v[3])*sin(v[9])))/2. + (M[9]*(2*cos(v[3])*cos(v[9])*L[1]*L[7] + 2*L[1]*L[7]*sin(v[3])*sin(v[9])))/2. + (M[10]*(2*cos(v[3])*cos(v[9])*L[1]*L[7] + 2*L[1]*L[7]*sin(v[3])*sin(v[9])))/2.;
 coefMat[110] = (M[8]*(cos(v[3])*cos(v[10])*L[1]*L[8] + L[1]*L[8]*sin(v[3])*sin(v[10])))/2. + (M[9]*(2*cos(v[3])*cos(v[10])*L[1]*L[8] + 2*L[1]*L[8]*sin(v[3])*sin(v[10])))/2. + (M[10]*(2*cos(v[3])*cos(v[10])*L[1]*L[8] + 2*L[1]*L[8]*sin(v[3])*sin(v[10])))/2.;
 coefMat[122] = (M[9]*(cos(v[3])*cos(v[11])*L[1]*L[9] + L[1]*L[9]*sin(v[3])*sin(v[11])))/2. + (M[10]*(2*cos(v[3])*cos(v[11])*L[1]*L[9] + 2*L[1]*L[9]*sin(v[3])*sin(v[11])))/2.;
 coefMat[134] = (M[10]*(cos(v[3])*cos(v[12])*L[1]*L[10] + L[1]*L[10]*sin(v[3])*sin(v[12])))/2.;
 rhsVec[2] = tauL + forceRY*cos(v[3])*L[1] - (Cs*pow(L[1],3)*v[15])/12. - forceRX*L[1]*sin(v[3]) - (L[1]*sin(v[3])*(-(Cv*pow(cos(v[3]),2)*L[1]*v[13]) + Cs*cos(v[3])*L[1]*v[14]*sin(v[3]) - Cv*cos(v[3])*L[1]*v[14]*sin(v[3]) + (Cs*pow(L[1],2)*v[15]*sin(v[3]))/2. - Cs*L[1]*v[13]*pow(sin(v[3]),2)))/2. + (cos(v[3])*L[1]*(-(Cs*pow(cos(v[3]),2)*L[1]*v[14]) - (Cs*cos(v[3])*pow(L[1],2)*v[15])/2. + Cs*cos(v[3])*L[1]*v[13]*sin(v[3]) - Cv*cos(v[3])*L[1]*v[13]*sin(v[3]) - Cv*L[1]*v[14]*pow(sin(v[3]),2)))/2. - L[1]*sin(v[3])*(-(Cv*pow(cos(v[4]),2)*L[2]*v[13]) + Cv*cos(v[4])*L[1]*L[2]*v[15]*sin(v[3] - v[4]) + Cs*cos(v[4])*L[2]*v[14]*sin(v[4]) - Cv*cos(v[4])*L[2]*v[14]*sin(v[4]) + Cs*cos(v[3] - v[4])*L[1]*L[2]*v[15]*sin(v[4]) + (Cs*pow(L[2],2)*v[16]*sin(v[4]))/2. - Cs*L[2]*v[13]*pow(sin(v[4]),2)) + cos(v[3])*L[1]*(-(Cs*pow(cos(v[4]),2)*L[2]*v[14]) - Cs*cos(v[3] - v[4])*cos(v[4])*L[1]*L[2]*v[15] - (Cs*cos(v[4])*pow(L[2],2)*v[16])/2. + Cs*cos(v[4])*L[2]*v[13]*sin(v[4]) - Cv*cos(v[4])*L[2]*v[13]*sin(v[4]) + Cv*L[1]*L[2]*v[15]*sin(v[3] - v[4])*sin(v[4]) - Cv*L[2]*v[14]*pow(sin(v[4]),2)) + (M[2]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + (cos(v[4])*L[2]*v[16])/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - (L[2]*v[16]*sin(v[4]))/2.)))/2. - (M[2]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + (cos(v[4])*L[2]*v[16])/2.)*sin(v[3]) - 2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) - (cos(v[4])*L[2]*pow(v[16],2))/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - (L[2]*v[16]*sin(v[4]))/2.) + 2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) - (L[2]*pow(v[16],2)*sin(v[4]))/2.)))/2. - L[1]*sin(v[3])*(-(Cv*pow(cos(v[5]),2)*L[3]*v[13]) + Cv*cos(v[5])*L[1]*L[3]*v[15]*sin(v[3] - v[5]) + Cv*cos(v[5])*L[2]*L[3]*v[16]*sin(v[4] - v[5]) + Cs*cos(v[5])*L[3]*v[14]*sin(v[5]) - Cv*cos(v[5])*L[3]*v[14]*sin(v[5]) + Cs*cos(v[3] - v[5])*L[1]*L[3]*v[15]*sin(v[5]) + Cs*cos(v[4] - v[5])*L[2]*L[3]*v[16]*sin(v[5]) + (Cs*pow(L[3],2)*v[17]*sin(v[5]))/2. - Cs*L[3]*v[13]*pow(sin(v[5]),2)) + cos(v[3])*L[1]*(-(Cs*pow(cos(v[5]),2)*L[3]*v[14]) - Cs*cos(v[3] - v[5])*cos(v[5])*L[1]*L[3]*v[15] - Cs*cos(v[4] - v[5])*cos(v[5])*L[2]*L[3]*v[16] - (Cs*cos(v[5])*pow(L[3],2)*v[17])/2. + Cs*cos(v[5])*L[3]*v[13]*sin(v[5]) - Cv*cos(v[5])*L[3]*v[13]*sin(v[5]) + Cv*L[1]*L[3]*v[15]*sin(v[3] - v[5])*sin(v[5]) + Cv*L[2]*L[3]*v[16]*sin(v[4] - v[5])*sin(v[5]) - Cv*L[3]*v[14]*pow(sin(v[5]),2)) + (M[3]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + (cos(v[5])*L[3]*v[17])/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - (L[3]*v[17]*sin(v[5]))/2.)))/2. - (M[3]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + (cos(v[5])*L[3]*v[17])/2.)*sin(v[3]) - 2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - (cos(v[5])*L[3]*pow(v[17],2))/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - (L[3]*v[17]*sin(v[5]))/2.) + 2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - (L[3]*pow(v[17],2)*sin(v[5]))/2.)))/2. - L[1]*sin(v[3])*(-(Cv*pow(cos(v[6]),2)*L[4]*v[13]) + Cv*cos(v[6])*L[1]*L[4]*v[15]*sin(v[3] - v[6]) + Cv*cos(v[6])*L[2]*L[4]*v[16]*sin(v[4] - v[6]) + Cv*cos(v[6])*L[3]*L[4]*v[17]*sin(v[5] - v[6]) + Cs*cos(v[6])*L[4]*v[14]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[14]*sin(v[6]) + Cs*cos(v[3] - v[6])*L[1]*L[4]*v[15]*sin(v[6]) + Cs*cos(v[4] - v[6])*L[2]*L[4]*v[16]*sin(v[6]) + Cs*cos(v[5] - v[6])*L[3]*L[4]*v[17]*sin(v[6]) + (Cs*pow(L[4],2)*v[18]*sin(v[6]))/2. - Cs*L[4]*v[13]*pow(sin(v[6]),2)) + cos(v[3])*L[1]*(-(Cs*pow(cos(v[6]),2)*L[4]*v[14]) - Cs*cos(v[3] - v[6])*cos(v[6])*L[1]*L[4]*v[15] - Cs*cos(v[4] - v[6])*cos(v[6])*L[2]*L[4]*v[16] - Cs*cos(v[5] - v[6])*cos(v[6])*L[3]*L[4]*v[17] - (Cs*cos(v[6])*pow(L[4],2)*v[18])/2. + Cs*cos(v[6])*L[4]*v[13]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[13]*sin(v[6]) + Cv*L[1]*L[4]*v[15]*sin(v[3] - v[6])*sin(v[6]) + Cv*L[2]*L[4]*v[16]*sin(v[4] - v[6])*sin(v[6]) + Cv*L[3]*L[4]*v[17]*sin(v[5] - v[6])*sin(v[6]) - Cv*L[4]*v[14]*pow(sin(v[6]),2)) + (M[4]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + (cos(v[6])*L[4]*v[18])/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - (L[4]*v[18]*sin(v[6]))/2.)))/2. - (M[4]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + (cos(v[6])*L[4]*v[18])/2.)*sin(v[3]) - 2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - (cos(v[6])*L[4]*pow(v[18],2))/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - (L[4]*v[18]*sin(v[6]))/2.) + 2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - (L[4]*pow(v[18],2)*sin(v[6]))/2.)))/2. - (L[1]*L[5]*sin(v[3])*(-(Cs*sin(v[7])*(-2*cos(v[7])*v[14] - 2*cos(v[3] - v[7])*L[1]*v[15] - 2*cos(v[4] - v[7])*L[2]*v[16] - 2*cos(v[5] - v[7])*L[3]*v[17] - 2*cos(v[6] - v[7])*L[4]*v[18] - L[5]*v[19] + 2*v[13]*sin(v[7]))) + 2*Cv*cos(v[7])*(-(cos(v[7])*v[13]) + L[1]*v[15]*sin(v[3] - v[7]) + L[2]*v[16]*sin(v[4] - v[7]) + L[3]*v[17]*sin(v[5] - v[7]) + L[4]*v[18]*sin(v[6] - v[7]) - v[14]*sin(v[7]))))/2. - (cos(v[3])*L[1]*L[5]*(Cs*cos(v[7])*(2*cos(v[7])*v[14] + 2*cos(v[3] - v[7])*L[1]*v[15] + 2*cos(v[4] - v[7])*L[2]*v[16] + 2*cos(v[5] - v[7])*L[3]*v[17] + 2*cos(v[6] - v[7])*L[4]*v[18] + L[5]*v[19] - 2*v[13]*sin(v[7])) + 2*Cv*sin(v[7])*(cos(v[7])*v[13] - L[1]*v[15]*sin(v[3] - v[7]) - L[2]*v[16]*sin(v[4] - v[7]) - L[3]*v[17]*sin(v[5] - v[7]) - L[4]*v[18]*sin(v[6] - v[7]) + v[14]*sin(v[7]))))/2. + (M[5]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + (cos(v[7])*L[5]*v[19])/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.)))/2. - (M[5]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + (cos(v[7])*L[5]*v[19])/2.)*sin(v[3]) - 2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - (cos(v[7])*L[5]*pow(v[19],2))/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.) + 2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - (L[5]*pow(v[19],2)*sin(v[7]))/2.)))/2. - (L[1]*L[6]*sin(v[3])*(-(Cs*sin(v[8])*(-2*cos(v[8])*v[14] - 2*cos(v[3] - v[8])*L[1]*v[15] - 2*cos(v[4] - v[8])*L[2]*v[16] - 2*cos(v[5] - v[8])*L[3]*v[17] - 2*cos(v[6] - v[8])*L[4]*v[18] - 2*cos(v[7] - v[8])*L[5]*v[19] - L[6]*v[20] + 2*v[13]*sin(v[8]))) + 2*Cv*cos(v[8])*(-(cos(v[8])*v[13]) + L[1]*v[15]*sin(v[3] - v[8]) + L[2]*v[16]*sin(v[4] - v[8]) + L[3]*v[17]*sin(v[5] - v[8]) + L[4]*v[18]*sin(v[6] - v[8]) + L[5]*v[19]*sin(v[7] - v[8]) - v[14]*sin(v[8]))))/2. + cos(v[3])*L[1]*(-(Cs*cos(v[8])*L[6]*(2*cos(v[8])*v[14] + 2*cos(v[3] - v[8])*L[1]*v[15] + 2*cos(v[4] - v[8])*L[2]*v[16] + 2*cos(v[5] - v[8])*L[3]*v[17] + 2*cos(v[6] - v[8])*L[4]*v[18] + 2*cos(v[7] - v[8])*L[5]*v[19] + L[6]*v[20] - 2*v[13]*sin(v[8])))/2. - Cv*L[6]*sin(v[8])*(cos(v[8])*v[13] - L[1]*v[15]*sin(v[3] - v[8]) - L[2]*v[16]*sin(v[4] - v[8]) - L[3]*v[17]*sin(v[5] - v[8]) - L[4]*v[18]*sin(v[6] - v[8]) - L[5]*v[19]*sin(v[7] - v[8]) + v[14]*sin(v[8]))) + (M[6]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + (cos(v[8])*L[6]*v[20])/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.)))/2. - (M[6]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + (cos(v[8])*L[6]*v[20])/2.)*sin(v[3]) - 2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - (cos(v[8])*L[6]*pow(v[20],2))/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.) + 2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - (L[6]*pow(v[20],2)*sin(v[8]))/2.)))/2. - L[1]*sin(v[3])*(-(Cs*L[7]*sin(v[9])*(-2*cos(v[9])*v[14] - 2*cos(v[3] - v[9])*L[1]*v[15] - 2*cos(v[4] - v[9])*L[2]*v[16] - 2*cos(v[5] - v[9])*L[3]*v[17] - 2*cos(v[6] - v[9])*L[4]*v[18] - 2*cos(v[7] - v[9])*L[5]*v[19] - 2*cos(v[8] - v[9])*L[6]*v[20] - L[7]*v[21] + 2*v[13]*sin(v[9])))/2. - Cv*cos(v[9])*L[7]*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) + cos(v[3])*L[1]*(-(Cs*cos(v[9])*L[7]*(2*cos(v[9])*v[14] + 2*cos(v[3] - v[9])*L[1]*v[15] + 2*cos(v[4] - v[9])*L[2]*v[16] + 2*cos(v[5] - v[9])*L[3]*v[17] + 2*cos(v[6] - v[9])*L[4]*v[18] + 2*cos(v[7] - v[9])*L[5]*v[19] + 2*cos(v[8] - v[9])*L[6]*v[20] + L[7]*v[21] - 2*v[13]*sin(v[9])))/2. - Cv*L[7]*sin(v[9])*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) + (M[7]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.)))/2. - (M[7]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[3]) - 2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - (cos(v[9])*L[7]*pow(v[21],2))/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.) + 2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - (L[7]*pow(v[21],2)*sin(v[9]))/2.)))/2. - L[1]*sin(v[3])*(-(Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10]))) + cos(v[3])*L[1]*(-(Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] + 2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + 2*cos(v[5] - v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] - v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10]))) + (M[8]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + (cos(v[10])*L[8]*v[22])/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.)))/2. - (M[8]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + (cos(v[10])*L[8]*v[22])/2.)*sin(v[3]) - 2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.) + 2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - (L[8]*pow(v[22],2)*sin(v[10]))/2.)))/2. - L[1]*sin(v[3])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + 2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))) + cos(v[3])*L[1]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] + 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + 2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] - v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - 2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))) + (M[9]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[3]) - 2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - (cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + 2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - L[1]*sin(v[3])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + cos(v[3])*L[1]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + (M[10]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[1]*v[15]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[3]) - 2*L[1]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[3]) - 2*cos(v[3])*L[1]*v[15]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + 2*cos(v[3])*L[1]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - (L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;
 coefMat[3] = -(L[2]*M[2]*sin(v[4]))/2. - L[2]*M[3]*sin(v[4]) - L[2]*M[4]*sin(v[4]) - L[2]*M[5]*sin(v[4]) - L[2]*M[6]*sin(v[4]) - L[2]*M[7]*sin(v[4]) - L[2]*M[8]*sin(v[4]) - L[2]*M[9]*sin(v[4]) - L[2]*M[10]*sin(v[4]);
 coefMat[15] = (cos(v[4])*L[2]*M[2])/2. + cos(v[4])*L[2]*M[3] + cos(v[4])*L[2]*M[4] + cos(v[4])*L[2]*M[5] + cos(v[4])*L[2]*M[6] + cos(v[4])*L[2]*M[7] + cos(v[4])*L[2]*M[8] + cos(v[4])*L[2]*M[9] + cos(v[4])*L[2]*M[10];
 coefMat[27] = (M[2]*(cos(v[3])*cos(v[4])*L[1]*L[2] + L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[3]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[4]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[5]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[6]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[7]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[8]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[9]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2. + (M[10]*(2*cos(v[3])*cos(v[4])*L[1]*L[2] + 2*L[1]*L[2]*sin(v[3])*sin(v[4])))/2.;
 coefMat[39] = (pow(L[2],2)*M[2])/12. + (M[2]*((pow(cos(v[4]),2)*pow(L[2],2))/2. + (pow(L[2],2)*pow(sin(v[4]),2))/2.))/2. + (M[3]*(2*pow(cos(v[4]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(v[4]),2)))/2. + (M[4]*(2*pow(cos(v[4]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(v[4]),2)))/2. + (M[5]*(2*pow(cos(v[4]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(v[4]),2)))/2. + (M[6]*(2*pow(cos(v[4]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(v[4]),2)))/2. + (M[7]*(2*pow(cos(v[4]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(v[4]),2)))/2. + (M[8]*(2*pow(cos(v[4]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(v[4]),2)))/2. + (M[9]*(2*pow(cos(v[4]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(v[4]),2)))/2. + (M[10]*(2*pow(cos(v[4]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(v[4]),2)))/2.;
 coefMat[51] = (M[3]*(cos(v[4])*cos(v[5])*L[2]*L[3] + L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[4]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[5]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[6]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[7]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[8]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[9]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[10]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2.;
 coefMat[63] = (M[4]*(cos(v[4])*cos(v[6])*L[2]*L[4] + L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + (M[5]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + (M[6]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + (M[7]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + (M[8]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + (M[9]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + (M[10]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2.;
 coefMat[75] = (M[5]*(cos(v[4])*cos(v[7])*L[2]*L[5] + L[2]*L[5]*sin(v[4])*sin(v[7])))/2. + (M[6]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + 2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2. + (M[7]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + 2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2. + (M[8]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + 2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2. + (M[9]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + 2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2. + (M[10]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + 2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2.;
 coefMat[87] = (M[6]*(cos(v[4])*cos(v[8])*L[2]*L[6] + L[2]*L[6]*sin(v[4])*sin(v[8])))/2. + (M[7]*(2*cos(v[4])*cos(v[8])*L[2]*L[6] + 2*L[2]*L[6]*sin(v[4])*sin(v[8])))/2. + (M[8]*(2*cos(v[4])*cos(v[8])*L[2]*L[6] + 2*L[2]*L[6]*sin(v[4])*sin(v[8])))/2. + (M[9]*(2*cos(v[4])*cos(v[8])*L[2]*L[6] + 2*L[2]*L[6]*sin(v[4])*sin(v[8])))/2. + (M[10]*(2*cos(v[4])*cos(v[8])*L[2]*L[6] + 2*L[2]*L[6]*sin(v[4])*sin(v[8])))/2.;
 coefMat[99] = (M[7]*(cos(v[4])*cos(v[9])*L[2]*L[7] + L[2]*L[7]*sin(v[4])*sin(v[9])))/2. + (M[8]*(2*cos(v[4])*cos(v[9])*L[2]*L[7] + 2*L[2]*L[7]*sin(v[4])*sin(v[9])))/2. + (M[9]*(2*cos(v[4])*cos(v[9])*L[2]*L[7] + 2*L[2]*L[7]*sin(v[4])*sin(v[9])))/2. + (M[10]*(2*cos(v[4])*cos(v[9])*L[2]*L[7] + 2*L[2]*L[7]*sin(v[4])*sin(v[9])))/2.;
 coefMat[111] = (M[8]*(cos(v[4])*cos(v[10])*L[2]*L[8] + L[2]*L[8]*sin(v[4])*sin(v[10])))/2. + (M[9]*(2*cos(v[4])*cos(v[10])*L[2]*L[8] + 2*L[2]*L[8]*sin(v[4])*sin(v[10])))/2. + (M[10]*(2*cos(v[4])*cos(v[10])*L[2]*L[8] + 2*L[2]*L[8]*sin(v[4])*sin(v[10])))/2.;
 coefMat[123] = (M[9]*(cos(v[4])*cos(v[11])*L[2]*L[9] + L[2]*L[9]*sin(v[4])*sin(v[11])))/2. + (M[10]*(2*cos(v[4])*cos(v[11])*L[2]*L[9] + 2*L[2]*L[9]*sin(v[4])*sin(v[11])))/2.;
 coefMat[135] = (M[10]*(cos(v[4])*cos(v[12])*L[2]*L[10] + L[2]*L[10]*sin(v[4])*sin(v[12])))/2.;
 rhsVec[3] = forceRY*cos(v[4])*L[2] - (Cs*pow(L[2],3)*v[16])/12. - forceRX*L[2]*sin(v[4]) - (L[2]*sin(v[4])*(-(Cv*pow(cos(v[4]),2)*L[2]*v[13]) + Cv*cos(v[4])*L[1]*L[2]*v[15]*sin(v[3] - v[4]) + Cs*cos(v[4])*L[2]*v[14]*sin(v[4]) - Cv*cos(v[4])*L[2]*v[14]*sin(v[4]) + Cs*cos(v[3] - v[4])*L[1]*L[2]*v[15]*sin(v[4]) + (Cs*pow(L[2],2)*v[16]*sin(v[4]))/2. - Cs*L[2]*v[13]*pow(sin(v[4]),2)))/2. + (cos(v[4])*L[2]*(-(Cs*pow(cos(v[4]),2)*L[2]*v[14]) - Cs*cos(v[3] - v[4])*cos(v[4])*L[1]*L[2]*v[15] - (Cs*cos(v[4])*pow(L[2],2)*v[16])/2. + Cs*cos(v[4])*L[2]*v[13]*sin(v[4]) - Cv*cos(v[4])*L[2]*v[13]*sin(v[4]) + Cv*L[1]*L[2]*v[15]*sin(v[3] - v[4])*sin(v[4]) - Cv*L[2]*v[14]*pow(sin(v[4]),2)))/2. + (M[2]*(-(L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + (cos(v[4])*L[2]*v[16])/2.)*sin(v[4])) - cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - (L[2]*v[16]*sin(v[4]))/2.)))/2. - (M[2]*(-(L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + (cos(v[4])*L[2]*v[16])/2.)*sin(v[4])) - L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) - (cos(v[4])*L[2]*pow(v[16],2))/2.)*sin(v[4]) - cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - (L[2]*v[16]*sin(v[4]))/2.) + cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - (L[2]*pow(v[16],2)*sin(v[4]))/2.)))/2. - L[2]*sin(v[4])*(-(Cv*pow(cos(v[5]),2)*L[3]*v[13]) + Cv*cos(v[5])*L[1]*L[3]*v[15]*sin(v[3] - v[5]) + Cv*cos(v[5])*L[2]*L[3]*v[16]*sin(v[4] - v[5]) + Cs*cos(v[5])*L[3]*v[14]*sin(v[5]) - Cv*cos(v[5])*L[3]*v[14]*sin(v[5]) + Cs*cos(v[3] - v[5])*L[1]*L[3]*v[15]*sin(v[5]) + Cs*cos(v[4] - v[5])*L[2]*L[3]*v[16]*sin(v[5]) + (Cs*pow(L[3],2)*v[17]*sin(v[5]))/2. - Cs*L[3]*v[13]*pow(sin(v[5]),2)) + cos(v[4])*L[2]*(-(Cs*pow(cos(v[5]),2)*L[3]*v[14]) - Cs*cos(v[3] - v[5])*cos(v[5])*L[1]*L[3]*v[15] - Cs*cos(v[4] - v[5])*cos(v[5])*L[2]*L[3]*v[16] - (Cs*cos(v[5])*pow(L[3],2)*v[17])/2. + Cs*cos(v[5])*L[3]*v[13]*sin(v[5]) - Cv*cos(v[5])*L[3]*v[13]*sin(v[5]) + Cv*L[1]*L[3]*v[15]*sin(v[3] - v[5])*sin(v[5]) + Cv*L[2]*L[3]*v[16]*sin(v[4] - v[5])*sin(v[5]) - Cv*L[3]*v[14]*pow(sin(v[5]),2)) + (M[3]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + (cos(v[5])*L[3]*v[17])/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - (L[3]*v[17]*sin(v[5]))/2.)))/2. - (M[3]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + (cos(v[5])*L[3]*v[17])/2.)*sin(v[4]) - 2*L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - (cos(v[5])*L[3]*pow(v[17],2))/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - (L[3]*v[17]*sin(v[5]))/2.) + 2*cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - (L[3]*pow(v[17],2)*sin(v[5]))/2.)))/2. - L[2]*sin(v[4])*(-(Cv*pow(cos(v[6]),2)*L[4]*v[13]) + Cv*cos(v[6])*L[1]*L[4]*v[15]*sin(v[3] - v[6]) + Cv*cos(v[6])*L[2]*L[4]*v[16]*sin(v[4] - v[6]) + Cv*cos(v[6])*L[3]*L[4]*v[17]*sin(v[5] - v[6]) + Cs*cos(v[6])*L[4]*v[14]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[14]*sin(v[6]) + Cs*cos(v[3] - v[6])*L[1]*L[4]*v[15]*sin(v[6]) + Cs*cos(v[4] - v[6])*L[2]*L[4]*v[16]*sin(v[6]) + Cs*cos(v[5] - v[6])*L[3]*L[4]*v[17]*sin(v[6]) + (Cs*pow(L[4],2)*v[18]*sin(v[6]))/2. - Cs*L[4]*v[13]*pow(sin(v[6]),2)) + cos(v[4])*L[2]*(-(Cs*pow(cos(v[6]),2)*L[4]*v[14]) - Cs*cos(v[3] - v[6])*cos(v[6])*L[1]*L[4]*v[15] - Cs*cos(v[4] - v[6])*cos(v[6])*L[2]*L[4]*v[16] - Cs*cos(v[5] - v[6])*cos(v[6])*L[3]*L[4]*v[17] - (Cs*cos(v[6])*pow(L[4],2)*v[18])/2. + Cs*cos(v[6])*L[4]*v[13]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[13]*sin(v[6]) + Cv*L[1]*L[4]*v[15]*sin(v[3] - v[6])*sin(v[6]) + Cv*L[2]*L[4]*v[16]*sin(v[4] - v[6])*sin(v[6]) + Cv*L[3]*L[4]*v[17]*sin(v[5] - v[6])*sin(v[6]) - Cv*L[4]*v[14]*pow(sin(v[6]),2)) + (M[4]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + (cos(v[6])*L[4]*v[18])/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - (L[4]*v[18]*sin(v[6]))/2.)))/2. - (M[4]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + (cos(v[6])*L[4]*v[18])/2.)*sin(v[4]) - 2*L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - (cos(v[6])*L[4]*pow(v[18],2))/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - (L[4]*v[18]*sin(v[6]))/2.) + 2*cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - (L[4]*pow(v[18],2)*sin(v[6]))/2.)))/2. - (L[2]*L[5]*sin(v[4])*(-(Cs*sin(v[7])*(-2*cos(v[7])*v[14] - 2*cos(v[3] - v[7])*L[1]*v[15] - 2*cos(v[4] - v[7])*L[2]*v[16] - 2*cos(v[5] - v[7])*L[3]*v[17] - 2*cos(v[6] - v[7])*L[4]*v[18] - L[5]*v[19] + 2*v[13]*sin(v[7]))) + 2*Cv*cos(v[7])*(-(cos(v[7])*v[13]) + L[1]*v[15]*sin(v[3] - v[7]) + L[2]*v[16]*sin(v[4] - v[7]) + L[3]*v[17]*sin(v[5] - v[7]) + L[4]*v[18]*sin(v[6] - v[7]) - v[14]*sin(v[7]))))/2. - (cos(v[4])*L[2]*L[5]*(Cs*cos(v[7])*(2*cos(v[7])*v[14] + 2*cos(v[3] - v[7])*L[1]*v[15] + 2*cos(v[4] - v[7])*L[2]*v[16] + 2*cos(v[5] - v[7])*L[3]*v[17] + 2*cos(v[6] - v[7])*L[4]*v[18] + L[5]*v[19] - 2*v[13]*sin(v[7])) + 2*Cv*sin(v[7])*(cos(v[7])*v[13] - L[1]*v[15]*sin(v[3] - v[7]) - L[2]*v[16]*sin(v[4] - v[7]) - L[3]*v[17]*sin(v[5] - v[7]) - L[4]*v[18]*sin(v[6] - v[7]) + v[14]*sin(v[7]))))/2. + (M[5]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + (cos(v[7])*L[5]*v[19])/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.)))/2. - (M[5]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + (cos(v[7])*L[5]*v[19])/2.)*sin(v[4]) - 2*L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - (cos(v[7])*L[5]*pow(v[19],2))/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.) + 2*cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - (L[5]*pow(v[19],2)*sin(v[7]))/2.)))/2. - (L[2]*L[6]*sin(v[4])*(-(Cs*sin(v[8])*(-2*cos(v[8])*v[14] - 2*cos(v[3] - v[8])*L[1]*v[15] - 2*cos(v[4] - v[8])*L[2]*v[16] - 2*cos(v[5] - v[8])*L[3]*v[17] - 2*cos(v[6] - v[8])*L[4]*v[18] - 2*cos(v[7] - v[8])*L[5]*v[19] - L[6]*v[20] + 2*v[13]*sin(v[8]))) + 2*Cv*cos(v[8])*(-(cos(v[8])*v[13]) + L[1]*v[15]*sin(v[3] - v[8]) + L[2]*v[16]*sin(v[4] - v[8]) + L[3]*v[17]*sin(v[5] - v[8]) + L[4]*v[18]*sin(v[6] - v[8]) + L[5]*v[19]*sin(v[7] - v[8]) - v[14]*sin(v[8]))))/2. + cos(v[4])*L[2]*(-(Cs*cos(v[8])*L[6]*(2*cos(v[8])*v[14] + 2*cos(v[3] - v[8])*L[1]*v[15] + 2*cos(v[4] - v[8])*L[2]*v[16] + 2*cos(v[5] - v[8])*L[3]*v[17] + 2*cos(v[6] - v[8])*L[4]*v[18] + 2*cos(v[7] - v[8])*L[5]*v[19] + L[6]*v[20] - 2*v[13]*sin(v[8])))/2. - Cv*L[6]*sin(v[8])*(cos(v[8])*v[13] - L[1]*v[15]*sin(v[3] - v[8]) - L[2]*v[16]*sin(v[4] - v[8]) - L[3]*v[17]*sin(v[5] - v[8]) - L[4]*v[18]*sin(v[6] - v[8]) - L[5]*v[19]*sin(v[7] - v[8]) + v[14]*sin(v[8]))) + (M[6]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + (cos(v[8])*L[6]*v[20])/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.)))/2. - (M[6]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + (cos(v[8])*L[6]*v[20])/2.)*sin(v[4]) - 2*L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - (cos(v[8])*L[6]*pow(v[20],2))/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.) + 2*cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - (L[6]*pow(v[20],2)*sin(v[8]))/2.)))/2. - L[2]*sin(v[4])*(-(Cs*L[7]*sin(v[9])*(-2*cos(v[9])*v[14] - 2*cos(v[3] - v[9])*L[1]*v[15] - 2*cos(v[4] - v[9])*L[2]*v[16] - 2*cos(v[5] - v[9])*L[3]*v[17] - 2*cos(v[6] - v[9])*L[4]*v[18] - 2*cos(v[7] - v[9])*L[5]*v[19] - 2*cos(v[8] - v[9])*L[6]*v[20] - L[7]*v[21] + 2*v[13]*sin(v[9])))/2. - Cv*cos(v[9])*L[7]*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) + cos(v[4])*L[2]*(-(Cs*cos(v[9])*L[7]*(2*cos(v[9])*v[14] + 2*cos(v[3] - v[9])*L[1]*v[15] + 2*cos(v[4] - v[9])*L[2]*v[16] + 2*cos(v[5] - v[9])*L[3]*v[17] + 2*cos(v[6] - v[9])*L[4]*v[18] + 2*cos(v[7] - v[9])*L[5]*v[19] + 2*cos(v[8] - v[9])*L[6]*v[20] + L[7]*v[21] - 2*v[13]*sin(v[9])))/2. - Cv*L[7]*sin(v[9])*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) + (M[7]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.)))/2. - (M[7]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[4]) - 2*L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - (cos(v[9])*L[7]*pow(v[21],2))/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.) + 2*cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - (L[7]*pow(v[21],2)*sin(v[9]))/2.)))/2. - L[2]*sin(v[4])*(-(Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10]))) + cos(v[4])*L[2]*(-(Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] + 2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + 2*cos(v[5] - v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] - v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10]))) + (M[8]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + (cos(v[10])*L[8]*v[22])/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.)))/2. - (M[8]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + (cos(v[10])*L[8]*v[22])/2.)*sin(v[4]) - 2*L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.) + 2*cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - (L[8]*pow(v[22],2)*sin(v[10]))/2.)))/2. - L[2]*sin(v[4])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + 2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))) + cos(v[4])*L[2]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] + 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + 2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] - v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - 2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))) + (M[9]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[4]) - 2*L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - (cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + 2*cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - L[2]*sin(v[4])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + cos(v[4])*L[2]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + (M[10]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[2]*v[16]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[4]) - 2*L[2]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[4]) - 2*cos(v[4])*L[2]*v[16]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + 2*cos(v[4])*L[2]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - (L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;
 coefMat[4] = -(L[3]*M[3]*sin(v[5]))/2. - L[3]*M[4]*sin(v[5]) - L[3]*M[5]*sin(v[5]) - L[3]*M[6]*sin(v[5]) - L[3]*M[7]*sin(v[5]) - L[3]*M[8]*sin(v[5]) - L[3]*M[9]*sin(v[5]) - L[3]*M[10]*sin(v[5]);
 coefMat[16] = (cos(v[5])*L[3]*M[3])/2. + cos(v[5])*L[3]*M[4] + cos(v[5])*L[3]*M[5] + cos(v[5])*L[3]*M[6] + cos(v[5])*L[3]*M[7] + cos(v[5])*L[3]*M[8] + cos(v[5])*L[3]*M[9] + cos(v[5])*L[3]*M[10];
 coefMat[28] = (M[3]*(cos(v[3])*cos(v[5])*L[1]*L[3] + L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[4]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[5]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[6]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[7]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[8]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[9]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2. + (M[10]*(2*cos(v[3])*cos(v[5])*L[1]*L[3] + 2*L[1]*L[3]*sin(v[3])*sin(v[5])))/2.;
 coefMat[40] = (M[3]*(cos(v[4])*cos(v[5])*L[2]*L[3] + L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[4]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[5]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[6]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[7]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[8]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[9]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2. + (M[10]*(2*cos(v[4])*cos(v[5])*L[2]*L[3] + 2*L[2]*L[3]*sin(v[4])*sin(v[5])))/2.;
 coefMat[52] = (pow(L[3],2)*M[3])/12. + (M[3]*((pow(cos(v[5]),2)*pow(L[3],2))/2. + (pow(L[3],2)*pow(sin(v[5]),2))/2.))/2. + (M[4]*(2*pow(cos(v[5]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(v[5]),2)))/2. + (M[5]*(2*pow(cos(v[5]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(v[5]),2)))/2. + (M[6]*(2*pow(cos(v[5]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(v[5]),2)))/2. + (M[7]*(2*pow(cos(v[5]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(v[5]),2)))/2. + (M[8]*(2*pow(cos(v[5]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(v[5]),2)))/2. + (M[9]*(2*pow(cos(v[5]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(v[5]),2)))/2. + (M[10]*(2*pow(cos(v[5]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(v[5]),2)))/2.;
 coefMat[64] = (M[4]*(cos(v[5])*cos(v[6])*L[3]*L[4] + L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + (M[5]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + (M[6]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + (M[7]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + (M[8]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + (M[9]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + (M[10]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2.;
 coefMat[76] = (M[5]*(cos(v[5])*cos(v[7])*L[3]*L[5] + L[3]*L[5]*sin(v[5])*sin(v[7])))/2. + (M[6]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + 2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2. + (M[7]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + 2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2. + (M[8]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + 2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2. + (M[9]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + 2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2. + (M[10]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + 2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2.;
 coefMat[88] = (M[6]*(cos(v[5])*cos(v[8])*L[3]*L[6] + L[3]*L[6]*sin(v[5])*sin(v[8])))/2. + (M[7]*(2*cos(v[5])*cos(v[8])*L[3]*L[6] + 2*L[3]*L[6]*sin(v[5])*sin(v[8])))/2. + (M[8]*(2*cos(v[5])*cos(v[8])*L[3]*L[6] + 2*L[3]*L[6]*sin(v[5])*sin(v[8])))/2. + (M[9]*(2*cos(v[5])*cos(v[8])*L[3]*L[6] + 2*L[3]*L[6]*sin(v[5])*sin(v[8])))/2. + (M[10]*(2*cos(v[5])*cos(v[8])*L[3]*L[6] + 2*L[3]*L[6]*sin(v[5])*sin(v[8])))/2.;
 coefMat[100] = (M[7]*(cos(v[5])*cos(v[9])*L[3]*L[7] + L[3]*L[7]*sin(v[5])*sin(v[9])))/2. + (M[8]*(2*cos(v[5])*cos(v[9])*L[3]*L[7] + 2*L[3]*L[7]*sin(v[5])*sin(v[9])))/2. + (M[9]*(2*cos(v[5])*cos(v[9])*L[3]*L[7] + 2*L[3]*L[7]*sin(v[5])*sin(v[9])))/2. + (M[10]*(2*cos(v[5])*cos(v[9])*L[3]*L[7] + 2*L[3]*L[7]*sin(v[5])*sin(v[9])))/2.;
 coefMat[112] = (M[8]*(cos(v[5])*cos(v[10])*L[3]*L[8] + L[3]*L[8]*sin(v[5])*sin(v[10])))/2. + (M[9]*(2*cos(v[5])*cos(v[10])*L[3]*L[8] + 2*L[3]*L[8]*sin(v[5])*sin(v[10])))/2. + (M[10]*(2*cos(v[5])*cos(v[10])*L[3]*L[8] + 2*L[3]*L[8]*sin(v[5])*sin(v[10])))/2.;
 coefMat[124] = (M[9]*(cos(v[5])*cos(v[11])*L[3]*L[9] + L[3]*L[9]*sin(v[5])*sin(v[11])))/2. + (M[10]*(2*cos(v[5])*cos(v[11])*L[3]*L[9] + 2*L[3]*L[9]*sin(v[5])*sin(v[11])))/2.;
 coefMat[136] = (M[10]*(cos(v[5])*cos(v[12])*L[3]*L[10] + L[3]*L[10]*sin(v[5])*sin(v[12])))/2.;
 rhsVec[4] = forceRY*cos(v[5])*L[3] - (Cs*pow(L[3],3)*v[17])/12. - forceRX*L[3]*sin(v[5]) - (L[3]*sin(v[5])*(-(Cv*pow(cos(v[5]),2)*L[3]*v[13]) + Cv*cos(v[5])*L[1]*L[3]*v[15]*sin(v[3] - v[5]) + Cv*cos(v[5])*L[2]*L[3]*v[16]*sin(v[4] - v[5]) + Cs*cos(v[5])*L[3]*v[14]*sin(v[5]) - Cv*cos(v[5])*L[3]*v[14]*sin(v[5]) + Cs*cos(v[3] - v[5])*L[1]*L[3]*v[15]*sin(v[5]) + Cs*cos(v[4] - v[5])*L[2]*L[3]*v[16]*sin(v[5]) + (Cs*pow(L[3],2)*v[17]*sin(v[5]))/2. - Cs*L[3]*v[13]*pow(sin(v[5]),2)))/2. + (cos(v[5])*L[3]*(-(Cs*pow(cos(v[5]),2)*L[3]*v[14]) - Cs*cos(v[3] - v[5])*cos(v[5])*L[1]*L[3]*v[15] - Cs*cos(v[4] - v[5])*cos(v[5])*L[2]*L[3]*v[16] - (Cs*cos(v[5])*pow(L[3],2)*v[17])/2. + Cs*cos(v[5])*L[3]*v[13]*sin(v[5]) - Cv*cos(v[5])*L[3]*v[13]*sin(v[5]) + Cv*L[1]*L[3]*v[15]*sin(v[3] - v[5])*sin(v[5]) + Cv*L[2]*L[3]*v[16]*sin(v[4] - v[5])*sin(v[5]) - Cv*L[3]*v[14]*pow(sin(v[5]),2)))/2. + (M[3]*(-(L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + (cos(v[5])*L[3]*v[17])/2.)*sin(v[5])) - cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - (L[3]*v[17]*sin(v[5]))/2.)))/2. - (M[3]*(-(L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + (cos(v[5])*L[3]*v[17])/2.)*sin(v[5])) - L[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - (cos(v[5])*L[3]*pow(v[17],2))/2.)*sin(v[5]) - cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - (L[3]*v[17]*sin(v[5]))/2.) + cos(v[5])*L[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - (L[3]*pow(v[17],2)*sin(v[5]))/2.)))/2. - L[3]*sin(v[5])*(-(Cv*pow(cos(v[6]),2)*L[4]*v[13]) + Cv*cos(v[6])*L[1]*L[4]*v[15]*sin(v[3] - v[6]) + Cv*cos(v[6])*L[2]*L[4]*v[16]*sin(v[4] - v[6]) + Cv*cos(v[6])*L[3]*L[4]*v[17]*sin(v[5] - v[6]) + Cs*cos(v[6])*L[4]*v[14]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[14]*sin(v[6]) + Cs*cos(v[3] - v[6])*L[1]*L[4]*v[15]*sin(v[6]) + Cs*cos(v[4] - v[6])*L[2]*L[4]*v[16]*sin(v[6]) + Cs*cos(v[5] - v[6])*L[3]*L[4]*v[17]*sin(v[6]) + (Cs*pow(L[4],2)*v[18]*sin(v[6]))/2. - Cs*L[4]*v[13]*pow(sin(v[6]),2)) + cos(v[5])*L[3]*(-(Cs*pow(cos(v[6]),2)*L[4]*v[14]) - Cs*cos(v[3] - v[6])*cos(v[6])*L[1]*L[4]*v[15] - Cs*cos(v[4] - v[6])*cos(v[6])*L[2]*L[4]*v[16] - Cs*cos(v[5] - v[6])*cos(v[6])*L[3]*L[4]*v[17] - (Cs*cos(v[6])*pow(L[4],2)*v[18])/2. + Cs*cos(v[6])*L[4]*v[13]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[13]*sin(v[6]) + Cv*L[1]*L[4]*v[15]*sin(v[3] - v[6])*sin(v[6]) + Cv*L[2]*L[4]*v[16]*sin(v[4] - v[6])*sin(v[6]) + Cv*L[3]*L[4]*v[17]*sin(v[5] - v[6])*sin(v[6]) - Cv*L[4]*v[14]*pow(sin(v[6]),2)) + (M[4]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + (cos(v[6])*L[4]*v[18])/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - (L[4]*v[18]*sin(v[6]))/2.)))/2. - (M[4]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + (cos(v[6])*L[4]*v[18])/2.)*sin(v[5]) - 2*L[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - (cos(v[6])*L[4]*pow(v[18],2))/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - (L[4]*v[18]*sin(v[6]))/2.) + 2*cos(v[5])*L[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - (L[4]*pow(v[18],2)*sin(v[6]))/2.)))/2. - (L[3]*L[5]*sin(v[5])*(-(Cs*sin(v[7])*(-2*cos(v[7])*v[14] - 2*cos(v[3] - v[7])*L[1]*v[15] - 2*cos(v[4] - v[7])*L[2]*v[16] - 2*cos(v[5] - v[7])*L[3]*v[17] - 2*cos(v[6] - v[7])*L[4]*v[18] - L[5]*v[19] + 2*v[13]*sin(v[7]))) + 2*Cv*cos(v[7])*(-(cos(v[7])*v[13]) + L[1]*v[15]*sin(v[3] - v[7]) + L[2]*v[16]*sin(v[4] - v[7]) + L[3]*v[17]*sin(v[5] - v[7]) + L[4]*v[18]*sin(v[6] - v[7]) - v[14]*sin(v[7]))))/2. - (cos(v[5])*L[3]*L[5]*(Cs*cos(v[7])*(2*cos(v[7])*v[14] + 2*cos(v[3] - v[7])*L[1]*v[15] + 2*cos(v[4] - v[7])*L[2]*v[16] + 2*cos(v[5] - v[7])*L[3]*v[17] + 2*cos(v[6] - v[7])*L[4]*v[18] + L[5]*v[19] - 2*v[13]*sin(v[7])) + 2*Cv*sin(v[7])*(cos(v[7])*v[13] - L[1]*v[15]*sin(v[3] - v[7]) - L[2]*v[16]*sin(v[4] - v[7]) - L[3]*v[17]*sin(v[5] - v[7]) - L[4]*v[18]*sin(v[6] - v[7]) + v[14]*sin(v[7]))))/2. + (M[5]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + (cos(v[7])*L[5]*v[19])/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.)))/2. - (M[5]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + (cos(v[7])*L[5]*v[19])/2.)*sin(v[5]) - 2*L[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - (cos(v[7])*L[5]*pow(v[19],2))/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.) + 2*cos(v[5])*L[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - (L[5]*pow(v[19],2)*sin(v[7]))/2.)))/2. - (L[3]*L[6]*sin(v[5])*(-(Cs*sin(v[8])*(-2*cos(v[8])*v[14] - 2*cos(v[3] - v[8])*L[1]*v[15] - 2*cos(v[4] - v[8])*L[2]*v[16] - 2*cos(v[5] - v[8])*L[3]*v[17] - 2*cos(v[6] - v[8])*L[4]*v[18] - 2*cos(v[7] - v[8])*L[5]*v[19] - L[6]*v[20] + 2*v[13]*sin(v[8]))) + 2*Cv*cos(v[8])*(-(cos(v[8])*v[13]) + L[1]*v[15]*sin(v[3] - v[8]) + L[2]*v[16]*sin(v[4] - v[8]) + L[3]*v[17]*sin(v[5] - v[8]) + L[4]*v[18]*sin(v[6] - v[8]) + L[5]*v[19]*sin(v[7] - v[8]) - v[14]*sin(v[8]))))/2. + cos(v[5])*L[3]*(-(Cs*cos(v[8])*L[6]*(2*cos(v[8])*v[14] + 2*cos(v[3] - v[8])*L[1]*v[15] + 2*cos(v[4] - v[8])*L[2]*v[16] + 2*cos(v[5] - v[8])*L[3]*v[17] + 2*cos(v[6] - v[8])*L[4]*v[18] + 2*cos(v[7] - v[8])*L[5]*v[19] + L[6]*v[20] - 2*v[13]*sin(v[8])))/2. - Cv*L[6]*sin(v[8])*(cos(v[8])*v[13] - L[1]*v[15]*sin(v[3] - v[8]) - L[2]*v[16]*sin(v[4] - v[8]) - L[3]*v[17]*sin(v[5] - v[8]) - L[4]*v[18]*sin(v[6] - v[8]) - L[5]*v[19]*sin(v[7] - v[8]) + v[14]*sin(v[8]))) + (M[6]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + (cos(v[8])*L[6]*v[20])/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.)))/2. - (M[6]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + (cos(v[8])*L[6]*v[20])/2.)*sin(v[5]) - 2*L[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - (cos(v[8])*L[6]*pow(v[20],2))/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.) + 2*cos(v[5])*L[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - (L[6]*pow(v[20],2)*sin(v[8]))/2.)))/2. - L[3]*sin(v[5])*(-(Cs*L[7]*sin(v[9])*(-2*cos(v[9])*v[14] - 2*cos(v[3] - v[9])*L[1]*v[15] - 2*cos(v[4] - v[9])*L[2]*v[16] - 2*cos(v[5] - v[9])*L[3]*v[17] - 2*cos(v[6] - v[9])*L[4]*v[18] - 2*cos(v[7] - v[9])*L[5]*v[19] - 2*cos(v[8] - v[9])*L[6]*v[20] - L[7]*v[21] + 2*v[13]*sin(v[9])))/2. - Cv*cos(v[9])*L[7]*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) + cos(v[5])*L[3]*(-(Cs*cos(v[9])*L[7]*(2*cos(v[9])*v[14] + 2*cos(v[3] - v[9])*L[1]*v[15] + 2*cos(v[4] - v[9])*L[2]*v[16] + 2*cos(v[5] - v[9])*L[3]*v[17] + 2*cos(v[6] - v[9])*L[4]*v[18] + 2*cos(v[7] - v[9])*L[5]*v[19] + 2*cos(v[8] - v[9])*L[6]*v[20] + L[7]*v[21] - 2*v[13]*sin(v[9])))/2. - Cv*L[7]*sin(v[9])*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) + (M[7]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.)))/2. - (M[7]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[5]) - 2*L[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - (cos(v[9])*L[7]*pow(v[21],2))/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.) + 2*cos(v[5])*L[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - (L[7]*pow(v[21],2)*sin(v[9]))/2.)))/2. - L[3]*sin(v[5])*(-(Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10]))) + cos(v[5])*L[3]*(-(Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] + 2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + 2*cos(v[5] - v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] - v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10]))) + (M[8]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + (cos(v[10])*L[8]*v[22])/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.)))/2. - (M[8]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + (cos(v[10])*L[8]*v[22])/2.)*sin(v[5]) - 2*L[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.) + 2*cos(v[5])*L[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - (L[8]*pow(v[22],2)*sin(v[10]))/2.)))/2. - L[3]*sin(v[5])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + 2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))) + cos(v[5])*L[3]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] + 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + 2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] - v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - 2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))) + (M[9]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[5]) - 2*L[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - (cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + 2*cos(v[5])*L[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - L[3]*sin(v[5])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + cos(v[5])*L[3]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + (M[10]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[3]*v[17]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[5]) - 2*L[3]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[5]) - 2*cos(v[5])*L[3]*v[17]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + 2*cos(v[5])*L[3]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - (L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;
 coefMat[5] = -(L[4]*M[4]*sin(v[6]))/2. - L[4]*M[5]*sin(v[6]) - L[4]*M[6]*sin(v[6]) - L[4]*M[7]*sin(v[6]) - L[4]*M[8]*sin(v[6]) - L[4]*M[9]*sin(v[6]) - L[4]*M[10]*sin(v[6]);
 coefMat[17] = (cos(v[6])*L[4]*M[4])/2. + cos(v[6])*L[4]*M[5] + cos(v[6])*L[4]*M[6] + cos(v[6])*L[4]*M[7] + cos(v[6])*L[4]*M[8] + cos(v[6])*L[4]*M[9] + cos(v[6])*L[4]*M[10];
 coefMat[29] = (M[4]*(cos(v[3])*cos(v[6])*L[1]*L[4] + L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + (M[5]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + (M[6]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + (M[7]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + (M[8]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + (M[9]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2. + (M[10]*(2*cos(v[3])*cos(v[6])*L[1]*L[4] + 2*L[1]*L[4]*sin(v[3])*sin(v[6])))/2.;
 coefMat[41] = (M[4]*(cos(v[4])*cos(v[6])*L[2]*L[4] + L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + (M[5]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + (M[6]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + (M[7]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + (M[8]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + (M[9]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2. + (M[10]*(2*cos(v[4])*cos(v[6])*L[2]*L[4] + 2*L[2]*L[4]*sin(v[4])*sin(v[6])))/2.;
 coefMat[53] = (M[4]*(cos(v[5])*cos(v[6])*L[3]*L[4] + L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + (M[5]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + (M[6]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + (M[7]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + (M[8]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + (M[9]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2. + (M[10]*(2*cos(v[5])*cos(v[6])*L[3]*L[4] + 2*L[3]*L[4]*sin(v[5])*sin(v[6])))/2.;
 coefMat[65] = (pow(L[4],2)*M[4])/12. + (M[4]*((pow(cos(v[6]),2)*pow(L[4],2))/2. + (pow(L[4],2)*pow(sin(v[6]),2))/2.))/2. + (M[5]*(2*pow(cos(v[6]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(v[6]),2)))/2. + (M[6]*(2*pow(cos(v[6]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(v[6]),2)))/2. + (M[7]*(2*pow(cos(v[6]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(v[6]),2)))/2. + (M[8]*(2*pow(cos(v[6]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(v[6]),2)))/2. + (M[9]*(2*pow(cos(v[6]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(v[6]),2)))/2. + (M[10]*(2*pow(cos(v[6]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(v[6]),2)))/2.;
 coefMat[77] = (M[5]*(cos(v[6])*cos(v[7])*L[4]*L[5] + L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + (M[6]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + 2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + (M[7]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + 2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + (M[8]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + 2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + (M[9]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + 2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + (M[10]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + 2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2.;
 coefMat[89] = (M[6]*(cos(v[6])*cos(v[8])*L[4]*L[6] + L[4]*L[6]*sin(v[6])*sin(v[8])))/2. + (M[7]*(2*cos(v[6])*cos(v[8])*L[4]*L[6] + 2*L[4]*L[6]*sin(v[6])*sin(v[8])))/2. + (M[8]*(2*cos(v[6])*cos(v[8])*L[4]*L[6] + 2*L[4]*L[6]*sin(v[6])*sin(v[8])))/2. + (M[9]*(2*cos(v[6])*cos(v[8])*L[4]*L[6] + 2*L[4]*L[6]*sin(v[6])*sin(v[8])))/2. + (M[10]*(2*cos(v[6])*cos(v[8])*L[4]*L[6] + 2*L[4]*L[6]*sin(v[6])*sin(v[8])))/2.;
 coefMat[101] = (M[7]*(cos(v[6])*cos(v[9])*L[4]*L[7] + L[4]*L[7]*sin(v[6])*sin(v[9])))/2. + (M[8]*(2*cos(v[6])*cos(v[9])*L[4]*L[7] + 2*L[4]*L[7]*sin(v[6])*sin(v[9])))/2. + (M[9]*(2*cos(v[6])*cos(v[9])*L[4]*L[7] + 2*L[4]*L[7]*sin(v[6])*sin(v[9])))/2. + (M[10]*(2*cos(v[6])*cos(v[9])*L[4]*L[7] + 2*L[4]*L[7]*sin(v[6])*sin(v[9])))/2.;
 coefMat[113] = (M[8]*(cos(v[6])*cos(v[10])*L[4]*L[8] + L[4]*L[8]*sin(v[6])*sin(v[10])))/2. + (M[9]*(2*cos(v[6])*cos(v[10])*L[4]*L[8] + 2*L[4]*L[8]*sin(v[6])*sin(v[10])))/2. + (M[10]*(2*cos(v[6])*cos(v[10])*L[4]*L[8] + 2*L[4]*L[8]*sin(v[6])*sin(v[10])))/2.;
 coefMat[125] = (M[9]*(cos(v[6])*cos(v[11])*L[4]*L[9] + L[4]*L[9]*sin(v[6])*sin(v[11])))/2. + (M[10]*(2*cos(v[6])*cos(v[11])*L[4]*L[9] + 2*L[4]*L[9]*sin(v[6])*sin(v[11])))/2.;
 coefMat[137] = (M[10]*(cos(v[6])*cos(v[12])*L[4]*L[10] + L[4]*L[10]*sin(v[6])*sin(v[12])))/2.;
 rhsVec[5] = forceRY*cos(v[6])*L[4] - (Cs*pow(L[4],3)*v[18])/12. - forceRX*L[4]*sin(v[6]) - (L[4]*sin(v[6])*(-(Cv*pow(cos(v[6]),2)*L[4]*v[13]) + Cv*cos(v[6])*L[1]*L[4]*v[15]*sin(v[3] - v[6]) + Cv*cos(v[6])*L[2]*L[4]*v[16]*sin(v[4] - v[6]) + Cv*cos(v[6])*L[3]*L[4]*v[17]*sin(v[5] - v[6]) + Cs*cos(v[6])*L[4]*v[14]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[14]*sin(v[6]) + Cs*cos(v[3] - v[6])*L[1]*L[4]*v[15]*sin(v[6]) + Cs*cos(v[4] - v[6])*L[2]*L[4]*v[16]*sin(v[6]) + Cs*cos(v[5] - v[6])*L[3]*L[4]*v[17]*sin(v[6]) + (Cs*pow(L[4],2)*v[18]*sin(v[6]))/2. - Cs*L[4]*v[13]*pow(sin(v[6]),2)))/2. + (cos(v[6])*L[4]*(-(Cs*pow(cos(v[6]),2)*L[4]*v[14]) - Cs*cos(v[3] - v[6])*cos(v[6])*L[1]*L[4]*v[15] - Cs*cos(v[4] - v[6])*cos(v[6])*L[2]*L[4]*v[16] - Cs*cos(v[5] - v[6])*cos(v[6])*L[3]*L[4]*v[17] - (Cs*cos(v[6])*pow(L[4],2)*v[18])/2. + Cs*cos(v[6])*L[4]*v[13]*sin(v[6]) - Cv*cos(v[6])*L[4]*v[13]*sin(v[6]) + Cv*L[1]*L[4]*v[15]*sin(v[3] - v[6])*sin(v[6]) + Cv*L[2]*L[4]*v[16]*sin(v[4] - v[6])*sin(v[6]) + Cv*L[3]*L[4]*v[17]*sin(v[5] - v[6])*sin(v[6]) - Cv*L[4]*v[14]*pow(sin(v[6]),2)))/2. + (M[4]*(-(L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + (cos(v[6])*L[4]*v[18])/2.)*sin(v[6])) - cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - (L[4]*v[18]*sin(v[6]))/2.)))/2. - (M[4]*(-(L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + (cos(v[6])*L[4]*v[18])/2.)*sin(v[6])) - L[4]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - (cos(v[6])*L[4]*pow(v[18],2))/2.)*sin(v[6]) - cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - (L[4]*v[18]*sin(v[6]))/2.) + cos(v[6])*L[4]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - (L[4]*pow(v[18],2)*sin(v[6]))/2.)))/2. - (L[4]*L[5]*sin(v[6])*(-(Cs*sin(v[7])*(-2*cos(v[7])*v[14] - 2*cos(v[3] - v[7])*L[1]*v[15] - 2*cos(v[4] - v[7])*L[2]*v[16] - 2*cos(v[5] - v[7])*L[3]*v[17] - 2*cos(v[6] - v[7])*L[4]*v[18] - L[5]*v[19] + 2*v[13]*sin(v[7]))) + 2*Cv*cos(v[7])*(-(cos(v[7])*v[13]) + L[1]*v[15]*sin(v[3] - v[7]) + L[2]*v[16]*sin(v[4] - v[7]) + L[3]*v[17]*sin(v[5] - v[7]) + L[4]*v[18]*sin(v[6] - v[7]) - v[14]*sin(v[7]))))/2. - (cos(v[6])*L[4]*L[5]*(Cs*cos(v[7])*(2*cos(v[7])*v[14] + 2*cos(v[3] - v[7])*L[1]*v[15] + 2*cos(v[4] - v[7])*L[2]*v[16] + 2*cos(v[5] - v[7])*L[3]*v[17] + 2*cos(v[6] - v[7])*L[4]*v[18] + L[5]*v[19] - 2*v[13]*sin(v[7])) + 2*Cv*sin(v[7])*(cos(v[7])*v[13] - L[1]*v[15]*sin(v[3] - v[7]) - L[2]*v[16]*sin(v[4] - v[7]) - L[3]*v[17]*sin(v[5] - v[7]) - L[4]*v[18]*sin(v[6] - v[7]) + v[14]*sin(v[7]))))/2. + (M[5]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + (cos(v[7])*L[5]*v[19])/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.)))/2. - (M[5]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + (cos(v[7])*L[5]*v[19])/2.)*sin(v[6]) - 2*L[4]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - (cos(v[7])*L[5]*pow(v[19],2))/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.) + 2*cos(v[6])*L[4]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - (L[5]*pow(v[19],2)*sin(v[7]))/2.)))/2. - (L[4]*L[6]*sin(v[6])*(-(Cs*sin(v[8])*(-2*cos(v[8])*v[14] - 2*cos(v[3] - v[8])*L[1]*v[15] - 2*cos(v[4] - v[8])*L[2]*v[16] - 2*cos(v[5] - v[8])*L[3]*v[17] - 2*cos(v[6] - v[8])*L[4]*v[18] - 2*cos(v[7] - v[8])*L[5]*v[19] - L[6]*v[20] + 2*v[13]*sin(v[8]))) + 2*Cv*cos(v[8])*(-(cos(v[8])*v[13]) + L[1]*v[15]*sin(v[3] - v[8]) + L[2]*v[16]*sin(v[4] - v[8]) + L[3]*v[17]*sin(v[5] - v[8]) + L[4]*v[18]*sin(v[6] - v[8]) + L[5]*v[19]*sin(v[7] - v[8]) - v[14]*sin(v[8]))))/2. + cos(v[6])*L[4]*(-(Cs*cos(v[8])*L[6]*(2*cos(v[8])*v[14] + 2*cos(v[3] - v[8])*L[1]*v[15] + 2*cos(v[4] - v[8])*L[2]*v[16] + 2*cos(v[5] - v[8])*L[3]*v[17] + 2*cos(v[6] - v[8])*L[4]*v[18] + 2*cos(v[7] - v[8])*L[5]*v[19] + L[6]*v[20] - 2*v[13]*sin(v[8])))/2. - Cv*L[6]*sin(v[8])*(cos(v[8])*v[13] - L[1]*v[15]*sin(v[3] - v[8]) - L[2]*v[16]*sin(v[4] - v[8]) - L[3]*v[17]*sin(v[5] - v[8]) - L[4]*v[18]*sin(v[6] - v[8]) - L[5]*v[19]*sin(v[7] - v[8]) + v[14]*sin(v[8]))) + (M[6]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + (cos(v[8])*L[6]*v[20])/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.)))/2. - (M[6]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + (cos(v[8])*L[6]*v[20])/2.)*sin(v[6]) - 2*L[4]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - (cos(v[8])*L[6]*pow(v[20],2))/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.) + 2*cos(v[6])*L[4]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - (L[6]*pow(v[20],2)*sin(v[8]))/2.)))/2. - L[4]*sin(v[6])*(-(Cs*L[7]*sin(v[9])*(-2*cos(v[9])*v[14] - 2*cos(v[3] - v[9])*L[1]*v[15] - 2*cos(v[4] - v[9])*L[2]*v[16] - 2*cos(v[5] - v[9])*L[3]*v[17] - 2*cos(v[6] - v[9])*L[4]*v[18] - 2*cos(v[7] - v[9])*L[5]*v[19] - 2*cos(v[8] - v[9])*L[6]*v[20] - L[7]*v[21] + 2*v[13]*sin(v[9])))/2. - Cv*cos(v[9])*L[7]*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) + cos(v[6])*L[4]*(-(Cs*cos(v[9])*L[7]*(2*cos(v[9])*v[14] + 2*cos(v[3] - v[9])*L[1]*v[15] + 2*cos(v[4] - v[9])*L[2]*v[16] + 2*cos(v[5] - v[9])*L[3]*v[17] + 2*cos(v[6] - v[9])*L[4]*v[18] + 2*cos(v[7] - v[9])*L[5]*v[19] + 2*cos(v[8] - v[9])*L[6]*v[20] + L[7]*v[21] - 2*v[13]*sin(v[9])))/2. - Cv*L[7]*sin(v[9])*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) + (M[7]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.)))/2. - (M[7]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[6]) - 2*L[4]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - (cos(v[9])*L[7]*pow(v[21],2))/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.) + 2*cos(v[6])*L[4]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - (L[7]*pow(v[21],2)*sin(v[9]))/2.)))/2. - L[4]*sin(v[6])*(-(Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10]))) + cos(v[6])*L[4]*(-(Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] + 2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + 2*cos(v[5] - v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] - v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10]))) + (M[8]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + (cos(v[10])*L[8]*v[22])/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.)))/2. - (M[8]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + (cos(v[10])*L[8]*v[22])/2.)*sin(v[6]) - 2*L[4]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.) + 2*cos(v[6])*L[4]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - (L[8]*pow(v[22],2)*sin(v[10]))/2.)))/2. - L[4]*sin(v[6])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + 2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))) + cos(v[6])*L[4]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] + 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + 2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] - v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - 2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))) + (M[9]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[6]) - 2*L[4]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - (cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + 2*cos(v[6])*L[4]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - L[4]*sin(v[6])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + cos(v[6])*L[4]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + (M[10]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[4]*v[18]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[6]) - 2*L[4]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[6]) - 2*cos(v[6])*L[4]*v[18]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + 2*cos(v[6])*L[4]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - (L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;
 coefMat[6] = -(L[5]*M[5]*sin(v[7]))/2. - L[5]*M[6]*sin(v[7]) - L[5]*M[7]*sin(v[7]) - L[5]*M[8]*sin(v[7]) - L[5]*M[9]*sin(v[7]) - L[5]*M[10]*sin(v[7]);
 coefMat[18] = (cos(v[7])*L[5]*M[5])/2. + cos(v[7])*L[5]*M[6] + cos(v[7])*L[5]*M[7] + cos(v[7])*L[5]*M[8] + cos(v[7])*L[5]*M[9] + cos(v[7])*L[5]*M[10];
 coefMat[30] = (M[5]*(cos(v[3])*cos(v[7])*L[1]*L[5] + L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + (M[6]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + 2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + (M[7]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + 2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + (M[8]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + 2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + (M[9]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + 2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2. + (M[10]*(2*cos(v[3])*cos(v[7])*L[1]*L[5] + 2*L[1]*L[5]*sin(v[3])*sin(v[7])))/2.;
 coefMat[42] = (M[5]*(cos(v[4])*cos(v[7])*L[2]*L[5] + L[2]*L[5]*sin(v[4])*sin(v[7])))/2. + (M[6]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + 2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2. + (M[7]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + 2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2. + (M[8]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + 2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2. + (M[9]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + 2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2. + (M[10]*(2*cos(v[4])*cos(v[7])*L[2]*L[5] + 2*L[2]*L[5]*sin(v[4])*sin(v[7])))/2.;
 coefMat[54] = (M[5]*(cos(v[5])*cos(v[7])*L[3]*L[5] + L[3]*L[5]*sin(v[5])*sin(v[7])))/2. + (M[6]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + 2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2. + (M[7]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + 2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2. + (M[8]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + 2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2. + (M[9]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + 2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2. + (M[10]*(2*cos(v[5])*cos(v[7])*L[3]*L[5] + 2*L[3]*L[5]*sin(v[5])*sin(v[7])))/2.;
 coefMat[66] = (M[5]*(cos(v[6])*cos(v[7])*L[4]*L[5] + L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + (M[6]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + 2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + (M[7]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + 2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + (M[8]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + 2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + (M[9]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + 2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2. + (M[10]*(2*cos(v[6])*cos(v[7])*L[4]*L[5] + 2*L[4]*L[5]*sin(v[6])*sin(v[7])))/2.;
 coefMat[78] = (pow(L[5],2)*M[5])/12. + (M[5]*((pow(cos(v[7]),2)*pow(L[5],2))/2. + (pow(L[5],2)*pow(sin(v[7]),2))/2.))/2. + (M[6]*(2*pow(cos(v[7]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(v[7]),2)))/2. + (M[7]*(2*pow(cos(v[7]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(v[7]),2)))/2. + (M[8]*(2*pow(cos(v[7]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(v[7]),2)))/2. + (M[9]*(2*pow(cos(v[7]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(v[7]),2)))/2. + (M[10]*(2*pow(cos(v[7]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(v[7]),2)))/2.;
 coefMat[90] = (M[6]*(cos(v[7])*cos(v[8])*L[5]*L[6] + L[5]*L[6]*sin(v[7])*sin(v[8])))/2. + (M[7]*(2*cos(v[7])*cos(v[8])*L[5]*L[6] + 2*L[5]*L[6]*sin(v[7])*sin(v[8])))/2. + (M[8]*(2*cos(v[7])*cos(v[8])*L[5]*L[6] + 2*L[5]*L[6]*sin(v[7])*sin(v[8])))/2. + (M[9]*(2*cos(v[7])*cos(v[8])*L[5]*L[6] + 2*L[5]*L[6]*sin(v[7])*sin(v[8])))/2. + (M[10]*(2*cos(v[7])*cos(v[8])*L[5]*L[6] + 2*L[5]*L[6]*sin(v[7])*sin(v[8])))/2.;
 coefMat[102] = (M[7]*(cos(v[7])*cos(v[9])*L[5]*L[7] + L[5]*L[7]*sin(v[7])*sin(v[9])))/2. + (M[8]*(2*cos(v[7])*cos(v[9])*L[5]*L[7] + 2*L[5]*L[7]*sin(v[7])*sin(v[9])))/2. + (M[9]*(2*cos(v[7])*cos(v[9])*L[5]*L[7] + 2*L[5]*L[7]*sin(v[7])*sin(v[9])))/2. + (M[10]*(2*cos(v[7])*cos(v[9])*L[5]*L[7] + 2*L[5]*L[7]*sin(v[7])*sin(v[9])))/2.;
 coefMat[114] = (M[8]*(cos(v[7])*cos(v[10])*L[5]*L[8] + L[5]*L[8]*sin(v[7])*sin(v[10])))/2. + (M[9]*(2*cos(v[7])*cos(v[10])*L[5]*L[8] + 2*L[5]*L[8]*sin(v[7])*sin(v[10])))/2. + (M[10]*(2*cos(v[7])*cos(v[10])*L[5]*L[8] + 2*L[5]*L[8]*sin(v[7])*sin(v[10])))/2.;
 coefMat[126] = (M[9]*(cos(v[7])*cos(v[11])*L[5]*L[9] + L[5]*L[9]*sin(v[7])*sin(v[11])))/2. + (M[10]*(2*cos(v[7])*cos(v[11])*L[5]*L[9] + 2*L[5]*L[9]*sin(v[7])*sin(v[11])))/2.;
 coefMat[138] = (M[10]*(cos(v[7])*cos(v[12])*L[5]*L[10] + L[5]*L[10]*sin(v[7])*sin(v[12])))/2.;
 rhsVec[6] = forceRY*cos(v[7])*L[5] - (Cs*pow(L[5],3)*v[19])/12. - forceRX*L[5]*sin(v[7]) - (pow(L[5],2)*sin(v[7])*(-(Cs*sin(v[7])*(-2*cos(v[7])*v[14] - 2*cos(v[3] - v[7])*L[1]*v[15] - 2*cos(v[4] - v[7])*L[2]*v[16] - 2*cos(v[5] - v[7])*L[3]*v[17] - 2*cos(v[6] - v[7])*L[4]*v[18] - L[5]*v[19] + 2*v[13]*sin(v[7]))) + 2*Cv*cos(v[7])*(-(cos(v[7])*v[13]) + L[1]*v[15]*sin(v[3] - v[7]) + L[2]*v[16]*sin(v[4] - v[7]) + L[3]*v[17]*sin(v[5] - v[7]) + L[4]*v[18]*sin(v[6] - v[7]) - v[14]*sin(v[7]))))/4. - (cos(v[7])*pow(L[5],2)*(Cs*cos(v[7])*(2*cos(v[7])*v[14] + 2*cos(v[3] - v[7])*L[1]*v[15] + 2*cos(v[4] - v[7])*L[2]*v[16] + 2*cos(v[5] - v[7])*L[3]*v[17] + 2*cos(v[6] - v[7])*L[4]*v[18] + L[5]*v[19] - 2*v[13]*sin(v[7])) + 2*Cv*sin(v[7])*(cos(v[7])*v[13] - L[1]*v[15]*sin(v[3] - v[7]) - L[2]*v[16]*sin(v[4] - v[7]) - L[3]*v[17]*sin(v[5] - v[7]) - L[4]*v[18]*sin(v[6] - v[7]) + v[14]*sin(v[7]))))/4. + (M[5]*(-(L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + (cos(v[7])*L[5]*v[19])/2.)*sin(v[7])) - cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.)))/2. - (M[5]*(-(L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + (cos(v[7])*L[5]*v[19])/2.)*sin(v[7])) - L[5]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - (cos(v[7])*L[5]*pow(v[19],2))/2.)*sin(v[7]) - cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - (L[5]*v[19]*sin(v[7]))/2.) + cos(v[7])*L[5]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - (L[5]*pow(v[19],2)*sin(v[7]))/2.)))/2. - (L[5]*L[6]*sin(v[7])*(-(Cs*sin(v[8])*(-2*cos(v[8])*v[14] - 2*cos(v[3] - v[8])*L[1]*v[15] - 2*cos(v[4] - v[8])*L[2]*v[16] - 2*cos(v[5] - v[8])*L[3]*v[17] - 2*cos(v[6] - v[8])*L[4]*v[18] - 2*cos(v[7] - v[8])*L[5]*v[19] - L[6]*v[20] + 2*v[13]*sin(v[8]))) + 2*Cv*cos(v[8])*(-(cos(v[8])*v[13]) + L[1]*v[15]*sin(v[3] - v[8]) + L[2]*v[16]*sin(v[4] - v[8]) + L[3]*v[17]*sin(v[5] - v[8]) + L[4]*v[18]*sin(v[6] - v[8]) + L[5]*v[19]*sin(v[7] - v[8]) - v[14]*sin(v[8]))))/2. + cos(v[7])*L[5]*(-(Cs*cos(v[8])*L[6]*(2*cos(v[8])*v[14] + 2*cos(v[3] - v[8])*L[1]*v[15] + 2*cos(v[4] - v[8])*L[2]*v[16] + 2*cos(v[5] - v[8])*L[3]*v[17] + 2*cos(v[6] - v[8])*L[4]*v[18] + 2*cos(v[7] - v[8])*L[5]*v[19] + L[6]*v[20] - 2*v[13]*sin(v[8])))/2. - Cv*L[6]*sin(v[8])*(cos(v[8])*v[13] - L[1]*v[15]*sin(v[3] - v[8]) - L[2]*v[16]*sin(v[4] - v[8]) - L[3]*v[17]*sin(v[5] - v[8]) - L[4]*v[18]*sin(v[6] - v[8]) - L[5]*v[19]*sin(v[7] - v[8]) + v[14]*sin(v[8]))) + (M[6]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + (cos(v[8])*L[6]*v[20])/2.)*sin(v[7]) - 2*cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.)))/2. - (M[6]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + (cos(v[8])*L[6]*v[20])/2.)*sin(v[7]) - 2*L[5]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - (cos(v[8])*L[6]*pow(v[20],2))/2.)*sin(v[7]) - 2*cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.) + 2*cos(v[7])*L[5]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - (L[6]*pow(v[20],2)*sin(v[8]))/2.)))/2. - L[5]*sin(v[7])*(-(Cs*L[7]*sin(v[9])*(-2*cos(v[9])*v[14] - 2*cos(v[3] - v[9])*L[1]*v[15] - 2*cos(v[4] - v[9])*L[2]*v[16] - 2*cos(v[5] - v[9])*L[3]*v[17] - 2*cos(v[6] - v[9])*L[4]*v[18] - 2*cos(v[7] - v[9])*L[5]*v[19] - 2*cos(v[8] - v[9])*L[6]*v[20] - L[7]*v[21] + 2*v[13]*sin(v[9])))/2. - Cv*cos(v[9])*L[7]*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) + cos(v[7])*L[5]*(-(Cs*cos(v[9])*L[7]*(2*cos(v[9])*v[14] + 2*cos(v[3] - v[9])*L[1]*v[15] + 2*cos(v[4] - v[9])*L[2]*v[16] + 2*cos(v[5] - v[9])*L[3]*v[17] + 2*cos(v[6] - v[9])*L[4]*v[18] + 2*cos(v[7] - v[9])*L[5]*v[19] + 2*cos(v[8] - v[9])*L[6]*v[20] + L[7]*v[21] - 2*v[13]*sin(v[9])))/2. - Cv*L[7]*sin(v[9])*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) + (M[7]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[7]) - 2*cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.)))/2. - (M[7]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[7]) - 2*L[5]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - (cos(v[9])*L[7]*pow(v[21],2))/2.)*sin(v[7]) - 2*cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.) + 2*cos(v[7])*L[5]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - (L[7]*pow(v[21],2)*sin(v[9]))/2.)))/2. - L[5]*sin(v[7])*(-(Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10]))) + cos(v[7])*L[5]*(-(Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] + 2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + 2*cos(v[5] - v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] - v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10]))) + (M[8]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + (cos(v[10])*L[8]*v[22])/2.)*sin(v[7]) - 2*cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.)))/2. - (M[8]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + (cos(v[10])*L[8]*v[22])/2.)*sin(v[7]) - 2*L[5]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.)*sin(v[7]) - 2*cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.) + 2*cos(v[7])*L[5]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - (L[8]*pow(v[22],2)*sin(v[10]))/2.)))/2. - L[5]*sin(v[7])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + 2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))) + cos(v[7])*L[5]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] + 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + 2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] - v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - 2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))) + (M[9]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[7]) - 2*cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[7]) - 2*L[5]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - (cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[7]) - 2*cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + 2*cos(v[7])*L[5]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - L[5]*sin(v[7])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + cos(v[7])*L[5]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + (M[10]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[7]) - 2*cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[5]*v[19]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[7]) - 2*L[5]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[7]) - 2*cos(v[7])*L[5]*v[19]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + 2*cos(v[7])*L[5]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - (L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;
 coefMat[7] = -(L[6]*M[6]*sin(v[8]))/2. - L[6]*M[7]*sin(v[8]) - L[6]*M[8]*sin(v[8]) - L[6]*M[9]*sin(v[8]) - L[6]*M[10]*sin(v[8]);
 coefMat[19] = (cos(v[8])*L[6]*M[6])/2. + cos(v[8])*L[6]*M[7] + cos(v[8])*L[6]*M[8] + cos(v[8])*L[6]*M[9] + cos(v[8])*L[6]*M[10];
 coefMat[31] = (M[6]*(cos(v[3])*cos(v[8])*L[1]*L[6] + L[1]*L[6]*sin(v[3])*sin(v[8])))/2. + (M[7]*(2*cos(v[3])*cos(v[8])*L[1]*L[6] + 2*L[1]*L[6]*sin(v[3])*sin(v[8])))/2. + (M[8]*(2*cos(v[3])*cos(v[8])*L[1]*L[6] + 2*L[1]*L[6]*sin(v[3])*sin(v[8])))/2. + (M[9]*(2*cos(v[3])*cos(v[8])*L[1]*L[6] + 2*L[1]*L[6]*sin(v[3])*sin(v[8])))/2. + (M[10]*(2*cos(v[3])*cos(v[8])*L[1]*L[6] + 2*L[1]*L[6]*sin(v[3])*sin(v[8])))/2.;
 coefMat[43] = (M[6]*(cos(v[4])*cos(v[8])*L[2]*L[6] + L[2]*L[6]*sin(v[4])*sin(v[8])))/2. + (M[7]*(2*cos(v[4])*cos(v[8])*L[2]*L[6] + 2*L[2]*L[6]*sin(v[4])*sin(v[8])))/2. + (M[8]*(2*cos(v[4])*cos(v[8])*L[2]*L[6] + 2*L[2]*L[6]*sin(v[4])*sin(v[8])))/2. + (M[9]*(2*cos(v[4])*cos(v[8])*L[2]*L[6] + 2*L[2]*L[6]*sin(v[4])*sin(v[8])))/2. + (M[10]*(2*cos(v[4])*cos(v[8])*L[2]*L[6] + 2*L[2]*L[6]*sin(v[4])*sin(v[8])))/2.;
 coefMat[55] = (M[6]*(cos(v[5])*cos(v[8])*L[3]*L[6] + L[3]*L[6]*sin(v[5])*sin(v[8])))/2. + (M[7]*(2*cos(v[5])*cos(v[8])*L[3]*L[6] + 2*L[3]*L[6]*sin(v[5])*sin(v[8])))/2. + (M[8]*(2*cos(v[5])*cos(v[8])*L[3]*L[6] + 2*L[3]*L[6]*sin(v[5])*sin(v[8])))/2. + (M[9]*(2*cos(v[5])*cos(v[8])*L[3]*L[6] + 2*L[3]*L[6]*sin(v[5])*sin(v[8])))/2. + (M[10]*(2*cos(v[5])*cos(v[8])*L[3]*L[6] + 2*L[3]*L[6]*sin(v[5])*sin(v[8])))/2.;
 coefMat[67] = (M[6]*(cos(v[6])*cos(v[8])*L[4]*L[6] + L[4]*L[6]*sin(v[6])*sin(v[8])))/2. + (M[7]*(2*cos(v[6])*cos(v[8])*L[4]*L[6] + 2*L[4]*L[6]*sin(v[6])*sin(v[8])))/2. + (M[8]*(2*cos(v[6])*cos(v[8])*L[4]*L[6] + 2*L[4]*L[6]*sin(v[6])*sin(v[8])))/2. + (M[9]*(2*cos(v[6])*cos(v[8])*L[4]*L[6] + 2*L[4]*L[6]*sin(v[6])*sin(v[8])))/2. + (M[10]*(2*cos(v[6])*cos(v[8])*L[4]*L[6] + 2*L[4]*L[6]*sin(v[6])*sin(v[8])))/2.;
 coefMat[79] = (M[6]*(cos(v[7])*cos(v[8])*L[5]*L[6] + L[5]*L[6]*sin(v[7])*sin(v[8])))/2. + (M[7]*(2*cos(v[7])*cos(v[8])*L[5]*L[6] + 2*L[5]*L[6]*sin(v[7])*sin(v[8])))/2. + (M[8]*(2*cos(v[7])*cos(v[8])*L[5]*L[6] + 2*L[5]*L[6]*sin(v[7])*sin(v[8])))/2. + (M[9]*(2*cos(v[7])*cos(v[8])*L[5]*L[6] + 2*L[5]*L[6]*sin(v[7])*sin(v[8])))/2. + (M[10]*(2*cos(v[7])*cos(v[8])*L[5]*L[6] + 2*L[5]*L[6]*sin(v[7])*sin(v[8])))/2.;
 coefMat[91] = (pow(L[6],2)*M[6])/12. + (M[6]*((pow(cos(v[8]),2)*pow(L[6],2))/2. + (pow(L[6],2)*pow(sin(v[8]),2))/2.))/2. + (M[7]*(2*pow(cos(v[8]),2)*pow(L[6],2) + 2*pow(L[6],2)*pow(sin(v[8]),2)))/2. + (M[8]*(2*pow(cos(v[8]),2)*pow(L[6],2) + 2*pow(L[6],2)*pow(sin(v[8]),2)))/2. + (M[9]*(2*pow(cos(v[8]),2)*pow(L[6],2) + 2*pow(L[6],2)*pow(sin(v[8]),2)))/2. + (M[10]*(2*pow(cos(v[8]),2)*pow(L[6],2) + 2*pow(L[6],2)*pow(sin(v[8]),2)))/2.;
 coefMat[103] = (M[7]*(cos(v[8])*cos(v[9])*L[6]*L[7] + L[6]*L[7]*sin(v[8])*sin(v[9])))/2. + (M[8]*(2*cos(v[8])*cos(v[9])*L[6]*L[7] + 2*L[6]*L[7]*sin(v[8])*sin(v[9])))/2. + (M[9]*(2*cos(v[8])*cos(v[9])*L[6]*L[7] + 2*L[6]*L[7]*sin(v[8])*sin(v[9])))/2. + (M[10]*(2*cos(v[8])*cos(v[9])*L[6]*L[7] + 2*L[6]*L[7]*sin(v[8])*sin(v[9])))/2.;
 coefMat[115] = (M[8]*(cos(v[8])*cos(v[10])*L[6]*L[8] + L[6]*L[8]*sin(v[8])*sin(v[10])))/2. + (M[9]*(2*cos(v[8])*cos(v[10])*L[6]*L[8] + 2*L[6]*L[8]*sin(v[8])*sin(v[10])))/2. + (M[10]*(2*cos(v[8])*cos(v[10])*L[6]*L[8] + 2*L[6]*L[8]*sin(v[8])*sin(v[10])))/2.;
 coefMat[127] = (M[9]*(cos(v[8])*cos(v[11])*L[6]*L[9] + L[6]*L[9]*sin(v[8])*sin(v[11])))/2. + (M[10]*(2*cos(v[8])*cos(v[11])*L[6]*L[9] + 2*L[6]*L[9]*sin(v[8])*sin(v[11])))/2.;
 coefMat[139] = (M[10]*(cos(v[8])*cos(v[12])*L[6]*L[10] + L[6]*L[10]*sin(v[8])*sin(v[12])))/2.;
 rhsVec[7] = forceRY*cos(v[8])*L[6] - (Cs*pow(L[6],3)*v[20])/12. - forceRX*L[6]*sin(v[8]) - (pow(L[6],2)*sin(v[8])*(-(Cs*sin(v[8])*(-2*cos(v[8])*v[14] - 2*cos(v[3] - v[8])*L[1]*v[15] - 2*cos(v[4] - v[8])*L[2]*v[16] - 2*cos(v[5] - v[8])*L[3]*v[17] - 2*cos(v[6] - v[8])*L[4]*v[18] - 2*cos(v[7] - v[8])*L[5]*v[19] - L[6]*v[20] + 2*v[13]*sin(v[8]))) + 2*Cv*cos(v[8])*(-(cos(v[8])*v[13]) + L[1]*v[15]*sin(v[3] - v[8]) + L[2]*v[16]*sin(v[4] - v[8]) + L[3]*v[17]*sin(v[5] - v[8]) + L[4]*v[18]*sin(v[6] - v[8]) + L[5]*v[19]*sin(v[7] - v[8]) - v[14]*sin(v[8]))))/4. + (cos(v[8])*L[6]*(-(Cs*cos(v[8])*L[6]*(2*cos(v[8])*v[14] + 2*cos(v[3] - v[8])*L[1]*v[15] + 2*cos(v[4] - v[8])*L[2]*v[16] + 2*cos(v[5] - v[8])*L[3]*v[17] + 2*cos(v[6] - v[8])*L[4]*v[18] + 2*cos(v[7] - v[8])*L[5]*v[19] + L[6]*v[20] - 2*v[13]*sin(v[8])))/2. - Cv*L[6]*sin(v[8])*(cos(v[8])*v[13] - L[1]*v[15]*sin(v[3] - v[8]) - L[2]*v[16]*sin(v[4] - v[8]) - L[3]*v[17]*sin(v[5] - v[8]) - L[4]*v[18]*sin(v[6] - v[8]) - L[5]*v[19]*sin(v[7] - v[8]) + v[14]*sin(v[8]))))/2. + (M[6]*(-(L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + (cos(v[8])*L[6]*v[20])/2.)*sin(v[8])) - cos(v[8])*L[6]*v[20]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.)))/2. - (M[6]*(-(L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + (cos(v[8])*L[6]*v[20])/2.)*sin(v[8])) - L[6]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - (cos(v[8])*L[6]*pow(v[20],2))/2.)*sin(v[8]) - cos(v[8])*L[6]*v[20]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - (L[6]*v[20]*sin(v[8]))/2.) + cos(v[8])*L[6]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - (L[6]*pow(v[20],2)*sin(v[8]))/2.)))/2. - L[6]*sin(v[8])*(-(Cs*L[7]*sin(v[9])*(-2*cos(v[9])*v[14] - 2*cos(v[3] - v[9])*L[1]*v[15] - 2*cos(v[4] - v[9])*L[2]*v[16] - 2*cos(v[5] - v[9])*L[3]*v[17] - 2*cos(v[6] - v[9])*L[4]*v[18] - 2*cos(v[7] - v[9])*L[5]*v[19] - 2*cos(v[8] - v[9])*L[6]*v[20] - L[7]*v[21] + 2*v[13]*sin(v[9])))/2. - Cv*cos(v[9])*L[7]*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) + cos(v[8])*L[6]*(-(Cs*cos(v[9])*L[7]*(2*cos(v[9])*v[14] + 2*cos(v[3] - v[9])*L[1]*v[15] + 2*cos(v[4] - v[9])*L[2]*v[16] + 2*cos(v[5] - v[9])*L[3]*v[17] + 2*cos(v[6] - v[9])*L[4]*v[18] + 2*cos(v[7] - v[9])*L[5]*v[19] + 2*cos(v[8] - v[9])*L[6]*v[20] + L[7]*v[21] - 2*v[13]*sin(v[9])))/2. - Cv*L[7]*sin(v[9])*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))) + (M[7]*(-2*L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[8]) - 2*cos(v[8])*L[6]*v[20]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.)))/2. - (M[7]*(-2*L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[8]) - 2*L[6]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - (cos(v[9])*L[7]*pow(v[21],2))/2.)*sin(v[8]) - 2*cos(v[8])*L[6]*v[20]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.) + 2*cos(v[8])*L[6]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - (L[7]*pow(v[21],2)*sin(v[9]))/2.)))/2. - L[6]*sin(v[8])*(-(Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10]))) + cos(v[8])*L[6]*(-(Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] + 2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + 2*cos(v[5] - v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] - v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10]))) + (M[8]*(-2*L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + (cos(v[10])*L[8]*v[22])/2.)*sin(v[8]) - 2*cos(v[8])*L[6]*v[20]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.)))/2. - (M[8]*(-2*L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + (cos(v[10])*L[8]*v[22])/2.)*sin(v[8]) - 2*L[6]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.)*sin(v[8]) - 2*cos(v[8])*L[6]*v[20]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.) + 2*cos(v[8])*L[6]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - (L[8]*pow(v[22],2)*sin(v[10]))/2.)))/2. - L[6]*sin(v[8])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + 2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))) + cos(v[8])*L[6]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] + 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + 2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] - v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - 2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))) + (M[9]*(-2*L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[8]) - 2*cos(v[8])*L[6]*v[20]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-2*L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[8]) - 2*L[6]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - (cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[8]) - 2*cos(v[8])*L[6]*v[20]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + 2*cos(v[8])*L[6]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - L[6]*sin(v[8])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + cos(v[8])*L[6]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + (M[10]*(-2*L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[8]) - 2*cos(v[8])*L[6]*v[20]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[6]*v[20]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[8]) - 2*L[6]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[8]) - 2*cos(v[8])*L[6]*v[20]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + 2*cos(v[8])*L[6]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - (L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;
 coefMat[8] = -(L[7]*M[7]*sin(v[9]))/2. - L[7]*M[8]*sin(v[9]) - L[7]*M[9]*sin(v[9]) - L[7]*M[10]*sin(v[9]);
 coefMat[20] = (cos(v[9])*L[7]*M[7])/2. + cos(v[9])*L[7]*M[8] + cos(v[9])*L[7]*M[9] + cos(v[9])*L[7]*M[10];
 coefMat[32] = (M[7]*(cos(v[3])*cos(v[9])*L[1]*L[7] + L[1]*L[7]*sin(v[3])*sin(v[9])))/2. + (M[8]*(2*cos(v[3])*cos(v[9])*L[1]*L[7] + 2*L[1]*L[7]*sin(v[3])*sin(v[9])))/2. + (M[9]*(2*cos(v[3])*cos(v[9])*L[1]*L[7] + 2*L[1]*L[7]*sin(v[3])*sin(v[9])))/2. + (M[10]*(2*cos(v[3])*cos(v[9])*L[1]*L[7] + 2*L[1]*L[7]*sin(v[3])*sin(v[9])))/2.;
 coefMat[44] = (M[7]*(cos(v[4])*cos(v[9])*L[2]*L[7] + L[2]*L[7]*sin(v[4])*sin(v[9])))/2. + (M[8]*(2*cos(v[4])*cos(v[9])*L[2]*L[7] + 2*L[2]*L[7]*sin(v[4])*sin(v[9])))/2. + (M[9]*(2*cos(v[4])*cos(v[9])*L[2]*L[7] + 2*L[2]*L[7]*sin(v[4])*sin(v[9])))/2. + (M[10]*(2*cos(v[4])*cos(v[9])*L[2]*L[7] + 2*L[2]*L[7]*sin(v[4])*sin(v[9])))/2.;
 coefMat[56] = (M[7]*(cos(v[5])*cos(v[9])*L[3]*L[7] + L[3]*L[7]*sin(v[5])*sin(v[9])))/2. + (M[8]*(2*cos(v[5])*cos(v[9])*L[3]*L[7] + 2*L[3]*L[7]*sin(v[5])*sin(v[9])))/2. + (M[9]*(2*cos(v[5])*cos(v[9])*L[3]*L[7] + 2*L[3]*L[7]*sin(v[5])*sin(v[9])))/2. + (M[10]*(2*cos(v[5])*cos(v[9])*L[3]*L[7] + 2*L[3]*L[7]*sin(v[5])*sin(v[9])))/2.;
 coefMat[68] = (M[7]*(cos(v[6])*cos(v[9])*L[4]*L[7] + L[4]*L[7]*sin(v[6])*sin(v[9])))/2. + (M[8]*(2*cos(v[6])*cos(v[9])*L[4]*L[7] + 2*L[4]*L[7]*sin(v[6])*sin(v[9])))/2. + (M[9]*(2*cos(v[6])*cos(v[9])*L[4]*L[7] + 2*L[4]*L[7]*sin(v[6])*sin(v[9])))/2. + (M[10]*(2*cos(v[6])*cos(v[9])*L[4]*L[7] + 2*L[4]*L[7]*sin(v[6])*sin(v[9])))/2.;
 coefMat[80] = (M[7]*(cos(v[7])*cos(v[9])*L[5]*L[7] + L[5]*L[7]*sin(v[7])*sin(v[9])))/2. + (M[8]*(2*cos(v[7])*cos(v[9])*L[5]*L[7] + 2*L[5]*L[7]*sin(v[7])*sin(v[9])))/2. + (M[9]*(2*cos(v[7])*cos(v[9])*L[5]*L[7] + 2*L[5]*L[7]*sin(v[7])*sin(v[9])))/2. + (M[10]*(2*cos(v[7])*cos(v[9])*L[5]*L[7] + 2*L[5]*L[7]*sin(v[7])*sin(v[9])))/2.;
 coefMat[92] = (M[7]*(cos(v[8])*cos(v[9])*L[6]*L[7] + L[6]*L[7]*sin(v[8])*sin(v[9])))/2. + (M[8]*(2*cos(v[8])*cos(v[9])*L[6]*L[7] + 2*L[6]*L[7]*sin(v[8])*sin(v[9])))/2. + (M[9]*(2*cos(v[8])*cos(v[9])*L[6]*L[7] + 2*L[6]*L[7]*sin(v[8])*sin(v[9])))/2. + (M[10]*(2*cos(v[8])*cos(v[9])*L[6]*L[7] + 2*L[6]*L[7]*sin(v[8])*sin(v[9])))/2.;
 coefMat[104] = (pow(L[7],2)*M[7])/12. + (M[7]*((pow(cos(v[9]),2)*pow(L[7],2))/2. + (pow(L[7],2)*pow(sin(v[9]),2))/2.))/2. + (M[8]*(2*pow(cos(v[9]),2)*pow(L[7],2) + 2*pow(L[7],2)*pow(sin(v[9]),2)))/2. + (M[9]*(2*pow(cos(v[9]),2)*pow(L[7],2) + 2*pow(L[7],2)*pow(sin(v[9]),2)))/2. + (M[10]*(2*pow(cos(v[9]),2)*pow(L[7],2) + 2*pow(L[7],2)*pow(sin(v[9]),2)))/2.;
 coefMat[116] = (M[8]*(cos(v[9])*cos(v[10])*L[7]*L[8] + L[7]*L[8]*sin(v[9])*sin(v[10])))/2. + (M[9]*(2*cos(v[9])*cos(v[10])*L[7]*L[8] + 2*L[7]*L[8]*sin(v[9])*sin(v[10])))/2. + (M[10]*(2*cos(v[9])*cos(v[10])*L[7]*L[8] + 2*L[7]*L[8]*sin(v[9])*sin(v[10])))/2.;
 coefMat[128] = (M[9]*(cos(v[9])*cos(v[11])*L[7]*L[9] + L[7]*L[9]*sin(v[9])*sin(v[11])))/2. + (M[10]*(2*cos(v[9])*cos(v[11])*L[7]*L[9] + 2*L[7]*L[9]*sin(v[9])*sin(v[11])))/2.;
 coefMat[140] = (M[10]*(cos(v[9])*cos(v[12])*L[7]*L[10] + L[7]*L[10]*sin(v[9])*sin(v[12])))/2.;
 rhsVec[8] = forceRY*cos(v[9])*L[7] - (Cs*pow(L[7],3)*v[21])/12. - forceRX*L[7]*sin(v[9]) - (L[7]*sin(v[9])*(-(Cs*L[7]*sin(v[9])*(-2*cos(v[9])*v[14] - 2*cos(v[3] - v[9])*L[1]*v[15] - 2*cos(v[4] - v[9])*L[2]*v[16] - 2*cos(v[5] - v[9])*L[3]*v[17] - 2*cos(v[6] - v[9])*L[4]*v[18] - 2*cos(v[7] - v[9])*L[5]*v[19] - 2*cos(v[8] - v[9])*L[6]*v[20] - L[7]*v[21] + 2*v[13]*sin(v[9])))/2. - Cv*cos(v[9])*L[7]*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))))/2. + (cos(v[9])*L[7]*(-(Cs*cos(v[9])*L[7]*(2*cos(v[9])*v[14] + 2*cos(v[3] - v[9])*L[1]*v[15] + 2*cos(v[4] - v[9])*L[2]*v[16] + 2*cos(v[5] - v[9])*L[3]*v[17] + 2*cos(v[6] - v[9])*L[4]*v[18] + 2*cos(v[7] - v[9])*L[5]*v[19] + 2*cos(v[8] - v[9])*L[6]*v[20] + L[7]*v[21] - 2*v[13]*sin(v[9])))/2. - Cv*L[7]*sin(v[9])*(cos(v[9])*v[13] - L[1]*v[15]*sin(v[3] - v[9]) - L[2]*v[16]*sin(v[4] - v[9]) - L[3]*v[17]*sin(v[5] - v[9]) - L[4]*v[18]*sin(v[6] - v[9]) - L[5]*v[19]*sin(v[7] - v[9]) - L[6]*v[20]*sin(v[8] - v[9]) + v[14]*sin(v[9]))))/2. + (M[7]*(-(L[7]*v[21]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[9])) - cos(v[9])*L[7]*v[21]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.)))/2. - (M[7]*(-(L[7]*v[21]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + (cos(v[9])*L[7]*v[21])/2.)*sin(v[9])) - L[7]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - (cos(v[9])*L[7]*pow(v[21],2))/2.)*sin(v[9]) - cos(v[9])*L[7]*v[21]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - (L[7]*v[21]*sin(v[9]))/2.) + cos(v[9])*L[7]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - (L[7]*pow(v[21],2)*sin(v[9]))/2.)))/2. - L[7]*sin(v[9])*(-(Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10]))) + cos(v[9])*L[7]*(-(Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] + 2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + 2*cos(v[5] - v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] - v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10]))) + (M[8]*(-2*L[7]*v[21]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + (cos(v[10])*L[8]*v[22])/2.)*sin(v[9]) - 2*cos(v[9])*L[7]*v[21]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.)))/2. - (M[8]*(-2*L[7]*v[21]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + (cos(v[10])*L[8]*v[22])/2.)*sin(v[9]) - 2*L[7]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.)*sin(v[9]) - 2*cos(v[9])*L[7]*v[21]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.) + 2*cos(v[9])*L[7]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - (L[8]*pow(v[22],2)*sin(v[10]))/2.)))/2. - L[7]*sin(v[9])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + 2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))) + cos(v[9])*L[7]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] + 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + 2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] - v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - 2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))) + (M[9]*(-2*L[7]*v[21]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[9]) - 2*cos(v[9])*L[7]*v[21]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-2*L[7]*v[21]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[9]) - 2*L[7]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - (cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[9]) - 2*cos(v[9])*L[7]*v[21]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + 2*cos(v[9])*L[7]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - L[7]*sin(v[9])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + cos(v[9])*L[7]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + (M[10]*(-2*L[7]*v[21]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[9]) - 2*cos(v[9])*L[7]*v[21]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[7]*v[21]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[9]) - 2*L[7]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[9]) - 2*cos(v[9])*L[7]*v[21]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + 2*cos(v[9])*L[7]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - (L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;
 coefMat[9] = -(L[8]*M[8]*sin(v[10]))/2. - L[8]*M[9]*sin(v[10]) - L[8]*M[10]*sin(v[10]);
 coefMat[21] = (cos(v[10])*L[8]*M[8])/2. + cos(v[10])*L[8]*M[9] + cos(v[10])*L[8]*M[10];
 coefMat[33] = (M[8]*(cos(v[3])*cos(v[10])*L[1]*L[8] + L[1]*L[8]*sin(v[3])*sin(v[10])))/2. + (M[9]*(2*cos(v[3])*cos(v[10])*L[1]*L[8] + 2*L[1]*L[8]*sin(v[3])*sin(v[10])))/2. + (M[10]*(2*cos(v[3])*cos(v[10])*L[1]*L[8] + 2*L[1]*L[8]*sin(v[3])*sin(v[10])))/2.;
 coefMat[45] = (M[8]*(cos(v[4])*cos(v[10])*L[2]*L[8] + L[2]*L[8]*sin(v[4])*sin(v[10])))/2. + (M[9]*(2*cos(v[4])*cos(v[10])*L[2]*L[8] + 2*L[2]*L[8]*sin(v[4])*sin(v[10])))/2. + (M[10]*(2*cos(v[4])*cos(v[10])*L[2]*L[8] + 2*L[2]*L[8]*sin(v[4])*sin(v[10])))/2.;
 coefMat[57] = (M[8]*(cos(v[5])*cos(v[10])*L[3]*L[8] + L[3]*L[8]*sin(v[5])*sin(v[10])))/2. + (M[9]*(2*cos(v[5])*cos(v[10])*L[3]*L[8] + 2*L[3]*L[8]*sin(v[5])*sin(v[10])))/2. + (M[10]*(2*cos(v[5])*cos(v[10])*L[3]*L[8] + 2*L[3]*L[8]*sin(v[5])*sin(v[10])))/2.;
 coefMat[69] = (M[8]*(cos(v[6])*cos(v[10])*L[4]*L[8] + L[4]*L[8]*sin(v[6])*sin(v[10])))/2. + (M[9]*(2*cos(v[6])*cos(v[10])*L[4]*L[8] + 2*L[4]*L[8]*sin(v[6])*sin(v[10])))/2. + (M[10]*(2*cos(v[6])*cos(v[10])*L[4]*L[8] + 2*L[4]*L[8]*sin(v[6])*sin(v[10])))/2.;
 coefMat[81] = (M[8]*(cos(v[7])*cos(v[10])*L[5]*L[8] + L[5]*L[8]*sin(v[7])*sin(v[10])))/2. + (M[9]*(2*cos(v[7])*cos(v[10])*L[5]*L[8] + 2*L[5]*L[8]*sin(v[7])*sin(v[10])))/2. + (M[10]*(2*cos(v[7])*cos(v[10])*L[5]*L[8] + 2*L[5]*L[8]*sin(v[7])*sin(v[10])))/2.;
 coefMat[93] = (M[8]*(cos(v[8])*cos(v[10])*L[6]*L[8] + L[6]*L[8]*sin(v[8])*sin(v[10])))/2. + (M[9]*(2*cos(v[8])*cos(v[10])*L[6]*L[8] + 2*L[6]*L[8]*sin(v[8])*sin(v[10])))/2. + (M[10]*(2*cos(v[8])*cos(v[10])*L[6]*L[8] + 2*L[6]*L[8]*sin(v[8])*sin(v[10])))/2.;
 coefMat[105] = (M[8]*(cos(v[9])*cos(v[10])*L[7]*L[8] + L[7]*L[8]*sin(v[9])*sin(v[10])))/2. + (M[9]*(2*cos(v[9])*cos(v[10])*L[7]*L[8] + 2*L[7]*L[8]*sin(v[9])*sin(v[10])))/2. + (M[10]*(2*cos(v[9])*cos(v[10])*L[7]*L[8] + 2*L[7]*L[8]*sin(v[9])*sin(v[10])))/2.;
 coefMat[117] = (pow(L[8],2)*M[8])/12. + (M[8]*((pow(cos(v[10]),2)*pow(L[8],2))/2. + (pow(L[8],2)*pow(sin(v[10]),2))/2.))/2. + (M[9]*(2*pow(cos(v[10]),2)*pow(L[8],2) + 2*pow(L[8],2)*pow(sin(v[10]),2)))/2. + (M[10]*(2*pow(cos(v[10]),2)*pow(L[8],2) + 2*pow(L[8],2)*pow(sin(v[10]),2)))/2.;
 coefMat[129] = (M[9]*(cos(v[10])*cos(v[11])*L[8]*L[9] + L[8]*L[9]*sin(v[10])*sin(v[11])))/2. + (M[10]*(2*cos(v[10])*cos(v[11])*L[8]*L[9] + 2*L[8]*L[9]*sin(v[10])*sin(v[11])))/2.;
 coefMat[141] = (M[10]*(cos(v[10])*cos(v[12])*L[8]*L[10] + L[8]*L[10]*sin(v[10])*sin(v[12])))/2.;
 rhsVec[9] = forceRY*cos(v[10])*L[8] - (Cs*pow(L[8],3)*v[22])/12. - forceRX*L[8]*sin(v[10]) - (L[8]*sin(v[10])*(-(Cs*L[8]*sin(v[10])*(-2*cos(v[10])*v[14] - 2*cos(v[3] - v[10])*L[1]*v[15] - 2*cos(v[4] - v[10])*L[2]*v[16] - 2*cos(v[5] - v[10])*L[3]*v[17] - 2*cos(v[6] - v[10])*L[4]*v[18] - 2*cos(v[7] - v[10])*L[5]*v[19] - 2*cos(v[8] - v[10])*L[6]*v[20] - 2*cos(v[9] - v[10])*L[7]*v[21] - L[8]*v[22] + 2*v[13]*sin(v[10])))/2. - Cv*cos(v[10])*L[8]*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10]))))/2. + (cos(v[10])*L[8]*(-(Cs*cos(v[10])*L[8]*(2*cos(v[10])*v[14] + 2*cos(v[3] - v[10])*L[1]*v[15] + 2*cos(v[4] - v[10])*L[2]*v[16] + 2*cos(v[5] - v[10])*L[3]*v[17] + 2*cos(v[6] - v[10])*L[4]*v[18] + 2*cos(v[7] - v[10])*L[5]*v[19] + 2*cos(v[8] - v[10])*L[6]*v[20] + 2*cos(v[9] - v[10])*L[7]*v[21] + L[8]*v[22] - 2*v[13]*sin(v[10])))/2. - Cv*L[8]*sin(v[10])*(cos(v[10])*v[13] - L[1]*v[15]*sin(v[3] - v[10]) - L[2]*v[16]*sin(v[4] - v[10]) - L[3]*v[17]*sin(v[5] - v[10]) - L[4]*v[18]*sin(v[6] - v[10]) - L[5]*v[19]*sin(v[7] - v[10]) - L[6]*v[20]*sin(v[8] - v[10]) - L[7]*v[21]*sin(v[9] - v[10]) + v[14]*sin(v[10]))))/2. + (M[8]*(-(L[8]*v[22]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + (cos(v[10])*L[8]*v[22])/2.)*sin(v[10])) - cos(v[10])*L[8]*v[22]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.)))/2. - (M[8]*(-(L[8]*v[22]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + (cos(v[10])*L[8]*v[22])/2.)*sin(v[10])) - L[8]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - (cos(v[10])*L[8]*pow(v[22],2))/2.)*sin(v[10]) - cos(v[10])*L[8]*v[22]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - (L[8]*v[22]*sin(v[10]))/2.) + cos(v[10])*L[8]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - (L[8]*pow(v[22],2)*sin(v[10]))/2.)))/2. - L[8]*sin(v[10])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + 2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))) + cos(v[10])*L[8]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] + 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + 2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] - v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - 2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))) + (M[9]*(-2*L[8]*v[22]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[10]) - 2*cos(v[10])*L[8]*v[22]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-2*L[8]*v[22]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[10]) - 2*L[8]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - (cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[10]) - 2*cos(v[10])*L[8]*v[22]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + 2*cos(v[10])*L[8]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - L[8]*sin(v[10])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + cos(v[10])*L[8]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + (M[10]*(-2*L[8]*v[22]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[10]) - 2*cos(v[10])*L[8]*v[22]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[8]*v[22]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[10]) - 2*L[8]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[10]) - 2*cos(v[10])*L[8]*v[22]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + 2*cos(v[10])*L[8]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - (L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;
 coefMat[10] = -(L[9]*M[9]*sin(v[11]))/2. - L[9]*M[10]*sin(v[11]);
 coefMat[22] = (cos(v[11])*L[9]*M[9])/2. + cos(v[11])*L[9]*M[10];
 coefMat[34] = (M[9]*(cos(v[3])*cos(v[11])*L[1]*L[9] + L[1]*L[9]*sin(v[3])*sin(v[11])))/2. + (M[10]*(2*cos(v[3])*cos(v[11])*L[1]*L[9] + 2*L[1]*L[9]*sin(v[3])*sin(v[11])))/2.;
 coefMat[46] = (M[9]*(cos(v[4])*cos(v[11])*L[2]*L[9] + L[2]*L[9]*sin(v[4])*sin(v[11])))/2. + (M[10]*(2*cos(v[4])*cos(v[11])*L[2]*L[9] + 2*L[2]*L[9]*sin(v[4])*sin(v[11])))/2.;
 coefMat[58] = (M[9]*(cos(v[5])*cos(v[11])*L[3]*L[9] + L[3]*L[9]*sin(v[5])*sin(v[11])))/2. + (M[10]*(2*cos(v[5])*cos(v[11])*L[3]*L[9] + 2*L[3]*L[9]*sin(v[5])*sin(v[11])))/2.;
 coefMat[70] = (M[9]*(cos(v[6])*cos(v[11])*L[4]*L[9] + L[4]*L[9]*sin(v[6])*sin(v[11])))/2. + (M[10]*(2*cos(v[6])*cos(v[11])*L[4]*L[9] + 2*L[4]*L[9]*sin(v[6])*sin(v[11])))/2.;
 coefMat[82] = (M[9]*(cos(v[7])*cos(v[11])*L[5]*L[9] + L[5]*L[9]*sin(v[7])*sin(v[11])))/2. + (M[10]*(2*cos(v[7])*cos(v[11])*L[5]*L[9] + 2*L[5]*L[9]*sin(v[7])*sin(v[11])))/2.;
 coefMat[94] = (M[9]*(cos(v[8])*cos(v[11])*L[6]*L[9] + L[6]*L[9]*sin(v[8])*sin(v[11])))/2. + (M[10]*(2*cos(v[8])*cos(v[11])*L[6]*L[9] + 2*L[6]*L[9]*sin(v[8])*sin(v[11])))/2.;
 coefMat[106] = (M[9]*(cos(v[9])*cos(v[11])*L[7]*L[9] + L[7]*L[9]*sin(v[9])*sin(v[11])))/2. + (M[10]*(2*cos(v[9])*cos(v[11])*L[7]*L[9] + 2*L[7]*L[9]*sin(v[9])*sin(v[11])))/2.;
 coefMat[118] = (M[9]*(cos(v[10])*cos(v[11])*L[8]*L[9] + L[8]*L[9]*sin(v[10])*sin(v[11])))/2. + (M[10]*(2*cos(v[10])*cos(v[11])*L[8]*L[9] + 2*L[8]*L[9]*sin(v[10])*sin(v[11])))/2.;
 coefMat[130] = (pow(L[9],2)*M[9])/12. + (M[9]*((pow(cos(v[11]),2)*pow(L[9],2))/2. + (pow(L[9],2)*pow(sin(v[11]),2))/2.))/2. + (M[10]*(2*pow(cos(v[11]),2)*pow(L[9],2) + 2*pow(L[9],2)*pow(sin(v[11]),2)))/2.;
 coefMat[142] = (M[10]*(cos(v[11])*cos(v[12])*L[9]*L[10] + L[9]*L[10]*sin(v[11])*sin(v[12])))/2.;
 rhsVec[10] = forceRY*cos(v[11])*L[9] - (Cs*pow(L[9],3)*v[23])/12. - forceRX*L[9]*sin(v[11]) - (L[9]*sin(v[11])*(-(Cs*L[9]*sin(v[11])*(-2*cos(v[11])*v[14] - 2*cos(v[3] - v[11])*L[1]*v[15] - 2*cos(v[4] - v[11])*L[2]*v[16] - 2*cos(v[5] - v[11])*L[3]*v[17] - 2*cos(v[6] - v[11])*L[4]*v[18] - 2*cos(v[7] - v[11])*L[5]*v[19] - 2*cos(v[8] - v[11])*L[6]*v[20] - 2*cos(v[9] - v[11])*L[7]*v[21] - 2*cos(v[10] - v[11])*L[8]*v[22] - L[9]*v[23] + 2*v[13]*sin(v[11])))/2. - Cv*cos(v[11])*L[9]*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))))/2. + (cos(v[11])*L[9]*(-(Cs*cos(v[11])*L[9]*(2*cos(v[11])*v[14] + 2*cos(v[3] - v[11])*L[1]*v[15] + 2*cos(v[4] - v[11])*L[2]*v[16] + 2*cos(v[5] - v[11])*L[3]*v[17] + 2*cos(v[6] - v[11])*L[4]*v[18] + 2*cos(v[7] - v[11])*L[5]*v[19] + 2*cos(v[8] - v[11])*L[6]*v[20] + 2*cos(v[9] - v[11])*L[7]*v[21] + 2*cos(v[10] - v[11])*L[8]*v[22] + L[9]*v[23] - 2*v[13]*sin(v[11])))/2. - Cv*L[9]*sin(v[11])*(cos(v[11])*v[13] - L[1]*v[15]*sin(v[3] - v[11]) - L[2]*v[16]*sin(v[4] - v[11]) - L[3]*v[17]*sin(v[5] - v[11]) - L[4]*v[18]*sin(v[6] - v[11]) - L[5]*v[19]*sin(v[7] - v[11]) - L[6]*v[20]*sin(v[8] - v[11]) - L[7]*v[21]*sin(v[9] - v[11]) - L[8]*v[22]*sin(v[10] - v[11]) + v[14]*sin(v[11]))))/2. + (M[9]*(-(L[9]*v[23]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[11])) - cos(v[11])*L[9]*v[23]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.)))/2. - (M[9]*(-(L[9]*v[23]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + (cos(v[11])*L[9]*v[23])/2.)*sin(v[11])) - L[9]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - (cos(v[11])*L[9]*pow(v[23],2))/2.)*sin(v[11]) - cos(v[11])*L[9]*v[23]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - (L[9]*v[23]*sin(v[11]))/2.) + cos(v[11])*L[9]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - (L[9]*pow(v[23],2)*sin(v[11]))/2.)))/2. - L[9]*sin(v[11])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + cos(v[11])*L[9]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))) + (M[10]*(-2*L[9]*v[23]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[11]) - 2*cos(v[11])*L[9]*v[23]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-2*L[9]*v[23]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[11]) - 2*L[9]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[11]) - 2*cos(v[11])*L[9]*v[23]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + 2*cos(v[11])*L[9]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - (L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;
 coefMat[11] = -(L[10]*M[10]*sin(v[12]))/2.;
 coefMat[23] = (cos(v[12])*L[10]*M[10])/2.;
 coefMat[35] = (M[10]*(cos(v[3])*cos(v[12])*L[1]*L[10] + L[1]*L[10]*sin(v[3])*sin(v[12])))/2.;
 coefMat[47] = (M[10]*(cos(v[4])*cos(v[12])*L[2]*L[10] + L[2]*L[10]*sin(v[4])*sin(v[12])))/2.;
 coefMat[59] = (M[10]*(cos(v[5])*cos(v[12])*L[3]*L[10] + L[3]*L[10]*sin(v[5])*sin(v[12])))/2.;
 coefMat[71] = (M[10]*(cos(v[6])*cos(v[12])*L[4]*L[10] + L[4]*L[10]*sin(v[6])*sin(v[12])))/2.;
 coefMat[83] = (M[10]*(cos(v[7])*cos(v[12])*L[5]*L[10] + L[5]*L[10]*sin(v[7])*sin(v[12])))/2.;
 coefMat[95] = (M[10]*(cos(v[8])*cos(v[12])*L[6]*L[10] + L[6]*L[10]*sin(v[8])*sin(v[12])))/2.;
 coefMat[107] = (M[10]*(cos(v[9])*cos(v[12])*L[7]*L[10] + L[7]*L[10]*sin(v[9])*sin(v[12])))/2.;
 coefMat[119] = (M[10]*(cos(v[10])*cos(v[12])*L[8]*L[10] + L[8]*L[10]*sin(v[10])*sin(v[12])))/2.;
 coefMat[131] = (M[10]*(cos(v[11])*cos(v[12])*L[9]*L[10] + L[9]*L[10]*sin(v[11])*sin(v[12])))/2.;
 coefMat[143] = (pow(L[10],2)*M[10])/12. + (M[10]*((pow(cos(v[12]),2)*pow(L[10],2))/2. + (pow(L[10],2)*pow(sin(v[12]),2))/2.))/2.;
 rhsVec[11] = tauR + forceRY*cos(v[12])*L[10] - (Cs*pow(L[10],3)*v[24])/12. - forceRX*L[10]*sin(v[12]) - (L[10]*sin(v[12])*(-(Cs*L[10]*sin(v[12])*(-2*cos(v[12])*v[14] - 2*cos(v[3] - v[12])*L[1]*v[15] - 2*cos(v[4] - v[12])*L[2]*v[16] - 2*cos(v[5] - v[12])*L[3]*v[17] - 2*cos(v[6] - v[12])*L[4]*v[18] - 2*cos(v[7] - v[12])*L[5]*v[19] - 2*cos(v[8] - v[12])*L[6]*v[20] - 2*cos(v[9] - v[12])*L[7]*v[21] - 2*cos(v[10] - v[12])*L[8]*v[22] - 2*cos(v[11] - v[12])*L[9]*v[23] - L[10]*v[24] + 2*v[13]*sin(v[12])))/2. - Cv*cos(v[12])*L[10]*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))))/2. + (cos(v[12])*L[10]*(-(Cs*cos(v[12])*L[10]*(2*cos(v[12])*v[14] + 2*cos(v[3] - v[12])*L[1]*v[15] + 2*cos(v[4] - v[12])*L[2]*v[16] + 2*cos(v[5] - v[12])*L[3]*v[17] + 2*cos(v[6] - v[12])*L[4]*v[18] + 2*cos(v[7] - v[12])*L[5]*v[19] + 2*cos(v[8] - v[12])*L[6]*v[20] + 2*cos(v[9] - v[12])*L[7]*v[21] + 2*cos(v[10] - v[12])*L[8]*v[22] + 2*cos(v[11] - v[12])*L[9]*v[23] + L[10]*v[24] - 2*v[13]*sin(v[12])))/2. - Cv*L[10]*sin(v[12])*(cos(v[12])*v[13] - L[1]*v[15]*sin(v[3] - v[12]) - L[2]*v[16]*sin(v[4] - v[12]) - L[3]*v[17]*sin(v[5] - v[12]) - L[4]*v[18]*sin(v[6] - v[12]) - L[5]*v[19]*sin(v[7] - v[12]) - L[6]*v[20]*sin(v[8] - v[12]) - L[7]*v[21]*sin(v[9] - v[12]) - L[8]*v[22]*sin(v[10] - v[12]) - L[9]*v[23]*sin(v[11] - v[12]) + v[14]*sin(v[12]))))/2. + (M[10]*(-(L[10]*v[24]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[12])) - cos(v[12])*L[10]*v[24]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.)))/2. - (M[10]*(-(L[10]*v[24]*(v[14] + cos(v[3])*L[1]*v[15] + cos(v[4])*L[2]*v[16] + cos(v[5])*L[3]*v[17] + cos(v[6])*L[4]*v[18] + cos(v[7])*L[5]*v[19] + cos(v[8])*L[6]*v[20] + cos(v[9])*L[7]*v[21] + cos(v[10])*L[8]*v[22] + cos(v[11])*L[9]*v[23] + (cos(v[12])*L[10]*v[24])/2.)*sin(v[12])) - L[10]*(-(cos(v[3])*L[1]*pow(v[15],2)) - cos(v[4])*L[2]*pow(v[16],2) - cos(v[5])*L[3]*pow(v[17],2) - cos(v[6])*L[4]*pow(v[18],2) - cos(v[7])*L[5]*pow(v[19],2) - cos(v[8])*L[6]*pow(v[20],2) - cos(v[9])*L[7]*pow(v[21],2) - cos(v[10])*L[8]*pow(v[22],2) - cos(v[11])*L[9]*pow(v[23],2) - (cos(v[12])*L[10]*pow(v[24],2))/2.)*sin(v[12]) - cos(v[12])*L[10]*v[24]*(v[13] - L[1]*v[15]*sin(v[3]) - L[2]*v[16]*sin(v[4]) - L[3]*v[17]*sin(v[5]) - L[4]*v[18]*sin(v[6]) - L[5]*v[19]*sin(v[7]) - L[6]*v[20]*sin(v[8]) - L[7]*v[21]*sin(v[9]) - L[8]*v[22]*sin(v[10]) - L[9]*v[23]*sin(v[11]) - (L[10]*v[24]*sin(v[12]))/2.) + cos(v[12])*L[10]*(-(L[1]*pow(v[15],2)*sin(v[3])) - L[2]*pow(v[16],2)*sin(v[4]) - L[3]*pow(v[17],2)*sin(v[5]) - L[4]*pow(v[18],2)*sin(v[6]) - L[5]*pow(v[19],2)*sin(v[7]) - L[6]*pow(v[20],2)*sin(v[8]) - L[7]*pow(v[21],2)*sin(v[9]) - L[8]*pow(v[22],2)*sin(v[10]) - L[9]*pow(v[23],2)*sin(v[11]) - (L[10]*pow(v[24],2)*sin(v[12]))/2.)))/2.;

 // ===================
    
    
}
