(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    934023,      14484]*)
(*NotebookOutlinePosition[    934668,      14506]*)
(*  CellTagsIndexPosition[    934624,      14502]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[{\(mySimplify[expr_] := Chop[expr];\), "\[IndentingNewLine]", 
    StyleBox[\(Print["\<Generalized coordinates and drag forces ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(n = 10;\), "\[IndentingNewLine]", 
    StyleBox[\(\[Mu] = 10\^\(-3\);\),
      FontColor->GrayLevel[0.666667]], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[\(reNo = 1.0;\),
        FontColor->GrayLevel[0.666667]], "\[IndentingNewLine]", 
      StyleBox[
        RowBox[{"(*", " ", 
          RowBox[{
            
            StyleBox[\(c\_S = \(4\ \[Pi]\ \[Mu]\)\/\(1\/2 - 0.577 - \
Log[reNo\/8]\)\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[";",
              FontColor->GrayLevel[0.666667]], "\[IndentingNewLine]", 
            StyleBox[\(c\_V\  = \(\[Mu]\ 2\ \[Pi]\ 0.1\)\/0.1\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[";",
              FontColor->GrayLevel[0.666667]]}], " ", "*)"}],
        FontColor->GrayLevel[
        0.666667]]}], "\[IndentingNewLine]", \(w\_0 = {x\_L[t], 
          y\_L[t]};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"For", "[", 
        RowBox[{\(a = 1\), ",", \(a \[LessEqual] n\), ",", 
          "\[IndentingNewLine]", 
          RowBox[{\(Print[a]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ \[Lambda]\_a = 1.0; \[IndentingNewLine]m\_a = 
                  1.0;\ *) \),
              FontColor->GrayLevel[0.666667]], 
            "\[IndentingNewLine]", \(th\_a = \[Theta]\_a[t]\), ";", 
            "\[IndentingNewLine]", \(vec\_a = {Cos[th\_a], Sin[th\_a]}\), ";",
             "\[IndentingNewLine]", \(p\_a = 
              w\_\(a - 1\) + \[Lambda]\_a\/2\ vec\_a\), ";", 
            "\[IndentingNewLine]", \(w\_a = 
              w\_\(a - 1\) + \[Lambda]\_a\ vec\_a\), ";", 
            "\[IndentingNewLine]", \(v\_a = D[p\_a, t]\), ";", 
            "\[IndentingNewLine]", \(rotMat\_a = {{Cos[th\_a], 
                  Sin[th\_a]}, {\(-Sin[th\_a]\), Cos[th\_a]}}\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ 
                For\ an\ infinidecimal\ point\ on\ segment\ a\ *) \),
              Background->GrayLevel[0.900008]], 
            "\[IndentingNewLine]", \(pPt\_a = 
              p\_a + s\ {Cos[th\_a], Sin[th\_a]}\), ";", 
            "\[IndentingNewLine]", \(vPt\_a = D[pPt\_a, t]\), ";", 
            "\[IndentingNewLine]", \(vPtLocal\_a = rotMat\_a . vPt\_a\), ";", 
            "\[IndentingNewLine]", \(fPtDrag\_a = 
              Inverse[rotMat\_a] . {\(-c\_V\)\ vPtLocal\_a[\([1]\)], \
\(-c\_S\)\ vPtLocal\_a[\([2]\)]}\), ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ Integrating\ *) \),
              Background->GrayLevel[0.900008]], 
            "\[IndentingNewLine]", \(fDrag\_a = 
              mySimplify[
                Integrate[
                  fPtDrag\_a, {s, \(-\(\[Lambda]\_a\/2\)\), \
\[Lambda]\_a\/2}]]\), ";", 
            "\[IndentingNewLine]", \(tauDrag\_a = 
              mySimplify[
                Integrate[
                  s\ \((fPtDrag\_a[\([2]\)]\ Cos[th\_a] - 
                        fPtDrag\_a[\([1]\)]\ Sin[
                            th\_a])\), {s, \(-\(\[Lambda]\_a\/2\)\), \
\[Lambda]\_a\/2}]]\), ";", "\[IndentingNewLine]", \(a++\)}]}], "]"}], 
      ";"}], "\[IndentingNewLine]", 
    StyleBox[\(Print["\<Kinetic Energy ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(ke = 
        mySimplify[\[Sum]\+\(k = 1\)\%n\((1\/2\ m\_k\ \((v\_k . v\_k)\) + 
                1\/2\ \(m\_k\ \[Lambda]\_k\^2\)\/12\ \((D[th\_k, \
t])\)\^2)\)];\), "\[IndentingNewLine]", 
    StyleBox[\(Print["\<Generalized forces ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(q\_XL = {f\_LX[t], f\_LY[t]} . 
            D[w\_0, x\_L[t]] + \[Sum]\+\(k = 1\)\%n\((fDrag\_k . 
                D[p\_k, x\_L[t]])\) + {f\_RX[t], f\_RY[t]} . 
            D[w\_n, x\_L[t]];\), "\[IndentingNewLine]", \(q\_YL = {f\_LX[t], 
              f\_LY[t]} . 
            D[w\_0, y\_L[t]] + \[Sum]\+\(k = 1\)\%n\((fDrag\_k . 
                D[p\_k, y\_L[t]])\) + {f\_RX[t], f\_RY[t]} . 
            D[w\_n, y\_L[t]];\), "\[IndentingNewLine]", \(For[a = 1, 
      a \[LessEqual] 
        n, \[IndentingNewLine]q\_a = {f\_LX[t], f\_LY[t]} . 
            D[w\_0, \[Theta]\_a[t]] + \[Sum]\+\(k = 1\)\%n\((fDrag\_k . 
                D[p\_k, \[Theta]\_a[t]])\) + {f\_RX[t], f\_RY[t]} . 
            D[w\_n, \[Theta]\_a[t]] + 
          tauDrag\_a; \[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", \
\(q\_1 = q\_1 + \[Tau]\_L[t];\), "\[IndentingNewLine]", \(q\_n = 
        q\_n + \[Tau]\_R[t];\), "\[IndentingNewLine]", 
    StyleBox[\(Print["\<The LHS of the equations ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(Print[
        1];\), "\[IndentingNewLine]", \(eqLHS\_XL = 
        mySimplify[
          D[D[ke, \(x\_L'\)[t]], t] - D[ke, x\_L[t]] - 
            q\_XL];\), "\[IndentingNewLine]", \(Print[
        2];\), "\[IndentingNewLine]", \(eqLHS\_YL = 
        mySimplify[
          D[D[ke, \(y\_L'\)[t]], t] - D[ke, y\_L[t]] - 
            q\_YL];\), "\[IndentingNewLine]", 
    RowBox[{\(For[a = 1, 
        a \[LessEqual] n, \[IndentingNewLine]Print[
          a + 2]; \[IndentingNewLine]eqLHS\_a = 
          mySimplify[
            D[D[ke, \(\[Theta]\_a'\)[t]], t] - D[ke, \[Theta]\_a[t]] - 
              q\_a]; \[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", 
      StyleBox[\( (*\ Aux\ equations\ for\ position\ control\ *) \),
        Background->GrayLevel[
        0.900008]]}], "\[IndentingNewLine]", \(eqLHS\_XR = 
        D[x\_R[t] - w\_n[\([1]\)], {t, 
            2}];\), "\[IndentingNewLine]", \(eqLHS\_YR = 
        D[y\_R[t] - w\_n[\([2]\)], {t, 2}];\), "\[IndentingNewLine]", 
    StyleBox[\(Print["\<The ODEs ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(varReplacement = 
        Table[Null, {2\ n + 
              8}];\), "\n", \(varReplacement[\([1]\)] = \(x\_L'\)[t] \[Rule] 
          dx\_L[t];\), "\n", \(varReplacement[\([2]\)] = \(y\_L'\)[t] \[Rule] 
          dy\_L[t];\), "\n", \(varReplacement[\([3]\)] = \(x\_L''\)[
            t] \[Rule] 
          ddx\_L[t];\), "\n", \(varReplacement[\([4]\)] = \(y\_L''\)[
            t] \[Rule] 
          ddy\_L[t];\), "\[IndentingNewLine]", \(varReplacement[\([5]\)] = \
\(x\_R'\)[t] \[Rule] 
          dx\_R[t];\), "\n", \(varReplacement[\([6]\)] = \(y\_R'\)[t] \[Rule] 
          dy\_R[t];\), "\n", \(varReplacement[\([7]\)] = \(x\_R''\)[
            t] \[Rule] 
          ddx\_R[t];\), "\n", \(varReplacement[\([8]\)] = \(y\_R''\)[
            t] \[Rule] ddy\_R[t];\), "\[IndentingNewLine]", \(For[a = 1, 
        a \[LessEqual] n, 
        varReplacement[\([a + 8]\)] = \(\[Theta]\_a'\)[t] \[Rule] 
            d\[Theta]\_a[t]; \(a++\)];\), "\[IndentingNewLine]", 
    RowBox[{\(For[a = 1, a \[LessEqual] n, 
          varReplacement[\([a + n + 8]\)] = \(\[Theta]\_a''\)[
                t] \[Rule] \(d\[Theta]\_a'\)[t]; \(a++\)];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(varList = 
        Table[Null, {n + 4}];\), "\[IndentingNewLine]", \(varList[\([1]\)] = 
        f\_LX[t];\), "\n", \(varList[\([2]\)] = 
        f\_LY[t];\), "\n", \(varList[\([3]\)] = 
        f\_RX[t];\), "\n", \(varList[\([4]\)] = 
        f\_RY[t];\), "\[IndentingNewLine]", 
    RowBox[{\(For[a = 1, a \[LessEqual] n, 
          varList[\([a + 4]\)] = \(d\[Theta]\_a'\)[t]; \(a++\)];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(mainEqns = 
        Table[Null, {n + 4}];\), "\[IndentingNewLine]", \(mainEqns[\([1]\)] = 
        eqLHS\_XL;\), "\[IndentingNewLine]", \(mainEqns[\([2]\)] = 
        eqLHS\_YL;\), "\[IndentingNewLine]", \(mainEqns[\([3]\)] = 
        eqLHS\_XR;\), "\n", \(mainEqns[\([4]\)] = 
        eqLHS\_YR;\), "\[IndentingNewLine]", \(For[a = 1, a \[LessEqual] n, 
        mainEqns[\([a + 4]\)] = eqLHS\_a; \(a++\)];\), "\[IndentingNewLine]", 
  
    RowBox[{\(mainEqnsReplaced = mainEqns\  /. \ varReplacement;\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(primesZeroReplace = 
        Table[Null, {n + 4}];\), "\[IndentingNewLine]", 
    RowBox[{\(For[a = 1, a \[LessEqual] n + 4, 
        primesZeroReplace[\([a]\)] = varList[\([a]\)] \[Rule] 0; \ \(a++\)]\),
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
      StyleBox[\( (*\ 
          Computing\ the\ LHS\ matrix\ and\ the\ RHS\ vector\ \ *) \),
        Background->GrayLevel[0.900008]]}], "\[IndentingNewLine]", \(matLHS = 
        Table[Null, {n + 4}, {n + 4}];\), "\[IndentingNewLine]", \(vecRHS = 
        Table[Null, {n + 4}];\), "\[IndentingNewLine]", \(For[a = 1, 
      a \[LessEqual] n + 4, \[IndentingNewLine]Print[
        a]; \[IndentingNewLine]For[b = 1, 
        b \[LessEqual] n + 4, \[IndentingNewLine]matLHS[\([a, b]\)] = 
          Chop[mySimplify[\ 
              D[mainEqnsReplaced[\([a]\)], 
                varList[\([b]\)]]\ ]]; \[IndentingNewLine]\(b++\)]; \
\[IndentingNewLine]vecRHS[\([a]\)] = \(-Chop[
            mySimplify[
              mainEqnsReplaced[\([a]\)]\  /. \ 
                primesZeroReplace]]\); \[IndentingNewLine]\(a++\)]\)}], \
"Input"],

Cell[BoxData[
    \("Generalized coordinates and drag forces ..."\)], "Print"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"],

Cell[BoxData[
    \(7\)], "Print"],

Cell[BoxData[
    \(8\)], "Print"],

Cell[BoxData[
    \(9\)], "Print"],

Cell[BoxData[
    \(10\)], "Print"],

Cell[BoxData[
    \("Kinetic Energy ..."\)], "Print"],

Cell[BoxData[
    \("Generalized forces ..."\)], "Print"],

Cell[BoxData[
    \("The LHS of the equations ..."\)], "Print"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"],

Cell[BoxData[
    \(7\)], "Print"],

Cell[BoxData[
    \(8\)], "Print"],

Cell[BoxData[
    \(9\)], "Print"],

Cell[BoxData[
    \(10\)], "Print"],

Cell[BoxData[
    \(11\)], "Print"],

Cell[BoxData[
    \(12\)], "Print"],

Cell[BoxData[
    \("The ODEs ..."\)], "Print"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"],

Cell[BoxData[
    \(7\)], "Print"],

Cell[BoxData[
    \(8\)], "Print"],

Cell[BoxData[
    \(9\)], "Print"],

Cell[BoxData[
    \(10\)], "Print"],

Cell[BoxData[
    \(11\)], "Print"],

Cell[BoxData[
    \(12\)], "Print"],

Cell[BoxData[
    \(13\)], "Print"],

Cell[BoxData[
    \(14\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cformVarReplace = 
        Table[Null, {4\ n + 16}];\)\), "\[IndentingNewLine]", 
    \(\(For[a = 1, 
        a \[LessEqual] 
          n, \[IndentingNewLine]cformVarReplace[\([a]\)] = \[Theta]\_a[
              t] \[Rule] 
            Th[\([a]\)]; \[IndentingNewLine]cformVarReplace[\([a + n]\)] = 
          d\[Theta]\_a[t] \[Rule] 
            dTh[\([a]\)]; \[IndentingNewLine]\(a++\)];\)\), "\
\[IndentingNewLine]", 
    \(For[a = 1, 
      a \[LessEqual] n, \[IndentingNewLine]cformVarReplace[\([a + 2\ n]\)] = 
        m\_a \[Rule] 
          M[\([a]\)]; \[IndentingNewLine]cformVarReplace[\([a + 
              3\ n]\)] = \[Lambda]\_a \[Rule] 
          L[\([a]\)]; \[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ n + 1]\)] = 
        c\_V \[Rule] Cv;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ n + 2]\)] = 
        c\_S \[Rule] Cs;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ n + 3]\)] = \[Tau]\_L[t] \[Rule] 
          tauL;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ n + 4]\)] = \[Tau]\_R[t] \[Rule] 
          tauR;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ n + 5]\)] = x\_L[t] \[Rule] xL;\)\), "\n", 
    \(\(cformVarReplace[\([4\ n + 6]\)] = 
        y\_L[t] \[Rule] yL;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ n + 7]\)] = dx\_L[t] \[Rule] dxL;\)\), "\n", 
    \(\(cformVarReplace[\([4\ n + 8]\)] = 
        dy\_L[t] \[Rule] dyL;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ n + 9]\)] = ddx\_L[t] \[Rule] ddxL;\)\), "\n", 
    \(\(cformVarReplace[\([4\ n + 10]\)] = 
        ddy\_L[t] \[Rule] ddyL;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ n + 11]\)] = x\_R[t] \[Rule] xR;\)\), "\n", 
    \(\(cformVarReplace[\([4\ n + 12]\)] = 
        y\_R[t] \[Rule] yR;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ n + 13]\)] = dx\_R[t] \[Rule] dxR;\)\), "\n", 
    \(\(cformVarReplace[\([4\ n + 14]\)] = 
        dy\_R[t] \[Rule] dyR;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ n + 15]\)] = 
        ddx\_R[t] \[Rule] ddxR;\)\), "\n", 
    \(\(\(cformVarReplace[\([4\ n + 16]\)] = 
        ddy\_R[t] \[Rule] ddyR;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(matLHS\  // \ MatrixForm\), "\n", 
    \(vecRHS\  // \ MatrixForm\), "\[IndentingNewLine]", 
    \(\(\(cformVarReplace\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(outCString = "\<\>";\)\), "\[IndentingNewLine]", 
    \(For[a = 1, 
      a \[LessEqual] n + 4, \[IndentingNewLine]For[b = 1, 
        b \[LessEqual] n + 4, \[IndentingNewLine]outCString = 
          outCString <> "\<\n coefMat[\>" <> 
            ToString[CForm[\((b - 1)\)\ \((n + 4)\) + a - 1]] <> "\<] = \>" <> 
            ToString[
              CForm[matLHS[\([a, b]\)]\  /. \ 
                  cformVarReplace]] <> "\<;\>"; \[IndentingNewLine]\(b++\)]; \
\[IndentingNewLine]outCString = 
        outCString <> "\<\n rhsVec[\>" <> 
          ToString[CForm[a - 1]] <> "\<] = \>" <> 
          ToString[
            CForm[vecRHS[\([a]\)]\  /. \ 
                cformVarReplace]] <> "\<;\>"; \[IndentingNewLine]\(a++\)]\), \
"\[IndentingNewLine]", 
    \(\(outCString = 
        StringReplace[
          outCString, {"\<Cos\>" \[Rule] "\<cos\>", "\<Sin\>" \[Rule] \
"\<sin\>", "\<Tan\>" \[Rule] "\<tan\>", "\<Power\>" \[Rule] "\<pow\>"}];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[outCString];\)\), "\[IndentingNewLine]", 
    \(\(SetSystemOptions["\<BinaryFormat\>" -> True];\)\), "\n", 
    \(\(BinaryWrite["\<boom10bb.txt\>", 
        outCString];\)\), "\[IndentingNewLine]", 
    \(\(Close["\<boom10bb.txt\>"];\)\)}], "Input"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(Th \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(Th \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(dTh \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than \
depth of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Part :: \\\"partd\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(M \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(L \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(M \[LeftDoubleBracket] 2 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Part :: \\\"partd\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(tauR\\)\\\" is similar to existing symbol \\\
\"\\!\\(tauL\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"spell"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(ddxL\\)\\\" is similar to existing symbols \
\\!\\({ddx, dxL}\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"spell"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(ddyL\\)\\\" is similar to existing symbols \
\\!\\({ddxL, ddy, dyL}\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"spell"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(ddxR\\)\\\" is similar to existing symbols \
\\!\\({ddx, ddxL, dxR}\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"spell"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(ddyR\\)\\\" is similar to existing symbols \
\\!\\({ddxR, ddy, ddyL, dyR}\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-1\), "0", \(-1\), 
              "0", \(\(-\(1\/2\)\)\ Sin[\[Theta]\_1[t]]\ m\_1\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_2\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_3\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_4\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_5\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_6\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_7\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_8\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[t]]\ m\_9\ \[Lambda]\_1 - 
                Sin[\[Theta]\_1[
                      t]]\ m\_10\ \[Lambda]\_1\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_2[t]]\ m\_2\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_3\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_4\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_5\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_6\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_7\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_8\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[t]]\ m\_9\ \[Lambda]\_2 - 
                Sin[\[Theta]\_2[
                      t]]\ m\_10\ \[Lambda]\_2\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_3[t]]\ m\_3\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_4\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_5\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_6\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_7\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_8\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[t]]\ m\_9\ \[Lambda]\_3 - 
                Sin[\[Theta]\_3[
                      t]]\ m\_10\ \[Lambda]\_3\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_4[t]]\ m\_4\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[t]]\ m\_5\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[t]]\ m\_6\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[t]]\ m\_7\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[t]]\ m\_8\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[t]]\ m\_9\ \[Lambda]\_4 - 
                Sin[\[Theta]\_4[
                      t]]\ m\_10\ \[Lambda]\_4\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_5[t]]\ m\_5\ \[Lambda]\_5 - 
                Sin[\[Theta]\_5[t]]\ m\_6\ \[Lambda]\_5 - 
                Sin[\[Theta]\_5[t]]\ m\_7\ \[Lambda]\_5 - 
                Sin[\[Theta]\_5[t]]\ m\_8\ \[Lambda]\_5 - 
                Sin[\[Theta]\_5[t]]\ m\_9\ \[Lambda]\_5 - 
                Sin[\[Theta]\_5[
                      t]]\ m\_10\ \[Lambda]\_5\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_6[t]]\ m\_6\ \[Lambda]\_6 - 
                Sin[\[Theta]\_6[t]]\ m\_7\ \[Lambda]\_6 - 
                Sin[\[Theta]\_6[t]]\ m\_8\ \[Lambda]\_6 - 
                Sin[\[Theta]\_6[t]]\ m\_9\ \[Lambda]\_6 - 
                Sin[\[Theta]\_6[
                      t]]\ m\_10\ \[Lambda]\_6\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_7[t]]\ m\_7\ \[Lambda]\_7 - 
                Sin[\[Theta]\_7[t]]\ m\_8\ \[Lambda]\_7 - 
                Sin[\[Theta]\_7[t]]\ m\_9\ \[Lambda]\_7 - 
                Sin[\[Theta]\_7[
                      t]]\ m\_10\ \[Lambda]\_7\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_8[t]]\ m\_8\ \[Lambda]\_8 - 
                Sin[\[Theta]\_8[t]]\ m\_9\ \[Lambda]\_8 - 
                Sin[\[Theta]\_8[
                      t]]\ m\_10\ \[Lambda]\_8\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_9[t]]\ m\_9\ \[Lambda]\_9 - 
                Sin[\[Theta]\_9[
                      t]]\ m\_10\ \[Lambda]\_9\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_10[t]]\ m\_10\ \[Lambda]\_10\)},
            {"0", \(-1\), 
              "0", \(-1\), \(1\/2\ Cos[\[Theta]\_1[t]]\ m\_1\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_2\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_3\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_4\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_5\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_6\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_7\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_8\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[t]]\ m\_9\ \[Lambda]\_1 + 
                Cos[\[Theta]\_1[
                      t]]\ m\_10\ \[Lambda]\_1\), \(1\/2\ Cos[\[Theta]\_2[
                      t]]\ m\_2\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_3\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_4\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_5\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_6\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_7\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_8\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[t]]\ m\_9\ \[Lambda]\_2 + 
                Cos[\[Theta]\_2[
                      t]]\ m\_10\ \[Lambda]\_2\), \(1\/2\ Cos[\[Theta]\_3[
                      t]]\ m\_3\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_4\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_5\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_6\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_7\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_8\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[t]]\ m\_9\ \[Lambda]\_3 + 
                Cos[\[Theta]\_3[
                      t]]\ m\_10\ \[Lambda]\_3\), \(1\/2\ Cos[\[Theta]\_4[
                      t]]\ m\_4\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[t]]\ m\_5\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[t]]\ m\_6\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[t]]\ m\_7\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[t]]\ m\_8\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[t]]\ m\_9\ \[Lambda]\_4 + 
                Cos[\[Theta]\_4[
                      t]]\ m\_10\ \[Lambda]\_4\), \(1\/2\ Cos[\[Theta]\_5[
                      t]]\ m\_5\ \[Lambda]\_5 + 
                Cos[\[Theta]\_5[t]]\ m\_6\ \[Lambda]\_5 + 
                Cos[\[Theta]\_5[t]]\ m\_7\ \[Lambda]\_5 + 
                Cos[\[Theta]\_5[t]]\ m\_8\ \[Lambda]\_5 + 
                Cos[\[Theta]\_5[t]]\ m\_9\ \[Lambda]\_5 + 
                Cos[\[Theta]\_5[
                      t]]\ m\_10\ \[Lambda]\_5\), \(1\/2\ Cos[\[Theta]\_6[
                      t]]\ m\_6\ \[Lambda]\_6 + 
                Cos[\[Theta]\_6[t]]\ m\_7\ \[Lambda]\_6 + 
                Cos[\[Theta]\_6[t]]\ m\_8\ \[Lambda]\_6 + 
                Cos[\[Theta]\_6[t]]\ m\_9\ \[Lambda]\_6 + 
                Cos[\[Theta]\_6[
                      t]]\ m\_10\ \[Lambda]\_6\), \(1\/2\ Cos[\[Theta]\_7[
                      t]]\ m\_7\ \[Lambda]\_7 + 
                Cos[\[Theta]\_7[t]]\ m\_8\ \[Lambda]\_7 + 
                Cos[\[Theta]\_7[t]]\ m\_9\ \[Lambda]\_7 + 
                Cos[\[Theta]\_7[
                      t]]\ m\_10\ \[Lambda]\_7\), \(1\/2\ Cos[\[Theta]\_8[
                      t]]\ m\_8\ \[Lambda]\_8 + 
                Cos[\[Theta]\_8[t]]\ m\_9\ \[Lambda]\_8 + 
                Cos[\[Theta]\_8[
                      t]]\ m\_10\ \[Lambda]\_8\), \(1\/2\ Cos[\[Theta]\_9[
                      t]]\ m\_9\ \[Lambda]\_9 + 
                Cos[\[Theta]\_9[
                      t]]\ m\_10\ \[Lambda]\_9\), \(1\/2\ Cos[\[Theta]\_10[
                    t]]\ m\_10\ \[Lambda]\_10\)},
            {"0", "0", "0", 
              "0", \(Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\), \(Sin[\[Theta]\_2[
                    t]]\ \[Lambda]\_2\), \(Sin[\[Theta]\_3[
                    t]]\ \[Lambda]\_3\), \(Sin[\[Theta]\_4[
                    t]]\ \[Lambda]\_4\), \(Sin[\[Theta]\_5[
                    t]]\ \[Lambda]\_5\), \(Sin[\[Theta]\_6[
                    t]]\ \[Lambda]\_6\), \(Sin[\[Theta]\_7[
                    t]]\ \[Lambda]\_7\), \(Sin[\[Theta]\_8[
                    t]]\ \[Lambda]\_8\), \(Sin[\[Theta]\_9[
                    t]]\ \[Lambda]\_9\), \(Sin[\[Theta]\_10[
                    t]]\ \[Lambda]\_10\)},
            {"0", "0", "0", 
              "0", \(\(-Cos[\[Theta]\_1[
                      t]]\)\ \[Lambda]\_1\), \(\(-Cos[\[Theta]\_2[
                      t]]\)\ \[Lambda]\_2\), \(\(-Cos[\[Theta]\_3[
                      t]]\)\ \[Lambda]\_3\), \(\(-Cos[\[Theta]\_4[
                      t]]\)\ \[Lambda]\_4\), \(\(-Cos[\[Theta]\_5[
                      t]]\)\ \[Lambda]\_5\), \(\(-Cos[\[Theta]\_6[
                      t]]\)\ \[Lambda]\_6\), \(\(-Cos[\[Theta]\_7[
                      t]]\)\ \[Lambda]\_7\), \(\(-Cos[\[Theta]\_8[
                      t]]\)\ \[Lambda]\_8\), \(\(-Cos[\[Theta]\_9[
                      t]]\)\ \[Lambda]\_9\), \(\(-Cos[\[Theta]\_10[
                      t]]\)\ \[Lambda]\_10\)},
            {"0", 
              "0", \(Sin[\[Theta]\_1[
                    t]]\ \[Lambda]\_1\), \(\(-Cos[\[Theta]\_1[
                      t]]\)\ \[Lambda]\_1\), \(1\/12\ m\_1\ \[Lambda]\_1\%2 + 
                1\/2\ m\_1\ \((1\/2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 \
+ 1\/2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_2\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_3\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2 + 
                      2\ Sin[\[Theta]\_1[t]]\^2\ \[Lambda]\_1\%2)\)\), \(1\/2\
\ m\_2\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_3\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\)\), \(1\/2\ \
m\_3\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\)\), \(1\/2\ \
m\_4\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\)\), \(1\/2\ \
m\_5\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\)\), \(1\/2\ \
m\_6\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_1\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_1\ \[Lambda]\_10)\)\)},
            {"0", 
              "0", \(Sin[\[Theta]\_2[
                    t]]\ \[Lambda]\_2\), \(\(-Cos[\[Theta]\_2[
                      t]]\)\ \[Lambda]\_2\), \(1\/2\ m\_2\ \((Cos[\[Theta]\_1[
                            t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_3\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_2[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_2)\)\), \(1\/12\ \
m\_2\ \[Lambda]\_2\%2 + 
                1\/2\ m\_2\ \((1\/2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 \
+ 1\/2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\) + 
                1\/2\ m\_3\ \((2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 + 
                      2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 + 
                      2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 + 
                      2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 + 
                      2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 + 
                      2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 + 
                      2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 + 
                      2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2 + 
                      2\ Sin[\[Theta]\_2[t]]\^2\ \[Lambda]\_2\%2)\)\), \(1\/2\
\ m\_3\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\)\), \(1\/2\ \
m\_4\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\)\), \(1\/2\ \
m\_5\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\)\), \(1\/2\ \
m\_6\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_2\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_2\ \[Lambda]\_10)\)\)},
            {"0", 
              "0", \(Sin[\[Theta]\_3[
                    t]]\ \[Lambda]\_3\), \(\(-Cos[\[Theta]\_3[
                      t]]\)\ \[Lambda]\_3\), \(1\/2\ m\_3\ \((Cos[\[Theta]\_1[
                            t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_3)\)\), \(1\/2\ \
m\_3\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_3[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_3)\)\), \(1\/12\ \
m\_3\ \[Lambda]\_3\%2 + 
                1\/2\ m\_3\ \((1\/2\ Cos[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2 \
+ 1\/2\ Sin[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2)\) + 
                1\/2\ m\_4\ \((2\ Cos[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2 + 
                      2\ Sin[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2 + 
                      2\ Sin[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2 + 
                      2\ Sin[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2 + 
                      2\ Sin[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2 + 
                      2\ Sin[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2 + 
                      2\ Sin[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2 + 
                      2\ Sin[\[Theta]\_3[t]]\^2\ \[Lambda]\_3\%2)\)\), \(1\/2\
\ m\_4\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\)\), \(1\/2\ \
m\_5\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\)\), \(1\/2\ \
m\_6\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_3\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_3\ \[Lambda]\_10)\)\)},
            {"0", 
              "0", \(Sin[\[Theta]\_4[
                    t]]\ \[Lambda]\_4\), \(\(-Cos[\[Theta]\_4[
                      t]]\)\ \[Lambda]\_4\), \(1\/2\ m\_4\ \((Cos[\[Theta]\_1[
                            t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_4)\)\), \(1\/2\ \
m\_4\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_4)\)\), \(1\/2\ \
m\_4\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_4[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_4)\)\), \(1\/12\ \
m\_4\ \[Lambda]\_4\%2 + 
                1\/2\ m\_4\ \((1\/2\ Cos[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2 \
+ 1\/2\ Sin[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2)\) + 
                1\/2\ m\_5\ \((2\ Cos[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2 + 
                      2\ Sin[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2 + 
                      2\ Sin[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2 + 
                      2\ Sin[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2 + 
                      2\ Sin[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2 + 
                      2\ Sin[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2 + 
                      2\ Sin[\[Theta]\_4[t]]\^2\ \[Lambda]\_4\%2)\)\), \(1\/2\
\ m\_5\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\)\), \(1\/2\ \
m\_6\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_4\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_4\ \[Lambda]\_10)\)\)},
            {"0", 
              "0", \(Sin[\[Theta]\_5[
                    t]]\ \[Lambda]\_5\), \(\(-Cos[\[Theta]\_5[
                      t]]\)\ \[Lambda]\_5\), \(1\/2\ m\_5\ \((Cos[\[Theta]\_1[
                            t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_5)\)\), \(1\/2\ \
m\_5\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_5)\)\), \(1\/2\ \
m\_5\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_5)\)\), \(1\/2\ \
m\_5\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_5[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_5)\)\), \(1\/12\ \
m\_5\ \[Lambda]\_5\%2 + 
                1\/2\ m\_5\ \((1\/2\ Cos[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2 \
+ 1\/2\ Sin[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2)\) + 
                1\/2\ m\_6\ \((2\ Cos[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2 + 
                      2\ Sin[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2 + 
                      2\ Sin[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2 + 
                      2\ Sin[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2 + 
                      2\ Sin[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2 + 
                      2\ Sin[\[Theta]\_5[t]]\^2\ \[Lambda]\_5\%2)\)\), \(1\/2\
\ m\_6\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_5\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_5\ \[Lambda]\_10)\)\)},
            {"0", 
              "0", \(Sin[\[Theta]\_6[
                    t]]\ \[Lambda]\_6\), \(\(-Cos[\[Theta]\_6[
                      t]]\)\ \[Lambda]\_6\), \(1\/2\ m\_6\ \((Cos[\[Theta]\_1[
                            t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_6\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_6\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_6\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_6)\)\), \(1\/2\ \
m\_6\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_6[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_6)\)\), \(1\/12\ \
m\_6\ \[Lambda]\_6\%2 + 
                1\/2\ m\_6\ \((1\/2\ Cos[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2 \
+ 1\/2\ Sin[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2)\) + 
                1\/2\ m\_7\ \((2\ Cos[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2 + 
                      2\ Sin[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2 + 
                      2\ Sin[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2 + 
                      2\ Sin[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2 + 
                      2\ Sin[\[Theta]\_6[t]]\^2\ \[Lambda]\_6\%2)\)\), \(1\/2\
\ m\_7\ \((Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_6\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_6\ \[Lambda]\_10)\)\)},
            {"0", 
              "0", \(Sin[\[Theta]\_7[
                    t]]\ \[Lambda]\_7\), \(\(-Cos[\[Theta]\_7[
                      t]]\)\ \[Lambda]\_7\), \(1\/2\ m\_7\ \((Cos[\[Theta]\_1[
                            t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_7)\)\), \(1\/2\ \
m\_7\ \((Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7 + 
                      Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_7[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_7)\)\), \(1\/12\ \
m\_7\ \[Lambda]\_7\%2 + 
                1\/2\ m\_7\ \((1\/2\ Cos[\[Theta]\_7[t]]\^2\ \[Lambda]\_7\%2 \
+ 1\/2\ Sin[\[Theta]\_7[t]]\^2\ \[Lambda]\_7\%2)\) + 
                1\/2\ m\_8\ \((2\ Cos[\[Theta]\_7[t]]\^2\ \[Lambda]\_7\%2 + 
                      2\ Sin[\[Theta]\_7[t]]\^2\ \[Lambda]\_7\%2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_7[t]]\^2\ \[Lambda]\_7\%2 + 
                      2\ Sin[\[Theta]\_7[t]]\^2\ \[Lambda]\_7\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_7[t]]\^2\ \[Lambda]\_7\%2 + 
                      2\ Sin[\[Theta]\_7[t]]\^2\ \[Lambda]\_7\%2)\)\), \(1\/2\
\ m\_8\ \((Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_7\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_7\ \[Lambda]\_10)\)\)},
            {"0", 
              "0", \(Sin[\[Theta]\_8[
                    t]]\ \[Lambda]\_8\), \(\(-Cos[\[Theta]\_8[
                      t]]\)\ \[Lambda]\_8\), \(1\/2\ m\_8\ \((Cos[\[Theta]\_1[
                            t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_8[
                            
                            t]]\ \[Lambda]\_6\ \[Lambda]\_8)\)\), \(1\/2\ \
m\_8\ \((Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8 + 
                      Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8 + 
                      2\ Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_8[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_8)\)\), \(1\/12\ \
m\_8\ \[Lambda]\_8\%2 + 
                1\/2\ m\_8\ \((1\/2\ Cos[\[Theta]\_8[t]]\^2\ \[Lambda]\_8\%2 \
+ 1\/2\ Sin[\[Theta]\_8[t]]\^2\ \[Lambda]\_8\%2)\) + 
                1\/2\ m\_9\ \((2\ Cos[\[Theta]\_8[t]]\^2\ \[Lambda]\_8\%2 + 
                      2\ Sin[\[Theta]\_8[t]]\^2\ \[Lambda]\_8\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_8[t]]\^2\ \[Lambda]\_8\%2 + 
                      2\ Sin[\[Theta]\_8[t]]\^2\ \[Lambda]\_8\%2)\)\), \(1\/2\
\ m\_9\ \((Cos[\[Theta]\_8[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_8\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_8[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_8\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_8[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_8\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_8[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_8\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_8[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_8\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_8[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_8\ \[Lambda]\_10)\)\)},
            {"0", 
              "0", \(Sin[\[Theta]\_9[
                    t]]\ \[Lambda]\_9\), \(\(-Cos[\[Theta]\_9[
                      t]]\)\ \[Lambda]\_9\), \(1\/2\ m\_9\ \((Cos[\[Theta]\_1[
                            t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_1\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_2\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_3\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_4\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_5\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_6\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_7\ \[Lambda]\_9)\)\), \(1\/2\ \
m\_9\ \((Cos[\[Theta]\_8[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_8\ \[Lambda]\_9 + 
                      Sin[\[Theta]\_8[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_8\ \[Lambda]\_9)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_8[t]]\ Cos[\[Theta]\_9[
                            t]]\ \[Lambda]\_8\ \[Lambda]\_9 + 
                      2\ Sin[\[Theta]\_8[t]]\ Sin[\[Theta]\_9[
                            t]]\ \[Lambda]\_8\ \[Lambda]\_9)\)\), \(1\/12\ \
m\_9\ \[Lambda]\_9\%2 + 
                1\/2\ m\_9\ \((1\/2\ Cos[\[Theta]\_9[t]]\^2\ \[Lambda]\_9\%2 \
+ 1\/2\ Sin[\[Theta]\_9[t]]\^2\ \[Lambda]\_9\%2)\) + 
                1\/2\ m\_10\ \((2\ Cos[\[Theta]\_9[t]]\^2\ \[Lambda]\_9\%2 + 
                      2\ Sin[\[Theta]\_9[t]]\^2\ \[Lambda]\_9\%2)\)\), \(1\/2\
\ m\_10\ \((Cos[\[Theta]\_9[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_9\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_9[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_9\ \[Lambda]\_10)\)\)},
            {"0", 
              "0", \(Sin[\[Theta]\_10[
                    t]]\ \[Lambda]\_10\), \(\(-Cos[\[Theta]\_10[
                      t]]\)\ \[Lambda]\_10\), \(1\/2\ m\_10\ \
\((Cos[\[Theta]\_1[t]]\ Cos[\[Theta]\_10[t]]\ \[Lambda]\_1\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_1[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_1\ \[Lambda]\_10)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_2[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_2\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_2[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_2\ \[Lambda]\_10)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_3[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_3\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_3[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_3\ \[Lambda]\_10)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_4[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_4\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_4[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_4\ \[Lambda]\_10)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_5[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_5\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_5[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_5\ \[Lambda]\_10)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_6[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_6\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_6[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_6\ \[Lambda]\_10)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_7[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_7\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_7[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_7\ \[Lambda]\_10)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_8[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_8\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_8[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_8\ \[Lambda]\_10)\)\), \(1\/2\ \
m\_10\ \((Cos[\[Theta]\_9[t]]\ Cos[\[Theta]\_10[
                          t]]\ \[Lambda]\_9\ \[Lambda]\_10 + 
                    Sin[\[Theta]\_9[t]]\ Sin[\[Theta]\_10[
                          t]]\ \[Lambda]\_9\ \[Lambda]\_10)\)\), \(1\/12\ \
m\_10\ \[Lambda]\_10\%2 + 
                1\/2\ m\_10\ \((1\/2\ Cos[\[Theta]\_10[t]]\^2\ \
\[Lambda]\_10\%2 + 1\/2\ Sin[\[Theta]\_10[t]]\^2\ \[Lambda]\_10\%2)\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", 
        TagBox[GridBox[{
              {\(\(-Sin[\[Theta]\_1[t]]\^2\)\ c\_S\ \[Lambda]\_1\ dx\_L[t] - 
                  Cos[\[Theta]\_1[t]]\^2\ c\_V\ \[Lambda]\_1\ dx\_L[t] - 
                  Sin[\[Theta]\_2[t]]\^2\ c\_S\ \[Lambda]\_2\ dx\_L[t] - 
                  Cos[\[Theta]\_2[t]]\^2\ c\_V\ \[Lambda]\_2\ dx\_L[t] - 
                  Sin[\[Theta]\_3[t]]\^2\ c\_S\ \[Lambda]\_3\ dx\_L[t] - 
                  Cos[\[Theta]\_3[t]]\^2\ c\_V\ \[Lambda]\_3\ dx\_L[t] - 
                  Sin[\[Theta]\_4[t]]\^2\ c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                  Cos[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ dx\_L[t] + 
                  Cos[\[Theta]\_1[t]]\ Sin[\[Theta]\_1[
                        t]]\ c\_S\ \[Lambda]\_1\ dy\_L[t] - 
                  Cos[\[Theta]\_1[t]]\ Sin[\[Theta]\_1[
                        t]]\ c\_V\ \[Lambda]\_1\ dy\_L[t] + 
                  Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                        t]]\ c\_S\ \[Lambda]\_2\ dy\_L[t] - 
                  Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                        t]]\ c\_V\ \[Lambda]\_2\ dy\_L[t] + 
                  Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                        t]]\ c\_S\ \[Lambda]\_3\ dy\_L[t] - 
                  Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                        t]]\ c\_V\ \[Lambda]\_3\ dy\_L[t] + 
                  Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_4\ dy\_L[t] - 
                  Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_V\ \[Lambda]\_4\ dy\_L[t] + 
                  1\/2\ Sin[\[Theta]\_1[
                        t]]\ c\_S\ \[Lambda]\_1\%2\ d\[Theta]\_1[t] + 
                  Cos[\[Theta]\_1[t] - \[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                        t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_2\ d\[Theta]\_1[
                      t] + Cos[\[Theta]\_2[
                        t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_2[
                          t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_2\ d\[Theta]\_1[
                      t] + Cos[\[Theta]\_1[t] - \[Theta]\_3[
                          t]]\ Sin[\[Theta]\_3[
                        t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_3\ d\[Theta]\_1[
                      t] + Cos[\[Theta]\_3[
                        t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_3[
                          t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_3\ d\[Theta]\_1[
                      t] + Cos[\[Theta]\_1[t] - \[Theta]\_4[
                          t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ d\[Theta]\_1[
                      t] + Cos[\[Theta]\_4[
                        t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_4[
                          t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ d\[Theta]\_1[
                      t] - m\_1\ \((ddx\_L[t] - 
                        1\/2\ Cos[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2)\) + 
                  1\/2\ Sin[\[Theta]\_2[
                        t]]\ c\_S\ \[Lambda]\_2\%2\ d\[Theta]\_2[t] + 
                  Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                        t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_3\ d\[Theta]\_2[
                      t] + Cos[\[Theta]\_3[
                        t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_3[
                          t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_3\ d\[Theta]\_2[
                      t] + Cos[\[Theta]\_2[t] - \[Theta]\_4[
                          t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ d\[Theta]\_2[
                      t] + Cos[\[Theta]\_4[
                        t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                          t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ d\[Theta]\_2[
                      t] - m\_2\ \((ddx\_L[t] - 
                        Cos[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2)\) + 
                  1\/2\ Sin[\[Theta]\_3[
                        t]]\ c\_S\ \[Lambda]\_3\%2\ d\[Theta]\_3[t] + 
                  Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ d\[Theta]\_3[
                      t] + Cos[\[Theta]\_4[
                        t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                          t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ d\[Theta]\_3[
                      t] - m\_3\ \((ddx\_L[t] - 
                        Cos[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\) + 
                  1\/2\ Sin[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[t] - 
                  m\_4\ \((ddx\_L[t] - 
                        Cos[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\) - 
                  m\_5\ \((ddx\_L[t] - 
                        Cos[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Cos[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\) + 
                  1\/2\ \[Lambda]\_5\ \((2\ Cos[\[Theta]\_5[
                              t]]\ c\_V\ \((\(-Cos[\[Theta]\_5[t]]\)\ dx\_L[
                                  t] - Sin[\[Theta]\_5[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Sin[\[Theta]\_5[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_5[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - \[Lambda]\_5\ d\[Theta]\_5[t])\))\) - 
                  Cos[\[Theta]\_7[
                        t]]\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                              t]]\ dx\_L[t] + Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                  m\_6\ \((ddx\_L[t] - 
                        Cos[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Cos[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Cos[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\) + 
                  1\/2\ \[Lambda]\_6\ \((2\ Cos[\[Theta]\_6[
                              t]]\ c\_V\ \((\(-Cos[\[Theta]\_6[t]]\)\ dx\_L[
                                  t] - Sin[\[Theta]\_6[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Sin[\[Theta]\_6[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_6[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - \[Lambda]\_6\ d\[Theta]\_6[t])\))\) - 
                  1\/2\ Sin[\[Theta]\_7[
                        t]]\ c\_S\ \[Lambda]\_7\ \((2\ Sin[\[Theta]\_7[
                              t]]\ dx\_L[t] - 
                        2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] - 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t] - \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                  Cos[\[Theta]\_8[
                        t]]\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                              t]]\ dx\_L[t] + Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                  m\_7\ \((ddx\_L[t] - 
                        Cos[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Cos[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Cos[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        Cos[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) - 
                  1\/2\ Sin[\[Theta]\_8[
                        t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                              t]]\ dx\_L[t] - 
                        2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t] - \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                  Cos[\[Theta]\_9[
                        t]]\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                              t]]\ dx\_L[t] + Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                        Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                  m\_8\ \((ddx\_L[t] - 
                        Cos[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Cos[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Cos[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        Cos[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                        Cos[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) - 
                  1\/2\ Sin[\[Theta]\_9[
                        t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                              t]]\ dx\_L[t] - 
                        2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                        2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t] - \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                  Cos[\[Theta]\_10[
                        t]]\ c\_V\ \[Lambda]\_10\ \((Cos[\[Theta]\_10[
                              t]]\ dx\_L[t] + 
                        Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                        Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                        Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                  m\_9\ \((ddx\_L[t] - 
                        Cos[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Cos[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Cos[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        Cos[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                        Cos[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                        Cos[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) - 
                  1\/2\ Sin[\[Theta]\_10[
                        t]]\ c\_S\ \[Lambda]\_10\ \((2\ Sin[\[Theta]\_10[
                              t]]\ dx\_L[t] - 
                        2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                        2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                        2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                            t] - \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                  m\_10\ \((ddx\_L[t] - 
                        Cos[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Cos[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Cos[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Cos[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Cos[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        Cos[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                        Cos[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                        Cos[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                        Cos[\[Theta]\_9[
                              t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ \[Lambda]\_10\ d\[Theta]\_10[t]\^2)\)\)},
              {\(Cos[\[Theta]\_1[t]]\ Sin[\[Theta]\_1[
                        t]]\ c\_S\ \[Lambda]\_1\ dx\_L[t] - 
                  Cos[\[Theta]\_1[t]]\ Sin[\[Theta]\_1[
                        t]]\ c\_V\ \[Lambda]\_1\ dx\_L[t] + 
                  Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                        t]]\ c\_S\ \[Lambda]\_2\ dx\_L[t] - 
                  Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                        t]]\ c\_V\ \[Lambda]\_2\ dx\_L[t] + 
                  Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                        t]]\ c\_S\ \[Lambda]\_3\ dx\_L[t] - 
                  Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                        t]]\ c\_V\ \[Lambda]\_3\ dx\_L[t] + 
                  Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                  Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_V\ \[Lambda]\_4\ dx\_L[t] - 
                  Cos[\[Theta]\_1[t]]\^2\ c\_S\ \[Lambda]\_1\ dy\_L[t] - 
                  Sin[\[Theta]\_1[t]]\^2\ c\_V\ \[Lambda]\_1\ dy\_L[t] - 
                  Cos[\[Theta]\_2[t]]\^2\ c\_S\ \[Lambda]\_2\ dy\_L[t] - 
                  Sin[\[Theta]\_2[t]]\^2\ c\_V\ \[Lambda]\_2\ dy\_L[t] - 
                  Cos[\[Theta]\_3[t]]\^2\ c\_S\ \[Lambda]\_3\ dy\_L[t] - 
                  Sin[\[Theta]\_3[t]]\^2\ c\_V\ \[Lambda]\_3\ dy\_L[t] - 
                  Cos[\[Theta]\_4[t]]\^2\ c\_S\ \[Lambda]\_4\ dy\_L[t] - 
                  Sin[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ dy\_L[t] - 
                  1\/2\ Cos[\[Theta]\_1[
                        t]]\ c\_S\ \[Lambda]\_1\%2\ d\[Theta]\_1[t] - 
                  Cos[\[Theta]\_1[t] - \[Theta]\_2[t]]\ Cos[\[Theta]\_2[
                        t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_2\ d\[Theta]\_1[
                      t] + Sin[\[Theta]\_1[t] - \[Theta]\_2[
                          t]]\ Sin[\[Theta]\_2[
                        t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_2\ d\[Theta]\_1[
                      t] - Cos[\[Theta]\_1[t] - \[Theta]\_3[
                          t]]\ Cos[\[Theta]\_3[
                        t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_3\ d\[Theta]\_1[
                      t] + Sin[\[Theta]\_1[t] - \[Theta]\_3[
                          t]]\ Sin[\[Theta]\_3[
                        t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_3\ d\[Theta]\_1[
                      t] - Cos[\[Theta]\_1[t] - \[Theta]\_4[
                          t]]\ Cos[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ d\[Theta]\_1[
                      t] + Sin[\[Theta]\_1[t] - \[Theta]\_4[
                          t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ d\[Theta]\_1[
                      t] - m\_1\ \((ddy\_L[t] - 
                        1\/2\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2)\) - 
                  1\/2\ Cos[\[Theta]\_2[
                        t]]\ c\_S\ \[Lambda]\_2\%2\ d\[Theta]\_2[t] - 
                  Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Cos[\[Theta]\_3[
                        t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_3\ d\[Theta]\_2[
                      t] + Sin[\[Theta]\_2[t] - \[Theta]\_3[
                          t]]\ Sin[\[Theta]\_3[
                        t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_3\ d\[Theta]\_2[
                      t] - Cos[\[Theta]\_2[t] - \[Theta]\_4[
                          t]]\ Cos[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ d\[Theta]\_2[
                      t] + Sin[\[Theta]\_2[t] - \[Theta]\_4[
                          t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ d\[Theta]\_2[
                      t] - m\_2\ \((ddy\_L[t] - 
                        Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2)\) - 
                  1\/2\ Cos[\[Theta]\_3[
                        t]]\ c\_S\ \[Lambda]\_3\%2\ d\[Theta]\_3[t] - 
                  Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ d\[Theta]\_3[
                      t] + Sin[\[Theta]\_3[t] - \[Theta]\_4[
                          t]]\ Sin[\[Theta]\_4[
                        t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ d\[Theta]\_3[
                      t] - m\_3\ \((ddy\_L[t] - 
                        Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\) - 
                  1\/2\ Cos[\[Theta]\_4[
                        t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[t] - 
                  m\_4\ \((ddy\_L[t] - 
                        Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\) - 
                  m\_5\ \((ddy\_L[t] - 
                        Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\) - 
                  1\/2\ \[Lambda]\_5\ \((2\ Sin[\[Theta]\_5[
                              t]]\ c\_V\ \((Cos[\[Theta]\_5[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) + 
                        Cos[\[Theta]\_5[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_5[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + \[Lambda]\_5\ d\[Theta]\_5[t])\))\) - 
                  Sin[\[Theta]\_7[
                        t]]\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                              t]]\ dx\_L[t] + Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                  m\_6\ \((ddy\_L[t] - 
                        Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\) - 
                  1\/2\ \[Lambda]\_6\ \((2\ Sin[\[Theta]\_6[
                              t]]\ c\_V\ \((Cos[\[Theta]\_6[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) + 
                        Cos[\[Theta]\_6[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_6[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + \[Lambda]\_6\ d\[Theta]\_6[t])\))\) - 
                  1\/2\ Cos[\[Theta]\_7[
                        t]]\ c\_S\ \[Lambda]\_7\ \((\(-2\)\ Sin[\[Theta]\_7[
                              t]]\ dx\_L[t] + 
                        2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] + 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                        2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t] + \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                  Sin[\[Theta]\_8[
                        t]]\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                              t]]\ dx\_L[t] + Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                  m\_7\ \((ddy\_L[t] - 
                        Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) - 
                  1\/2\ Cos[\[Theta]\_8[
                        t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ Sin[\[Theta]\_8[
                              t]]\ dx\_L[t] + 
                        2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                        2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                        2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t] + \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                  Sin[\[Theta]\_9[
                        t]]\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                              t]]\ dx\_L[t] + Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                        Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                  m\_8\ \((ddy\_L[t] - 
                        Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                        Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) - 
                  1\/2\ Cos[\[Theta]\_9[
                        t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ Sin[\[Theta]\_9[
                              t]]\ dx\_L[t] + 
                        2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                        2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                        2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                        2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t] + \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                  Sin[\[Theta]\_10[
                        t]]\ c\_V\ \[Lambda]\_10\ \((Cos[\[Theta]\_10[
                              t]]\ dx\_L[t] + 
                        Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                        Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                        Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                        Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                        Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                        Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                        Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                        Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                        Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                        Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                  m\_9\ \((ddy\_L[t] - 
                        Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                        Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                        Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) - 
                  1\/2\ Cos[\[Theta]\_10[
                        t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\[Theta]\_10[
                              t]]\ dx\_L[t] + 
                        2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                        2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                        2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                        2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                        2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                        2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                        2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                        2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                        2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                        2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                            t] + \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                  m\_10\ \((ddy\_L[t] - 
                        Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                        Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                        Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                        Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                        Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                        Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                        Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                        Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                        Sin[\[Theta]\_9[
                              t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ \[Lambda]\_10\ d\[Theta]\_10[t]\^2)\)\)},
              {\(ddx\_L[t] - ddx\_R[t] - 
                  Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                  Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                  Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                  Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                  Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                  Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                  Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                  Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                  Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                  Cos[\[Theta]\_10[
                        t]]\ \[Lambda]\_10\ d\[Theta]\_10[t]\^2\)},
              {\(ddy\_L[t] - ddy\_R[t] - 
                  Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                  Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                  Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                  Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                  Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                  Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                  Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                  Sin[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                  Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                  Sin[\[Theta]\_10[
                        t]]\ \[Lambda]\_10\ d\[Theta]\_10[t]\^2\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_1\%3\ d\[Theta]\_1[t] + 
                  1\/2\ Cos[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((Cos[\[Theta]\_1[
                              t]]\ Sin[\[Theta]\_1[
                              t]]\ c\_S\ \[Lambda]\_1\ dx\_L[t] - 
                        Cos[\[Theta]\_1[t]]\ Sin[\[Theta]\_1[
                              t]]\ c\_V\ \[Lambda]\_1\ dx\_L[t] - 
                        Cos[\[Theta]\_1[t]]\^2\ c\_S\ \[Lambda]\_1\ dy\_L[
                            t] - Sin[\[Theta]\_1[t]]\^2\ c\_V\ \[Lambda]\_1\ \
dy\_L[t] - 1\/2\ Cos[\[Theta]\_1[t]]\ c\_S\ \[Lambda]\_1\%2\ d\[Theta]\_1[
                            t])\) - 
                  1\/2\ Sin[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_1[t]]\^2\)\ \
c\_S\ \[Lambda]\_1\ dx\_L[t] - 
                        Cos[\[Theta]\_1[t]]\^2\ c\_V\ \[Lambda]\_1\ dx\_L[
                            t] + Cos[\[Theta]\_1[t]]\ Sin[\[Theta]\_1[
                              t]]\ c\_S\ \[Lambda]\_1\ dy\_L[t] - 
                        Cos[\[Theta]\_1[t]]\ Sin[\[Theta]\_1[
                              t]]\ c\_V\ \[Lambda]\_1\ dy\_L[t] + 
                        1\/2\ Sin[\[Theta]\_1[
                              t]]\ c\_S\ \[Lambda]\_1\%2\ d\[Theta]\_1[
                            t])\) + 
                  1\/2\ m\_1\ \((\(-Sin[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              1\/2\ Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t])\) - 
                        Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              1\/2\ Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t])\))\) - 
                  1\/2\ m\_1\ \((\(-Sin[\[Theta]\_1[
                                t]]\)\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              1\/2\ Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t])\) - 
                        Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              1\/2\ Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t])\) - 
                        Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddx\_L[t] - 
                              1\/2\ Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2)\) \
+ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddy\_L[t] - 
                              1\/2\ Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2)\))\
\) + Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((Cos[\[Theta]\_2[
                              t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_2\ dx\_L[t] - 
                        Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_V\ \[Lambda]\_2\ dx\_L[t] - 
                        Cos[\[Theta]\_2[t]]\^2\ c\_S\ \[Lambda]\_2\ dy\_L[
                            t] - Sin[\[Theta]\_2[t]]\^2\ c\_V\ \[Lambda]\_2\ \
dy\_L[t] - Cos[\[Theta]\_1[t] - \[Theta]\_2[t]]\ Cos[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_2\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_2\ \
d\[Theta]\_1[t] - 1\/2\ Cos[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_2\%2\ d\[Theta]\_2[
                            t])\) - 
                  Sin[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_2[t]]\^2\)\ \
c\_S\ \[Lambda]\_2\ dx\_L[t] - 
                        Cos[\[Theta]\_2[t]]\^2\ c\_V\ \[Lambda]\_2\ dx\_L[
                            t] + Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_2\ dy\_L[t] - 
                        Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_V\ \[Lambda]\_2\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_2\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_2[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_2[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_2\ d\
\[Theta]\_1[t] + 1\/2\ Sin[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_2\%2\ d\[Theta]\_2[
                            t])\) + 
                  1\/2\ m\_2\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + 1\/2\ Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - 1\/2\ Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                  t])\))\) - 
                  1\/2\ m\_2\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + 1\/2\ Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - 1\/2\ Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t])\) - 
                        2\ Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2)\) \
+ 2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2)\))\
\) + Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\^2\ c\_S\ \[Lambda]\_3\ dy\_L[
                            t] - 
                        Sin[\[Theta]\_3[t]]\^2\ c\_V\ \[Lambda]\_3\ dy\_L[
                            t] - Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                t]]\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] - Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] + Sin[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] - 1\/2\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\%2\ d\[Theta]\_3[
                            t])\) - 
                  Sin[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_3[t]]\^2\)\ \
c\_S\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\^2\ c\_V\ \[Lambda]\_3\ dx\_L[
                            t] + Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\ dy\_L[t] - 
                        Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_3\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_3\ d\
\[Theta]\_1[t] + Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] + Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_3[
                                t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_3\ d\
\[Theta]\_2[t] + 1\/2\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\%2\ d\[Theta]\_3[
                            t])\) + 
                  1\/2\ m\_3\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t])\))\) - 
                  1\/2\ m\_3\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        2\ Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\) \
+ 2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\))\
\) + Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\^2\ c\_S\ \[Lambda]\_4\ dy\_L[
                            t] - Sin[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ \
dy\_L[t] - Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] - Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] + Sin[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] - Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] + Sin[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              
                              t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] - 1\/2\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[
                            t])\) - 
                  Sin[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_4[t]]\^2\)\ \
c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ dx\_L[
                            t] + Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\ dy\_L[t] - 
                        Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_4\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ d\
\[Theta]\_1[t] + Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ d\
\[Theta]\_2[t] + Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ d\
\[Theta]\_3[t] + 1\/2\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[
                            t])\) + 
                  1\/2\ m\_4\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t])\))\) - 
                  1\/2\ m\_4\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\) \
+ 2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \[Lambda]\_5\ \((2\ \
Cos[\[Theta]\_5[t]]\ c\_V\ \((\(-Cos[\[Theta]\_5[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Sin[\[Theta]\_5[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_5[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - \[Lambda]\_5\ d\[Theta]\_5[t])\))\) - 
                  1\/2\ Cos[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \[Lambda]\_5\ \((2\ \
Sin[\[Theta]\_5[t]]\ c\_V\ \((Cos[\[Theta]\_5[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) + 
                        Cos[\[Theta]\_5[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_5[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + \[Lambda]\_5\ d\[Theta]\_5[t])\))\) + 
                  1\/2\ m\_5\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t])\))\) - 
                  1\/2\ m\_5\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\) \
+ 2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \[Lambda]\_6\ \((2\ \
Cos[\[Theta]\_6[t]]\ c\_V\ \((\(-Cos[\[Theta]\_6[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Sin[\[Theta]\_6[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_6[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - \[Lambda]\_6\ d\[Theta]\_6[t])\))\) - 
                  1\/2\ Cos[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \[Lambda]\_6\ \((2\ \
Sin[\[Theta]\_6[t]]\ c\_V\ \((Cos[\[Theta]\_6[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) + 
                        Cos[\[Theta]\_6[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_6[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - 
                              Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                  t] - Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t])\))\) - 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\) \
+ 2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\))\
\) - Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Sin[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((2\ Sin[\[Theta]\_7[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  Cos[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Cos[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((\(-2\)\ \
Sin[\[Theta]\_7[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t])\))\) - 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) \
+ 2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\))\
\) - Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  Cos[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ \
Sin[\[Theta]\_8[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t])\))\) - 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) \
+ 2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\))\
\) - Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  Cos[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + 
                              Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                  t] + Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + 1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ 2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_1[
                        t]]\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_1[
                              t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        2\ Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\) + \[Tau]\_L[t]\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_2\%3\ d\[Theta]\_2[t] + 
                  1\/2\ Cos[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((Cos[\[Theta]\_2[
                              t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_2\ dx\_L[t] - 
                        Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_V\ \[Lambda]\_2\ dx\_L[t] - 
                        Cos[\[Theta]\_2[t]]\^2\ c\_S\ \[Lambda]\_2\ dy\_L[
                            t] - Sin[\[Theta]\_2[t]]\^2\ c\_V\ \[Lambda]\_2\ \
dy\_L[t] - Cos[\[Theta]\_1[t] - \[Theta]\_2[t]]\ Cos[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_2\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_2\ \
d\[Theta]\_1[t] - 1\/2\ Cos[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_2\%2\ d\[Theta]\_2[
                            t])\) - 
                  1\/2\ Sin[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_2[t]]\^2\)\ \
c\_S\ \[Lambda]\_2\ dx\_L[t] - 
                        Cos[\[Theta]\_2[t]]\^2\ c\_V\ \[Lambda]\_2\ dx\_L[
                            t] + Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_2\ dy\_L[t] - 
                        Cos[\[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_V\ \[Lambda]\_2\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_2[t]]\ Sin[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_2\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_2[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_2[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_2\ d\
\[Theta]\_1[t] + 1\/2\ Sin[\[Theta]\_2[
                              t]]\ c\_S\ \[Lambda]\_2\%2\ d\[Theta]\_2[
                            t])\) + 
                  1\/2\ m\_2\ \((\(-Sin[\[Theta]\_2[
                                t]]\)\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + 1\/2\ Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t])\) - 
                        Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - 1\/2\ Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                  t])\))\) - 
                  1\/2\ m\_2\ \((\(-Sin[\[Theta]\_2[
                                t]]\)\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + 1\/2\ Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t])\) - 
                        Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - 1\/2\ Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t])\) - 
                        Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2)\) \
+ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2)\))\
\) + Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\^2\ c\_S\ \[Lambda]\_3\ dy\_L[
                            t] - Sin[\[Theta]\_3[t]]\^2\ c\_V\ \[Lambda]\_3\ \
dy\_L[t] - Cos[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] - Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] + Sin[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] - 1\/2\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\%2\ d\[Theta]\_3[
                            t])\) - 
                  Sin[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_3[t]]\^2\)\ \
c\_S\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\^2\ c\_V\ \[Lambda]\_3\ dx\_L[
                            t] + Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\ dy\_L[t] - 
                        Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_3\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_3\ d\
\[Theta]\_1[t] + Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] + Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_3[
                                t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_3\ d\
\[Theta]\_2[t] + 1\/2\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\%2\ d\[Theta]\_3[
                            t])\) + 
                  1\/2\ m\_3\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t])\))\) - 
                  1\/2\ m\_3\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        2\ Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\) \
+ 2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\))\
\) + Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\^2\ c\_S\ \[Lambda]\_4\ dy\_L[
                            t] - Sin[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ \
dy\_L[t] - Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] - Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] + Sin[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] - Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] + Sin[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] - 1\/2\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[
                            t])\) - 
                  Sin[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_4[t]]\^2\)\ \
c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ dx\_L[
                            t] + Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\ dy\_L[t] - 
                        Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_4\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ d\
\[Theta]\_1[t] + Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ d\
\[Theta]\_2[t] + Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ d\
\[Theta]\_3[t] + 1\/2\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[
                            t])\) + 
                  1\/2\ m\_4\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + 
                              Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                  t] + Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t])\))\) - 
                  1\/2\ m\_4\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\) \
+ 2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \[Lambda]\_5\ \((2\ \
Cos[\[Theta]\_5[t]]\ c\_V\ \((\(-Cos[\[Theta]\_5[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Sin[\[Theta]\_5[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_5[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - \[Lambda]\_5\ d\[Theta]\_5[t])\))\) - 
                  1\/2\ Cos[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \[Lambda]\_5\ \((2\ \
Sin[\[Theta]\_5[t]]\ c\_V\ \((Cos[\[Theta]\_5[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) + 
                        Cos[\[Theta]\_5[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_5[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + \[Lambda]\_5\ d\[Theta]\_5[t])\))\) + 
                  1\/2\ m\_5\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t])\))\) - 
                  1\/2\ m\_5\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\) \
+ 2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \[Lambda]\_6\ \((2\ \
Cos[\[Theta]\_6[t]]\ c\_V\ \((\(-Cos[\[Theta]\_6[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Sin[\[Theta]\_6[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_6[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - \[Lambda]\_6\ d\[Theta]\_6[t])\))\) - 
                  1\/2\ Cos[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \[Lambda]\_6\ \((2\ \
Sin[\[Theta]\_6[t]]\ c\_V\ \((Cos[\[Theta]\_6[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) + 
                        Cos[\[Theta]\_6[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_6[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t])\))\) - 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\) \
+ 2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\))\
\) - Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Sin[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((2\ Sin[\[Theta]\_7[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  Cos[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Cos[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((\(-2\)\ \
Sin[\[Theta]\_7[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t])\))\) - 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) \
+ 2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\))\
\) - Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  Cos[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ \
Sin[\[Theta]\_8[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t])\))\) - 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) \
+ 2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\))\
\) - Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  Cos[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ 2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_2[
                        t]]\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_2[
                              t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + 
                              Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                  t] + Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t] + 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        2\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\)\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_3\%3\ d\[Theta]\_3[t] + 
                  1\/2\ Cos[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \((Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\^2\ c\_S\ \[Lambda]\_3\ dy\_L[
                            t] - Sin[\[Theta]\_3[t]]\^2\ c\_V\ \[Lambda]\_3\ \
dy\_L[t] - Cos[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] - Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] + Sin[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] - 1\/2\ Cos[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\%2\ d\[Theta]\_3[
                            t])\) - 
                  1\/2\ Sin[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_3[t]]\^2\)\ \
c\_S\ \[Lambda]\_3\ dx\_L[t] - 
                        Cos[\[Theta]\_3[t]]\^2\ c\_V\ \[Lambda]\_3\ dx\_L[
                            t] + Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\ dy\_L[t] - 
                        Cos[\[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_V\ \[Lambda]\_3\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_3\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_3\ d\
\[Theta]\_1[t] + Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_3\ \
d\[Theta]\_2[t] + Cos[\[Theta]\_3[
                              t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_3[
                                t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_3\ d\
\[Theta]\_2[t] + 1\/2\ Sin[\[Theta]\_3[
                              t]]\ c\_S\ \[Lambda]\_3\%2\ d\[Theta]\_3[
                            t])\) + 
                  1\/2\ m\_3\ \((\(-Sin[\[Theta]\_3[
                                t]]\)\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t])\))\) - 
                  1\/2\ m\_3\ \((\(-Sin[\[Theta]\_3[
                                t]]\)\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t])\) - 
                        Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\) \
+ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\))\
\) + Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\^2\ c\_S\ \[Lambda]\_4\ dy\_L[
                            t] - Sin[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ \
dy\_L[t] - Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] - Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] + Sin[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] - Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] + Sin[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] - 1\/2\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[
                            t])\) - 
                  Sin[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_4[t]]\^2\)\ \
c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ dx\_L[
                            t] + Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\ dy\_L[t] - 
                        Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_4\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ d\
\[Theta]\_1[t] + Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ d\
\[Theta]\_2[t] + Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                
                                t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ d\
\[Theta]\_3[t] + 1\/2\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[
                            t])\) + 
                  1\/2\ m\_4\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t])\))\) - 
                  1\/2\ m\_4\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        2\ Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\) \
+ 2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_4[
                                    
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \[Lambda]\_5\ \((2\ \
Cos[\[Theta]\_5[t]]\ c\_V\ \((\(-Cos[\[Theta]\_5[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Sin[\[Theta]\_5[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_5[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - \[Lambda]\_5\ d\[Theta]\_5[t])\))\) - 
                  1\/2\ Cos[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \[Lambda]\_5\ \((2\ \
Sin[\[Theta]\_5[t]]\ c\_V\ \((Cos[\[Theta]\_5[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) + 
                        Cos[\[Theta]\_5[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_5[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + \[Lambda]\_5\ d\[Theta]\_5[t])\))\) + 
                  1\/2\ m\_5\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t])\))\) - 
                  1\/2\ m\_5\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\) \
+ 2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \[Lambda]\_6\ \((2\ \
Cos[\[Theta]\_6[t]]\ c\_V\ \((\(-Cos[\[Theta]\_6[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Sin[\[Theta]\_6[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_6[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - \[Lambda]\_6\ d\[Theta]\_6[t])\))\) - 
                  1\/2\ Cos[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \[Lambda]\_6\ \((2\ \
Sin[\[Theta]\_6[t]]\ c\_V\ \((Cos[\[Theta]\_6[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) + 
                        Cos[\[Theta]\_6[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_6[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t])\))\) - 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 
                              1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\) \
+ 2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\))\
\) - Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((\(-Cos[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Sin[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((2\ Sin[\[Theta]\_7[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  Cos[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Cos[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((\(-2\)\ \
Sin[\[Theta]\_7[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t])\))\) - 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) \
+ 2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\))\
\) - Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((\(-Cos[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  Cos[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ \
Sin[\[Theta]\_8[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t])\))\) - 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) \
+ 2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\))\
\) - Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  Cos[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 
                              Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + 1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ 2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_3[
                        t]]\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_3[
                              t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        2\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\)\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_4\%3\ d\[Theta]\_4[t] + 
                  1\/2\ Cos[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \((Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\^2\ c\_S\ \[Lambda]\_4\ dy\_L[
                            t] - Sin[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ \
dy\_L[t] - Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] + Sin[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] - Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] + Sin[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] - Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] + Sin[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] - 1\/2\ Cos[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[
                            t])\) - 
                  1\/2\ Sin[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_4[t]]\^2\)\ \
c\_S\ \[Lambda]\_4\ dx\_L[t] - 
                        Cos[\[Theta]\_4[t]]\^2\ c\_V\ \[Lambda]\_4\ dx\_L[
                            t] + Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\ dy\_L[t] - 
                        Cos[\[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_V\ \[Lambda]\_4\ dy\_L[t] + 
                        Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\ \
d\[Theta]\_1[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_1\ \[Lambda]\_4\ d\
\[Theta]\_1[t] + Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\ \
d\[Theta]\_2[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_2\ \[Lambda]\_4\ d\
\[Theta]\_2[t] + Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\ \
d\[Theta]\_3[t] + Cos[\[Theta]\_4[
                              t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                t]]\ c\_V\ \[Lambda]\_3\ \[Lambda]\_4\ d\
\[Theta]\_3[t] + 1\/2\ Sin[\[Theta]\_4[
                              t]]\ c\_S\ \[Lambda]\_4\%2\ d\[Theta]\_4[
                            t])\) + 
                  1\/2\ m\_4\ \((\(-Sin[\[Theta]\_4[
                                t]]\)\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t])\))\) - 
                  1\/2\ m\_4\ \((\(-Sin[\[Theta]\_4[
                                t]]\)\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 
                              1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\) \
+ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \[Lambda]\_5\ \((2\ \
Cos[\[Theta]\_5[t]]\ c\_V\ \((\(-Cos[\[Theta]\_5[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Sin[\[Theta]\_5[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_5[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - \[Lambda]\_5\ d\[Theta]\_5[t])\))\) - 
                  1\/2\ Cos[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \[Lambda]\_5\ \((2\ \
Sin[\[Theta]\_5[t]]\ c\_V\ \((Cos[\[Theta]\_5[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) + 
                        Cos[\[Theta]\_5[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_5[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + \[Lambda]\_5\ d\[Theta]\_5[t])\))\) + 
                  1\/2\ m\_5\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t])\))\) - 
                  1\/2\ m\_5\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        2\ Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\) \
+ 2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \[Lambda]\_6\ \((2\ \
Cos[\[Theta]\_6[t]]\ c\_V\ \((\(-Cos[\[Theta]\_6[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Sin[\[Theta]\_6[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_6[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - \[Lambda]\_6\ d\[Theta]\_6[t])\))\) - 
                  1\/2\ Cos[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \[Lambda]\_6\ \((2\ \
Sin[\[Theta]\_6[t]]\ c\_V\ \((Cos[\[Theta]\_6[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) + 
                        Cos[\[Theta]\_6[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_6[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t])\))\) - 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\) \
+ 2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\))\
\) - Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((\(-Cos[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Sin[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((2\ Sin[\[Theta]\_7[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  Cos[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Cos[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((\(-2\)\ \
Sin[\[Theta]\_7[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t])\))\) - 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - 
                              Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                  t] - Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - 1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) \
+ 2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\))\
\) - Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((\(-Cos[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  Cos[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ \
Sin[\[Theta]\_8[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t])\))\) - 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 
                              Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) \
+ 2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\))\
\) - Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  Cos[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ 2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_4[
                        t]]\ \[Lambda]\_4\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 
                              Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t] + 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_4[
                              t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 
                              Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t] - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        2\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\)\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_5\%3\ d\[Theta]\_5[t] - 
                  1\/4\ Sin[\[Theta]\_5[
                        t]]\ \[Lambda]\_5\%2\ \((2\ Cos[\[Theta]\_5[
                              t]]\ c\_V\ \((\(-Cos[\[Theta]\_5[t]]\)\ dx\_L[
                                  t] - Sin[\[Theta]\_5[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) - 
                        Sin[\[Theta]\_5[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_5[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - \[Lambda]\_5\ d\[Theta]\_5[t])\))\) - 
                  1\/4\ Cos[\[Theta]\_5[
                        t]]\ \[Lambda]\_5\%2\ \((2\ Sin[\[Theta]\_5[
                              t]]\ c\_V\ \((Cos[\[Theta]\_5[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_5[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t])\) + 
                        Cos[\[Theta]\_5[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_5[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_5[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + \[Lambda]\_5\ d\[Theta]\_5[t])\))\) + 
                  1\/2\ m\_5\ \((\(-Sin[\[Theta]\_5[
                                t]]\)\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t])\))\) - 
                  1\/2\ m\_5\ \((\(-Sin[\[Theta]\_5[
                                t]]\)\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\) \
+ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2)\))\
\) - 1\/2\ Sin[\[Theta]\_5[
                        t]]\ \[Lambda]\_5\ \[Lambda]\_6\ \((2\ \
Cos[\[Theta]\_6[t]]\ c\_V\ \((\(-Cos[\[Theta]\_6[t]]\)\ dx\_L[t] - 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Sin[\[Theta]\_6[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_6[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - \[Lambda]\_6\ d\[Theta]\_6[t])\))\) - 
                  1\/2\ Cos[\[Theta]\_5[
                        t]]\ \[Lambda]\_5\ \[Lambda]\_6\ \((2\ \
Sin[\[Theta]\_6[t]]\ c\_V\ \((Cos[\[Theta]\_6[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) + 
                        Cos[\[Theta]\_6[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_6[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t])\))\) - 
                  1\/2\ m\_6\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        2\ Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\) \
+ 2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\))\
\) - Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((\(-Cos[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Sin[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((2\ Sin[\[Theta]\_7[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  Cos[\[Theta]\_5[
                        t]]\ \[Lambda]\_5\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Cos[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((\(-2\)\ \
Sin[\[Theta]\_7[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t])\))\) - 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) \
+ 2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\))\
\) - Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((\(-Cos[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  Cos[\[Theta]\_5[
                        t]]\ \[Lambda]\_5\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ \
Sin[\[Theta]\_8[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t])\))\) - 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) \
+ 2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\))\
\) - Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  Cos[\[Theta]\_5[
                        t]]\ \[Lambda]\_5\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ 2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_5[
                        t]]\ \[Lambda]\_5\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_5[
                              t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        2\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\)\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_6\%3\ d\[Theta]\_6[t] - 
                  1\/4\ Sin[\[Theta]\_6[
                        t]]\ \[Lambda]\_6\%2\ \((2\ Cos[\[Theta]\_6[
                              t]]\ c\_V\ \((\(-Cos[\[Theta]\_6[t]]\)\ dx\_L[
                                  t] - Sin[\[Theta]\_6[t]]\ dy\_L[t] + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) - 
                        Sin[\[Theta]\_6[
                              t]]\ c\_S\ \((2\ Sin[\[Theta]\_6[t]]\ dx\_L[
                                  t] - 2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - \[Lambda]\_6\ d\[Theta]\_6[t])\))\) - 
                  1\/4\ Cos[\[Theta]\_6[
                        t]]\ \[Lambda]\_6\%2\ \((2\ Sin[\[Theta]\_6[
                              t]]\ c\_V\ \((Cos[\[Theta]\_6[t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_6[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t])\) + 
                        Cos[\[Theta]\_6[
                              t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_6[
                                    t]]\ dx\_L[t] + 
                              2\ Cos[\[Theta]\_6[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + \[Lambda]\_6\ d\[Theta]\_6[t])\))\) + 
                  1\/2\ m\_6\ \((\(-Sin[\[Theta]\_6[
                                t]]\)\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - 1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t])\))\) - 
                  1\/2\ m\_6\ \((\(-Sin[\[Theta]\_6[
                                t]]\)\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + 1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - 
                              Sin[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                  t] - Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\) \
+ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2)\))\
\) - Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((\(-Cos[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Sin[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((2\ Sin[\[Theta]\_7[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  Cos[\[Theta]\_6[
                        t]]\ \[Lambda]\_6\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Cos[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((\(-2\)\ \
Sin[\[Theta]\_7[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t])\))\) - 
                  1\/2\ m\_7\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        2\ Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) \
+ 2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\))\
\) - Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((\(-Cos[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  Cos[\[Theta]\_6[
                        t]]\ \[Lambda]\_6\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ \
Sin[\[Theta]\_8[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t])\))\) - 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) \
+ 2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\))\
\) - Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  Cos[\[Theta]\_6[
                        t]]\ \[Lambda]\_6\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ 2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_6[
                        t]]\ \[Lambda]\_6\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_6[
                              t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        2\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\)\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_7\%3\ d\[Theta]\_7[t] - 
                  1\/2\ Sin[\[Theta]\_7[
                        t]]\ \[Lambda]\_7\ \((\(-Cos[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Sin[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((2\ Sin[\[Theta]\_7[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  1\/2\ Cos[\[Theta]\_7[
                        t]]\ \[Lambda]\_7\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ c\_V\ \[Lambda]\_7\ \((Cos[\[Theta]\_7[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_7[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t])\) - 
                        1\/2\ Cos[\[Theta]\_7[
                              t]]\ c\_S\ \[Lambda]\_7\ \((\(-2\)\ \
Sin[\[Theta]\_7[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_7[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + \[Lambda]\_7\ d\[Theta]\_7[t])\))\) + 
                  1\/2\ m\_7\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t])\))\) - 
                  1\/2\ m\_7\ \((\(-Sin[\[Theta]\_7[
                                t]]\)\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\) \
+ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2)\))\
\) - Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((\(-Cos[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  Cos[\[Theta]\_7[
                        t]]\ \[Lambda]\_7\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ \
Sin[\[Theta]\_8[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t])\))\) - 
                  1\/2\ m\_8\ \((\(-2\)\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        2\ Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_8[
                                    
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) \
+ 2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\))\
\) - Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  Cos[\[Theta]\_7[
                        t]]\ \[Lambda]\_7\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 
                              Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + 1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ 2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_7[
                        t]]\ \[Lambda]\_7\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_7[
                              t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        2\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\)\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_8\%3\ d\[Theta]\_8[t] - 
                  1\/2\ Sin[\[Theta]\_8[
                        t]]\ \[Lambda]\_8\ \((\(-Cos[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Sin[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((2\ Sin[\[Theta]\_8[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ Cos[\[Theta]\_8[
                        t]]\ \[Lambda]\_8\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ c\_V\ \[Lambda]\_8\ \((Cos[\[Theta]\_8[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_8[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t])\) - 
                        1\/2\ Cos[\[Theta]\_8[
                              t]]\ c\_S\ \[Lambda]\_8\ \((\(-2\)\ \
Sin[\[Theta]\_8[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_8[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + \[Lambda]\_8\ d\[Theta]\_8[t])\))\) + 
                  1\/2\ m\_8\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + 
                              Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                  t] + Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t])\))\) - 
                  1\/2\ m\_8\ \((\(-Sin[\[Theta]\_8[
                                t]]\)\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + 1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - 1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        Sin[\[Theta]\_8[t]]\ \[Lambda]\_8\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\) \
+ Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2)\))\
\) - Sin[\[Theta]\_8[t]]\ \[Lambda]\_8\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  Cos[\[Theta]\_8[
                        t]]\ \[Lambda]\_8\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-2\)\ Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        2\ Sin[\[Theta]\_8[t]]\ \[Lambda]\_8\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ 2\ Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_8[t]]\ \[Lambda]\_8\ \((\(-Cos[\[Theta]\_10[
                                
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_8[
                        t]]\ \[Lambda]\_8\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_8[
                              t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_8[t]]\ \[Lambda]\_8\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        2\ Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\)\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_9\%3\ d\[Theta]\_9[t] - 
                  1\/2\ Sin[\[Theta]\_9[
                        t]]\ \[Lambda]\_9\ \((\(-Cos[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Sin[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_9[
                                    t]]\ dx\_L[t] - 
                              2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ Cos[\[Theta]\_9[
                        t]]\ \[Lambda]\_9\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ c\_V\ \[Lambda]\_9\ \((Cos[\[Theta]\_9[
                                    t]]\ dx\_L[t] + 
                              Sin[\[Theta]\_9[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t])\) - 
                        1\/2\ Cos[\[Theta]\_9[
                              t]]\ c\_S\ \[Lambda]\_9\ \((\(-2\)\ \
Sin[\[Theta]\_9[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_9[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + \[Lambda]\_9\ d\[Theta]\_9[t])\))\) + 
                  1\/2\ m\_9\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ \[Lambda]\_9\ d\[Theta]\_9[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t])\))\) - 
                  1\/2\ m\_9\ \((\(-Sin[\[Theta]\_9[
                                t]]\)\ \[Lambda]\_9\ d\[Theta]\_9[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + 
                              Cos[\[Theta]\_2[t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                  t] + Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + 1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\) \
+ Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2)\))\
\) - Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  Cos[\[Theta]\_9[
                        t]]\ \[Lambda]\_9\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_9[
                              t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + 
                              Cos[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] + Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              Cos[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] + Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              Cos[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] + Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t] + 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-2\)\ Sin[\[Theta]\_9[
                              t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - 
                              Sin[\[Theta]\_4[t]]\ \[Lambda]\_4\ d\[Theta]\_4[
                                  t] - Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t]]\ \[Lambda]\_6\ d\[Theta]\_6[
                                  t] - Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t]]\ \[Lambda]\_8\ d\[Theta]\_8[
                                  t] - Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t] - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        2\ Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        2\ Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\)\)},
              {\(\(-\(1\/12\)\)\ c\_S\ \[Lambda]\_10\%3\ d\[Theta]\_10[t] - 
                  1\/2\ Sin[\[Theta]\_10[
                        t]]\ \[Lambda]\_10\ \((\(-Cos[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Sin[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((2\ \
Sin[\[Theta]\_10[t]]\ dx\_L[t] - 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] - 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ Cos[\[Theta]\_10[
                        t]]\ \[Lambda]\_10\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ c\_V\ \[Lambda]\_10\ \
\((Cos[\[Theta]\_10[t]]\ dx\_L[t] + Sin[\[Theta]\_10[t]]\ dy\_L[t] - 
                              Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                              Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] - 
                              Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] - 
                              Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] - 
                              Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[t])\) - 
                        1\/2\ Cos[\[Theta]\_10[
                              t]]\ c\_S\ \[Lambda]\_10\ \((\(-2\)\ Sin[\
\[Theta]\_10[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_10[t]]\ dy\_L[t] + 
                              2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                              2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_3\ d\[Theta]\_3[t] + 
                              2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_5\ d\[Theta]\_5[t] + 
                              2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_7\ d\[Theta]\_7[t] + 
                              2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                      t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) + 
                  1\/2\ m\_10\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ \[Lambda]\_10\ d\[Theta]\_10[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        Cos[\[Theta]\_10[t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                                  t])\))\) - 
                  1\/2\ m\_10\ \((\(-Sin[\[Theta]\_10[
                                t]]\)\ \[Lambda]\_10\ d\[Theta]\_10[
                            t]\ \((dy\_L[t] + 
                              Cos[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] + Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                              Cos[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] + Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] + 
                              Cos[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] + Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] + 
                              Cos[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] + Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] + 
                              Cos[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] + 1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        Cos[\[Theta]\_10[t]]\ \[Lambda]\_10\ d\[Theta]\_10[
                            t]\ \((dx\_L[t] - 
                              Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                  t] - Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                              Sin[\[Theta]\_3[t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                  t] - Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t] - 
                              Sin[\[Theta]\_5[t]]\ \[Lambda]\_5\ d\[Theta]\_5[
                                  t] - Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t] - 
                              Sin[\[Theta]\_7[t]]\ \[Lambda]\_7\ d\[Theta]\_7[
                                  t] - Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t] - 
                              Sin[\[Theta]\_9[t]]\ \[Lambda]\_9\ d\[Theta]\_9[
                                  t] - 1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ d\[Theta]\_10[t])\) - 
                        Sin[\[Theta]\_10[t]]\ \[Lambda]\_10\ \((ddx\_L[t] - 
                              Cos[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Cos[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Cos[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Cos[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Cos[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Cos[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Cos[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Cos[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Cos[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Cos[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\) + 
                        Cos[\[Theta]\_10[t]]\ \[Lambda]\_10\ \((ddy\_L[t] - 
                              Sin[\[Theta]\_1[
                                    t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                              Sin[\[Theta]\_2[
                                    t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 - 
                              Sin[\[Theta]\_3[
                                    t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                              Sin[\[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 - 
                              Sin[\[Theta]\_5[
                                    t]]\ \[Lambda]\_5\ d\[Theta]\_5[t]\^2 - 
                              Sin[\[Theta]\_6[
                                    t]]\ \[Lambda]\_6\ d\[Theta]\_6[t]\^2 - 
                              Sin[\[Theta]\_7[
                                    t]]\ \[Lambda]\_7\ d\[Theta]\_7[t]\^2 - 
                              Sin[\[Theta]\_8[
                                    t]]\ \[Lambda]\_8\ d\[Theta]\_8[t]\^2 - 
                              Sin[\[Theta]\_9[
                                    t]]\ \[Lambda]\_9\ d\[Theta]\_9[t]\^2 - 
                              1\/2\ Sin[\[Theta]\_10[
                                    t]]\ \[Lambda]\_10\ \
d\[Theta]\_10[t]\^2)\))\) + \[Tau]\_R[t]\)}
              },
            RowSpacings->1,
            ColumnAlignments->{Left}],
          Column], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    \({\[Theta]\_1[t] \[Rule] 
        Th\[LeftDoubleBracket]1\[RightDoubleBracket], \[Theta]\_2[t] \[Rule] 
        Th\[LeftDoubleBracket]2\[RightDoubleBracket], \[Theta]\_3[t] \[Rule] 
        Th\[LeftDoubleBracket]3\[RightDoubleBracket], \[Theta]\_4[t] \[Rule] 
        Th\[LeftDoubleBracket]4\[RightDoubleBracket], \[Theta]\_5[t] \[Rule] 
        Th\[LeftDoubleBracket]5\[RightDoubleBracket], \[Theta]\_6[t] \[Rule] 
        Th\[LeftDoubleBracket]6\[RightDoubleBracket], \[Theta]\_7[t] \[Rule] 
        Th\[LeftDoubleBracket]7\[RightDoubleBracket], \[Theta]\_8[t] \[Rule] 
        Th\[LeftDoubleBracket]8\[RightDoubleBracket], \[Theta]\_9[t] \[Rule] 
        Th\[LeftDoubleBracket]9\[RightDoubleBracket], \[Theta]\_10[t] \[Rule] 
        Th\[LeftDoubleBracket]10\[RightDoubleBracket], 
      d\[Theta]\_1[t] \[Rule] dTh\[LeftDoubleBracket]1\[RightDoubleBracket], 
      d\[Theta]\_2[t] \[Rule] dTh\[LeftDoubleBracket]2\[RightDoubleBracket], 
      d\[Theta]\_3[t] \[Rule] dTh\[LeftDoubleBracket]3\[RightDoubleBracket], 
      d\[Theta]\_4[t] \[Rule] dTh\[LeftDoubleBracket]4\[RightDoubleBracket], 
      d\[Theta]\_5[t] \[Rule] dTh\[LeftDoubleBracket]5\[RightDoubleBracket], 
      d\[Theta]\_6[t] \[Rule] dTh\[LeftDoubleBracket]6\[RightDoubleBracket], 
      d\[Theta]\_7[t] \[Rule] dTh\[LeftDoubleBracket]7\[RightDoubleBracket], 
      d\[Theta]\_8[t] \[Rule] dTh\[LeftDoubleBracket]8\[RightDoubleBracket], 
      d\[Theta]\_9[t] \[Rule] dTh\[LeftDoubleBracket]9\[RightDoubleBracket], 
      d\[Theta]\_10[t] \[Rule] 
        dTh\[LeftDoubleBracket]10\[RightDoubleBracket], 
      m\_1 \[Rule] M\[LeftDoubleBracket]1\[RightDoubleBracket], 
      m\_2 \[Rule] M\[LeftDoubleBracket]2\[RightDoubleBracket], 
      m\_3 \[Rule] M\[LeftDoubleBracket]3\[RightDoubleBracket], 
      m\_4 \[Rule] M\[LeftDoubleBracket]4\[RightDoubleBracket], 
      m\_5 \[Rule] M\[LeftDoubleBracket]5\[RightDoubleBracket], 
      m\_6 \[Rule] M\[LeftDoubleBracket]6\[RightDoubleBracket], 
      m\_7 \[Rule] M\[LeftDoubleBracket]7\[RightDoubleBracket], 
      m\_8 \[Rule] M\[LeftDoubleBracket]8\[RightDoubleBracket], 
      m\_9 \[Rule] M\[LeftDoubleBracket]9\[RightDoubleBracket], 
      m\_10 \[Rule] 
        M\[LeftDoubleBracket]10\[RightDoubleBracket], \[Lambda]\_1 \[Rule] 
        L\[LeftDoubleBracket]1\[RightDoubleBracket], \[Lambda]\_2 \[Rule] 
        L\[LeftDoubleBracket]2\[RightDoubleBracket], \[Lambda]\_3 \[Rule] 
        L\[LeftDoubleBracket]3\[RightDoubleBracket], \[Lambda]\_4 \[Rule] 
        L\[LeftDoubleBracket]4\[RightDoubleBracket], \[Lambda]\_5 \[Rule] 
        L\[LeftDoubleBracket]5\[RightDoubleBracket], \[Lambda]\_6 \[Rule] 
        L\[LeftDoubleBracket]6\[RightDoubleBracket], \[Lambda]\_7 \[Rule] 
        L\[LeftDoubleBracket]7\[RightDoubleBracket], \[Lambda]\_8 \[Rule] 
        L\[LeftDoubleBracket]8\[RightDoubleBracket], \[Lambda]\_9 \[Rule] 
        L\[LeftDoubleBracket]9\[RightDoubleBracket], \[Lambda]\_10 \[Rule] 
        L\[LeftDoubleBracket]10\[RightDoubleBracket], c\_V \[Rule] Cv, 
      c\_S \[Rule] Cs, \[Tau]\_L[t] \[Rule] tauL, \[Tau]\_R[t] \[Rule] tauR, 
      x\_L[t] \[Rule] xL, y\_L[t] \[Rule] yL, dx\_L[t] \[Rule] dxL, 
      dy\_L[t] \[Rule] dyL, ddx\_L[t] \[Rule] ddxL, ddy\_L[t] \[Rule] ddyL, 
      x\_R[t] \[Rule] xR, y\_R[t] \[Rule] yR, dx\_R[t] \[Rule] dxR, 
      dy\_R[t] \[Rule] dyR, ddx\_R[t] \[Rule] ddxR, 
      ddy\_R[t] \[Rule] ddyR}\)], "Output"],

Cell[BoxData[
    \("\n coefMat[0] = -1;\n coefMat[14] = 0;\n coefMat[28] = -1;\n \
coefMat[42] = 0;\n coefMat[56] = -(L[1]*M[1]*sin(Th[1]))/2. - \
L[1]*M[2]*sin(Th[1]) - L[1]*M[3]*sin(Th[1]) - L[1]*M[4]*sin(Th[1]) - \
L[1]*M[5]*sin(Th[1]) - L[1]*M[6]*sin(Th[1]) - L[1]*M[7]*sin(Th[1]) - \
L[1]*M[8]*sin(Th[1]) - L[1]*M[9]*sin(Th[1]) - L[1]*M[10]*sin(Th[1]);\n \
coefMat[70] = -(L[2]*M[2]*sin(Th[2]))/2. - L[2]*M[3]*sin(Th[2]) - \
L[2]*M[4]*sin(Th[2]) - L[2]*M[5]*sin(Th[2]) - L[2]*M[6]*sin(Th[2]) - \
L[2]*M[7]*sin(Th[2]) - L[2]*M[8]*sin(Th[2]) - L[2]*M[9]*sin(Th[2]) - \
L[2]*M[10]*sin(Th[2]);\n coefMat[84] = -(L[3]*M[3]*sin(Th[3]))/2. - \
L[3]*M[4]*sin(Th[3]) - L[3]*M[5]*sin(Th[3]) - L[3]*M[6]*sin(Th[3]) - \
L[3]*M[7]*sin(Th[3]) - L[3]*M[8]*sin(Th[3]) - L[3]*M[9]*sin(Th[3]) - \
L[3]*M[10]*sin(Th[3]);\n coefMat[98] = -(L[4]*M[4]*sin(Th[4]))/2. - \
L[4]*M[5]*sin(Th[4]) - L[4]*M[6]*sin(Th[4]) - L[4]*M[7]*sin(Th[4]) - \
L[4]*M[8]*sin(Th[4]) - L[4]*M[9]*sin(Th[4]) - L[4]*M[10]*sin(Th[4]);\n \
coefMat[112] = -(L[5]*M[5]*sin(Th[5]))/2. - L[5]*M[6]*sin(Th[5]) - \
L[5]*M[7]*sin(Th[5]) - L[5]*M[8]*sin(Th[5]) - L[5]*M[9]*sin(Th[5]) - \
L[5]*M[10]*sin(Th[5]);\n coefMat[126] = -(L[6]*M[6]*sin(Th[6]))/2. - \
L[6]*M[7]*sin(Th[6]) - L[6]*M[8]*sin(Th[6]) - L[6]*M[9]*sin(Th[6]) - \
L[6]*M[10]*sin(Th[6]);\n coefMat[140] = -(L[7]*M[7]*sin(Th[7]))/2. - \
L[7]*M[8]*sin(Th[7]) - L[7]*M[9]*sin(Th[7]) - L[7]*M[10]*sin(Th[7]);\n \
coefMat[154] = -(L[8]*M[8]*sin(Th[8]))/2. - L[8]*M[9]*sin(Th[8]) - \
L[8]*M[10]*sin(Th[8]);\n coefMat[168] = -(L[9]*M[9]*sin(Th[9]))/2. - \
L[9]*M[10]*sin(Th[9]);\n coefMat[182] = -(L[10]*M[10]*sin(Th[10]))/2.;\n \
rhsVec[0] = -(Cv*dxL*pow(cos(Th[1]),2)*L[1]) - Cv*dxL*pow(cos(Th[2]),2)*L[2] \
- Cv*dxL*pow(cos(Th[3]),2)*L[3] - Cv*dxL*pow(cos(Th[4]),2)*L[4] - (ddxL - \
(cos(Th[1])*pow(dTh[1],2)*L[1])/2.)*M[1] - (ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - (cos(Th[2])*pow(dTh[2],2)*L[2])/2.)*M[2] - \
(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
(cos(Th[3])*pow(dTh[3],2)*L[3])/2.)*M[3] - (ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - (cos(Th[4])*pow(dTh[4],2)*L[4])/2.)*M[4] - \
(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
(cos(Th[5])*pow(dTh[5],2)*L[5])/2.)*M[5] - (ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - (cos(Th[6])*pow(dTh[6],2)*L[6])/2.)*M[6] - \
(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
(cos(Th[7])*pow(dTh[7],2)*L[7])/2.)*M[7] - (ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - (cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*M[8] - \
(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
(cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*M[9] - (ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
cos(Th[9])*pow(dTh[9],2)*L[9] - (cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*M[10] \
+ Cs*dyL*cos(Th[1])*L[1]*sin(Th[1]) - Cv*dyL*cos(Th[1])*L[1]*sin(Th[1]) + \
(Cs*dTh[1]*pow(L[1],2)*sin(Th[1]))/2. - Cs*dxL*L[1]*pow(sin(Th[1]),2) + \
Cv*cos(Th[2])*dTh[1]*L[1]*L[2]*sin(Th[1] - Th[2]) + \
Cs*dyL*cos(Th[2])*L[2]*sin(Th[2]) - Cv*dyL*cos(Th[2])*L[2]*sin(Th[2]) + \
Cs*cos(Th[1] - Th[2])*dTh[1]*L[1]*L[2]*sin(Th[2]) + \
(Cs*dTh[2]*pow(L[2],2)*sin(Th[2]))/2. - Cs*dxL*L[2]*pow(sin(Th[2]),2) + \
Cv*cos(Th[3])*dTh[1]*L[1]*L[3]*sin(Th[1] - Th[3]) + \
Cv*cos(Th[3])*dTh[2]*L[2]*L[3]*sin(Th[2] - Th[3]) + \
Cs*dyL*cos(Th[3])*L[3]*sin(Th[3]) - Cv*dyL*cos(Th[3])*L[3]*sin(Th[3]) + \
Cs*cos(Th[1] - Th[3])*dTh[1]*L[1]*L[3]*sin(Th[3]) + Cs*cos(Th[2] - \
Th[3])*dTh[2]*L[2]*L[3]*sin(Th[3]) + (Cs*dTh[3]*pow(L[3],2)*sin(Th[3]))/2. - \
Cs*dxL*L[3]*pow(sin(Th[3]),2) + Cv*cos(Th[4])*dTh[1]*L[1]*L[4]*sin(Th[1] - \
Th[4]) + Cv*cos(Th[4])*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4]) + \
Cv*cos(Th[4])*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4]) + \
Cs*dyL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dyL*cos(Th[4])*L[4]*sin(Th[4]) + \
Cs*cos(Th[1] - Th[4])*dTh[1]*L[1]*L[4]*sin(Th[4]) + Cs*cos(Th[2] - \
Th[4])*dTh[2]*L[2]*L[4]*sin(Th[4]) + Cs*cos(Th[3] - \
Th[4])*dTh[3]*L[3]*L[4]*sin(Th[4]) + (Cs*dTh[4]*pow(L[4],2)*sin(Th[4]))/2. - \
Cs*dxL*L[4]*pow(sin(Th[4]),2) + (L[5]*(-(Cs*sin(Th[5])*(-2*dyL*cos(Th[5]) - \
2*cos(Th[1] - Th[5])*dTh[1]*L[1] - 2*cos(Th[2] - Th[5])*dTh[2]*L[2] - \
2*cos(Th[3] - Th[5])*dTh[3]*L[3] - 2*cos(Th[4] - Th[5])*dTh[4]*L[4] - \
dTh[5]*L[5] + 2*dxL*sin(Th[5]))) + 2*Cv*cos(Th[5])*(-(dxL*cos(Th[5])) + \
dTh[1]*L[1]*sin(Th[1] - Th[5]) + dTh[2]*L[2]*sin(Th[2] - Th[5]) + \
dTh[3]*L[3]*sin(Th[3] - Th[5]) + dTh[4]*L[4]*sin(Th[4] - Th[5]) - \
dyL*sin(Th[5]))))/2. + (L[6]*(-(Cs*sin(Th[6])*(-2*dyL*cos(Th[6]) - \
2*cos(Th[1] - Th[6])*dTh[1]*L[1] - 2*cos(Th[2] - Th[6])*dTh[2]*L[2] - \
2*cos(Th[3] - Th[6])*dTh[3]*L[3] - 2*cos(Th[4] - Th[6])*dTh[4]*L[4] - \
2*cos(Th[5] - Th[6])*dTh[5]*L[5] - dTh[6]*L[6] + 2*dxL*sin(Th[6]))) + \
2*Cv*cos(Th[6])*(-(dxL*cos(Th[6])) + dTh[1]*L[1]*sin(Th[1] - Th[6]) + \
dTh[2]*L[2]*sin(Th[2] - Th[6]) + dTh[3]*L[3]*sin(Th[3] - Th[6]) + \
dTh[4]*L[4]*sin(Th[4] - Th[6]) + dTh[5]*L[5]*sin(Th[5] - Th[6]) - \
dyL*sin(Th[6]))))/2. - (Cs*L[7]*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - \
Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + \
2*dxL*sin(Th[7])))/2. - Cv*cos(Th[7])*L[7]*(dxL*cos(Th[7]) - \
dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - \
dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - \
dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + \
dyL*sin(Th[7])) - (Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - \
Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - \
Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8])) - (Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - \
Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + \
2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9])) - (Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - \
Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]));\n coefMat[1] = 0;\n coefMat[15] = -1;\n coefMat[29] = 0;\n \
coefMat[43] = -1;\n coefMat[57] = (cos(Th[1])*L[1]*M[1])/2. + \
cos(Th[1])*L[1]*M[2] + cos(Th[1])*L[1]*M[3] + cos(Th[1])*L[1]*M[4] + \
cos(Th[1])*L[1]*M[5] + cos(Th[1])*L[1]*M[6] + cos(Th[1])*L[1]*M[7] + \
cos(Th[1])*L[1]*M[8] + cos(Th[1])*L[1]*M[9] + cos(Th[1])*L[1]*M[10];\n \
coefMat[71] = (cos(Th[2])*L[2]*M[2])/2. + cos(Th[2])*L[2]*M[3] + \
cos(Th[2])*L[2]*M[4] + cos(Th[2])*L[2]*M[5] + cos(Th[2])*L[2]*M[6] + \
cos(Th[2])*L[2]*M[7] + cos(Th[2])*L[2]*M[8] + cos(Th[2])*L[2]*M[9] + \
cos(Th[2])*L[2]*M[10];\n coefMat[85] = (cos(Th[3])*L[3]*M[3])/2. + \
cos(Th[3])*L[3]*M[4] + cos(Th[3])*L[3]*M[5] + cos(Th[3])*L[3]*M[6] + \
cos(Th[3])*L[3]*M[7] + cos(Th[3])*L[3]*M[8] + cos(Th[3])*L[3]*M[9] + \
cos(Th[3])*L[3]*M[10];\n coefMat[99] = (cos(Th[4])*L[4]*M[4])/2. + \
cos(Th[4])*L[4]*M[5] + cos(Th[4])*L[4]*M[6] + cos(Th[4])*L[4]*M[7] + \
cos(Th[4])*L[4]*M[8] + cos(Th[4])*L[4]*M[9] + cos(Th[4])*L[4]*M[10];\n \
coefMat[113] = (cos(Th[5])*L[5]*M[5])/2. + cos(Th[5])*L[5]*M[6] + \
cos(Th[5])*L[5]*M[7] + cos(Th[5])*L[5]*M[8] + cos(Th[5])*L[5]*M[9] + \
cos(Th[5])*L[5]*M[10];\n coefMat[127] = (cos(Th[6])*L[6]*M[6])/2. + \
cos(Th[6])*L[6]*M[7] + cos(Th[6])*L[6]*M[8] + cos(Th[6])*L[6]*M[9] + \
cos(Th[6])*L[6]*M[10];\n coefMat[141] = (cos(Th[7])*L[7]*M[7])/2. + \
cos(Th[7])*L[7]*M[8] + cos(Th[7])*L[7]*M[9] + cos(Th[7])*L[7]*M[10];\n \
coefMat[155] = (cos(Th[8])*L[8]*M[8])/2. + cos(Th[8])*L[8]*M[9] + \
cos(Th[8])*L[8]*M[10];\n coefMat[169] = (cos(Th[9])*L[9]*M[9])/2. + \
cos(Th[9])*L[9]*M[10];\n coefMat[183] = (cos(Th[10])*L[10]*M[10])/2.;\n \
rhsVec[1] = -(Cs*dyL*pow(cos(Th[1]),2)*L[1]) - \
(Cs*cos(Th[1])*dTh[1]*pow(L[1],2))/2. - Cs*dyL*pow(cos(Th[2]),2)*L[2] - \
Cs*cos(Th[1] - Th[2])*cos(Th[2])*dTh[1]*L[1]*L[2] - \
(Cs*cos(Th[2])*dTh[2]*pow(L[2],2))/2. - Cs*dyL*pow(cos(Th[3]),2)*L[3] - \
Cs*cos(Th[1] - Th[3])*cos(Th[3])*dTh[1]*L[1]*L[3] - Cs*cos(Th[2] - \
Th[3])*cos(Th[3])*dTh[2]*L[2]*L[3] - (Cs*cos(Th[3])*dTh[3]*pow(L[3],2))/2. - \
Cs*dyL*pow(cos(Th[4]),2)*L[4] - Cs*cos(Th[1] - \
Th[4])*cos(Th[4])*dTh[1]*L[1]*L[4] - Cs*cos(Th[2] - \
Th[4])*cos(Th[4])*dTh[2]*L[2]*L[4] - Cs*cos(Th[3] - \
Th[4])*cos(Th[4])*dTh[3]*L[3]*L[4] - (Cs*cos(Th[4])*dTh[4]*pow(L[4],2))/2. + \
Cs*dxL*cos(Th[1])*L[1]*sin(Th[1]) - Cv*dxL*cos(Th[1])*L[1]*sin(Th[1]) - \
Cv*dyL*L[1]*pow(sin(Th[1]),2) - M[1]*(ddyL - \
(pow(dTh[1],2)*L[1]*sin(Th[1]))/2.) + Cs*dxL*cos(Th[2])*L[2]*sin(Th[2]) - \
Cv*dxL*cos(Th[2])*L[2]*sin(Th[2]) + Cv*dTh[1]*L[1]*L[2]*sin(Th[1] - \
Th[2])*sin(Th[2]) - Cv*dyL*L[2]*pow(sin(Th[2]),2) - M[2]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - (pow(dTh[2],2)*L[2]*sin(Th[2]))/2.) + \
Cs*dxL*cos(Th[3])*L[3]*sin(Th[3]) - Cv*dxL*cos(Th[3])*L[3]*sin(Th[3]) + \
Cv*dTh[1]*L[1]*L[3]*sin(Th[1] - Th[3])*sin(Th[3]) + \
Cv*dTh[2]*L[2]*L[3]*sin(Th[2] - Th[3])*sin(Th[3]) - \
Cv*dyL*L[3]*pow(sin(Th[3]),2) - M[3]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - (pow(dTh[3],2)*L[3]*sin(Th[3]))/2.) + \
Cs*dxL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dxL*cos(Th[4])*L[4]*sin(Th[4]) + \
Cv*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4])*sin(Th[4]) + \
Cv*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4])*sin(Th[4]) + \
Cv*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4])*sin(Th[4]) - \
Cv*dyL*L[4]*pow(sin(Th[4]),2) - M[4]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
(pow(dTh[4],2)*L[4]*sin(Th[4]))/2.) - M[5]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
(pow(dTh[5],2)*L[5]*sin(Th[5]))/2.) - (L[5]*(Cs*cos(Th[5])*(2*dyL*cos(Th[5]) \
+ 2*cos(Th[1] - Th[5])*dTh[1]*L[1] + 2*cos(Th[2] - Th[5])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[5])*dTh[3]*L[3] + 2*cos(Th[4] - Th[5])*dTh[4]*L[4] + \
dTh[5]*L[5] - 2*dxL*sin(Th[5])) + 2*Cv*sin(Th[5])*(dxL*cos(Th[5]) - \
dTh[1]*L[1]*sin(Th[1] - Th[5]) - dTh[2]*L[2]*sin(Th[2] - Th[5]) - \
dTh[3]*L[3]*sin(Th[3] - Th[5]) - dTh[4]*L[4]*sin(Th[4] - Th[5]) + \
dyL*sin(Th[5]))))/2. - M[6]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
(pow(dTh[6],2)*L[6]*sin(Th[6]))/2.) - (L[6]*(Cs*cos(Th[6])*(2*dyL*cos(Th[6]) \
+ 2*cos(Th[1] - Th[6])*dTh[1]*L[1] + 2*cos(Th[2] - Th[6])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[6])*dTh[3]*L[3] + 2*cos(Th[4] - Th[6])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[6])*dTh[5]*L[5] + dTh[6]*L[6] - 2*dxL*sin(Th[6])) + \
2*Cv*sin(Th[6])*(dxL*cos(Th[6]) - dTh[1]*L[1]*sin(Th[1] - Th[6]) - \
dTh[2]*L[2]*sin(Th[2] - Th[6]) - dTh[3]*L[3]*sin(Th[3] - Th[6]) - \
dTh[4]*L[4]*sin(Th[4] - Th[6]) - dTh[5]*L[5]*sin(Th[5] - Th[6]) + \
dyL*sin(Th[6]))))/2. - (Cs*cos(Th[7])*L[7]*(2*dyL*cos(Th[7]) + 2*cos(Th[1] - \
Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + 2*cos(Th[5] - \
Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + dTh[7]*L[7] - \
2*dxL*sin(Th[7])))/2. - Cv*L[7]*sin(Th[7])*(dxL*cos(Th[7]) - \
dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - \
dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - \
dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + \
dyL*sin(Th[7])) - M[7]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
pow(dTh[6],2)*L[6]*sin(Th[6]) - (pow(dTh[7],2)*L[7]*sin(Th[7]))/2.) - \
(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + 2*cos(Th[1] - Th[8])*dTh[1]*L[1] + \
2*cos(Th[2] - Th[8])*dTh[2]*L[2] + 2*cos(Th[3] - Th[8])*dTh[3]*L[3] + \
2*cos(Th[4] - Th[8])*dTh[4]*L[4] + 2*cos(Th[5] - Th[8])*dTh[5]*L[5] + \
2*cos(Th[6] - Th[8])*dTh[6]*L[6] + 2*cos(Th[7] - Th[8])*dTh[7]*L[7] + \
dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - \
dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - \
dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - \
dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - \
dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8])) - M[8]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.) - \
(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + 2*cos(Th[1] - Th[9])*dTh[1]*L[1] + \
2*cos(Th[2] - Th[9])*dTh[2]*L[2] + 2*cos(Th[3] - Th[9])*dTh[3]*L[3] + \
2*cos(Th[4] - Th[9])*dTh[4]*L[4] + 2*cos(Th[5] - Th[9])*dTh[5]*L[5] + \
2*cos(Th[6] - Th[9])*dTh[6]*L[6] + 2*cos(Th[7] - Th[9])*dTh[7]*L[7] + \
2*cos(Th[8] - Th[9])*dTh[8]*L[8] + dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - \
Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - \
dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - \
dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - \
dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - \
dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9])) - M[9]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - \
(pow(dTh[9],2)*L[9]*sin(Th[9]))/2.) - \
(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - Th[10])*dTh[1]*L[1] \
+ 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - Th[10])*dTh[3]*L[3] + \
2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - Th[10])*dTh[5]*L[5] + \
2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - Th[10])*dTh[7]*L[7] + \
2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - Th[10])*dTh[9]*L[9] + \
dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - \
Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10])) - M[10]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - \
pow(dTh[8],2)*L[8]*sin(Th[8]) - pow(dTh[9],2)*L[9]*sin(Th[9]) - \
(pow(dTh[10],2)*L[10]*sin(Th[10]))/2.);\n coefMat[2] = 0;\n coefMat[16] = 0;\n\
 coefMat[30] = 0;\n coefMat[44] = 0;\n coefMat[58] = L[1]*sin(Th[1]);\n \
coefMat[72] = L[2]*sin(Th[2]);\n coefMat[86] = L[3]*sin(Th[3]);\n \
coefMat[100] = L[4]*sin(Th[4]);\n coefMat[114] = L[5]*sin(Th[5]);\n \
coefMat[128] = L[6]*sin(Th[6]);\n coefMat[142] = L[7]*sin(Th[7]);\n \
coefMat[156] = L[8]*sin(Th[8]);\n coefMat[170] = L[9]*sin(Th[9]);\n \
coefMat[184] = L[10]*sin(Th[10]);\n rhsVec[2] = ddxL - ddxR - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
cos(Th[9])*pow(dTh[9],2)*L[9] - cos(Th[10])*pow(dTh[10],2)*L[10];\n \
coefMat[3] = 0;\n coefMat[17] = 0;\n coefMat[31] = 0;\n coefMat[45] = 0;\n \
coefMat[59] = -(cos(Th[1])*L[1]);\n coefMat[73] = -(cos(Th[2])*L[2]);\n \
coefMat[87] = -(cos(Th[3])*L[3]);\n coefMat[101] = -(cos(Th[4])*L[4]);\n \
coefMat[115] = -(cos(Th[5])*L[5]);\n coefMat[129] = -(cos(Th[6])*L[6]);\n \
coefMat[143] = -(cos(Th[7])*L[7]);\n coefMat[157] = -(cos(Th[8])*L[8]);\n \
coefMat[171] = -(cos(Th[9])*L[9]);\n coefMat[185] = -(cos(Th[10])*L[10]);\n \
rhsVec[3] = ddyL - ddyR - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - \
pow(dTh[8],2)*L[8]*sin(Th[8]) - pow(dTh[9],2)*L[9]*sin(Th[9]) - \
pow(dTh[10],2)*L[10]*sin(Th[10]);\n coefMat[4] = 0;\n coefMat[18] = 0;\n \
coefMat[32] = L[1]*sin(Th[1]);\n coefMat[46] = -(cos(Th[1])*L[1]);\n \
coefMat[60] = (pow(L[1],2)*M[1])/12. + \
(M[1]*((pow(cos(Th[1]),2)*pow(L[1],2))/2. + \
(pow(L[1],2)*pow(sin(Th[1]),2))/2.))/2. + \
(M[2]*(2*pow(cos(Th[1]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(Th[1]),2)))/2. \
+ (M[3]*(2*pow(cos(Th[1]),2)*pow(L[1],2) + \
2*pow(L[1],2)*pow(sin(Th[1]),2)))/2. + (M[4]*(2*pow(cos(Th[1]),2)*pow(L[1],2) \
+ 2*pow(L[1],2)*pow(sin(Th[1]),2)))/2. + \
(M[5]*(2*pow(cos(Th[1]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(Th[1]),2)))/2. \
+ (M[6]*(2*pow(cos(Th[1]),2)*pow(L[1],2) + \
2*pow(L[1],2)*pow(sin(Th[1]),2)))/2. + (M[7]*(2*pow(cos(Th[1]),2)*pow(L[1],2) \
+ 2*pow(L[1],2)*pow(sin(Th[1]),2)))/2. + \
(M[8]*(2*pow(cos(Th[1]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(Th[1]),2)))/2. \
+ (M[9]*(2*pow(cos(Th[1]),2)*pow(L[1],2) + \
2*pow(L[1],2)*pow(sin(Th[1]),2)))/2. + \
(M[10]*(2*pow(cos(Th[1]),2)*pow(L[1],2) + \
2*pow(L[1],2)*pow(sin(Th[1]),2)))/2.;\n coefMat[74] = \
(M[2]*(cos(Th[1])*cos(Th[2])*L[1]*L[2] + L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. \
+ (M[3]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + \
2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + \
(M[4]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + \
2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + \
(M[5]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + \
2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + \
(M[6]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + \
2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + \
(M[7]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + \
2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + \
(M[8]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + \
2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + \
(M[9]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + \
2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + \
(M[10]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + \
2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2.;\n coefMat[88] = \
(M[3]*(cos(Th[1])*cos(Th[3])*L[1]*L[3] + L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. \
+ (M[4]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + \
2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + \
(M[5]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + \
2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + \
(M[6]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + \
2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + \
(M[7]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + \
2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + \
(M[8]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + \
2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + \
(M[9]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + \
2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + \
(M[10]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + \
2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2.;\n coefMat[102] = \
(M[4]*(cos(Th[1])*cos(Th[4])*L[1]*L[4] + L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. \
+ (M[5]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + \
2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + \
(M[6]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + \
2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + \
(M[7]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + \
2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + \
(M[8]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + \
2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + \
(M[9]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + \
2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + \
(M[10]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + \
2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2.;\n coefMat[116] = \
(M[5]*(cos(Th[1])*cos(Th[5])*L[1]*L[5] + L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. \
+ (M[6]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + \
2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + \
(M[7]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + \
2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + \
(M[8]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + \
2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + \
(M[9]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + \
2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + \
(M[10]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + \
2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2.;\n coefMat[130] = \
(M[6]*(cos(Th[1])*cos(Th[6])*L[1]*L[6] + L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2. \
+ (M[7]*(2*cos(Th[1])*cos(Th[6])*L[1]*L[6] + \
2*L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2. + \
(M[8]*(2*cos(Th[1])*cos(Th[6])*L[1]*L[6] + \
2*L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2. + \
(M[9]*(2*cos(Th[1])*cos(Th[6])*L[1]*L[6] + \
2*L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2. + \
(M[10]*(2*cos(Th[1])*cos(Th[6])*L[1]*L[6] + \
2*L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2.;\n coefMat[144] = \
(M[7]*(cos(Th[1])*cos(Th[7])*L[1]*L[7] + L[1]*L[7]*sin(Th[1])*sin(Th[7])))/2. \
+ (M[8]*(2*cos(Th[1])*cos(Th[7])*L[1]*L[7] + \
2*L[1]*L[7]*sin(Th[1])*sin(Th[7])))/2. + \
(M[9]*(2*cos(Th[1])*cos(Th[7])*L[1]*L[7] + \
2*L[1]*L[7]*sin(Th[1])*sin(Th[7])))/2. + \
(M[10]*(2*cos(Th[1])*cos(Th[7])*L[1]*L[7] + \
2*L[1]*L[7]*sin(Th[1])*sin(Th[7])))/2.;\n coefMat[158] = \
(M[8]*(cos(Th[1])*cos(Th[8])*L[1]*L[8] + L[1]*L[8]*sin(Th[1])*sin(Th[8])))/2. \
+ (M[9]*(2*cos(Th[1])*cos(Th[8])*L[1]*L[8] + \
2*L[1]*L[8]*sin(Th[1])*sin(Th[8])))/2. + \
(M[10]*(2*cos(Th[1])*cos(Th[8])*L[1]*L[8] + \
2*L[1]*L[8]*sin(Th[1])*sin(Th[8])))/2.;\n coefMat[172] = \
(M[9]*(cos(Th[1])*cos(Th[9])*L[1]*L[9] + L[1]*L[9]*sin(Th[1])*sin(Th[9])))/2. \
+ (M[10]*(2*cos(Th[1])*cos(Th[9])*L[1]*L[9] + \
2*L[1]*L[9]*sin(Th[1])*sin(Th[9])))/2.;\n coefMat[186] = \
(M[10]*(cos(Th[1])*cos(Th[10])*L[1]*L[10] + \
L[1]*L[10]*sin(Th[1])*sin(Th[10])))/2.;\n rhsVec[4] = tauL - \
(Cs*dTh[1]*pow(L[1],3))/12. - \
(L[1]*sin(Th[1])*(-(Cv*dxL*pow(cos(Th[1]),2)*L[1]) + \
Cs*dyL*cos(Th[1])*L[1]*sin(Th[1]) - Cv*dyL*cos(Th[1])*L[1]*sin(Th[1]) + \
(Cs*dTh[1]*pow(L[1],2)*sin(Th[1]))/2. - Cs*dxL*L[1]*pow(sin(Th[1]),2)))/2. + \
(cos(Th[1])*L[1]*(-(Cs*dyL*pow(cos(Th[1]),2)*L[1]) - \
(Cs*cos(Th[1])*dTh[1]*pow(L[1],2))/2. + Cs*dxL*cos(Th[1])*L[1]*sin(Th[1]) - \
Cv*dxL*cos(Th[1])*L[1]*sin(Th[1]) - Cv*dyL*L[1]*pow(sin(Th[1]),2)))/2. + \
(M[1]*(-(dTh[1]*L[1]*(dyL + (cos(Th[1])*dTh[1]*L[1])/2.)*sin(Th[1])) - \
cos(Th[1])*dTh[1]*L[1]*(dxL - (dTh[1]*L[1]*sin(Th[1]))/2.)))/2. - \
(M[1]*(-(dTh[1]*L[1]*(dyL + (cos(Th[1])*dTh[1]*L[1])/2.)*sin(Th[1])) - \
L[1]*(ddxL - (cos(Th[1])*pow(dTh[1],2)*L[1])/2.)*sin(Th[1]) - \
cos(Th[1])*dTh[1]*L[1]*(dxL - (dTh[1]*L[1]*sin(Th[1]))/2.) + \
cos(Th[1])*L[1]*(ddyL - (pow(dTh[1],2)*L[1]*sin(Th[1]))/2.)))/2. - \
L[1]*sin(Th[1])*(-(Cv*dxL*pow(cos(Th[2]),2)*L[2]) + \
Cv*cos(Th[2])*dTh[1]*L[1]*L[2]*sin(Th[1] - Th[2]) + \
Cs*dyL*cos(Th[2])*L[2]*sin(Th[2]) - Cv*dyL*cos(Th[2])*L[2]*sin(Th[2]) + \
Cs*cos(Th[1] - Th[2])*dTh[1]*L[1]*L[2]*sin(Th[2]) + \
(Cs*dTh[2]*pow(L[2],2)*sin(Th[2]))/2. - Cs*dxL*L[2]*pow(sin(Th[2]),2)) + \
cos(Th[1])*L[1]*(-(Cs*dyL*pow(cos(Th[2]),2)*L[2]) - Cs*cos(Th[1] - \
Th[2])*cos(Th[2])*dTh[1]*L[1]*L[2] - (Cs*cos(Th[2])*dTh[2]*pow(L[2],2))/2. + \
Cs*dxL*cos(Th[2])*L[2]*sin(Th[2]) - Cv*dxL*cos(Th[2])*L[2]*sin(Th[2]) + \
Cv*dTh[1]*L[1]*L[2]*sin(Th[1] - Th[2])*sin(Th[2]) - \
Cv*dyL*L[2]*pow(sin(Th[2]),2)) + (M[2]*(-2*dTh[1]*L[1]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + (cos(Th[2])*dTh[2]*L[2])/2.)*sin(Th[1]) - \
2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
(dTh[2]*L[2]*sin(Th[2]))/2.)))/2. - (M[2]*(-2*dTh[1]*L[1]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + (cos(Th[2])*dTh[2]*L[2])/2.)*sin(Th[1]) - \
2*L[1]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - \
(cos(Th[2])*pow(dTh[2],2)*L[2])/2.)*sin(Th[1]) - \
2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
(dTh[2]*L[2]*sin(Th[2]))/2.) + 2*cos(Th[1])*L[1]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - (pow(dTh[2],2)*L[2]*sin(Th[2]))/2.)))/2. - \
L[1]*sin(Th[1])*(-(Cv*dxL*pow(cos(Th[3]),2)*L[3]) + \
Cv*cos(Th[3])*dTh[1]*L[1]*L[3]*sin(Th[1] - Th[3]) + \
Cv*cos(Th[3])*dTh[2]*L[2]*L[3]*sin(Th[2] - Th[3]) + \
Cs*dyL*cos(Th[3])*L[3]*sin(Th[3]) - Cv*dyL*cos(Th[3])*L[3]*sin(Th[3]) + \
Cs*cos(Th[1] - Th[3])*dTh[1]*L[1]*L[3]*sin(Th[3]) + Cs*cos(Th[2] - \
Th[3])*dTh[2]*L[2]*L[3]*sin(Th[3]) + (Cs*dTh[3]*pow(L[3],2)*sin(Th[3]))/2. - \
Cs*dxL*L[3]*pow(sin(Th[3]),2)) + \
cos(Th[1])*L[1]*(-(Cs*dyL*pow(cos(Th[3]),2)*L[3]) - Cs*cos(Th[1] - \
Th[3])*cos(Th[3])*dTh[1]*L[1]*L[3] - Cs*cos(Th[2] - \
Th[3])*cos(Th[3])*dTh[2]*L[2]*L[3] - (Cs*cos(Th[3])*dTh[3]*pow(L[3],2))/2. + \
Cs*dxL*cos(Th[3])*L[3]*sin(Th[3]) - Cv*dxL*cos(Th[3])*L[3]*sin(Th[3]) + \
Cv*dTh[1]*L[1]*L[3]*sin(Th[1] - Th[3])*sin(Th[3]) + \
Cv*dTh[2]*L[2]*L[3]*sin(Th[2] - Th[3])*sin(Th[3]) - \
Cv*dyL*L[3]*pow(sin(Th[3]),2)) + (M[3]*(-2*dTh[1]*L[1]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + \
(cos(Th[3])*dTh[3]*L[3])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - \
(dTh[3]*L[3]*sin(Th[3]))/2.)))/2. - (M[3]*(-2*dTh[1]*L[1]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + \
(cos(Th[3])*dTh[3]*L[3])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
(cos(Th[3])*pow(dTh[3],2)*L[3])/2.)*sin(Th[1]) - \
2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - (dTh[3]*L[3]*sin(Th[3]))/2.) + \
2*cos(Th[1])*L[1]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - (pow(dTh[3],2)*L[3]*sin(Th[3]))/2.)))/2. - \
L[1]*sin(Th[1])*(-(Cv*dxL*pow(cos(Th[4]),2)*L[4]) + \
Cv*cos(Th[4])*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4]) + \
Cv*cos(Th[4])*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4]) + \
Cv*cos(Th[4])*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4]) + \
Cs*dyL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dyL*cos(Th[4])*L[4]*sin(Th[4]) + \
Cs*cos(Th[1] - Th[4])*dTh[1]*L[1]*L[4]*sin(Th[4]) + Cs*cos(Th[2] - \
Th[4])*dTh[2]*L[2]*L[4]*sin(Th[4]) + Cs*cos(Th[3] - \
Th[4])*dTh[3]*L[3]*L[4]*sin(Th[4]) + (Cs*dTh[4]*pow(L[4],2)*sin(Th[4]))/2. - \
Cs*dxL*L[4]*pow(sin(Th[4]),2)) + \
cos(Th[1])*L[1]*(-(Cs*dyL*pow(cos(Th[4]),2)*L[4]) - Cs*cos(Th[1] - \
Th[4])*cos(Th[4])*dTh[1]*L[1]*L[4] - Cs*cos(Th[2] - \
Th[4])*cos(Th[4])*dTh[2]*L[2]*L[4] - Cs*cos(Th[3] - \
Th[4])*cos(Th[4])*dTh[3]*L[3]*L[4] - (Cs*cos(Th[4])*dTh[4]*pow(L[4],2))/2. + \
Cs*dxL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dxL*cos(Th[4])*L[4]*sin(Th[4]) + \
Cv*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4])*sin(Th[4]) + \
Cv*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4])*sin(Th[4]) + \
Cv*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4])*sin(Th[4]) - \
Cv*dyL*L[4]*pow(sin(Th[4]),2)) + (M[4]*(-2*dTh[1]*L[1]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
(cos(Th[4])*dTh[4]*L[4])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
(dTh[4]*L[4]*sin(Th[4]))/2.)))/2. - (M[4]*(-2*dTh[1]*L[1]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
(cos(Th[4])*dTh[4]*L[4])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - \
(cos(Th[4])*pow(dTh[4],2)*L[4])/2.)*sin(Th[1]) - \
2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
(dTh[4]*L[4]*sin(Th[4]))/2.) + 2*cos(Th[1])*L[1]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - (pow(dTh[4],2)*L[4]*sin(Th[4]))/2.)))/2. - \
(L[1]*L[5]*sin(Th[1])*(-(Cs*sin(Th[5])*(-2*dyL*cos(Th[5]) - 2*cos(Th[1] - \
Th[5])*dTh[1]*L[1] - 2*cos(Th[2] - Th[5])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[5])*dTh[3]*L[3] - 2*cos(Th[4] - Th[5])*dTh[4]*L[4] - dTh[5]*L[5] + \
2*dxL*sin(Th[5]))) + 2*Cv*cos(Th[5])*(-(dxL*cos(Th[5])) + \
dTh[1]*L[1]*sin(Th[1] - Th[5]) + dTh[2]*L[2]*sin(Th[2] - Th[5]) + \
dTh[3]*L[3]*sin(Th[3] - Th[5]) + dTh[4]*L[4]*sin(Th[4] - Th[5]) - \
dyL*sin(Th[5]))))/2. - (cos(Th[1])*L[1]*L[5]*(Cs*cos(Th[5])*(2*dyL*cos(Th[5]) \
+ 2*cos(Th[1] - Th[5])*dTh[1]*L[1] + 2*cos(Th[2] - Th[5])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[5])*dTh[3]*L[3] + 2*cos(Th[4] - Th[5])*dTh[4]*L[4] + \
dTh[5]*L[5] - 2*dxL*sin(Th[5])) + 2*Cv*sin(Th[5])*(dxL*cos(Th[5]) - \
dTh[1]*L[1]*sin(Th[1] - Th[5]) - dTh[2]*L[2]*sin(Th[2] - Th[5]) - \
dTh[3]*L[3]*sin(Th[3] - Th[5]) - dTh[4]*L[4]*sin(Th[4] - Th[5]) + \
dyL*sin(Th[5]))))/2. + (M[5]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
(cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - (dTh[5]*L[5]*sin(Th[5]))/2.)))/2. - \
(M[5]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
(cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
(cos(Th[5])*pow(dTh[5],2)*L[5])/2.)*sin(Th[1]) - \
2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
(dTh[5]*L[5]*sin(Th[5]))/2.) + 2*cos(Th[1])*L[1]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
(pow(dTh[5],2)*L[5]*sin(Th[5]))/2.)))/2. - \
(L[1]*L[6]*sin(Th[1])*(-(Cs*sin(Th[6])*(-2*dyL*cos(Th[6]) - 2*cos(Th[1] - \
Th[6])*dTh[1]*L[1] - 2*cos(Th[2] - Th[6])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[6])*dTh[3]*L[3] - 2*cos(Th[4] - Th[6])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[6])*dTh[5]*L[5] - dTh[6]*L[6] + 2*dxL*sin(Th[6]))) + \
2*Cv*cos(Th[6])*(-(dxL*cos(Th[6])) + dTh[1]*L[1]*sin(Th[1] - Th[6]) + \
dTh[2]*L[2]*sin(Th[2] - Th[6]) + dTh[3]*L[3]*sin(Th[3] - Th[6]) + \
dTh[4]*L[4]*sin(Th[4] - Th[6]) + dTh[5]*L[5]*sin(Th[5] - Th[6]) - \
dyL*sin(Th[6]))))/2. - (cos(Th[1])*L[1]*L[6]*(Cs*cos(Th[6])*(2*dyL*cos(Th[6]) \
+ 2*cos(Th[1] - Th[6])*dTh[1]*L[1] + 2*cos(Th[2] - Th[6])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[6])*dTh[3]*L[3] + 2*cos(Th[4] - Th[6])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[6])*dTh[5]*L[5] + dTh[6]*L[6] - 2*dxL*sin(Th[6])) + \
2*Cv*sin(Th[6])*(dxL*cos(Th[6]) - dTh[1]*L[1]*sin(Th[1] - Th[6]) - \
dTh[2]*L[2]*sin(Th[2] - Th[6]) - dTh[3]*L[3]*sin(Th[3] - Th[6]) - \
dTh[4]*L[4]*sin(Th[4] - Th[6]) - dTh[5]*L[5]*sin(Th[5] - Th[6]) + \
dyL*sin(Th[6]))))/2. + (M[6]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[1]) - \
2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.)))/2. - \
(M[6]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
(cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - \
(cos(Th[6])*pow(dTh[6],2)*L[6])/2.)*sin(Th[1]) - \
2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.) + \
2*cos(Th[1])*L[1]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
(pow(dTh[6],2)*L[6]*sin(Th[6]))/2.)))/2. - \
L[1]*sin(Th[1])*(-(Cs*L[7]*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - \
Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + \
2*dxL*sin(Th[7])))/2. - Cv*cos(Th[7])*L[7]*(dxL*cos(Th[7]) - \
dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - \
dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - \
dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + \
dyL*sin(Th[7]))) + cos(Th[1])*L[1]*(-(Cs*cos(Th[7])*L[7]*(2*dyL*cos(Th[7]) + \
2*cos(Th[1] - Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + \
dTh[7]*L[7] - 2*dxL*sin(Th[7])))/2. - Cv*L[7]*sin(Th[7])*(dxL*cos(Th[7]) - \
dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - \
dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - \
dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + \
dyL*sin(Th[7]))) + (M[7]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
(cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
(dTh[7]*L[7]*sin(Th[7]))/2.)))/2. - (M[7]*(-2*dTh[1]*L[1]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
(cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
(cos(Th[7])*pow(dTh[7],2)*L[7])/2.)*sin(Th[1]) - \
2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
(dTh[7]*L[7]*sin(Th[7]))/2.) + 2*cos(Th[1])*L[1]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
(pow(dTh[7],2)*L[7]*sin(Th[7]))/2.)))/2. - \
L[1]*sin(Th[1])*(-(Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - \
Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - \
Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8]))) + cos(Th[1])*L[1]*(-(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + \
2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + \
2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - \
Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8]))) + (M[8]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
(cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.)))/2. - \
(M[8]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
(cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - \
(cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*sin(Th[1]) - \
2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
(dTh[8]*L[8]*sin(Th[8]))/2.) + 2*cos(Th[1])*L[1]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.)))/2. - \
L[1]*sin(Th[1])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - \
Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + \
2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))) + cos(Th[1])*L[1]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + \
2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + \
2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + \
dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))) + (M[9]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[1]) - \
2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - \
(M[9]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + \
(cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
(cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[1]) - \
2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + \
2*cos(Th[1])*L[1]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - \
pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - \
L[1]*sin(Th[1])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - \
Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + \
cos(Th[1])*L[1]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - \
Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + (M[10]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[1]*L[1]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
cos(Th[9])*pow(dTh[9],2)*L[9] - \
(cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[1]) - \
2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[1])*L[1]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - \
pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;\n\
 coefMat[5] = 0;\n coefMat[19] = 0;\n coefMat[33] = L[2]*sin(Th[2]);\n \
coefMat[47] = -(cos(Th[2])*L[2]);\n coefMat[61] = \
(M[2]*(cos(Th[1])*cos(Th[2])*L[1]*L[2] + L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. \
+ (M[3]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + \
2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + \
(M[4]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + \
2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + \
(M[5]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + \
2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + \
(M[6]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + \
2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + \
(M[7]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + \
2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + \
(M[8]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + \
2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + \
(M[9]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + \
2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + \
(M[10]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + \
2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2.;\n coefMat[75] = \
(pow(L[2],2)*M[2])/12. + (M[2]*((pow(cos(Th[2]),2)*pow(L[2],2))/2. + \
(pow(L[2],2)*pow(sin(Th[2]),2))/2.))/2. + \
(M[3]*(2*pow(cos(Th[2]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(Th[2]),2)))/2. \
+ (M[4]*(2*pow(cos(Th[2]),2)*pow(L[2],2) + \
2*pow(L[2],2)*pow(sin(Th[2]),2)))/2. + (M[5]*(2*pow(cos(Th[2]),2)*pow(L[2],2) \
+ 2*pow(L[2],2)*pow(sin(Th[2]),2)))/2. + \
(M[6]*(2*pow(cos(Th[2]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(Th[2]),2)))/2. \
+ (M[7]*(2*pow(cos(Th[2]),2)*pow(L[2],2) + \
2*pow(L[2],2)*pow(sin(Th[2]),2)))/2. + (M[8]*(2*pow(cos(Th[2]),2)*pow(L[2],2) \
+ 2*pow(L[2],2)*pow(sin(Th[2]),2)))/2. + \
(M[9]*(2*pow(cos(Th[2]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(Th[2]),2)))/2. \
+ (M[10]*(2*pow(cos(Th[2]),2)*pow(L[2],2) + \
2*pow(L[2],2)*pow(sin(Th[2]),2)))/2.;\n coefMat[89] = \
(M[3]*(cos(Th[2])*cos(Th[3])*L[2]*L[3] + L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. \
+ (M[4]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + \
2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + \
(M[5]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + \
2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + \
(M[6]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + \
2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + \
(M[7]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + \
2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + \
(M[8]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + \
2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + \
(M[9]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + \
2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + \
(M[10]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + \
2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2.;\n coefMat[103] = \
(M[4]*(cos(Th[2])*cos(Th[4])*L[2]*L[4] + L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. \
+ (M[5]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + \
2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + \
(M[6]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + \
2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + \
(M[7]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + \
2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + \
(M[8]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + \
2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + \
(M[9]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + \
2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + \
(M[10]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + \
2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2.;\n coefMat[117] = \
(M[5]*(cos(Th[2])*cos(Th[5])*L[2]*L[5] + L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. \
+ (M[6]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + \
2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + \
(M[7]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + \
2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + \
(M[8]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + \
2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + \
(M[9]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + \
2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + \
(M[10]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + \
2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2.;\n coefMat[131] = \
(M[6]*(cos(Th[2])*cos(Th[6])*L[2]*L[6] + L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2. \
+ (M[7]*(2*cos(Th[2])*cos(Th[6])*L[2]*L[6] + \
2*L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2. + \
(M[8]*(2*cos(Th[2])*cos(Th[6])*L[2]*L[6] + \
2*L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2. + \
(M[9]*(2*cos(Th[2])*cos(Th[6])*L[2]*L[6] + \
2*L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2. + \
(M[10]*(2*cos(Th[2])*cos(Th[6])*L[2]*L[6] + \
2*L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2.;\n coefMat[145] = \
(M[7]*(cos(Th[2])*cos(Th[7])*L[2]*L[7] + L[2]*L[7]*sin(Th[2])*sin(Th[7])))/2. \
+ (M[8]*(2*cos(Th[2])*cos(Th[7])*L[2]*L[7] + \
2*L[2]*L[7]*sin(Th[2])*sin(Th[7])))/2. + \
(M[9]*(2*cos(Th[2])*cos(Th[7])*L[2]*L[7] + \
2*L[2]*L[7]*sin(Th[2])*sin(Th[7])))/2. + \
(M[10]*(2*cos(Th[2])*cos(Th[7])*L[2]*L[7] + \
2*L[2]*L[7]*sin(Th[2])*sin(Th[7])))/2.;\n coefMat[159] = \
(M[8]*(cos(Th[2])*cos(Th[8])*L[2]*L[8] + L[2]*L[8]*sin(Th[2])*sin(Th[8])))/2. \
+ (M[9]*(2*cos(Th[2])*cos(Th[8])*L[2]*L[8] + \
2*L[2]*L[8]*sin(Th[2])*sin(Th[8])))/2. + \
(M[10]*(2*cos(Th[2])*cos(Th[8])*L[2]*L[8] + \
2*L[2]*L[8]*sin(Th[2])*sin(Th[8])))/2.;\n coefMat[173] = \
(M[9]*(cos(Th[2])*cos(Th[9])*L[2]*L[9] + L[2]*L[9]*sin(Th[2])*sin(Th[9])))/2. \
+ (M[10]*(2*cos(Th[2])*cos(Th[9])*L[2]*L[9] + \
2*L[2]*L[9]*sin(Th[2])*sin(Th[9])))/2.;\n coefMat[187] = \
(M[10]*(cos(Th[2])*cos(Th[10])*L[2]*L[10] + \
L[2]*L[10]*sin(Th[2])*sin(Th[10])))/2.;\n rhsVec[5] = \
-(Cs*dTh[2]*pow(L[2],3))/12. - \
(L[2]*sin(Th[2])*(-(Cv*dxL*pow(cos(Th[2]),2)*L[2]) + \
Cv*cos(Th[2])*dTh[1]*L[1]*L[2]*sin(Th[1] - Th[2]) + \
Cs*dyL*cos(Th[2])*L[2]*sin(Th[2]) - Cv*dyL*cos(Th[2])*L[2]*sin(Th[2]) + \
Cs*cos(Th[1] - Th[2])*dTh[1]*L[1]*L[2]*sin(Th[2]) + \
(Cs*dTh[2]*pow(L[2],2)*sin(Th[2]))/2. - Cs*dxL*L[2]*pow(sin(Th[2]),2)))/2. + \
(cos(Th[2])*L[2]*(-(Cs*dyL*pow(cos(Th[2]),2)*L[2]) - Cs*cos(Th[1] - \
Th[2])*cos(Th[2])*dTh[1]*L[1]*L[2] - (Cs*cos(Th[2])*dTh[2]*pow(L[2],2))/2. + \
Cs*dxL*cos(Th[2])*L[2]*sin(Th[2]) - Cv*dxL*cos(Th[2])*L[2]*sin(Th[2]) + \
Cv*dTh[1]*L[1]*L[2]*sin(Th[1] - Th[2])*sin(Th[2]) - \
Cv*dyL*L[2]*pow(sin(Th[2]),2)))/2. + (M[2]*(-(dTh[2]*L[2]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + (cos(Th[2])*dTh[2]*L[2])/2.)*sin(Th[2])) - \
cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
(dTh[2]*L[2]*sin(Th[2]))/2.)))/2. - (M[2]*(-(dTh[2]*L[2]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + (cos(Th[2])*dTh[2]*L[2])/2.)*sin(Th[2])) - \
L[2]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - \
(cos(Th[2])*pow(dTh[2],2)*L[2])/2.)*sin(Th[2]) - cos(Th[2])*dTh[2]*L[2]*(dxL \
- dTh[1]*L[1]*sin(Th[1]) - (dTh[2]*L[2]*sin(Th[2]))/2.) + \
cos(Th[2])*L[2]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
(pow(dTh[2],2)*L[2]*sin(Th[2]))/2.)))/2. - \
L[2]*sin(Th[2])*(-(Cv*dxL*pow(cos(Th[3]),2)*L[3]) + \
Cv*cos(Th[3])*dTh[1]*L[1]*L[3]*sin(Th[1] - Th[3]) + \
Cv*cos(Th[3])*dTh[2]*L[2]*L[3]*sin(Th[2] - Th[3]) + \
Cs*dyL*cos(Th[3])*L[3]*sin(Th[3]) - Cv*dyL*cos(Th[3])*L[3]*sin(Th[3]) + \
Cs*cos(Th[1] - Th[3])*dTh[1]*L[1]*L[3]*sin(Th[3]) + Cs*cos(Th[2] - \
Th[3])*dTh[2]*L[2]*L[3]*sin(Th[3]) + (Cs*dTh[3]*pow(L[3],2)*sin(Th[3]))/2. - \
Cs*dxL*L[3]*pow(sin(Th[3]),2)) + \
cos(Th[2])*L[2]*(-(Cs*dyL*pow(cos(Th[3]),2)*L[3]) - Cs*cos(Th[1] - \
Th[3])*cos(Th[3])*dTh[1]*L[1]*L[3] - Cs*cos(Th[2] - \
Th[3])*cos(Th[3])*dTh[2]*L[2]*L[3] - (Cs*cos(Th[3])*dTh[3]*pow(L[3],2))/2. + \
Cs*dxL*cos(Th[3])*L[3]*sin(Th[3]) - Cv*dxL*cos(Th[3])*L[3]*sin(Th[3]) + \
Cv*dTh[1]*L[1]*L[3]*sin(Th[1] - Th[3])*sin(Th[3]) + \
Cv*dTh[2]*L[2]*L[3]*sin(Th[2] - Th[3])*sin(Th[3]) - \
Cv*dyL*L[3]*pow(sin(Th[3]),2)) + (M[3]*(-2*dTh[2]*L[2]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + \
(cos(Th[3])*dTh[3]*L[3])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - \
(dTh[3]*L[3]*sin(Th[3]))/2.)))/2. - (M[3]*(-2*dTh[2]*L[2]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + \
(cos(Th[3])*dTh[3]*L[3])/2.)*sin(Th[2]) - 2*L[2]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
(cos(Th[3])*pow(dTh[3],2)*L[3])/2.)*sin(Th[2]) - \
2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - (dTh[3]*L[3]*sin(Th[3]))/2.) + \
2*cos(Th[2])*L[2]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - (pow(dTh[3],2)*L[3]*sin(Th[3]))/2.)))/2. - \
L[2]*sin(Th[2])*(-(Cv*dxL*pow(cos(Th[4]),2)*L[4]) + \
Cv*cos(Th[4])*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4]) + \
Cv*cos(Th[4])*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4]) + \
Cv*cos(Th[4])*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4]) + \
Cs*dyL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dyL*cos(Th[4])*L[4]*sin(Th[4]) + \
Cs*cos(Th[1] - Th[4])*dTh[1]*L[1]*L[4]*sin(Th[4]) + Cs*cos(Th[2] - \
Th[4])*dTh[2]*L[2]*L[4]*sin(Th[4]) + Cs*cos(Th[3] - \
Th[4])*dTh[3]*L[3]*L[4]*sin(Th[4]) + (Cs*dTh[4]*pow(L[4],2)*sin(Th[4]))/2. - \
Cs*dxL*L[4]*pow(sin(Th[4]),2)) + \
cos(Th[2])*L[2]*(-(Cs*dyL*pow(cos(Th[4]),2)*L[4]) - Cs*cos(Th[1] - \
Th[4])*cos(Th[4])*dTh[1]*L[1]*L[4] - Cs*cos(Th[2] - \
Th[4])*cos(Th[4])*dTh[2]*L[2]*L[4] - Cs*cos(Th[3] - \
Th[4])*cos(Th[4])*dTh[3]*L[3]*L[4] - (Cs*cos(Th[4])*dTh[4]*pow(L[4],2))/2. + \
Cs*dxL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dxL*cos(Th[4])*L[4]*sin(Th[4]) + \
Cv*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4])*sin(Th[4]) + \
Cv*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4])*sin(Th[4]) + \
Cv*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4])*sin(Th[4]) - \
Cv*dyL*L[4]*pow(sin(Th[4]),2)) + (M[4]*(-2*dTh[2]*L[2]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
(cos(Th[4])*dTh[4]*L[4])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
(dTh[4]*L[4]*sin(Th[4]))/2.)))/2. - (M[4]*(-2*dTh[2]*L[2]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
(cos(Th[4])*dTh[4]*L[4])/2.)*sin(Th[2]) - 2*L[2]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - \
(cos(Th[4])*pow(dTh[4],2)*L[4])/2.)*sin(Th[2]) - \
2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
(dTh[4]*L[4]*sin(Th[4]))/2.) + 2*cos(Th[2])*L[2]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - (pow(dTh[4],2)*L[4]*sin(Th[4]))/2.)))/2. - \
(L[2]*L[5]*sin(Th[2])*(-(Cs*sin(Th[5])*(-2*dyL*cos(Th[5]) - 2*cos(Th[1] - \
Th[5])*dTh[1]*L[1] - 2*cos(Th[2] - Th[5])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[5])*dTh[3]*L[3] - 2*cos(Th[4] - Th[5])*dTh[4]*L[4] - dTh[5]*L[5] + \
2*dxL*sin(Th[5]))) + 2*Cv*cos(Th[5])*(-(dxL*cos(Th[5])) + \
dTh[1]*L[1]*sin(Th[1] - Th[5]) + dTh[2]*L[2]*sin(Th[2] - Th[5]) + \
dTh[3]*L[3]*sin(Th[3] - Th[5]) + dTh[4]*L[4]*sin(Th[4] - Th[5]) - \
dyL*sin(Th[5]))))/2. - (cos(Th[2])*L[2]*L[5]*(Cs*cos(Th[5])*(2*dyL*cos(Th[5]) \
+ 2*cos(Th[1] - Th[5])*dTh[1]*L[1] + 2*cos(Th[2] - Th[5])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[5])*dTh[3]*L[3] + 2*cos(Th[4] - Th[5])*dTh[4]*L[4] + \
dTh[5]*L[5] - 2*dxL*sin(Th[5])) + 2*Cv*sin(Th[5])*(dxL*cos(Th[5]) - \
dTh[1]*L[1]*sin(Th[1] - Th[5]) - dTh[2]*L[2]*sin(Th[2] - Th[5]) - \
dTh[3]*L[3]*sin(Th[3] - Th[5]) - dTh[4]*L[4]*sin(Th[4] - Th[5]) + \
dyL*sin(Th[5]))))/2. + (M[5]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
(cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - (dTh[5]*L[5]*sin(Th[5]))/2.)))/2. - \
(M[5]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
(cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[2]) - 2*L[2]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
(cos(Th[5])*pow(dTh[5],2)*L[5])/2.)*sin(Th[2]) - \
2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
(dTh[5]*L[5]*sin(Th[5]))/2.) + 2*cos(Th[2])*L[2]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
(pow(dTh[5],2)*L[5]*sin(Th[5]))/2.)))/2. - \
(L[2]*L[6]*sin(Th[2])*(-(Cs*sin(Th[6])*(-2*dyL*cos(Th[6]) - 2*cos(Th[1] - \
Th[6])*dTh[1]*L[1] - 2*cos(Th[2] - Th[6])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[6])*dTh[3]*L[3] - 2*cos(Th[4] - Th[6])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[6])*dTh[5]*L[5] - dTh[6]*L[6] + 2*dxL*sin(Th[6]))) + \
2*Cv*cos(Th[6])*(-(dxL*cos(Th[6])) + dTh[1]*L[1]*sin(Th[1] - Th[6]) + \
dTh[2]*L[2]*sin(Th[2] - Th[6]) + dTh[3]*L[3]*sin(Th[3] - Th[6]) + \
dTh[4]*L[4]*sin(Th[4] - Th[6]) + dTh[5]*L[5]*sin(Th[5] - Th[6]) - \
dyL*sin(Th[6]))))/2. - (cos(Th[2])*L[2]*L[6]*(Cs*cos(Th[6])*(2*dyL*cos(Th[6]) \
+ 2*cos(Th[1] - Th[6])*dTh[1]*L[1] + 2*cos(Th[2] - Th[6])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[6])*dTh[3]*L[3] + 2*cos(Th[4] - Th[6])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[6])*dTh[5]*L[5] + dTh[6]*L[6] - 2*dxL*sin(Th[6])) + \
2*Cv*sin(Th[6])*(dxL*cos(Th[6]) - dTh[1]*L[1]*sin(Th[1] - Th[6]) - \
dTh[2]*L[2]*sin(Th[2] - Th[6]) - dTh[3]*L[3]*sin(Th[3] - Th[6]) - \
dTh[4]*L[4]*sin(Th[4] - Th[6]) - dTh[5]*L[5]*sin(Th[5] - Th[6]) + \
dyL*sin(Th[6]))))/2. + (M[6]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[2]) - \
2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.)))/2. - \
(M[6]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
(cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[2]) - 2*L[2]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - \
(cos(Th[6])*pow(dTh[6],2)*L[6])/2.)*sin(Th[2]) - \
2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.) + \
2*cos(Th[2])*L[2]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
(pow(dTh[6],2)*L[6]*sin(Th[6]))/2.)))/2. - \
L[2]*sin(Th[2])*(-(Cs*L[7]*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - \
Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + \
2*dxL*sin(Th[7])))/2. - Cv*cos(Th[7])*L[7]*(dxL*cos(Th[7]) - \
dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - \
dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - \
dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + \
dyL*sin(Th[7]))) + cos(Th[2])*L[2]*(-(Cs*cos(Th[7])*L[7]*(2*dyL*cos(Th[7]) + \
2*cos(Th[1] - Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + \
dTh[7]*L[7] - 2*dxL*sin(Th[7])))/2. - Cv*L[7]*sin(Th[7])*(dxL*cos(Th[7]) - \
dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - \
dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - \
dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + \
dyL*sin(Th[7]))) + (M[7]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
(cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
(dTh[7]*L[7]*sin(Th[7]))/2.)))/2. - (M[7]*(-2*dTh[2]*L[2]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
(cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[2]) - 2*L[2]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
(cos(Th[7])*pow(dTh[7],2)*L[7])/2.)*sin(Th[2]) - \
2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
(dTh[7]*L[7]*sin(Th[7]))/2.) + 2*cos(Th[2])*L[2]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
(pow(dTh[7],2)*L[7]*sin(Th[7]))/2.)))/2. - \
L[2]*sin(Th[2])*(-(Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - \
Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - \
Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8]))) + cos(Th[2])*L[2]*(-(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + \
2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + \
2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - \
Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8]))) + (M[8]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
(cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.)))/2. - \
(M[8]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
(cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[2]) - 2*L[2]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - \
(cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*sin(Th[2]) - \
2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
(dTh[8]*L[8]*sin(Th[8]))/2.) + 2*cos(Th[2])*L[2]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.)))/2. - \
L[2]*sin(Th[2])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - \
Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + \
2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))) + cos(Th[2])*L[2]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + \
2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + \
2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + \
dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))) + (M[9]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[2]) - \
2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - \
(M[9]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + \
(cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[2]) - 2*L[2]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
(cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[2]) - \
2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + \
2*cos(Th[2])*L[2]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - \
pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - \
L[2]*sin(Th[2])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - \
Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + \
cos(Th[2])*L[2]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - \
Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + (M[10]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[2]*L[2]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[2]) - 2*L[2]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
cos(Th[9])*pow(dTh[9],2)*L[9] - \
(cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[2]) - \
2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[2])*L[2]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - \
pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;\n\
 coefMat[6] = 0;\n coefMat[20] = 0;\n coefMat[34] = L[3]*sin(Th[3]);\n \
coefMat[48] = -(cos(Th[3])*L[3]);\n coefMat[62] = \
(M[3]*(cos(Th[1])*cos(Th[3])*L[1]*L[3] + L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. \
+ (M[4]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + \
2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + \
(M[5]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + \
2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + \
(M[6]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + \
2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + \
(M[7]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + \
2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + \
(M[8]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + \
2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + \
(M[9]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + \
2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + \
(M[10]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + \
2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2.;\n coefMat[76] = \
(M[3]*(cos(Th[2])*cos(Th[3])*L[2]*L[3] + L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. \
+ (M[4]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + \
2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + \
(M[5]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + \
2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + \
(M[6]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + \
2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + \
(M[7]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + \
2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + \
(M[8]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + \
2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + \
(M[9]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + \
2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + \
(M[10]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + \
2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2.;\n coefMat[90] = \
(pow(L[3],2)*M[3])/12. + (M[3]*((pow(cos(Th[3]),2)*pow(L[3],2))/2. + \
(pow(L[3],2)*pow(sin(Th[3]),2))/2.))/2. + \
(M[4]*(2*pow(cos(Th[3]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(Th[3]),2)))/2. \
+ (M[5]*(2*pow(cos(Th[3]),2)*pow(L[3],2) + \
2*pow(L[3],2)*pow(sin(Th[3]),2)))/2. + (M[6]*(2*pow(cos(Th[3]),2)*pow(L[3],2) \
+ 2*pow(L[3],2)*pow(sin(Th[3]),2)))/2. + \
(M[7]*(2*pow(cos(Th[3]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(Th[3]),2)))/2. \
+ (M[8]*(2*pow(cos(Th[3]),2)*pow(L[3],2) + \
2*pow(L[3],2)*pow(sin(Th[3]),2)))/2. + (M[9]*(2*pow(cos(Th[3]),2)*pow(L[3],2) \
+ 2*pow(L[3],2)*pow(sin(Th[3]),2)))/2. + \
(M[10]*(2*pow(cos(Th[3]),2)*pow(L[3],2) + \
2*pow(L[3],2)*pow(sin(Th[3]),2)))/2.;\n coefMat[104] = \
(M[4]*(cos(Th[3])*cos(Th[4])*L[3]*L[4] + L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. \
+ (M[5]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + \
2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + \
(M[6]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + \
2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + \
(M[7]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + \
2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + \
(M[8]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + \
2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + \
(M[9]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + \
2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + \
(M[10]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + \
2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2.;\n coefMat[118] = \
(M[5]*(cos(Th[3])*cos(Th[5])*L[3]*L[5] + L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. \
+ (M[6]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + \
2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + \
(M[7]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + \
2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + \
(M[8]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + \
2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + \
(M[9]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + \
2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + \
(M[10]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + \
2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2.;\n coefMat[132] = \
(M[6]*(cos(Th[3])*cos(Th[6])*L[3]*L[6] + L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2. \
+ (M[7]*(2*cos(Th[3])*cos(Th[6])*L[3]*L[6] + \
2*L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2. + \
(M[8]*(2*cos(Th[3])*cos(Th[6])*L[3]*L[6] + \
2*L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2. + \
(M[9]*(2*cos(Th[3])*cos(Th[6])*L[3]*L[6] + \
2*L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2. + \
(M[10]*(2*cos(Th[3])*cos(Th[6])*L[3]*L[6] + \
2*L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2.;\n coefMat[146] = \
(M[7]*(cos(Th[3])*cos(Th[7])*L[3]*L[7] + L[3]*L[7]*sin(Th[3])*sin(Th[7])))/2. \
+ (M[8]*(2*cos(Th[3])*cos(Th[7])*L[3]*L[7] + \
2*L[3]*L[7]*sin(Th[3])*sin(Th[7])))/2. + \
(M[9]*(2*cos(Th[3])*cos(Th[7])*L[3]*L[7] + \
2*L[3]*L[7]*sin(Th[3])*sin(Th[7])))/2. + \
(M[10]*(2*cos(Th[3])*cos(Th[7])*L[3]*L[7] + \
2*L[3]*L[7]*sin(Th[3])*sin(Th[7])))/2.;\n coefMat[160] = \
(M[8]*(cos(Th[3])*cos(Th[8])*L[3]*L[8] + L[3]*L[8]*sin(Th[3])*sin(Th[8])))/2. \
+ (M[9]*(2*cos(Th[3])*cos(Th[8])*L[3]*L[8] + \
2*L[3]*L[8]*sin(Th[3])*sin(Th[8])))/2. + \
(M[10]*(2*cos(Th[3])*cos(Th[8])*L[3]*L[8] + \
2*L[3]*L[8]*sin(Th[3])*sin(Th[8])))/2.;\n coefMat[174] = \
(M[9]*(cos(Th[3])*cos(Th[9])*L[3]*L[9] + L[3]*L[9]*sin(Th[3])*sin(Th[9])))/2. \
+ (M[10]*(2*cos(Th[3])*cos(Th[9])*L[3]*L[9] + \
2*L[3]*L[9]*sin(Th[3])*sin(Th[9])))/2.;\n coefMat[188] = \
(M[10]*(cos(Th[3])*cos(Th[10])*L[3]*L[10] + \
L[3]*L[10]*sin(Th[3])*sin(Th[10])))/2.;\n rhsVec[6] = \
-(Cs*dTh[3]*pow(L[3],3))/12. - \
(L[3]*sin(Th[3])*(-(Cv*dxL*pow(cos(Th[3]),2)*L[3]) + \
Cv*cos(Th[3])*dTh[1]*L[1]*L[3]*sin(Th[1] - Th[3]) + \
Cv*cos(Th[3])*dTh[2]*L[2]*L[3]*sin(Th[2] - Th[3]) + \
Cs*dyL*cos(Th[3])*L[3]*sin(Th[3]) - Cv*dyL*cos(Th[3])*L[3]*sin(Th[3]) + \
Cs*cos(Th[1] - Th[3])*dTh[1]*L[1]*L[3]*sin(Th[3]) + Cs*cos(Th[2] - \
Th[3])*dTh[2]*L[2]*L[3]*sin(Th[3]) + (Cs*dTh[3]*pow(L[3],2)*sin(Th[3]))/2. - \
Cs*dxL*L[3]*pow(sin(Th[3]),2)))/2. + \
(cos(Th[3])*L[3]*(-(Cs*dyL*pow(cos(Th[3]),2)*L[3]) - Cs*cos(Th[1] - \
Th[3])*cos(Th[3])*dTh[1]*L[1]*L[3] - Cs*cos(Th[2] - \
Th[3])*cos(Th[3])*dTh[2]*L[2]*L[3] - (Cs*cos(Th[3])*dTh[3]*pow(L[3],2))/2. + \
Cs*dxL*cos(Th[3])*L[3]*sin(Th[3]) - Cv*dxL*cos(Th[3])*L[3]*sin(Th[3]) + \
Cv*dTh[1]*L[1]*L[3]*sin(Th[1] - Th[3])*sin(Th[3]) + \
Cv*dTh[2]*L[2]*L[3]*sin(Th[2] - Th[3])*sin(Th[3]) - \
Cv*dyL*L[3]*pow(sin(Th[3]),2)))/2. + (M[3]*(-(dTh[3]*L[3]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + \
(cos(Th[3])*dTh[3]*L[3])/2.)*sin(Th[3])) - cos(Th[3])*dTh[3]*L[3]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - \
(dTh[3]*L[3]*sin(Th[3]))/2.)))/2. - (M[3]*(-(dTh[3]*L[3]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + \
(cos(Th[3])*dTh[3]*L[3])/2.)*sin(Th[3])) - L[3]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
(cos(Th[3])*pow(dTh[3],2)*L[3])/2.)*sin(Th[3]) - cos(Th[3])*dTh[3]*L[3]*(dxL \
- dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - \
(dTh[3]*L[3]*sin(Th[3]))/2.) + cos(Th[3])*L[3]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
(pow(dTh[3],2)*L[3]*sin(Th[3]))/2.)))/2. - \
L[3]*sin(Th[3])*(-(Cv*dxL*pow(cos(Th[4]),2)*L[4]) + \
Cv*cos(Th[4])*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4]) + \
Cv*cos(Th[4])*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4]) + \
Cv*cos(Th[4])*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4]) + \
Cs*dyL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dyL*cos(Th[4])*L[4]*sin(Th[4]) + \
Cs*cos(Th[1] - Th[4])*dTh[1]*L[1]*L[4]*sin(Th[4]) + Cs*cos(Th[2] - \
Th[4])*dTh[2]*L[2]*L[4]*sin(Th[4]) + Cs*cos(Th[3] - \
Th[4])*dTh[3]*L[3]*L[4]*sin(Th[4]) + (Cs*dTh[4]*pow(L[4],2)*sin(Th[4]))/2. - \
Cs*dxL*L[4]*pow(sin(Th[4]),2)) + \
cos(Th[3])*L[3]*(-(Cs*dyL*pow(cos(Th[4]),2)*L[4]) - Cs*cos(Th[1] - \
Th[4])*cos(Th[4])*dTh[1]*L[1]*L[4] - Cs*cos(Th[2] - \
Th[4])*cos(Th[4])*dTh[2]*L[2]*L[4] - Cs*cos(Th[3] - \
Th[4])*cos(Th[4])*dTh[3]*L[3]*L[4] - (Cs*cos(Th[4])*dTh[4]*pow(L[4],2))/2. + \
Cs*dxL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dxL*cos(Th[4])*L[4]*sin(Th[4]) + \
Cv*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4])*sin(Th[4]) + \
Cv*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4])*sin(Th[4]) + \
Cv*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4])*sin(Th[4]) - \
Cv*dyL*L[4]*pow(sin(Th[4]),2)) + (M[4]*(-2*dTh[3]*L[3]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
(cos(Th[4])*dTh[4]*L[4])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
(dTh[4]*L[4]*sin(Th[4]))/2.)))/2. - (M[4]*(-2*dTh[3]*L[3]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
(cos(Th[4])*dTh[4]*L[4])/2.)*sin(Th[3]) - 2*L[3]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - \
(cos(Th[4])*pow(dTh[4],2)*L[4])/2.)*sin(Th[3]) - \
2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
(dTh[4]*L[4]*sin(Th[4]))/2.) + 2*cos(Th[3])*L[3]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - (pow(dTh[4],2)*L[4]*sin(Th[4]))/2.)))/2. - \
(L[3]*L[5]*sin(Th[3])*(-(Cs*sin(Th[5])*(-2*dyL*cos(Th[5]) - 2*cos(Th[1] - \
Th[5])*dTh[1]*L[1] - 2*cos(Th[2] - Th[5])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[5])*dTh[3]*L[3] - 2*cos(Th[4] - Th[5])*dTh[4]*L[4] - dTh[5]*L[5] + \
2*dxL*sin(Th[5]))) + 2*Cv*cos(Th[5])*(-(dxL*cos(Th[5])) + \
dTh[1]*L[1]*sin(Th[1] - Th[5]) + dTh[2]*L[2]*sin(Th[2] - Th[5]) + \
dTh[3]*L[3]*sin(Th[3] - Th[5]) + dTh[4]*L[4]*sin(Th[4] - Th[5]) - \
dyL*sin(Th[5]))))/2. - (cos(Th[3])*L[3]*L[5]*(Cs*cos(Th[5])*(2*dyL*cos(Th[5]) \
+ 2*cos(Th[1] - Th[5])*dTh[1]*L[1] + 2*cos(Th[2] - Th[5])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[5])*dTh[3]*L[3] + 2*cos(Th[4] - Th[5])*dTh[4]*L[4] + \
dTh[5]*L[5] - 2*dxL*sin(Th[5])) + 2*Cv*sin(Th[5])*(dxL*cos(Th[5]) - \
dTh[1]*L[1]*sin(Th[1] - Th[5]) - dTh[2]*L[2]*sin(Th[2] - Th[5]) - \
dTh[3]*L[3]*sin(Th[3] - Th[5]) - dTh[4]*L[4]*sin(Th[4] - Th[5]) + \
dyL*sin(Th[5]))))/2. + (M[5]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
(cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - (dTh[5]*L[5]*sin(Th[5]))/2.)))/2. - \
(M[5]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
(cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[3]) - 2*L[3]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
(cos(Th[5])*pow(dTh[5],2)*L[5])/2.)*sin(Th[3]) - \
2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
(dTh[5]*L[5]*sin(Th[5]))/2.) + 2*cos(Th[3])*L[3]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
(pow(dTh[5],2)*L[5]*sin(Th[5]))/2.)))/2. - \
(L[3]*L[6]*sin(Th[3])*(-(Cs*sin(Th[6])*(-2*dyL*cos(Th[6]) - 2*cos(Th[1] - \
Th[6])*dTh[1]*L[1] - 2*cos(Th[2] - Th[6])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[6])*dTh[3]*L[3] - 2*cos(Th[4] - Th[6])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[6])*dTh[5]*L[5] - dTh[6]*L[6] + 2*dxL*sin(Th[6]))) + \
2*Cv*cos(Th[6])*(-(dxL*cos(Th[6])) + dTh[1]*L[1]*sin(Th[1] - Th[6]) + \
dTh[2]*L[2]*sin(Th[2] - Th[6]) + dTh[3]*L[3]*sin(Th[3] - Th[6]) + \
dTh[4]*L[4]*sin(Th[4] - Th[6]) + dTh[5]*L[5]*sin(Th[5] - Th[6]) - \
dyL*sin(Th[6]))))/2. - (cos(Th[3])*L[3]*L[6]*(Cs*cos(Th[6])*(2*dyL*cos(Th[6]) \
+ 2*cos(Th[1] - Th[6])*dTh[1]*L[1] + 2*cos(Th[2] - Th[6])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[6])*dTh[3]*L[3] + 2*cos(Th[4] - Th[6])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[6])*dTh[5]*L[5] + dTh[6]*L[6] - 2*dxL*sin(Th[6])) + \
2*Cv*sin(Th[6])*(dxL*cos(Th[6]) - dTh[1]*L[1]*sin(Th[1] - Th[6]) - \
dTh[2]*L[2]*sin(Th[2] - Th[6]) - dTh[3]*L[3]*sin(Th[3] - Th[6]) - \
dTh[4]*L[4]*sin(Th[4] - Th[6]) - dTh[5]*L[5]*sin(Th[5] - Th[6]) + \
dyL*sin(Th[6]))))/2. + (M[6]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[3]) - \
2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.)))/2. - \
(M[6]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
(cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[3]) - 2*L[3]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - \
(cos(Th[6])*pow(dTh[6],2)*L[6])/2.)*sin(Th[3]) - \
2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.) + \
2*cos(Th[3])*L[3]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
(pow(dTh[6],2)*L[6]*sin(Th[6]))/2.)))/2. - \
L[3]*sin(Th[3])*(-(Cs*L[7]*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - \
Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + \
2*dxL*sin(Th[7])))/2. - Cv*cos(Th[7])*L[7]*(dxL*cos(Th[7]) - \
dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - \
dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - \
dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + \
dyL*sin(Th[7]))) + cos(Th[3])*L[3]*(-(Cs*cos(Th[7])*L[7]*(2*dyL*cos(Th[7]) + \
2*cos(Th[1] - Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + \
dTh[7]*L[7] - 2*dxL*sin(Th[7])))/2. - Cv*L[7]*sin(Th[7])*(dxL*cos(Th[7]) - \
dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - \
dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - \
dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + \
dyL*sin(Th[7]))) + (M[7]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
(cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
(dTh[7]*L[7]*sin(Th[7]))/2.)))/2. - (M[7]*(-2*dTh[3]*L[3]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
(cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[3]) - 2*L[3]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
(cos(Th[7])*pow(dTh[7],2)*L[7])/2.)*sin(Th[3]) - \
2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
(dTh[7]*L[7]*sin(Th[7]))/2.) + 2*cos(Th[3])*L[3]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
(pow(dTh[7],2)*L[7]*sin(Th[7]))/2.)))/2. - \
L[3]*sin(Th[3])*(-(Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - \
Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - \
Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8]))) + cos(Th[3])*L[3]*(-(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + \
2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + \
2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - \
Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8]))) + (M[8]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
(cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.)))/2. - \
(M[8]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
(cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[3]) - 2*L[3]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - \
(cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*sin(Th[3]) - \
2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
(dTh[8]*L[8]*sin(Th[8]))/2.) + 2*cos(Th[3])*L[3]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.)))/2. - \
L[3]*sin(Th[3])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - \
Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + \
2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))) + cos(Th[3])*L[3]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + \
2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + \
2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + \
dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))) + (M[9]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[3]) - \
2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - \
(M[9]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + \
(cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[3]) - 2*L[3]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
(cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[3]) - \
2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + \
2*cos(Th[3])*L[3]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - \
pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - \
L[3]*sin(Th[3])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - \
Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + \
cos(Th[3])*L[3]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - \
Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + (M[10]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[3]*L[3]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[3]) - 2*L[3]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
cos(Th[9])*pow(dTh[9],2)*L[9] - \
(cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[3]) - \
2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[3])*L[3]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - \
pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;\n\
 coefMat[7] = 0;\n coefMat[21] = 0;\n coefMat[35] = L[4]*sin(Th[4]);\n \
coefMat[49] = -(cos(Th[4])*L[4]);\n coefMat[63] = \
(M[4]*(cos(Th[1])*cos(Th[4])*L[1]*L[4] + L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. \
+ (M[5]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + \
2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + \
(M[6]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + \
2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + \
(M[7]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + \
2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + \
(M[8]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + \
2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + \
(M[9]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + \
2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + \
(M[10]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + \
2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2.;\n coefMat[77] = \
(M[4]*(cos(Th[2])*cos(Th[4])*L[2]*L[4] + L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. \
+ (M[5]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + \
2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + \
(M[6]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + \
2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + \
(M[7]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + \
2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + \
(M[8]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + \
2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + \
(M[9]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + \
2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + \
(M[10]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + \
2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2.;\n coefMat[91] = \
(M[4]*(cos(Th[3])*cos(Th[4])*L[3]*L[4] + L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. \
+ (M[5]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + \
2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + \
(M[6]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + \
2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + \
(M[7]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + \
2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + \
(M[8]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + \
2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + \
(M[9]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + \
2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + \
(M[10]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + \
2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2.;\n coefMat[105] = \
(pow(L[4],2)*M[4])/12. + (M[4]*((pow(cos(Th[4]),2)*pow(L[4],2))/2. + \
(pow(L[4],2)*pow(sin(Th[4]),2))/2.))/2. + \
(M[5]*(2*pow(cos(Th[4]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(Th[4]),2)))/2. \
+ (M[6]*(2*pow(cos(Th[4]),2)*pow(L[4],2) + \
2*pow(L[4],2)*pow(sin(Th[4]),2)))/2. + (M[7]*(2*pow(cos(Th[4]),2)*pow(L[4],2) \
+ 2*pow(L[4],2)*pow(sin(Th[4]),2)))/2. + \
(M[8]*(2*pow(cos(Th[4]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(Th[4]),2)))/2. \
+ (M[9]*(2*pow(cos(Th[4]),2)*pow(L[4],2) + \
2*pow(L[4],2)*pow(sin(Th[4]),2)))/2. + \
(M[10]*(2*pow(cos(Th[4]),2)*pow(L[4],2) + \
2*pow(L[4],2)*pow(sin(Th[4]),2)))/2.;\n coefMat[119] = \
(M[5]*(cos(Th[4])*cos(Th[5])*L[4]*L[5] + L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. \
+ (M[6]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + \
2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + \
(M[7]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + \
2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + \
(M[8]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + \
2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + \
(M[9]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + \
2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + \
(M[10]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + \
2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2.;\n coefMat[133] = \
(M[6]*(cos(Th[4])*cos(Th[6])*L[4]*L[6] + L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2. \
+ (M[7]*(2*cos(Th[4])*cos(Th[6])*L[4]*L[6] + \
2*L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2. + \
(M[8]*(2*cos(Th[4])*cos(Th[6])*L[4]*L[6] + \
2*L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2. + \
(M[9]*(2*cos(Th[4])*cos(Th[6])*L[4]*L[6] + \
2*L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2. + \
(M[10]*(2*cos(Th[4])*cos(Th[6])*L[4]*L[6] + \
2*L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2.;\n coefMat[147] = \
(M[7]*(cos(Th[4])*cos(Th[7])*L[4]*L[7] + L[4]*L[7]*sin(Th[4])*sin(Th[7])))/2. \
+ (M[8]*(2*cos(Th[4])*cos(Th[7])*L[4]*L[7] + \
2*L[4]*L[7]*sin(Th[4])*sin(Th[7])))/2. + \
(M[9]*(2*cos(Th[4])*cos(Th[7])*L[4]*L[7] + \
2*L[4]*L[7]*sin(Th[4])*sin(Th[7])))/2. + \
(M[10]*(2*cos(Th[4])*cos(Th[7])*L[4]*L[7] + \
2*L[4]*L[7]*sin(Th[4])*sin(Th[7])))/2.;\n coefMat[161] = \
(M[8]*(cos(Th[4])*cos(Th[8])*L[4]*L[8] + L[4]*L[8]*sin(Th[4])*sin(Th[8])))/2. \
+ (M[9]*(2*cos(Th[4])*cos(Th[8])*L[4]*L[8] + \
2*L[4]*L[8]*sin(Th[4])*sin(Th[8])))/2. + \
(M[10]*(2*cos(Th[4])*cos(Th[8])*L[4]*L[8] + \
2*L[4]*L[8]*sin(Th[4])*sin(Th[8])))/2.;\n coefMat[175] = \
(M[9]*(cos(Th[4])*cos(Th[9])*L[4]*L[9] + L[4]*L[9]*sin(Th[4])*sin(Th[9])))/2. \
+ (M[10]*(2*cos(Th[4])*cos(Th[9])*L[4]*L[9] + \
2*L[4]*L[9]*sin(Th[4])*sin(Th[9])))/2.;\n coefMat[189] = \
(M[10]*(cos(Th[4])*cos(Th[10])*L[4]*L[10] + \
L[4]*L[10]*sin(Th[4])*sin(Th[10])))/2.;\n rhsVec[7] = \
-(Cs*dTh[4]*pow(L[4],3))/12. - \
(L[4]*sin(Th[4])*(-(Cv*dxL*pow(cos(Th[4]),2)*L[4]) + \
Cv*cos(Th[4])*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4]) + \
Cv*cos(Th[4])*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4]) + \
Cv*cos(Th[4])*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4]) + \
Cs*dyL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dyL*cos(Th[4])*L[4]*sin(Th[4]) + \
Cs*cos(Th[1] - Th[4])*dTh[1]*L[1]*L[4]*sin(Th[4]) + Cs*cos(Th[2] - \
Th[4])*dTh[2]*L[2]*L[4]*sin(Th[4]) + Cs*cos(Th[3] - \
Th[4])*dTh[3]*L[3]*L[4]*sin(Th[4]) + (Cs*dTh[4]*pow(L[4],2)*sin(Th[4]))/2. - \
Cs*dxL*L[4]*pow(sin(Th[4]),2)))/2. + \
(cos(Th[4])*L[4]*(-(Cs*dyL*pow(cos(Th[4]),2)*L[4]) - Cs*cos(Th[1] - \
Th[4])*cos(Th[4])*dTh[1]*L[1]*L[4] - Cs*cos(Th[2] - \
Th[4])*cos(Th[4])*dTh[2]*L[2]*L[4] - Cs*cos(Th[3] - \
Th[4])*cos(Th[4])*dTh[3]*L[3]*L[4] - (Cs*cos(Th[4])*dTh[4]*pow(L[4],2))/2. + \
Cs*dxL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dxL*cos(Th[4])*L[4]*sin(Th[4]) + \
Cv*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4])*sin(Th[4]) + \
Cv*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4])*sin(Th[4]) + \
Cv*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4])*sin(Th[4]) - \
Cv*dyL*L[4]*pow(sin(Th[4]),2)))/2. + (M[4]*(-(dTh[4]*L[4]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
(cos(Th[4])*dTh[4]*L[4])/2.)*sin(Th[4])) - cos(Th[4])*dTh[4]*L[4]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
(dTh[4]*L[4]*sin(Th[4]))/2.)))/2. - (M[4]*(-(dTh[4]*L[4]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
(cos(Th[4])*dTh[4]*L[4])/2.)*sin(Th[4])) - L[4]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - \
(cos(Th[4])*pow(dTh[4],2)*L[4])/2.)*sin(Th[4]) - cos(Th[4])*dTh[4]*L[4]*(dxL \
- dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
(dTh[4]*L[4]*sin(Th[4]))/2.) + cos(Th[4])*L[4]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - (pow(dTh[4],2)*L[4]*sin(Th[4]))/2.)))/2. - \
(L[4]*L[5]*sin(Th[4])*(-(Cs*sin(Th[5])*(-2*dyL*cos(Th[5]) - 2*cos(Th[1] - \
Th[5])*dTh[1]*L[1] - 2*cos(Th[2] - Th[5])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[5])*dTh[3]*L[3] - 2*cos(Th[4] - Th[5])*dTh[4]*L[4] - dTh[5]*L[5] + \
2*dxL*sin(Th[5]))) + 2*Cv*cos(Th[5])*(-(dxL*cos(Th[5])) + \
dTh[1]*L[1]*sin(Th[1] - Th[5]) + dTh[2]*L[2]*sin(Th[2] - Th[5]) + \
dTh[3]*L[3]*sin(Th[3] - Th[5]) + dTh[4]*L[4]*sin(Th[4] - Th[5]) - \
dyL*sin(Th[5]))))/2. - (cos(Th[4])*L[4]*L[5]*(Cs*cos(Th[5])*(2*dyL*cos(Th[5]) \
+ 2*cos(Th[1] - Th[5])*dTh[1]*L[1] + 2*cos(Th[2] - Th[5])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[5])*dTh[3]*L[3] + 2*cos(Th[4] - Th[5])*dTh[4]*L[4] + \
dTh[5]*L[5] - 2*dxL*sin(Th[5])) + 2*Cv*sin(Th[5])*(dxL*cos(Th[5]) - \
dTh[1]*L[1]*sin(Th[1] - Th[5]) - dTh[2]*L[2]*sin(Th[2] - Th[5]) - \
dTh[3]*L[3]*sin(Th[3] - Th[5]) - dTh[4]*L[4]*sin(Th[4] - Th[5]) + \
dyL*sin(Th[5]))))/2. + (M[5]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
(cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[4]) - 2*cos(Th[4])*dTh[4]*L[4]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - (dTh[5]*L[5]*sin(Th[5]))/2.)))/2. - \
(M[5]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
(cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[4]) - 2*L[4]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
(cos(Th[5])*pow(dTh[5],2)*L[5])/2.)*sin(Th[4]) - \
2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
(dTh[5]*L[5]*sin(Th[5]))/2.) + 2*cos(Th[4])*L[4]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
(pow(dTh[5],2)*L[5]*sin(Th[5]))/2.)))/2. - \
(L[4]*L[6]*sin(Th[4])*(-(Cs*sin(Th[6])*(-2*dyL*cos(Th[6]) - 2*cos(Th[1] - \
Th[6])*dTh[1]*L[1] - 2*cos(Th[2] - Th[6])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[6])*dTh[3]*L[3] - 2*cos(Th[4] - Th[6])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[6])*dTh[5]*L[5] - dTh[6]*L[6] + 2*dxL*sin(Th[6]))) + \
2*Cv*cos(Th[6])*(-(dxL*cos(Th[6])) + dTh[1]*L[1]*sin(Th[1] - Th[6]) + \
dTh[2]*L[2]*sin(Th[2] - Th[6]) + dTh[3]*L[3]*sin(Th[3] - Th[6]) + \
dTh[4]*L[4]*sin(Th[4] - Th[6]) + dTh[5]*L[5]*sin(Th[5] - Th[6]) - \
dyL*sin(Th[6]))))/2. - (cos(Th[4])*L[4]*L[6]*(Cs*cos(Th[6])*(2*dyL*cos(Th[6]) \
+ 2*cos(Th[1] - Th[6])*dTh[1]*L[1] + 2*cos(Th[2] - Th[6])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[6])*dTh[3]*L[3] + 2*cos(Th[4] - Th[6])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[6])*dTh[5]*L[5] + dTh[6]*L[6] - 2*dxL*sin(Th[6])) + \
2*Cv*sin(Th[6])*(dxL*cos(Th[6]) - dTh[1]*L[1]*sin(Th[1] - Th[6]) - \
dTh[2]*L[2]*sin(Th[2] - Th[6]) - dTh[3]*L[3]*sin(Th[3] - Th[6]) - \
dTh[4]*L[4]*sin(Th[4] - Th[6]) - dTh[5]*L[5]*sin(Th[5] - Th[6]) + \
dyL*sin(Th[6]))))/2. + (M[6]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[4]) - \
2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.)))/2. - \
(M[6]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
(cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[4]) - 2*L[4]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - \
(cos(Th[6])*pow(dTh[6],2)*L[6])/2.)*sin(Th[4]) - \
2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.) + \
2*cos(Th[4])*L[4]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
(pow(dTh[6],2)*L[6]*sin(Th[6]))/2.)))/2. - \
L[4]*sin(Th[4])*(-(Cs*L[7]*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - \
Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + \
2*dxL*sin(Th[7])))/2. - Cv*cos(Th[7])*L[7]*(dxL*cos(Th[7]) - \
dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - \
dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - \
dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + \
dyL*sin(Th[7]))) + cos(Th[4])*L[4]*(-(Cs*cos(Th[7])*L[7]*(2*dyL*cos(Th[7]) + \
2*cos(Th[1] - Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + \
dTh[7]*L[7] - 2*dxL*sin(Th[7])))/2. - Cv*L[7]*sin(Th[7])*(dxL*cos(Th[7]) - \
dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - \
dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - \
dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + \
dyL*sin(Th[7]))) + (M[7]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
(cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[4]) - 2*cos(Th[4])*dTh[4]*L[4]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
(dTh[7]*L[7]*sin(Th[7]))/2.)))/2. - (M[7]*(-2*dTh[4]*L[4]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
(cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[4]) - 2*L[4]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
(cos(Th[7])*pow(dTh[7],2)*L[7])/2.)*sin(Th[4]) - \
2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
(dTh[7]*L[7]*sin(Th[7]))/2.) + 2*cos(Th[4])*L[4]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
(pow(dTh[7],2)*L[7]*sin(Th[7]))/2.)))/2. - \
L[4]*sin(Th[4])*(-(Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - \
Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - \
Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8]))) + cos(Th[4])*L[4]*(-(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + \
2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + \
2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - \
Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8]))) + (M[8]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
(cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[4]) - 2*cos(Th[4])*dTh[4]*L[4]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.)))/2. - \
(M[8]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
(cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[4]) - 2*L[4]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - \
(cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*sin(Th[4]) - \
2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
(dTh[8]*L[8]*sin(Th[8]))/2.) + 2*cos(Th[4])*L[4]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.)))/2. - \
L[4]*sin(Th[4])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - \
Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + \
2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))) + cos(Th[4])*L[4]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + \
2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + \
2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + \
dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))) + (M[9]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[4]) - \
2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - \
(M[9]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + \
(cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[4]) - 2*L[4]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
(cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[4]) - \
2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + \
2*cos(Th[4])*L[4]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - \
pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - \
L[4]*sin(Th[4])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - \
Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + \
cos(Th[4])*L[4]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - \
Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + (M[10]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[4]) - 2*cos(Th[4])*dTh[4]*L[4]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[4]*L[4]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[4]) - 2*L[4]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
cos(Th[9])*pow(dTh[9],2)*L[9] - \
(cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[4]) - \
2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[4])*L[4]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - \
pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;\n\
 coefMat[8] = 0;\n coefMat[22] = 0;\n coefMat[36] = L[5]*sin(Th[5]);\n \
coefMat[50] = -(cos(Th[5])*L[5]);\n coefMat[64] = \
(M[5]*(cos(Th[1])*cos(Th[5])*L[1]*L[5] + L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. \
+ (M[6]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + \
2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + \
(M[7]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + \
2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + \
(M[8]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + \
2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + \
(M[9]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + \
2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + \
(M[10]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + \
2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2.;\n coefMat[78] = \
(M[5]*(cos(Th[2])*cos(Th[5])*L[2]*L[5] + L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. \
+ (M[6]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + \
2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + \
(M[7]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + \
2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + \
(M[8]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + \
2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + \
(M[9]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + \
2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + \
(M[10]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + \
2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2.;\n coefMat[92] = \
(M[5]*(cos(Th[3])*cos(Th[5])*L[3]*L[5] + L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. \
+ (M[6]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + \
2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + \
(M[7]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + \
2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + \
(M[8]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + \
2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + \
(M[9]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + \
2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + \
(M[10]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + \
2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2.;\n coefMat[106] = \
(M[5]*(cos(Th[4])*cos(Th[5])*L[4]*L[5] + L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. \
+ (M[6]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + \
2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + \
(M[7]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + \
2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + \
(M[8]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + \
2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + \
(M[9]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + \
2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + \
(M[10]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + \
2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2.;\n coefMat[120] = \
(pow(L[5],2)*M[5])/12. + (M[5]*((pow(cos(Th[5]),2)*pow(L[5],2))/2. + \
(pow(L[5],2)*pow(sin(Th[5]),2))/2.))/2. + \
(M[6]*(2*pow(cos(Th[5]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(Th[5]),2)))/2. \
+ (M[7]*(2*pow(cos(Th[5]),2)*pow(L[5],2) + \
2*pow(L[5],2)*pow(sin(Th[5]),2)))/2. + (M[8]*(2*pow(cos(Th[5]),2)*pow(L[5],2) \
+ 2*pow(L[5],2)*pow(sin(Th[5]),2)))/2. + \
(M[9]*(2*pow(cos(Th[5]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(Th[5]),2)))/2. \
+ (M[10]*(2*pow(cos(Th[5]),2)*pow(L[5],2) + \
2*pow(L[5],2)*pow(sin(Th[5]),2)))/2.;\n coefMat[134] = \
(M[6]*(cos(Th[5])*cos(Th[6])*L[5]*L[6] + L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2. \
+ (M[7]*(2*cos(Th[5])*cos(Th[6])*L[5]*L[6] + \
2*L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2. + \
(M[8]*(2*cos(Th[5])*cos(Th[6])*L[5]*L[6] + \
2*L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2. + \
(M[9]*(2*cos(Th[5])*cos(Th[6])*L[5]*L[6] + \
2*L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2. + \
(M[10]*(2*cos(Th[5])*cos(Th[6])*L[5]*L[6] + \
2*L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2.;\n coefMat[148] = \
(M[7]*(cos(Th[5])*cos(Th[7])*L[5]*L[7] + L[5]*L[7]*sin(Th[5])*sin(Th[7])))/2. \
+ (M[8]*(2*cos(Th[5])*cos(Th[7])*L[5]*L[7] + \
2*L[5]*L[7]*sin(Th[5])*sin(Th[7])))/2. + \
(M[9]*(2*cos(Th[5])*cos(Th[7])*L[5]*L[7] + \
2*L[5]*L[7]*sin(Th[5])*sin(Th[7])))/2. + \
(M[10]*(2*cos(Th[5])*cos(Th[7])*L[5]*L[7] + \
2*L[5]*L[7]*sin(Th[5])*sin(Th[7])))/2.;\n coefMat[162] = \
(M[8]*(cos(Th[5])*cos(Th[8])*L[5]*L[8] + L[5]*L[8]*sin(Th[5])*sin(Th[8])))/2. \
+ (M[9]*(2*cos(Th[5])*cos(Th[8])*L[5]*L[8] + \
2*L[5]*L[8]*sin(Th[5])*sin(Th[8])))/2. + \
(M[10]*(2*cos(Th[5])*cos(Th[8])*L[5]*L[8] + \
2*L[5]*L[8]*sin(Th[5])*sin(Th[8])))/2.;\n coefMat[176] = \
(M[9]*(cos(Th[5])*cos(Th[9])*L[5]*L[9] + L[5]*L[9]*sin(Th[5])*sin(Th[9])))/2. \
+ (M[10]*(2*cos(Th[5])*cos(Th[9])*L[5]*L[9] + \
2*L[5]*L[9]*sin(Th[5])*sin(Th[9])))/2.;\n coefMat[190] = \
(M[10]*(cos(Th[5])*cos(Th[10])*L[5]*L[10] + \
L[5]*L[10]*sin(Th[5])*sin(Th[10])))/2.;\n rhsVec[8] = \
-(Cs*dTh[5]*pow(L[5],3))/12. - \
(pow(L[5],2)*sin(Th[5])*(-(Cs*sin(Th[5])*(-2*dyL*cos(Th[5]) - 2*cos(Th[1] - \
Th[5])*dTh[1]*L[1] - 2*cos(Th[2] - Th[5])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[5])*dTh[3]*L[3] - 2*cos(Th[4] - Th[5])*dTh[4]*L[4] - dTh[5]*L[5] + \
2*dxL*sin(Th[5]))) + 2*Cv*cos(Th[5])*(-(dxL*cos(Th[5])) + \
dTh[1]*L[1]*sin(Th[1] - Th[5]) + dTh[2]*L[2]*sin(Th[2] - Th[5]) + \
dTh[3]*L[3]*sin(Th[3] - Th[5]) + dTh[4]*L[4]*sin(Th[4] - Th[5]) - \
dyL*sin(Th[5]))))/4. - \
(cos(Th[5])*pow(L[5],2)*(Cs*cos(Th[5])*(2*dyL*cos(Th[5]) + 2*cos(Th[1] - \
Th[5])*dTh[1]*L[1] + 2*cos(Th[2] - Th[5])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[5])*dTh[3]*L[3] + 2*cos(Th[4] - Th[5])*dTh[4]*L[4] + dTh[5]*L[5] - \
2*dxL*sin(Th[5])) + 2*Cv*sin(Th[5])*(dxL*cos(Th[5]) - dTh[1]*L[1]*sin(Th[1] - \
Th[5]) - dTh[2]*L[2]*sin(Th[2] - Th[5]) - dTh[3]*L[3]*sin(Th[3] - Th[5]) - \
dTh[4]*L[4]*sin(Th[4] - Th[5]) + dyL*sin(Th[5]))))/4. + \
(M[5]*(-(dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + \
cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
(cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[5])) - cos(Th[5])*dTh[5]*L[5]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - (dTh[5]*L[5]*sin(Th[5]))/2.)))/2. - \
(M[5]*(-(dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + \
cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
(cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[5])) - L[5]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
(cos(Th[5])*pow(dTh[5],2)*L[5])/2.)*sin(Th[5]) - cos(Th[5])*dTh[5]*L[5]*(dxL \
- dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - (dTh[5]*L[5]*sin(Th[5]))/2.) + cos(Th[5])*L[5]*(ddyL \
- pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
(pow(dTh[5],2)*L[5]*sin(Th[5]))/2.)))/2. - \
(L[5]*L[6]*sin(Th[5])*(-(Cs*sin(Th[6])*(-2*dyL*cos(Th[6]) - 2*cos(Th[1] - \
Th[6])*dTh[1]*L[1] - 2*cos(Th[2] - Th[6])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[6])*dTh[3]*L[3] - 2*cos(Th[4] - Th[6])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[6])*dTh[5]*L[5] - dTh[6]*L[6] + 2*dxL*sin(Th[6]))) + \
2*Cv*cos(Th[6])*(-(dxL*cos(Th[6])) + dTh[1]*L[1]*sin(Th[1] - Th[6]) + \
dTh[2]*L[2]*sin(Th[2] - Th[6]) + dTh[3]*L[3]*sin(Th[3] - Th[6]) + \
dTh[4]*L[4]*sin(Th[4] - Th[6]) + dTh[5]*L[5]*sin(Th[5] - Th[6]) - \
dyL*sin(Th[6]))))/2. - (cos(Th[5])*L[5]*L[6]*(Cs*cos(Th[6])*(2*dyL*cos(Th[6]) \
+ 2*cos(Th[1] - Th[6])*dTh[1]*L[1] + 2*cos(Th[2] - Th[6])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[6])*dTh[3]*L[3] + 2*cos(Th[4] - Th[6])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[6])*dTh[5]*L[5] + dTh[6]*L[6] - 2*dxL*sin(Th[6])) + \
2*Cv*sin(Th[6])*(dxL*cos(Th[6]) - dTh[1]*L[1]*sin(Th[1] - Th[6]) - \
dTh[2]*L[2]*sin(Th[2] - Th[6]) - dTh[3]*L[3]*sin(Th[3] - Th[6]) - \
dTh[4]*L[4]*sin(Th[4] - Th[6]) - dTh[5]*L[5]*sin(Th[5] - Th[6]) + \
dyL*sin(Th[6]))))/2. + (M[6]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[5]) - \
2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.)))/2. - \
(M[6]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
(cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[5]) - 2*L[5]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - \
(cos(Th[6])*pow(dTh[6],2)*L[6])/2.)*sin(Th[5]) - \
2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.) + \
2*cos(Th[5])*L[5]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
(pow(dTh[6],2)*L[6]*sin(Th[6]))/2.)))/2. - \
L[5]*sin(Th[5])*(-(Cs*L[7]*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - \
Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + \
2*dxL*sin(Th[7])))/2. - Cv*cos(Th[7])*L[7]*(dxL*cos(Th[7]) - \
dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - \
dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - \
dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + \
dyL*sin(Th[7]))) + cos(Th[5])*L[5]*(-(Cs*cos(Th[7])*L[7]*(2*dyL*cos(Th[7]) + \
2*cos(Th[1] - Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + \
dTh[7]*L[7] - 2*dxL*sin(Th[7])))/2. - Cv*L[7]*sin(Th[7])*(dxL*cos(Th[7]) - \
dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - \
dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - \
dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + \
dyL*sin(Th[7]))) + (M[7]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
(cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[5]) - 2*cos(Th[5])*dTh[5]*L[5]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
(dTh[7]*L[7]*sin(Th[7]))/2.)))/2. - (M[7]*(-2*dTh[5]*L[5]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
(cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[5]) - 2*L[5]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
(cos(Th[7])*pow(dTh[7],2)*L[7])/2.)*sin(Th[5]) - \
2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
(dTh[7]*L[7]*sin(Th[7]))/2.) + 2*cos(Th[5])*L[5]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
(pow(dTh[7],2)*L[7]*sin(Th[7]))/2.)))/2. - \
L[5]*sin(Th[5])*(-(Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - \
Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - \
Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8]))) + cos(Th[5])*L[5]*(-(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + \
2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + \
2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - \
Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8]))) + (M[8]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
(cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[5]) - 2*cos(Th[5])*dTh[5]*L[5]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.)))/2. - \
(M[8]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
(cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[5]) - 2*L[5]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - \
(cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*sin(Th[5]) - \
2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
(dTh[8]*L[8]*sin(Th[8]))/2.) + 2*cos(Th[5])*L[5]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.)))/2. - \
L[5]*sin(Th[5])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - \
Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + \
2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))) + cos(Th[5])*L[5]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + \
2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + \
2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + \
dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))) + (M[9]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[5]) - \
2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - \
(M[9]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + \
(cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[5]) - 2*L[5]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
(cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[5]) - \
2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + \
2*cos(Th[5])*L[5]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - \
pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - \
L[5]*sin(Th[5])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - \
Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + \
cos(Th[5])*L[5]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - \
Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + (M[10]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[5]) - 2*cos(Th[5])*dTh[5]*L[5]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[5]*L[5]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[5]) - 2*L[5]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
cos(Th[9])*pow(dTh[9],2)*L[9] - \
(cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[5]) - \
2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[5])*L[5]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - \
pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;\n\
 coefMat[9] = 0;\n coefMat[23] = 0;\n coefMat[37] = L[6]*sin(Th[6]);\n \
coefMat[51] = -(cos(Th[6])*L[6]);\n coefMat[65] = \
(M[6]*(cos(Th[1])*cos(Th[6])*L[1]*L[6] + L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2. \
+ (M[7]*(2*cos(Th[1])*cos(Th[6])*L[1]*L[6] + \
2*L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2. + \
(M[8]*(2*cos(Th[1])*cos(Th[6])*L[1]*L[6] + \
2*L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2. + \
(M[9]*(2*cos(Th[1])*cos(Th[6])*L[1]*L[6] + \
2*L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2. + \
(M[10]*(2*cos(Th[1])*cos(Th[6])*L[1]*L[6] + \
2*L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2.;\n coefMat[79] = \
(M[6]*(cos(Th[2])*cos(Th[6])*L[2]*L[6] + L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2. \
+ (M[7]*(2*cos(Th[2])*cos(Th[6])*L[2]*L[6] + \
2*L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2. + \
(M[8]*(2*cos(Th[2])*cos(Th[6])*L[2]*L[6] + \
2*L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2. + \
(M[9]*(2*cos(Th[2])*cos(Th[6])*L[2]*L[6] + \
2*L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2. + \
(M[10]*(2*cos(Th[2])*cos(Th[6])*L[2]*L[6] + \
2*L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2.;\n coefMat[93] = \
(M[6]*(cos(Th[3])*cos(Th[6])*L[3]*L[6] + L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2. \
+ (M[7]*(2*cos(Th[3])*cos(Th[6])*L[3]*L[6] + \
2*L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2. + \
(M[8]*(2*cos(Th[3])*cos(Th[6])*L[3]*L[6] + \
2*L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2. + \
(M[9]*(2*cos(Th[3])*cos(Th[6])*L[3]*L[6] + \
2*L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2. + \
(M[10]*(2*cos(Th[3])*cos(Th[6])*L[3]*L[6] + \
2*L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2.;\n coefMat[107] = \
(M[6]*(cos(Th[4])*cos(Th[6])*L[4]*L[6] + L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2. \
+ (M[7]*(2*cos(Th[4])*cos(Th[6])*L[4]*L[6] + \
2*L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2. + \
(M[8]*(2*cos(Th[4])*cos(Th[6])*L[4]*L[6] + \
2*L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2. + \
(M[9]*(2*cos(Th[4])*cos(Th[6])*L[4]*L[6] + \
2*L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2. + \
(M[10]*(2*cos(Th[4])*cos(Th[6])*L[4]*L[6] + \
2*L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2.;\n coefMat[121] = \
(M[6]*(cos(Th[5])*cos(Th[6])*L[5]*L[6] + L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2. \
+ (M[7]*(2*cos(Th[5])*cos(Th[6])*L[5]*L[6] + \
2*L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2. + \
(M[8]*(2*cos(Th[5])*cos(Th[6])*L[5]*L[6] + \
2*L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2. + \
(M[9]*(2*cos(Th[5])*cos(Th[6])*L[5]*L[6] + \
2*L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2. + \
(M[10]*(2*cos(Th[5])*cos(Th[6])*L[5]*L[6] + \
2*L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2.;\n coefMat[135] = \
(pow(L[6],2)*M[6])/12. + (M[6]*((pow(cos(Th[6]),2)*pow(L[6],2))/2. + \
(pow(L[6],2)*pow(sin(Th[6]),2))/2.))/2. + \
(M[7]*(2*pow(cos(Th[6]),2)*pow(L[6],2) + 2*pow(L[6],2)*pow(sin(Th[6]),2)))/2. \
+ (M[8]*(2*pow(cos(Th[6]),2)*pow(L[6],2) + \
2*pow(L[6],2)*pow(sin(Th[6]),2)))/2. + (M[9]*(2*pow(cos(Th[6]),2)*pow(L[6],2) \
+ 2*pow(L[6],2)*pow(sin(Th[6]),2)))/2. + \
(M[10]*(2*pow(cos(Th[6]),2)*pow(L[6],2) + \
2*pow(L[6],2)*pow(sin(Th[6]),2)))/2.;\n coefMat[149] = \
(M[7]*(cos(Th[6])*cos(Th[7])*L[6]*L[7] + L[6]*L[7]*sin(Th[6])*sin(Th[7])))/2. \
+ (M[8]*(2*cos(Th[6])*cos(Th[7])*L[6]*L[7] + \
2*L[6]*L[7]*sin(Th[6])*sin(Th[7])))/2. + \
(M[9]*(2*cos(Th[6])*cos(Th[7])*L[6]*L[7] + \
2*L[6]*L[7]*sin(Th[6])*sin(Th[7])))/2. + \
(M[10]*(2*cos(Th[6])*cos(Th[7])*L[6]*L[7] + \
2*L[6]*L[7]*sin(Th[6])*sin(Th[7])))/2.;\n coefMat[163] = \
(M[8]*(cos(Th[6])*cos(Th[8])*L[6]*L[8] + L[6]*L[8]*sin(Th[6])*sin(Th[8])))/2. \
+ (M[9]*(2*cos(Th[6])*cos(Th[8])*L[6]*L[8] + \
2*L[6]*L[8]*sin(Th[6])*sin(Th[8])))/2. + \
(M[10]*(2*cos(Th[6])*cos(Th[8])*L[6]*L[8] + \
2*L[6]*L[8]*sin(Th[6])*sin(Th[8])))/2.;\n coefMat[177] = \
(M[9]*(cos(Th[6])*cos(Th[9])*L[6]*L[9] + L[6]*L[9]*sin(Th[6])*sin(Th[9])))/2. \
+ (M[10]*(2*cos(Th[6])*cos(Th[9])*L[6]*L[9] + \
2*L[6]*L[9]*sin(Th[6])*sin(Th[9])))/2.;\n coefMat[191] = \
(M[10]*(cos(Th[6])*cos(Th[10])*L[6]*L[10] + \
L[6]*L[10]*sin(Th[6])*sin(Th[10])))/2.;\n rhsVec[9] = \
-(Cs*dTh[6]*pow(L[6],3))/12. - \
(pow(L[6],2)*sin(Th[6])*(-(Cs*sin(Th[6])*(-2*dyL*cos(Th[6]) - 2*cos(Th[1] - \
Th[6])*dTh[1]*L[1] - 2*cos(Th[2] - Th[6])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[6])*dTh[3]*L[3] - 2*cos(Th[4] - Th[6])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[6])*dTh[5]*L[5] - dTh[6]*L[6] + 2*dxL*sin(Th[6]))) + \
2*Cv*cos(Th[6])*(-(dxL*cos(Th[6])) + dTh[1]*L[1]*sin(Th[1] - Th[6]) + \
dTh[2]*L[2]*sin(Th[2] - Th[6]) + dTh[3]*L[3]*sin(Th[3] - Th[6]) + \
dTh[4]*L[4]*sin(Th[4] - Th[6]) + dTh[5]*L[5]*sin(Th[5] - Th[6]) - \
dyL*sin(Th[6]))))/4. - \
(cos(Th[6])*pow(L[6],2)*(Cs*cos(Th[6])*(2*dyL*cos(Th[6]) + 2*cos(Th[1] - \
Th[6])*dTh[1]*L[1] + 2*cos(Th[2] - Th[6])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[6])*dTh[3]*L[3] + 2*cos(Th[4] - Th[6])*dTh[4]*L[4] + 2*cos(Th[5] - \
Th[6])*dTh[5]*L[5] + dTh[6]*L[6] - 2*dxL*sin(Th[6])) + \
2*Cv*sin(Th[6])*(dxL*cos(Th[6]) - dTh[1]*L[1]*sin(Th[1] - Th[6]) - \
dTh[2]*L[2]*sin(Th[2] - Th[6]) - dTh[3]*L[3]*sin(Th[3] - Th[6]) - \
dTh[4]*L[4]*sin(Th[4] - Th[6]) - dTh[5]*L[5]*sin(Th[5] - Th[6]) + \
dyL*sin(Th[6]))))/4. + (M[6]*(-(dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[6])) - \
cos(Th[6])*dTh[6]*L[6]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) \
- dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - \
(dTh[6]*L[6]*sin(Th[6]))/2.)))/2. - (M[6]*(-(dTh[6]*L[6]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
(cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[6])) - L[6]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - \
(cos(Th[6])*pow(dTh[6],2)*L[6])/2.)*sin(Th[6]) - cos(Th[6])*dTh[6]*L[6]*(dxL \
- dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - \
(dTh[6]*L[6]*sin(Th[6]))/2.) + cos(Th[6])*L[6]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - (pow(dTh[6],2)*L[6]*sin(Th[6]))/2.)))/2. - \
L[6]*sin(Th[6])*(-(Cs*L[7]*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - \
Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + \
2*dxL*sin(Th[7])))/2. - Cv*cos(Th[7])*L[7]*(dxL*cos(Th[7]) - \
dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - \
dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - \
dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + \
dyL*sin(Th[7]))) + cos(Th[6])*L[6]*(-(Cs*cos(Th[7])*L[7]*(2*dyL*cos(Th[7]) + \
2*cos(Th[1] - Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + \
dTh[7]*L[7] - 2*dxL*sin(Th[7])))/2. - Cv*L[7]*sin(Th[7])*(dxL*cos(Th[7]) - \
dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - \
dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - \
dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + \
dyL*sin(Th[7]))) + (M[7]*(-2*dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
(cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[6]) - 2*cos(Th[6])*dTh[6]*L[6]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
(dTh[7]*L[7]*sin(Th[7]))/2.)))/2. - (M[7]*(-2*dTh[6]*L[6]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
(cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[6]) - 2*L[6]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
(cos(Th[7])*pow(dTh[7],2)*L[7])/2.)*sin(Th[6]) - \
2*cos(Th[6])*dTh[6]*L[6]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
(dTh[7]*L[7]*sin(Th[7]))/2.) + 2*cos(Th[6])*L[6]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
(pow(dTh[7],2)*L[7]*sin(Th[7]))/2.)))/2. - \
L[6]*sin(Th[6])*(-(Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - \
Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - \
Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8]))) + cos(Th[6])*L[6]*(-(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + \
2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + \
2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - \
Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8]))) + (M[8]*(-2*dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
(cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[6]) - 2*cos(Th[6])*dTh[6]*L[6]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.)))/2. - \
(M[8]*(-2*dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
(cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[6]) - 2*L[6]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - \
(cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*sin(Th[6]) - \
2*cos(Th[6])*dTh[6]*L[6]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
(dTh[8]*L[8]*sin(Th[8]))/2.) + 2*cos(Th[6])*L[6]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.)))/2. - \
L[6]*sin(Th[6])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - \
Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + \
2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))) + cos(Th[6])*L[6]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + \
2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + \
2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + \
dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))) + (M[9]*(-2*dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[6]) - \
2*cos(Th[6])*dTh[6]*L[6]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - \
(M[9]*(-2*dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + \
(cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[6]) - 2*L[6]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
(cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[6]) - \
2*cos(Th[6])*dTh[6]*L[6]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + \
2*cos(Th[6])*L[6]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - \
pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - \
L[6]*sin(Th[6])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - \
Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + \
cos(Th[6])*L[6]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - \
Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + (M[10]*(-2*dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[6]) - 2*cos(Th[6])*dTh[6]*L[6]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[6]*L[6]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[6]) - 2*L[6]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
cos(Th[9])*pow(dTh[9],2)*L[9] - \
(cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[6]) - \
2*cos(Th[6])*dTh[6]*L[6]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[6])*L[6]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - \
pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;\n\
 coefMat[10] = 0;\n coefMat[24] = 0;\n coefMat[38] = L[7]*sin(Th[7]);\n \
coefMat[52] = -(cos(Th[7])*L[7]);\n coefMat[66] = \
(M[7]*(cos(Th[1])*cos(Th[7])*L[1]*L[7] + L[1]*L[7]*sin(Th[1])*sin(Th[7])))/2. \
+ (M[8]*(2*cos(Th[1])*cos(Th[7])*L[1]*L[7] + \
2*L[1]*L[7]*sin(Th[1])*sin(Th[7])))/2. + \
(M[9]*(2*cos(Th[1])*cos(Th[7])*L[1]*L[7] + \
2*L[1]*L[7]*sin(Th[1])*sin(Th[7])))/2. + \
(M[10]*(2*cos(Th[1])*cos(Th[7])*L[1]*L[7] + \
2*L[1]*L[7]*sin(Th[1])*sin(Th[7])))/2.;\n coefMat[80] = \
(M[7]*(cos(Th[2])*cos(Th[7])*L[2]*L[7] + L[2]*L[7]*sin(Th[2])*sin(Th[7])))/2. \
+ (M[8]*(2*cos(Th[2])*cos(Th[7])*L[2]*L[7] + \
2*L[2]*L[7]*sin(Th[2])*sin(Th[7])))/2. + \
(M[9]*(2*cos(Th[2])*cos(Th[7])*L[2]*L[7] + \
2*L[2]*L[7]*sin(Th[2])*sin(Th[7])))/2. + \
(M[10]*(2*cos(Th[2])*cos(Th[7])*L[2]*L[7] + \
2*L[2]*L[7]*sin(Th[2])*sin(Th[7])))/2.;\n coefMat[94] = \
(M[7]*(cos(Th[3])*cos(Th[7])*L[3]*L[7] + L[3]*L[7]*sin(Th[3])*sin(Th[7])))/2. \
+ (M[8]*(2*cos(Th[3])*cos(Th[7])*L[3]*L[7] + \
2*L[3]*L[7]*sin(Th[3])*sin(Th[7])))/2. + \
(M[9]*(2*cos(Th[3])*cos(Th[7])*L[3]*L[7] + \
2*L[3]*L[7]*sin(Th[3])*sin(Th[7])))/2. + \
(M[10]*(2*cos(Th[3])*cos(Th[7])*L[3]*L[7] + \
2*L[3]*L[7]*sin(Th[3])*sin(Th[7])))/2.;\n coefMat[108] = \
(M[7]*(cos(Th[4])*cos(Th[7])*L[4]*L[7] + L[4]*L[7]*sin(Th[4])*sin(Th[7])))/2. \
+ (M[8]*(2*cos(Th[4])*cos(Th[7])*L[4]*L[7] + \
2*L[4]*L[7]*sin(Th[4])*sin(Th[7])))/2. + \
(M[9]*(2*cos(Th[4])*cos(Th[7])*L[4]*L[7] + \
2*L[4]*L[7]*sin(Th[4])*sin(Th[7])))/2. + \
(M[10]*(2*cos(Th[4])*cos(Th[7])*L[4]*L[7] + \
2*L[4]*L[7]*sin(Th[4])*sin(Th[7])))/2.;\n coefMat[122] = \
(M[7]*(cos(Th[5])*cos(Th[7])*L[5]*L[7] + L[5]*L[7]*sin(Th[5])*sin(Th[7])))/2. \
+ (M[8]*(2*cos(Th[5])*cos(Th[7])*L[5]*L[7] + \
2*L[5]*L[7]*sin(Th[5])*sin(Th[7])))/2. + \
(M[9]*(2*cos(Th[5])*cos(Th[7])*L[5]*L[7] + \
2*L[5]*L[7]*sin(Th[5])*sin(Th[7])))/2. + \
(M[10]*(2*cos(Th[5])*cos(Th[7])*L[5]*L[7] + \
2*L[5]*L[7]*sin(Th[5])*sin(Th[7])))/2.;\n coefMat[136] = \
(M[7]*(cos(Th[6])*cos(Th[7])*L[6]*L[7] + L[6]*L[7]*sin(Th[6])*sin(Th[7])))/2. \
+ (M[8]*(2*cos(Th[6])*cos(Th[7])*L[6]*L[7] + \
2*L[6]*L[7]*sin(Th[6])*sin(Th[7])))/2. + \
(M[9]*(2*cos(Th[6])*cos(Th[7])*L[6]*L[7] + \
2*L[6]*L[7]*sin(Th[6])*sin(Th[7])))/2. + \
(M[10]*(2*cos(Th[6])*cos(Th[7])*L[6]*L[7] + \
2*L[6]*L[7]*sin(Th[6])*sin(Th[7])))/2.;\n coefMat[150] = \
(pow(L[7],2)*M[7])/12. + (M[7]*((pow(cos(Th[7]),2)*pow(L[7],2))/2. + \
(pow(L[7],2)*pow(sin(Th[7]),2))/2.))/2. + \
(M[8]*(2*pow(cos(Th[7]),2)*pow(L[7],2) + 2*pow(L[7],2)*pow(sin(Th[7]),2)))/2. \
+ (M[9]*(2*pow(cos(Th[7]),2)*pow(L[7],2) + \
2*pow(L[7],2)*pow(sin(Th[7]),2)))/2. + \
(M[10]*(2*pow(cos(Th[7]),2)*pow(L[7],2) + \
2*pow(L[7],2)*pow(sin(Th[7]),2)))/2.;\n coefMat[164] = \
(M[8]*(cos(Th[7])*cos(Th[8])*L[7]*L[8] + L[7]*L[8]*sin(Th[7])*sin(Th[8])))/2. \
+ (M[9]*(2*cos(Th[7])*cos(Th[8])*L[7]*L[8] + \
2*L[7]*L[8]*sin(Th[7])*sin(Th[8])))/2. + \
(M[10]*(2*cos(Th[7])*cos(Th[8])*L[7]*L[8] + \
2*L[7]*L[8]*sin(Th[7])*sin(Th[8])))/2.;\n coefMat[178] = \
(M[9]*(cos(Th[7])*cos(Th[9])*L[7]*L[9] + L[7]*L[9]*sin(Th[7])*sin(Th[9])))/2. \
+ (M[10]*(2*cos(Th[7])*cos(Th[9])*L[7]*L[9] + \
2*L[7]*L[9]*sin(Th[7])*sin(Th[9])))/2.;\n coefMat[192] = \
(M[10]*(cos(Th[7])*cos(Th[10])*L[7]*L[10] + \
L[7]*L[10]*sin(Th[7])*sin(Th[10])))/2.;\n rhsVec[10] = \
-(Cs*dTh[7]*pow(L[7],3))/12. - \
(L[7]*sin(Th[7])*(-(Cs*L[7]*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - \
Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + \
2*dxL*sin(Th[7])))/2. - Cv*cos(Th[7])*L[7]*(dxL*cos(Th[7]) - \
dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - \
dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - \
dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + \
dyL*sin(Th[7]))))/2. + \
(cos(Th[7])*L[7]*(-(Cs*cos(Th[7])*L[7]*(2*dyL*cos(Th[7]) + 2*cos(Th[1] - \
Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + 2*cos(Th[5] - \
Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + dTh[7]*L[7] - \
2*dxL*sin(Th[7])))/2. - Cv*L[7]*sin(Th[7])*(dxL*cos(Th[7]) - \
dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - \
dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - \
dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + \
dyL*sin(Th[7]))))/2. + (M[7]*(-(dTh[7]*L[7]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
(cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[7])) - cos(Th[7])*dTh[7]*L[7]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
(dTh[7]*L[7]*sin(Th[7]))/2.)))/2. - (M[7]*(-(dTh[7]*L[7]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
(cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[7])) - L[7]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
(cos(Th[7])*pow(dTh[7],2)*L[7])/2.)*sin(Th[7]) - cos(Th[7])*dTh[7]*L[7]*(dxL \
- dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
(dTh[7]*L[7]*sin(Th[7]))/2.) + cos(Th[7])*L[7]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
(pow(dTh[7],2)*L[7]*sin(Th[7]))/2.)))/2. - \
L[7]*sin(Th[7])*(-(Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - \
Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - \
Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8]))) + cos(Th[7])*L[7]*(-(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + \
2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + \
2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - \
Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8]))) + (M[8]*(-2*dTh[7]*L[7]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
(cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[7]) - 2*cos(Th[7])*dTh[7]*L[7]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.)))/2. - \
(M[8]*(-2*dTh[7]*L[7]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
(cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[7]) - 2*L[7]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - \
(cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*sin(Th[7]) - \
2*cos(Th[7])*dTh[7]*L[7]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
(dTh[8]*L[8]*sin(Th[8]))/2.) + 2*cos(Th[7])*L[7]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.)))/2. - \
L[7]*sin(Th[7])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - \
Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + \
2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))) + cos(Th[7])*L[7]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + \
2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + \
2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + \
dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))) + (M[9]*(-2*dTh[7]*L[7]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[7]) - \
2*cos(Th[7])*dTh[7]*L[7]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - \
(M[9]*(-2*dTh[7]*L[7]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + \
(cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[7]) - 2*L[7]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
(cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[7]) - \
2*cos(Th[7])*dTh[7]*L[7]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + \
2*cos(Th[7])*L[7]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - \
pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - \
L[7]*sin(Th[7])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - \
Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + \
cos(Th[7])*L[7]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - \
Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + (M[10]*(-2*dTh[7]*L[7]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[7]) - 2*cos(Th[7])*dTh[7]*L[7]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[7]*L[7]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[7]) - 2*L[7]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
cos(Th[9])*pow(dTh[9],2)*L[9] - \
(cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[7]) - \
2*cos(Th[7])*dTh[7]*L[7]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[7])*L[7]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - \
pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;\n\
 coefMat[11] = 0;\n coefMat[25] = 0;\n coefMat[39] = L[8]*sin(Th[8]);\n \
coefMat[53] = -(cos(Th[8])*L[8]);\n coefMat[67] = \
(M[8]*(cos(Th[1])*cos(Th[8])*L[1]*L[8] + L[1]*L[8]*sin(Th[1])*sin(Th[8])))/2. \
+ (M[9]*(2*cos(Th[1])*cos(Th[8])*L[1]*L[8] + \
2*L[1]*L[8]*sin(Th[1])*sin(Th[8])))/2. + \
(M[10]*(2*cos(Th[1])*cos(Th[8])*L[1]*L[8] + \
2*L[1]*L[8]*sin(Th[1])*sin(Th[8])))/2.;\n coefMat[81] = \
(M[8]*(cos(Th[2])*cos(Th[8])*L[2]*L[8] + L[2]*L[8]*sin(Th[2])*sin(Th[8])))/2. \
+ (M[9]*(2*cos(Th[2])*cos(Th[8])*L[2]*L[8] + \
2*L[2]*L[8]*sin(Th[2])*sin(Th[8])))/2. + \
(M[10]*(2*cos(Th[2])*cos(Th[8])*L[2]*L[8] + \
2*L[2]*L[8]*sin(Th[2])*sin(Th[8])))/2.;\n coefMat[95] = \
(M[8]*(cos(Th[3])*cos(Th[8])*L[3]*L[8] + L[3]*L[8]*sin(Th[3])*sin(Th[8])))/2. \
+ (M[9]*(2*cos(Th[3])*cos(Th[8])*L[3]*L[8] + \
2*L[3]*L[8]*sin(Th[3])*sin(Th[8])))/2. + \
(M[10]*(2*cos(Th[3])*cos(Th[8])*L[3]*L[8] + \
2*L[3]*L[8]*sin(Th[3])*sin(Th[8])))/2.;\n coefMat[109] = \
(M[8]*(cos(Th[4])*cos(Th[8])*L[4]*L[8] + L[4]*L[8]*sin(Th[4])*sin(Th[8])))/2. \
+ (M[9]*(2*cos(Th[4])*cos(Th[8])*L[4]*L[8] + \
2*L[4]*L[8]*sin(Th[4])*sin(Th[8])))/2. + \
(M[10]*(2*cos(Th[4])*cos(Th[8])*L[4]*L[8] + \
2*L[4]*L[8]*sin(Th[4])*sin(Th[8])))/2.;\n coefMat[123] = \
(M[8]*(cos(Th[5])*cos(Th[8])*L[5]*L[8] + L[5]*L[8]*sin(Th[5])*sin(Th[8])))/2. \
+ (M[9]*(2*cos(Th[5])*cos(Th[8])*L[5]*L[8] + \
2*L[5]*L[8]*sin(Th[5])*sin(Th[8])))/2. + \
(M[10]*(2*cos(Th[5])*cos(Th[8])*L[5]*L[8] + \
2*L[5]*L[8]*sin(Th[5])*sin(Th[8])))/2.;\n coefMat[137] = \
(M[8]*(cos(Th[6])*cos(Th[8])*L[6]*L[8] + L[6]*L[8]*sin(Th[6])*sin(Th[8])))/2. \
+ (M[9]*(2*cos(Th[6])*cos(Th[8])*L[6]*L[8] + \
2*L[6]*L[8]*sin(Th[6])*sin(Th[8])))/2. + \
(M[10]*(2*cos(Th[6])*cos(Th[8])*L[6]*L[8] + \
2*L[6]*L[8]*sin(Th[6])*sin(Th[8])))/2.;\n coefMat[151] = \
(M[8]*(cos(Th[7])*cos(Th[8])*L[7]*L[8] + L[7]*L[8]*sin(Th[7])*sin(Th[8])))/2. \
+ (M[9]*(2*cos(Th[7])*cos(Th[8])*L[7]*L[8] + \
2*L[7]*L[8]*sin(Th[7])*sin(Th[8])))/2. + \
(M[10]*(2*cos(Th[7])*cos(Th[8])*L[7]*L[8] + \
2*L[7]*L[8]*sin(Th[7])*sin(Th[8])))/2.;\n coefMat[165] = \
(pow(L[8],2)*M[8])/12. + (M[8]*((pow(cos(Th[8]),2)*pow(L[8],2))/2. + \
(pow(L[8],2)*pow(sin(Th[8]),2))/2.))/2. + \
(M[9]*(2*pow(cos(Th[8]),2)*pow(L[8],2) + 2*pow(L[8],2)*pow(sin(Th[8]),2)))/2. \
+ (M[10]*(2*pow(cos(Th[8]),2)*pow(L[8],2) + \
2*pow(L[8],2)*pow(sin(Th[8]),2)))/2.;\n coefMat[179] = \
(M[9]*(cos(Th[8])*cos(Th[9])*L[8]*L[9] + L[8]*L[9]*sin(Th[8])*sin(Th[9])))/2. \
+ (M[10]*(2*cos(Th[8])*cos(Th[9])*L[8]*L[9] + \
2*L[8]*L[9]*sin(Th[8])*sin(Th[9])))/2.;\n coefMat[193] = \
(M[10]*(cos(Th[8])*cos(Th[10])*L[8]*L[10] + \
L[8]*L[10]*sin(Th[8])*sin(Th[10])))/2.;\n rhsVec[11] = \
-(Cs*dTh[8]*pow(L[8],3))/12. - \
(L[8]*sin(Th[8])*(-(Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - \
Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - \
Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8]))))/2. + \
(cos(Th[8])*L[8]*(-(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + 2*cos(Th[1] - \
Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + 2*cos(Th[5] - \
Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + 2*cos(Th[7] - \
Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - \
Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - \
dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - \
dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - \
dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + \
dyL*sin(Th[8]))))/2. + (M[8]*(-(dTh[8]*L[8]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
(cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[8])) - cos(Th[8])*dTh[8]*L[8]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.)))/2. - \
(M[8]*(-(dTh[8]*L[8]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + \
cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
(cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[8])) - L[8]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - \
(cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*sin(Th[8]) - cos(Th[8])*dTh[8]*L[8]*(dxL \
- dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.) + cos(Th[8])*L[8]*(ddyL \
- pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.)))/2. - \
L[8]*sin(Th[8])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - \
Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + \
2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))) + cos(Th[8])*L[8]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + \
2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + \
2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + \
2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + \
2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + \
dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))) + (M[9]*(-2*dTh[8]*L[8]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[8]) - \
2*cos(Th[8])*dTh[8]*L[8]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - \
(M[9]*(-2*dTh[8]*L[8]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] \
+ cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + \
cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + \
(cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[8]) - 2*L[8]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
(cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[8]) - \
2*cos(Th[8])*dTh[8]*L[8]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + \
2*cos(Th[8])*L[8]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - \
pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - \
pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - \
pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - \
pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - \
L[8]*sin(Th[8])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - \
Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + \
cos(Th[8])*L[8]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - \
Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + (M[10]*(-2*dTh[8]*L[8]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[8]) - 2*cos(Th[8])*dTh[8]*L[8]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[8]*L[8]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[8]) - 2*L[8]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
cos(Th[9])*pow(dTh[9],2)*L[9] - \
(cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[8]) - \
2*cos(Th[8])*dTh[8]*L[8]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[8])*L[8]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - \
pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;\n\
 coefMat[12] = 0;\n coefMat[26] = 0;\n coefMat[40] = L[9]*sin(Th[9]);\n \
coefMat[54] = -(cos(Th[9])*L[9]);\n coefMat[68] = \
(M[9]*(cos(Th[1])*cos(Th[9])*L[1]*L[9] + L[1]*L[9]*sin(Th[1])*sin(Th[9])))/2. \
+ (M[10]*(2*cos(Th[1])*cos(Th[9])*L[1]*L[9] + \
2*L[1]*L[9]*sin(Th[1])*sin(Th[9])))/2.;\n coefMat[82] = \
(M[9]*(cos(Th[2])*cos(Th[9])*L[2]*L[9] + L[2]*L[9]*sin(Th[2])*sin(Th[9])))/2. \
+ (M[10]*(2*cos(Th[2])*cos(Th[9])*L[2]*L[9] + \
2*L[2]*L[9]*sin(Th[2])*sin(Th[9])))/2.;\n coefMat[96] = \
(M[9]*(cos(Th[3])*cos(Th[9])*L[3]*L[9] + L[3]*L[9]*sin(Th[3])*sin(Th[9])))/2. \
+ (M[10]*(2*cos(Th[3])*cos(Th[9])*L[3]*L[9] + \
2*L[3]*L[9]*sin(Th[3])*sin(Th[9])))/2.;\n coefMat[110] = \
(M[9]*(cos(Th[4])*cos(Th[9])*L[4]*L[9] + L[4]*L[9]*sin(Th[4])*sin(Th[9])))/2. \
+ (M[10]*(2*cos(Th[4])*cos(Th[9])*L[4]*L[9] + \
2*L[4]*L[9]*sin(Th[4])*sin(Th[9])))/2.;\n coefMat[124] = \
(M[9]*(cos(Th[5])*cos(Th[9])*L[5]*L[9] + L[5]*L[9]*sin(Th[5])*sin(Th[9])))/2. \
+ (M[10]*(2*cos(Th[5])*cos(Th[9])*L[5]*L[9] + \
2*L[5]*L[9]*sin(Th[5])*sin(Th[9])))/2.;\n coefMat[138] = \
(M[9]*(cos(Th[6])*cos(Th[9])*L[6]*L[9] + L[6]*L[9]*sin(Th[6])*sin(Th[9])))/2. \
+ (M[10]*(2*cos(Th[6])*cos(Th[9])*L[6]*L[9] + \
2*L[6]*L[9]*sin(Th[6])*sin(Th[9])))/2.;\n coefMat[152] = \
(M[9]*(cos(Th[7])*cos(Th[9])*L[7]*L[9] + L[7]*L[9]*sin(Th[7])*sin(Th[9])))/2. \
+ (M[10]*(2*cos(Th[7])*cos(Th[9])*L[7]*L[9] + \
2*L[7]*L[9]*sin(Th[7])*sin(Th[9])))/2.;\n coefMat[166] = \
(M[9]*(cos(Th[8])*cos(Th[9])*L[8]*L[9] + L[8]*L[9]*sin(Th[8])*sin(Th[9])))/2. \
+ (M[10]*(2*cos(Th[8])*cos(Th[9])*L[8]*L[9] + \
2*L[8]*L[9]*sin(Th[8])*sin(Th[9])))/2.;\n coefMat[180] = \
(pow(L[9],2)*M[9])/12. + (M[9]*((pow(cos(Th[9]),2)*pow(L[9],2))/2. + \
(pow(L[9],2)*pow(sin(Th[9]),2))/2.))/2. + \
(M[10]*(2*pow(cos(Th[9]),2)*pow(L[9],2) + \
2*pow(L[9],2)*pow(sin(Th[9]),2)))/2.;\n coefMat[194] = \
(M[10]*(cos(Th[9])*cos(Th[10])*L[9]*L[10] + \
L[9]*L[10]*sin(Th[9])*sin(Th[10])))/2.;\n rhsVec[12] = \
-(Cs*dTh[9]*pow(L[9],3))/12. - \
(L[9]*sin(Th[9])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - \
Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + \
2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))))/2. + \
(cos(Th[9])*L[9]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + 2*cos(Th[1] - \
Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + 2*cos(Th[5] - \
Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + 2*cos(Th[7] - \
Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + dTh[9]*L[9] - \
2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - \
dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - \
dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - \
dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - \
dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + \
dyL*sin(Th[9]))))/2. + (M[9]*(-(dTh[9]*L[9]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[9])) - \
cos(Th[9])*dTh[9]*L[9]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) \
- dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - \
dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - \
(dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - (M[9]*(-(dTh[9]*L[9]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + \
(cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[9])) - L[9]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
(cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[9]) - cos(Th[9])*dTh[9]*L[9]*(dxL \
- dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - \
(dTh[9]*L[9]*sin(Th[9]))/2.) + cos(Th[9])*L[9]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - \
(pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - \
L[9]*sin(Th[9])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - \
Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + \
cos(Th[9])*L[9]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - \
Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))) + (M[10]*(-2*dTh[9]*L[9]*(dyL + cos(Th[1])*dTh[1]*L[1] + \
cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[9]) - 2*cos(Th[9])*dTh[9]*L[9]*(dxL - \
dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[9]*L[9]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[9]) - 2*L[9]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
cos(Th[9])*pow(dTh[9],2)*L[9] - \
(cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[9]) - \
2*cos(Th[9])*dTh[9]*L[9]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[9])*L[9]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - \
pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;\n\
 coefMat[13] = 0;\n coefMat[27] = 0;\n coefMat[41] = L[10]*sin(Th[10]);\n \
coefMat[55] = -(cos(Th[10])*L[10]);\n coefMat[69] = \
(M[10]*(cos(Th[1])*cos(Th[10])*L[1]*L[10] + \
L[1]*L[10]*sin(Th[1])*sin(Th[10])))/2.;\n coefMat[83] = \
(M[10]*(cos(Th[2])*cos(Th[10])*L[2]*L[10] + \
L[2]*L[10]*sin(Th[2])*sin(Th[10])))/2.;\n coefMat[97] = \
(M[10]*(cos(Th[3])*cos(Th[10])*L[3]*L[10] + \
L[3]*L[10]*sin(Th[3])*sin(Th[10])))/2.;\n coefMat[111] = \
(M[10]*(cos(Th[4])*cos(Th[10])*L[4]*L[10] + \
L[4]*L[10]*sin(Th[4])*sin(Th[10])))/2.;\n coefMat[125] = \
(M[10]*(cos(Th[5])*cos(Th[10])*L[5]*L[10] + \
L[5]*L[10]*sin(Th[5])*sin(Th[10])))/2.;\n coefMat[139] = \
(M[10]*(cos(Th[6])*cos(Th[10])*L[6]*L[10] + \
L[6]*L[10]*sin(Th[6])*sin(Th[10])))/2.;\n coefMat[153] = \
(M[10]*(cos(Th[7])*cos(Th[10])*L[7]*L[10] + \
L[7]*L[10]*sin(Th[7])*sin(Th[10])))/2.;\n coefMat[167] = \
(M[10]*(cos(Th[8])*cos(Th[10])*L[8]*L[10] + \
L[8]*L[10]*sin(Th[8])*sin(Th[10])))/2.;\n coefMat[181] = \
(M[10]*(cos(Th[9])*cos(Th[10])*L[9]*L[10] + \
L[9]*L[10]*sin(Th[9])*sin(Th[10])))/2.;\n coefMat[195] = \
(pow(L[10],2)*M[10])/12. + (M[10]*((pow(cos(Th[10]),2)*pow(L[10],2))/2. + \
(pow(L[10],2)*pow(sin(Th[10]),2))/2.))/2.;\n rhsVec[13] = tauR - \
(Cs*dTh[10]*pow(L[10],3))/12. - \
(L[10]*sin(Th[10])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] \
- Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - \
Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))))/2. + \
(cos(Th[10])*L[10]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - \
Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))))/2. + (M[10]*(-(dTh[10]*L[10]*(dyL + cos(Th[1])*dTh[1]*L[1] \
+ cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + \
cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + \
cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[10])) - cos(Th[10])*dTh[10]*L[10]*(dxL \
- dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - \
dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - \
dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-(dTh[10]*L[10]*(dyL + \
cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + \
cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + \
cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + \
(cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[10])) - L[10]*(ddxL - \
cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - \
cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - \
cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - \
cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - \
cos(Th[9])*pow(dTh[9],2)*L[9] - \
(cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[10]) - \
cos(Th[10])*dTh[10]*L[10]*(dxL - dTh[1]*L[1]*sin(Th[1]) - \
dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - \
dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - \
dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - \
(dTh[10]*L[10]*sin(Th[10]))/2.) + cos(Th[10])*L[10]*(ddyL - \
pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - \
pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - \
pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - \
pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - \
pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;"\
\)], "Print"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1360}, {0, 564}},
WindowSize->{1101, 510},
WindowMargins->{{46, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 9250, 176, 1978, "Input"],
Cell[11029, 231, 78, 1, 25, "Print"],
Cell[11110, 234, 34, 1, 25, "Print"],
Cell[11147, 237, 34, 1, 25, "Print"],
Cell[11184, 240, 34, 1, 25, "Print"],
Cell[11221, 243, 34, 1, 25, "Print"],
Cell[11258, 246, 34, 1, 25, "Print"],
Cell[11295, 249, 34, 1, 25, "Print"],
Cell[11332, 252, 34, 1, 25, "Print"],
Cell[11369, 255, 34, 1, 25, "Print"],
Cell[11406, 258, 34, 1, 25, "Print"],
Cell[11443, 261, 35, 1, 25, "Print"],
Cell[11481, 264, 53, 1, 25, "Print"],
Cell[11537, 267, 57, 1, 25, "Print"],
Cell[11597, 270, 63, 1, 25, "Print"],
Cell[11663, 273, 34, 1, 25, "Print"],
Cell[11700, 276, 34, 1, 25, "Print"],
Cell[11737, 279, 34, 1, 25, "Print"],
Cell[11774, 282, 34, 1, 25, "Print"],
Cell[11811, 285, 34, 1, 25, "Print"],
Cell[11848, 288, 34, 1, 25, "Print"],
Cell[11885, 291, 34, 1, 25, "Print"],
Cell[11922, 294, 34, 1, 25, "Print"],
Cell[11959, 297, 34, 1, 25, "Print"],
Cell[11996, 300, 35, 1, 25, "Print"],
Cell[12034, 303, 35, 1, 25, "Print"],
Cell[12072, 306, 35, 1, 25, "Print"],
Cell[12110, 309, 47, 1, 25, "Print"],
Cell[12160, 312, 34, 1, 25, "Print"],
Cell[12197, 315, 34, 1, 25, "Print"],
Cell[12234, 318, 34, 1, 25, "Print"],
Cell[12271, 321, 34, 1, 25, "Print"],
Cell[12308, 324, 34, 1, 25, "Print"],
Cell[12345, 327, 34, 1, 25, "Print"],
Cell[12382, 330, 34, 1, 25, "Print"],
Cell[12419, 333, 34, 1, 25, "Print"],
Cell[12456, 336, 34, 1, 25, "Print"],
Cell[12493, 339, 35, 1, 25, "Print"],
Cell[12531, 342, 35, 1, 25, "Print"],
Cell[12569, 345, 35, 1, 25, "Print"],
Cell[12607, 348, 35, 1, 25, "Print"],
Cell[12645, 351, 35, 1, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12717, 357, 3711, 74, 870, "Input"],
Cell[16431, 433, 343, 5, 22, "Message"],
Cell[16777, 440, 343, 5, 22, "Message"],
Cell[17123, 447, 344, 5, 22, "Message"],
Cell[17470, 454, 329, 5, 22, "Message"],
Cell[17802, 461, 342, 5, 22, "Message"],
Cell[18147, 468, 342, 5, 22, "Message"],
Cell[18492, 475, 342, 5, 22, "Message"],
Cell[18837, 482, 329, 5, 22, "Message"],
Cell[19169, 489, 356, 5, 22, "Message"],
Cell[19528, 496, 353, 5, 22, "Message"],
Cell[19884, 503, 359, 5, 22, "Message"],
Cell[20246, 510, 359, 5, 22, "Message"],
Cell[20608, 517, 365, 5, 22, "Message"],
Cell[20976, 524, 104612, 1640, 355, "Output"],
Cell[125591, 2166, 603926, 9143, 361, "Output"],
Cell[729520, 11311, 3414, 49, 124, "Output"],
Cell[732937, 11362, 201070, 3119, 30938, "Print"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

