(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    249027,       3998]*)
(*NotebookOutlinePosition[    249674,       4020]*)
(*  CellTagsIndexPosition[    249630,       4016]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[{\(mySimplify[expr_] := Chop[expr];\), "\[IndentingNewLine]", 
    StyleBox[\(Print["\<Generalized coordinates and drag forces ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(n = 10;\), "\[IndentingNewLine]", 
    StyleBox[\(\[Mu] = 10\^\(-3\);\),
      FontColor->GrayLevel[0.666667]], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[\(reNo = 1.0;\),
        FontColor->GrayLevel[0.666667]], "\[IndentingNewLine]", 
      StyleBox[
        RowBox[{"(*", " ", 
          RowBox[{
            
            StyleBox[\(c\_S = \(4\ \[Pi]\ \[Mu]\)\/\(1\/2 - 0.577 - \
Log[reNo\/8]\)\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[";",
              FontColor->GrayLevel[0.666667]], "\[IndentingNewLine]", 
            StyleBox[\(c\_V\  = \(\[Mu]\ 2\ \[Pi]\ 0.1\)\/0.1\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[";",
              FontColor->GrayLevel[0.666667]]}], " ", "*)"}],
        FontColor->GrayLevel[
        0.666667]]}], "\[IndentingNewLine]", \(w\_0 = {x\_L[t], 
          y\_L[t]};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"For", "[", 
        RowBox[{\(a = 1\), ",", \(a \[LessEqual] n\), ",", 
          "\[IndentingNewLine]", 
          RowBox[{\(Print[a]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ \[Lambda]\_a = 1.0; \[IndentingNewLine]m\_a = 
                  1.0;\ *) \),
              FontColor->GrayLevel[0.666667]], 
            "\[IndentingNewLine]", \(th\_a = \[Theta]\_a[t]\), ";", 
            "\[IndentingNewLine]", \(vec\_a = {Cos[th\_a], Sin[th\_a]}\), ";",
             "\[IndentingNewLine]", \(p\_a = 
              w\_\(a - 1\) + \[Lambda]\_a\/2\ vec\_a\), ";", 
            "\[IndentingNewLine]", \(w\_a = 
              w\_\(a - 1\) + \[Lambda]\_a\ vec\_a\), ";", 
            "\[IndentingNewLine]", \(v\_a = D[p\_a, t]\), ";", 
            "\[IndentingNewLine]", \(rotMat\_a = {{Cos[th\_a], 
                  Sin[th\_a]}, {\(-Sin[th\_a]\), Cos[th\_a]}}\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ 
                For\ an\ infinidecimal\ point\ on\ segment\ a\ *) \),
              Background->GrayLevel[0.900008]], 
            "\[IndentingNewLine]", \(pPt\_a = 
              p\_a + s\ {Cos[th\_a], Sin[th\_a]}\), ";", 
            "\[IndentingNewLine]", \(vPt\_a = D[pPt\_a, t]\), ";", 
            "\[IndentingNewLine]", \(vPtLocal\_a = rotMat\_a . vPt\_a\), ";", 
            "\[IndentingNewLine]", \(fPtDrag\_a = 
              Inverse[rotMat\_a] . {\(-c\_V\)\ vPtLocal\_a[\([1]\)], \
\(-c\_S\)\ vPtLocal\_a[\([2]\)]}\), ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ Integrating\ *) \),
              Background->GrayLevel[0.900008]], 
            "\[IndentingNewLine]", \(fDrag\_a = 
              mySimplify[
                Integrate[
                  fPtDrag\_a, {s, \(-\(\[Lambda]\_a\/2\)\), \
\[Lambda]\_a\/2}]]\), ";", 
            "\[IndentingNewLine]", \(tauDrag\_a = 
              mySimplify[
                Integrate[
                  s\ \((fPtDrag\_a[\([2]\)]\ Cos[th\_a] - 
                        fPtDrag\_a[\([1]\)]\ Sin[
                            th\_a])\), {s, \(-\(\[Lambda]\_a\/2\)\), \
\[Lambda]\_a\/2}]]\), ";", "\[IndentingNewLine]", \(a++\)}]}], "]"}], 
      ";"}], "\[IndentingNewLine]", 
    StyleBox[\(Print["\<Generalized forces ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(thetaDotSubsZeros = 
        Table[Null, {n}];\), "\[IndentingNewLine]", \(For[a = 1, 
      a \[LessEqual] 
        n, \[IndentingNewLine]q\_a = \[Sum]\+\(k = 1\)\%n\((fDrag\_k . 
                D[p\_k, \[Theta]\_a[t]])\) + {f\_RX[t], f\_RY[t]} . 
            D[w\_n, \[Theta]\_a[t]] + 
          tauDrag\_a; \[IndentingNewLine]thetaDotSubsZeros[\([a]\)] = 
        D[\[Theta]\_a[t], t] \[Rule] 
          0; \[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", \(q\_\(n + \
1\) = D[x\_R[t] - w\_n[\([1]\)], t];\), "\[IndentingNewLine]", 
    RowBox[{\(q\_\(n + 2\) = D[y\_R[t] - w\_n[\([2]\)], t];\), 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      StyleBox[\( (*\ 
          Computing\ the\ LHS\ matrix\ and\ the\ RHS\ matrix\ \ *) \),
        Background->GrayLevel[
        0.900008]]}], "\[IndentingNewLine]", \(varlist = 
        Table[Null, {n + 6}];\), "\[IndentingNewLine]", \(For[a = 1, 
      a \[LessEqual] n, 
      varlist[\([a]\)] = \(\[Theta]\_a'\)[
          t]; \(a++\)]\), "\[IndentingNewLine]", \(varlist[\([n + 
              1]\)] = \(x\_L'\)[
          t];\), "\[IndentingNewLine]", \(varlist[\([n + 2]\)] = \(y\_L'\)[
          t];\), "\[IndentingNewLine]", \(varlist[\([n + 3]\)] = \(x\_R'\)[
          t];\), "\[IndentingNewLine]", \(varlist[\([n + 4]\)] = \(y\_R'\)[
          t];\), "\[IndentingNewLine]", \(varlist[\([n + 5]\)] = 
        f\_RX[t];\), "\[IndentingNewLine]", 
    RowBox[{\(varlist[\([n + 6]\)] = f\_RY[t];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(matSys = 
        Table[Null, {n + 2}, {n + 6}];\), "\[IndentingNewLine]", \(For[a = 1, 
      a \[LessEqual] 
        n + 2, \[IndentingNewLine]For[b = 1, 
          b \[LessEqual] n + 6, \[IndentingNewLine]matSys[\([a, b]\)] = 
            Chop[mySimplify[\ 
                D[q\_a, 
                  varlist[\([b]\)]]\ ]]; \[IndentingNewLine]\(b++\)]\
\[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", 
    StyleBox[\(Print["\<Simplifying Matrix ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(matSys = 
        Simplify[matSys];\)}], "Input"],

Cell[BoxData[
    \("Generalized coordinates and drag forces ..."\)], "Print"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"],

Cell[BoxData[
    \(7\)], "Print"],

Cell[BoxData[
    \(8\)], "Print"],

Cell[BoxData[
    \(9\)], "Print"],

Cell[BoxData[
    \(10\)], "Print"],

Cell[BoxData[
    \("Generalized forces ..."\)], "Print"],

Cell[BoxData[
    \("Simplifying Matrix ..."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cformVarReplace = 
        Table[Null, {3\ n + 6}];\)\), "\[IndentingNewLine]", 
    \(\(For[a = 1, 
        a \[LessEqual] 
          n, \[IndentingNewLine]cformVarReplace[\([a]\)] = \[Theta]\_a[
              t] \[Rule] 
            Th[\([a]\)]; \[IndentingNewLine]\(a++\)];\)\), "\
\[IndentingNewLine]", 
    \(For[a = 1, 
      a \[LessEqual] n, \[IndentingNewLine]cformVarReplace[\([a + n]\)] = 
        m\_a \[Rule] 
          M[\([a]\)]; \[IndentingNewLine]cformVarReplace[\([a + 
              2\ n]\)] = \[Lambda]\_a \[Rule] 
          L[\([a]\)]; \[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([3\ n + 1]\)] = 
        c\_V \[Rule] Cv;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([3\ n + 2]\)] = 
        c\_S \[Rule] Cs;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([3\ n + 3]\)] = x\_L[t] \[Rule] xL;\)\), "\n", 
    \(\(cformVarReplace[\([3\ n + 4]\)] = 
        y\_L[t] \[Rule] yL;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([3\ n + 5]\)] = x\_R[t] \[Rule] xR;\)\), "\n", 
    \(\(\(cformVarReplace[\([3\ n + 6]\)] = 
        y\_R[t] \[Rule] yR;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(cformDVarReplace = Table[Null, {n + 4}];\)\), "\[IndentingNewLine]", 
    \(\(For[a = 1, 
        a \[LessEqual] 
          n, \[IndentingNewLine]cformDVarReplace[\([a]\)] = \(\[Theta]\_a'\)[
              t] \[Rule] 
            dTh[\([a]\)]; \[IndentingNewLine]\(a++\)];\)\), "\
\[IndentingNewLine]", 
    \(\(cformDVarReplace[\([n + 1]\)] = \(x\_L'\)[t] \[Rule] dxL;\)\), "\n", 
    \(\(cformDVarReplace[\([n + 2]\)] = \(y\_L'\)[t] \[Rule] dyL;\)\), "\n", 
    \(\(cformDVarReplace[\([n + 3]\)] = \(x\_R'\)[t] \[Rule] dxR;\)\), "\n", 
    \(\(\(cformDVarReplace[\([n + 4]\)] = \(y\_R'\)[t] \[Rule] 
          dyR;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(cformVarReplace\), "\[IndentingNewLine]", 
    \(cformDVarReplace\), "\[IndentingNewLine]", 
    \(\(\(matSys\  // \ MatrixForm\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(outCString = "\<\>";\)\), "\[IndentingNewLine]", 
    \(For[a = 1, 
      a \[LessEqual] n + 2, \[IndentingNewLine]For[b = 1, 
        b \[LessEqual] n + 6, \[IndentingNewLine]outCString = 
          outCString <> "\<\n matSys[\>" <> 
            ToString[CForm[\((b - 1)\)\ \((n + 2)\) + a - 1]] <> "\<] = \>" <> 
            ToString[
              CForm[matSys[\([a, b]\)]\  /. \ 
                  cformVarReplace]] <> "\<;\>"; \[IndentingNewLine]\(b++\)]; \
\[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", 
    \(\(For[a = 1, 
        a \[LessEqual] n, \[IndentingNewLine]Print[
          a]; \[IndentingNewLine]fDrag\_a = 
          Simplify[fDrag\_a]; \[IndentingNewLine]outCString = 
          outCString <> "\<\n dragForce[\>" <> 
            ToString[CForm[a - 1]] <> "\<] = \>" <> 
            ToString[
              CForm[Simplify[fDrag\_a[\([1]\)]]\  /. \ 
                  Join[cformVarReplace, 
                    cformDVarReplace]]] <> "\<;\>"; \
\[IndentingNewLine]outCString = 
          outCString <> "\<\n dragForce[\>" <> 
            ToString[CForm[n + a - 1]] <> "\<] = \>" <> 
            ToString[
              CForm[Simplify[fDrag\_a[\([2]\)]]\  /. \ 
                  Join[cformVarReplace, 
                    cformDVarReplace]]] <> "\<;\>"; \
\[IndentingNewLine]\(a++\)];\)\), "\[IndentingNewLine]", 
    \(\(outCString = 
        StringReplace[
          outCString, {"\<Cos\>" \[Rule] "\<cos\>", "\<Sin\>" \[Rule] \
"\<sin\>", "\<Tan\>" \[Rule] "\<tan\>", "\<Power\>" \[Rule] "\<pow\>"}];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[outCString];\)\), "\[IndentingNewLine]", 
    \(\(SetSystemOptions["\<BinaryFormat\>" -> True];\)\), "\n", 
    \(\(BinaryWrite["\<boom10dd.txt\>", 
        outCString];\)\), "\[IndentingNewLine]", 
    \(\(Close["\<boom10dd.txt\>"];\)\)}], "Input"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(Th \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(Th \[LeftDoubleBracket] 2 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(Th \[LeftDoubleBracket] 3 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Part :: \\\"partd\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(M \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(L \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(M \[LeftDoubleBracket] 2 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Part :: \\\"partd\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(dTh \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than \
depth of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(dTh \[LeftDoubleBracket] 2 \[RightDoubleBracket]\\) is longer than \
depth of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(dTh \[LeftDoubleBracket] 3 \[RightDoubleBracket]\\) is longer than \
depth of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Part :: \\\"partd\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    \({\[Theta]\_1[t] \[Rule] 
        Th\[LeftDoubleBracket]1\[RightDoubleBracket], \[Theta]\_2[t] \[Rule] 
        Th\[LeftDoubleBracket]2\[RightDoubleBracket], \[Theta]\_3[t] \[Rule] 
        Th\[LeftDoubleBracket]3\[RightDoubleBracket], \[Theta]\_4[t] \[Rule] 
        Th\[LeftDoubleBracket]4\[RightDoubleBracket], \[Theta]\_5[t] \[Rule] 
        Th\[LeftDoubleBracket]5\[RightDoubleBracket], \[Theta]\_6[t] \[Rule] 
        Th\[LeftDoubleBracket]6\[RightDoubleBracket], \[Theta]\_7[t] \[Rule] 
        Th\[LeftDoubleBracket]7\[RightDoubleBracket], \[Theta]\_8[t] \[Rule] 
        Th\[LeftDoubleBracket]8\[RightDoubleBracket], \[Theta]\_9[t] \[Rule] 
        Th\[LeftDoubleBracket]9\[RightDoubleBracket], \[Theta]\_10[t] \[Rule] 
        Th\[LeftDoubleBracket]10\[RightDoubleBracket], 
      m\_1 \[Rule] M\[LeftDoubleBracket]1\[RightDoubleBracket], 
      m\_2 \[Rule] M\[LeftDoubleBracket]2\[RightDoubleBracket], 
      m\_3 \[Rule] M\[LeftDoubleBracket]3\[RightDoubleBracket], 
      m\_4 \[Rule] M\[LeftDoubleBracket]4\[RightDoubleBracket], 
      m\_5 \[Rule] M\[LeftDoubleBracket]5\[RightDoubleBracket], 
      m\_6 \[Rule] M\[LeftDoubleBracket]6\[RightDoubleBracket], 
      m\_7 \[Rule] M\[LeftDoubleBracket]7\[RightDoubleBracket], 
      m\_8 \[Rule] M\[LeftDoubleBracket]8\[RightDoubleBracket], 
      m\_9 \[Rule] M\[LeftDoubleBracket]9\[RightDoubleBracket], 
      m\_10 \[Rule] 
        M\[LeftDoubleBracket]10\[RightDoubleBracket], \[Lambda]\_1 \[Rule] 
        L\[LeftDoubleBracket]1\[RightDoubleBracket], \[Lambda]\_2 \[Rule] 
        L\[LeftDoubleBracket]2\[RightDoubleBracket], \[Lambda]\_3 \[Rule] 
        L\[LeftDoubleBracket]3\[RightDoubleBracket], \[Lambda]\_4 \[Rule] 
        L\[LeftDoubleBracket]4\[RightDoubleBracket], \[Lambda]\_5 \[Rule] 
        L\[LeftDoubleBracket]5\[RightDoubleBracket], \[Lambda]\_6 \[Rule] 
        L\[LeftDoubleBracket]6\[RightDoubleBracket], \[Lambda]\_7 \[Rule] 
        L\[LeftDoubleBracket]7\[RightDoubleBracket], \[Lambda]\_8 \[Rule] 
        L\[LeftDoubleBracket]8\[RightDoubleBracket], \[Lambda]\_9 \[Rule] 
        L\[LeftDoubleBracket]9\[RightDoubleBracket], \[Lambda]\_10 \[Rule] 
        L\[LeftDoubleBracket]10\[RightDoubleBracket], c\_V \[Rule] Cv, 
      c\_S \[Rule] Cs, x\_L[t] \[Rule] xL, y\_L[t] \[Rule] yL, 
      x\_R[t] \[Rule] xR, y\_R[t] \[Rule] yR}\)], "Output"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_1\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dTh\[LeftDoubleBracket]1\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_2\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dTh\[LeftDoubleBracket]2\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_3\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dTh\[LeftDoubleBracket]3\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_4\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dTh\[LeftDoubleBracket]4\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_5\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dTh\[LeftDoubleBracket]5\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_6\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dTh\[LeftDoubleBracket]6\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_7\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dTh\[LeftDoubleBracket]7\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_8\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dTh\[LeftDoubleBracket]8\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_9\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dTh\[LeftDoubleBracket]9\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_10\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dTh\[LeftDoubleBracket]10\[RightDoubleBracket]\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox[\(x\_L\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "dxL"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox[\(y\_L\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "dyL"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox[\(x\_R\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "dxR"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox[\(y\_R\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "dyR"}]}],
       "}"}]], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(-\(1\/6\)\)\ \[Lambda]\_1\%2\ \((3\ c\_V\ \((2\ Sin[\[Theta]\
\_1[t] - \[Theta]\_2[t]]\^2\ \[Lambda]\_2 + 
                          2\ Sin[\[Theta]\_1[t] - \[Theta]\_3[t]]\^2\ \
\[Lambda]\_3 + \[Lambda]\_4 - 
                          Cos[2\ \((\[Theta]\_1[t] - \[Theta]\_4[
                                      t])\)]\ \[Lambda]\_4 + \[Lambda]\_5 - 
                          Cos[2\ \((\[Theta]\_1[t] - \[Theta]\_5[
                                      t])\)]\ \[Lambda]\_5 + \[Lambda]\_6 - 
                          Cos[2\ \((\[Theta]\_1[t] - \[Theta]\_6[
                                      t])\)]\ \[Lambda]\_6 + \[Lambda]\_7 - 
                          Cos[2\ \((\[Theta]\_1[t] - \[Theta]\_7[
                                      t])\)]\ \[Lambda]\_7 + \[Lambda]\_8 - 
                          Cos[2\ \((\[Theta]\_1[t] - \[Theta]\_8[
                                      t])\)]\ \[Lambda]\_8 + \[Lambda]\_9 - 
                          Cos[2\ \((\[Theta]\_1[t] - \[Theta]\_9[
                                      t])\)]\ \[Lambda]\_9 + \[Lambda]\_10 - 
                          Cos[2\ \((\[Theta]\_1[t] - \[Theta]\_10[
                                      t])\)]\ \[Lambda]\_10)\) + 
                    c\_S\ \((2\ \[Lambda]\_1 + 
                          3\ \((2\ Cos[\[Theta]\_1[t] - \[Theta]\_2[t]]\^2\ \
\[Lambda]\_2 + 
                                2\ Cos[\[Theta]\_1[t] - \[Theta]\_3[t]]\^2\ \
\[Lambda]\_3 + \[Lambda]\_4 + Cos[2\ \((\[Theta]\_1[t] - \[Theta]\_4[
                                        t])\)]\ \[Lambda]\_4 + \[Lambda]\_5 + 
                                Cos[2\ \((\[Theta]\_1[t] - \[Theta]\_5[
                                        t])\)]\ \[Lambda]\_5 + \[Lambda]\_6 + 
                                Cos[2\ \((\[Theta]\_1[t] - \[Theta]\_6[
                                        t])\)]\ \[Lambda]\_6 + \[Lambda]\_7 + 
                                Cos[2\ \((\[Theta]\_1[t] - \[Theta]\_7[
                                        t])\)]\ \[Lambda]\_7 + \[Lambda]\_8 + 
                                Cos[2\ \((\[Theta]\_1[t] - \[Theta]\_8[
                                        t])\)]\ \[Lambda]\_8 + \[Lambda]\_9 + 
                                Cos[2\ \((\[Theta]\_1[t] - \[Theta]\_9[
                                        t])\)]\ \[Lambda]\_9 + \[Lambda]\_10 \
+ Cos[2\ \((\[Theta]\_1[t] - \[Theta]\_10[
                                        t])\)]\ \[Lambda]\_10)\))\))\)\), \
\(\(-\(1\/2\)\)\ \[Lambda]\_1\ \[Lambda]\_2\ \((c\_V\ \((2\ Sin[\[Theta]\_1[
                                  t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_2[
                                  t] - \[Theta]\_3[t]]\ \[Lambda]\_3 + 
                          2\ Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_5 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_6 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_2 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_4[t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_1\ \[Lambda]\_3\ \((c\_V\ \((2\ Sin[\[Theta]\_1[
                                  t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_3[
                                  t] - \[Theta]\_4[t]]\ \[Lambda]\_4 + 
                          2\ Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_6 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_1\ \[Lambda]\_4\ \((c\_V\ \((2\ Sin[\[Theta]\_1[
                                  t] - \[Theta]\_5[t]]\ Sin[\[Theta]\_4[
                                  t] - \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          2\ Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                  t]]\ Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_1\ \[Lambda]\_5\ \((c\_V\ \((2\ Sin[\[Theta]\_1[
                                  t] - \[Theta]\_6[t]]\ Sin[\[Theta]\_5[
                                  t] - \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          2\ Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                  t]]\ Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                  t]]\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_1\ \[Lambda]\_6\ \((c\_V\ \((2\ Sin[\[Theta]\_1[
                                  t] - \[Theta]\_7[t]]\ Sin[\[Theta]\_6[
                                  t] - \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          2\ Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                  t]]\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_1\ \[Lambda]\_7\ \((c\_S\ \((Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                  t]]\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_1\ \[Lambda]\_8\ \((c\_S\ \((Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_1\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_1[t] - \[Theta]\_10[
                            t]]\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_10\%2\), \(1\/2\ \
\[Lambda]\_1\ \((c\_S\ \((Sin[\[Theta]\_1[t]]\ \[Lambda]\_1 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ Sin[\[Theta]\_2[t]]\ \[Lambda]\_2 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_3 - 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_3[t]]\ \[Lambda]\_3 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_4 - 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_4[t]]\ \[Lambda]\_4 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_5 - 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_6 - 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_7 - 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_8 - 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_9 - 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_10 - 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_V\ \((2\ Cos[\[Theta]\_2[
                                t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_2 + 
                          2\ Cos[\[Theta]\_3[
                                t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_4 + 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_4[t]]\ \[Lambda]\_4 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_5 + 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_6 + 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_7 + 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_10 + 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_1\ \((\(-c\_V\)\ \((2\ Sin[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ Sin[\[Theta]\_2[t]]\ \[Lambda]\_2 + 
                          2\ Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ Sin[\[Theta]\_3[t]]\ \[Lambda]\_3 - 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_4[t]]\ \[Lambda]\_4 - 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 - 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 - 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_1[t]]\ \[Lambda]\_1 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2 + 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_3 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_3[t]]\ \[Lambda]\_3 + 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_4[t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\))\)\), 
              "0", "0", \(\(-Sin[\[Theta]\_1[
                      t]]\)\ \[Lambda]\_1\), \(Cos[\[Theta]\_1[
                    t]]\ \[Lambda]\_1\)},
            {\(\(-\(1\/2\)\)\ \[Lambda]\_1\ \[Lambda]\_2\ \((c\_V\ \((2\ Sin[\
\[Theta]\_1[t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          2\ Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_5 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_6 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_2 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_4[t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_2[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/6\)\
\)\ \[Lambda]\_2\%2\ \((3\ c\_V\ \((2\ Sin[\[Theta]\_2[t] - \
\[Theta]\_3[t]]\^2\ \[Lambda]\_3 + 
                          2\ Sin[\[Theta]\_2[t] - \[Theta]\_4[t]]\^2\ \
\[Lambda]\_4 + \[Lambda]\_5 - 
                          Cos[2\ \((\[Theta]\_2[t] - \[Theta]\_5[
                                      t])\)]\ \[Lambda]\_5 + \[Lambda]\_6 - 
                          Cos[2\ \((\[Theta]\_2[t] - \[Theta]\_6[
                                      t])\)]\ \[Lambda]\_6 + \[Lambda]\_7 - 
                          Cos[2\ \((\[Theta]\_2[t] - \[Theta]\_7[
                                      t])\)]\ \[Lambda]\_7 + \[Lambda]\_8 - 
                          Cos[2\ \((\[Theta]\_2[t] - \[Theta]\_8[
                                      t])\)]\ \[Lambda]\_8 + \[Lambda]\_9 - 
                          Cos[2\ \((\[Theta]\_2[t] - \[Theta]\_9[
                                      t])\)]\ \[Lambda]\_9 + \[Lambda]\_10 - 
                          Cos[2\ \((\[Theta]\_2[t] - \[Theta]\_10[
                                      t])\)]\ \[Lambda]\_10)\) + 
                    c\_S\ \((2\ \[Lambda]\_2 + 
                          3\ \((2\ Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\^2\ \
\[Lambda]\_3 + 
                                2\ Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\^2\ \
\[Lambda]\_4 + \[Lambda]\_5 + Cos[2\ \((\[Theta]\_2[t] - \[Theta]\_5[
                                        t])\)]\ \[Lambda]\_5 + \[Lambda]\_6 + 
                                Cos[2\ \((\[Theta]\_2[t] - \[Theta]\_6[
                                        t])\)]\ \[Lambda]\_6 + \[Lambda]\_7 + 
                                Cos[2\ \((\[Theta]\_2[t] - \[Theta]\_7[
                                        t])\)]\ \[Lambda]\_7 + \[Lambda]\_8 + 
                                Cos[2\ \((\[Theta]\_2[t] - \[Theta]\_8[
                                        t])\)]\ \[Lambda]\_8 + \[Lambda]\_9 + 
                                Cos[2\ \((\[Theta]\_2[t] - \[Theta]\_9[
                                        t])\)]\ \[Lambda]\_9 + \[Lambda]\_10 \
+ Cos[2\ \((\[Theta]\_2[t] - \[Theta]\_10[
                                        t])\)]\ \[Lambda]\_10)\))\))\)\), \
\(\(-\(1\/2\)\)\ \[Lambda]\_2\ \[Lambda]\_3\ \((c\_V\ \((2\ Sin[\[Theta]\_2[
                                  t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_3[
                                  t] - \[Theta]\_4[t]]\ \[Lambda]\_4 + 
                          2\ Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_6 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_2\ \[Lambda]\_4\ \((c\_V\ \((2\ Sin[\[Theta]\_2[
                                  t] - \[Theta]\_5[t]]\ Sin[\[Theta]\_4[
                                  t] - \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          2\ Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                  t]]\ Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_2\ \[Lambda]\_5\ \((c\_V\ \((2\ Sin[\[Theta]\_2[
                                  t] - \[Theta]\_6[t]]\ Sin[\[Theta]\_5[
                                  t] - \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          2\ Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                  t]]\ Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                  t]]\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_2\ \[Lambda]\_6\ \((c\_V\ \((2\ Sin[\[Theta]\_2[
                                  t] - \[Theta]\_7[t]]\ Sin[\[Theta]\_6[
                                  t] - \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          2\ Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                  t]]\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_2\ \[Lambda]\_7\ \((c\_S\ \((Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                  t]]\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_2\ \[Lambda]\_8\ \((c\_S\ \((Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_2\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_2[t] - \[Theta]\_10[
                            t]]\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_10\%2\), \(1\/2\ \
\[Lambda]\_2\ \((c\_S\ \((Sin[\[Theta]\_2[t]]\ \[Lambda]\_2 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ Sin[\[Theta]\_3[t]]\ \[Lambda]\_3 + 
                          Sin[\[Theta]\_2[t]]\ \[Lambda]\_4 - 
                          Sin[\[Theta]\_2[t] - 
                                2\ \[Theta]\_4[t]]\ \[Lambda]\_4 + 
                          Sin[\[Theta]\_2[t]]\ \[Lambda]\_5 - 
                          Sin[\[Theta]\_2[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Sin[\[Theta]\_2[t]]\ \[Lambda]\_6 - 
                          Sin[\[Theta]\_2[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Sin[\[Theta]\_2[t]]\ \[Lambda]\_7 - 
                          Sin[\[Theta]\_2[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Sin[\[Theta]\_2[t]]\ \[Lambda]\_8 - 
                          Sin[\[Theta]\_2[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_2[t]]\ \[Lambda]\_9 - 
                          Sin[\[Theta]\_2[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_2[t]]\ \[Lambda]\_10 - 
                          Sin[\[Theta]\_2[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_V\ \((2\ Cos[\[Theta]\_3[
                                t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_4[
                                t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4 + 
                          Sin[\[Theta]\_2[t]]\ \[Lambda]\_5 + 
                          Sin[\[Theta]\_2[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Sin[\[Theta]\_2[t]]\ \[Lambda]\_6 + 
                          Sin[\[Theta]\_2[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Sin[\[Theta]\_2[t]]\ \[Lambda]\_7 + 
                          Sin[\[Theta]\_2[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Sin[\[Theta]\_2[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_2[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_2[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_2[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_2[t]]\ \[Lambda]\_10 + 
                          Sin[\[Theta]\_2[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_2\ \((\(-c\_V\)\ \((2\ Sin[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ Sin[\[Theta]\_3[t]]\ \[Lambda]\_3 + 
                          2\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ Sin[\[Theta]\_4[t]]\ \[Lambda]\_4 - 
                          Cos[\[Theta]\_2[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_2[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 - 
                          Cos[\[Theta]\_2[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 - 
                          Cos[\[Theta]\_2[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_2[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_2[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_2[t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_2[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_2[t]]\ \[Lambda]\_2 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3 + 
                          Cos[\[Theta]\_2[t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_2[t] - 
                                2\ \[Theta]\_4[t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_2[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_2[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_2[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_2[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\))\)\), 
              "0", "0", \(\(-Sin[\[Theta]\_2[
                      t]]\)\ \[Lambda]\_2\), \(Cos[\[Theta]\_2[
                    t]]\ \[Lambda]\_2\)},
            {\(\(-\(1\/2\)\)\ \[Lambda]\_1\ \[Lambda]\_3\ \((c\_V\ \((2\ Sin[\
\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4 + 
                          2\ Sin[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_6 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_2\ \[Lambda]\_3\ \((c\_V\ \((2\ Sin[\[Theta]\_2[
                                  t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_3[
                                  t] - \[Theta]\_4[t]]\ \[Lambda]\_4 + 
                          2\ Sin[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_6 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_3[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/6\)\
\)\ \[Lambda]\_3\%2\ \((3\ c\_V\ \((2\ Sin[\[Theta]\_3[t] - \
\[Theta]\_4[t]]\^2\ \[Lambda]\_4 + 
                          2\ Sin[\[Theta]\_3[t] - \[Theta]\_5[t]]\^2\ \
\[Lambda]\_5 + \[Lambda]\_6 - 
                          Cos[2\ \((\[Theta]\_3[t] - \[Theta]\_6[
                                      t])\)]\ \[Lambda]\_6 + \[Lambda]\_7 - 
                          Cos[2\ \((\[Theta]\_3[t] - \[Theta]\_7[
                                      t])\)]\ \[Lambda]\_7 + \[Lambda]\_8 - 
                          Cos[2\ \((\[Theta]\_3[t] - \[Theta]\_8[
                                      t])\)]\ \[Lambda]\_8 + \[Lambda]\_9 - 
                          Cos[2\ \((\[Theta]\_3[t] - \[Theta]\_9[
                                      t])\)]\ \[Lambda]\_9 + \[Lambda]\_10 - 
                          Cos[2\ \((\[Theta]\_3[t] - \[Theta]\_10[
                                      t])\)]\ \[Lambda]\_10)\) + 
                    c\_S\ \((2\ \[Lambda]\_3 + 
                          3\ \((2\ Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\^2\ \
\[Lambda]\_4 + 
                                2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[t]]\^2\ \
\[Lambda]\_5 + \[Lambda]\_6 + Cos[2\ \((\[Theta]\_3[t] - \[Theta]\_6[
                                        t])\)]\ \[Lambda]\_6 + \[Lambda]\_7 + 
                                Cos[2\ \((\[Theta]\_3[t] - \[Theta]\_7[
                                        t])\)]\ \[Lambda]\_7 + \[Lambda]\_8 + 
                                Cos[2\ \((\[Theta]\_3[t] - \[Theta]\_8[
                                        t])\)]\ \[Lambda]\_8 + \[Lambda]\_9 + 
                                Cos[2\ \((\[Theta]\_3[t] - \[Theta]\_9[
                                        t])\)]\ \[Lambda]\_9 + \[Lambda]\_10 \
+ Cos[2\ \((\[Theta]\_3[t] - \[Theta]\_10[
                                        t])\)]\ \[Lambda]\_10)\))\))\)\), \
\(\(-\(1\/2\)\)\ \[Lambda]\_3\ \[Lambda]\_4\ \((c\_V\ \((2\ Sin[\[Theta]\_3[
                                  t] - \[Theta]\_5[t]]\ Sin[\[Theta]\_4[
                                  t] - \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          2\ Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                  t]]\ Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_3\ \[Lambda]\_5\ \((c\_V\ \((2\ Sin[\[Theta]\_3[
                                  t] - \[Theta]\_6[t]]\ Sin[\[Theta]\_5[
                                  t] - \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          2\ Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                  t]]\ Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                  t]]\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_3\ \[Lambda]\_6\ \((c\_V\ \((2\ Sin[\[Theta]\_3[
                                  t] - \[Theta]\_7[t]]\ Sin[\[Theta]\_6[
                                  t] - \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          2\ Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                  t]]\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_3\ \[Lambda]\_7\ \((c\_S\ \((Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                  t]]\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_3\ \[Lambda]\_8\ \((c\_S\ \((Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_3\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_3[t] - \[Theta]\_10[
                            t]]\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_10\%2\), \(1\/2\ \
\[Lambda]\_3\ \((c\_S\ \((Sin[\[Theta]\_3[t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ Sin[\[Theta]\_4[t]]\ \[Lambda]\_4 + 
                          Sin[\[Theta]\_3[t]]\ \[Lambda]\_5 - 
                          Sin[\[Theta]\_3[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Sin[\[Theta]\_3[t]]\ \[Lambda]\_6 - 
                          Sin[\[Theta]\_3[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Sin[\[Theta]\_3[t]]\ \[Lambda]\_7 - 
                          Sin[\[Theta]\_3[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Sin[\[Theta]\_3[t]]\ \[Lambda]\_8 - 
                          Sin[\[Theta]\_3[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_3[t]]\ \[Lambda]\_9 - 
                          Sin[\[Theta]\_3[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_3[t]]\ \[Lambda]\_10 - 
                          Sin[\[Theta]\_3[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_V\ \((2\ Cos[\[Theta]\_4[
                                t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4 + 
                          2\ Cos[\[Theta]\_5[
                                t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          Sin[\[Theta]\_3[t]]\ \[Lambda]\_6 + 
                          Sin[\[Theta]\_3[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Sin[\[Theta]\_3[t]]\ \[Lambda]\_7 + 
                          Sin[\[Theta]\_3[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Sin[\[Theta]\_3[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_3[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_3[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_3[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_3[t]]\ \[Lambda]\_10 + 
                          Sin[\[Theta]\_3[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_3\ \((\(-c\_V\)\ \((2\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ Sin[\[Theta]\_4[t]]\ \[Lambda]\_4 + 
                          2\ Sin[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ Sin[\[Theta]\_5[t]]\ \[Lambda]\_5 - 
                          Cos[\[Theta]\_3[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_3[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 - 
                          Cos[\[Theta]\_3[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_3[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_3[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_3[t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_3[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_3[t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_3[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_3[t] - 
                                2\ \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_3[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_3[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_3[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_3[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\))\)\), 
              "0", "0", \(\(-Sin[\[Theta]\_3[
                      t]]\)\ \[Lambda]\_3\), \(Cos[\[Theta]\_3[
                    t]]\ \[Lambda]\_3\)},
            {\(\(-\(1\/2\)\)\ \[Lambda]\_1\ \[Lambda]\_4\ \((c\_V\ \((2\ Sin[\
\[Theta]\_1[t] - \[Theta]\_5[t]]\ Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          2\ Sin[\[Theta]\_1[t] - \[Theta]\_6[
                                  t]]\ Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_2\ \[Lambda]\_4\ \((c\_V\ \((2\ Sin[\[Theta]\_2[
                                  t] - \[Theta]\_5[t]]\ Sin[\[Theta]\_4[
                                  t] - \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          2\ Sin[\[Theta]\_2[t] - \[Theta]\_6[
                                  t]]\ Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_3\ \[Lambda]\_4\ \((c\_V\ \((2\ Sin[\[Theta]\_3[
                                  t] - \[Theta]\_5[t]]\ Sin[\[Theta]\_4[
                                  t] - \[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          2\ Sin[\[Theta]\_3[t] - \[Theta]\_6[
                                  t]]\ Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_4[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/6\)\
\)\ \[Lambda]\_4\%2\ \((3\ c\_V\ \((2\ Sin[\[Theta]\_4[t] - \
\[Theta]\_5[t]]\^2\ \[Lambda]\_5 + 
                          2\ Sin[\[Theta]\_4[t] - \[Theta]\_6[t]]\^2\ \
\[Lambda]\_6 + \[Lambda]\_7 - 
                          Cos[2\ \((\[Theta]\_4[t] - \[Theta]\_7[
                                      t])\)]\ \[Lambda]\_7 + \[Lambda]\_8 - 
                          Cos[2\ \((\[Theta]\_4[t] - \[Theta]\_8[
                                      t])\)]\ \[Lambda]\_8 + \[Lambda]\_9 - 
                          Cos[2\ \((\[Theta]\_4[t] - \[Theta]\_9[
                                      t])\)]\ \[Lambda]\_9 + \[Lambda]\_10 - 
                          Cos[2\ \((\[Theta]\_4[t] - \[Theta]\_10[
                                      t])\)]\ \[Lambda]\_10)\) + 
                    c\_S\ \((2\ \[Lambda]\_4 + 
                          3\ \((2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[t]]\^2\ \
\[Lambda]\_5 + 
                                2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[t]]\^2\ \
\[Lambda]\_6 + \[Lambda]\_7 + Cos[2\ \((\[Theta]\_4[t] - \[Theta]\_7[
                                        t])\)]\ \[Lambda]\_7 + \[Lambda]\_8 + 
                                Cos[2\ \((\[Theta]\_4[t] - \[Theta]\_8[
                                        t])\)]\ \[Lambda]\_8 + \[Lambda]\_9 + 
                                Cos[2\ \((\[Theta]\_4[t] - \[Theta]\_9[
                                        t])\)]\ \[Lambda]\_9 + \[Lambda]\_10 \
+ Cos[2\ \((\[Theta]\_4[t] - \[Theta]\_10[
                                        t])\)]\ \[Lambda]\_10)\))\))\)\), \
\(\(-\(1\/2\)\)\ \[Lambda]\_4\ \[Lambda]\_5\ \((c\_V\ \((2\ Sin[\[Theta]\_4[
                                  t] - \[Theta]\_6[t]]\ Sin[\[Theta]\_5[
                                  t] - \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          2\ Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                  t]]\ Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_4[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_4[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_4[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_4\ \[Lambda]\_6\ \((c\_V\ \((2\ Sin[\[Theta]\_4[
                                  t] - \[Theta]\_7[t]]\ Sin[\[Theta]\_6[
                                  t] - \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          2\ Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_4[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_4[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                  t]]\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_4\ \[Lambda]\_7\ \((c\_S\ \((Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                  t]]\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_4\ \[Lambda]\_8\ \((c\_S\ \((Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_4\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_4[t] - \[Theta]\_10[
                            t]]\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_4\ \[Lambda]\_10\%2\), \(1\/2\ \
\[Lambda]\_4\ \((c\_S\ \((Sin[\[Theta]\_4[t]]\ \[Lambda]\_4 + 
                          2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ Sin[\[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Sin[\[Theta]\_4[t]]\ \[Lambda]\_6 - 
                          Sin[\[Theta]\_4[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Sin[\[Theta]\_4[t]]\ \[Lambda]\_7 - 
                          Sin[\[Theta]\_4[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Sin[\[Theta]\_4[t]]\ \[Lambda]\_8 - 
                          Sin[\[Theta]\_4[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_4[t]]\ \[Lambda]\_9 - 
                          Sin[\[Theta]\_4[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_4[t]]\ \[Lambda]\_10 - 
                          Sin[\[Theta]\_4[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_V\ \((2\ Cos[\[Theta]\_5[
                                t]]\ Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          2\ Cos[\[Theta]\_6[
                                t]]\ Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          Sin[\[Theta]\_4[t]]\ \[Lambda]\_7 + 
                          Sin[\[Theta]\_4[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Sin[\[Theta]\_4[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_4[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_4[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_4[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_4[t]]\ \[Lambda]\_10 + 
                          Sin[\[Theta]\_4[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_4\ \((\(-c\_V\)\ \((2\ Sin[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ Sin[\[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          2\ Sin[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ Sin[\[Theta]\_6[t]]\ \[Lambda]\_6 - 
                          Cos[\[Theta]\_4[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_4[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_4[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_4[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_4[t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_4[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_4[t]]\ \[Lambda]\_4 + 
                          2\ Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ Cos[\[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          Cos[\[Theta]\_4[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_4[t] - 
                                2\ \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_4[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_4[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_4[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_4[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\))\)\), 
              "0", "0", \(\(-Sin[\[Theta]\_4[
                      t]]\)\ \[Lambda]\_4\), \(Cos[\[Theta]\_4[
                    t]]\ \[Lambda]\_4\)},
            {\(\(-\(1\/2\)\)\ \[Lambda]\_1\ \[Lambda]\_5\ \((c\_V\ \((2\ Sin[\
\[Theta]\_1[t] - \[Theta]\_6[t]]\ Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          2\ Sin[\[Theta]\_1[t] - \[Theta]\_7[
                                  t]]\ Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                  t]]\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_2\ \[Lambda]\_5\ \((c\_V\ \((2\ Sin[\[Theta]\_2[
                                  t] - \[Theta]\_6[t]]\ Sin[\[Theta]\_5[
                                  t] - \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          2\ Sin[\[Theta]\_2[t] - \[Theta]\_7[
                                  t]]\ Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                  t]]\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_3\ \[Lambda]\_5\ \((c\_V\ \((2\ Sin[\[Theta]\_3[
                                  t] - \[Theta]\_6[t]]\ Sin[\[Theta]\_5[
                                  t] - \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          2\ Sin[\[Theta]\_3[t] - \[Theta]\_7[
                                  t]]\ Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                  t]]\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_4\ \[Lambda]\_5\ \((c\_V\ \((2\ Sin[\[Theta]\_4[
                                  t] - \[Theta]\_6[t]]\ Sin[\[Theta]\_5[
                                  t] - \[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          2\ Sin[\[Theta]\_4[t] - \[Theta]\_7[
                                  t]]\ Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_4[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_4[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_4[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_5 + 
                          2\ Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_5[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_5[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/6\)\
\)\ \[Lambda]\_5\%2\ \((3\ c\_V\ \((2\ Sin[\[Theta]\_5[t] - \
\[Theta]\_6[t]]\^2\ \[Lambda]\_6 + 
                          2\ Sin[\[Theta]\_5[t] - \[Theta]\_7[t]]\^2\ \
\[Lambda]\_7 + \[Lambda]\_8 - 
                          Cos[2\ \((\[Theta]\_5[t] - \[Theta]\_8[
                                      t])\)]\ \[Lambda]\_8 + \[Lambda]\_9 - 
                          Cos[2\ \((\[Theta]\_5[t] - \[Theta]\_9[
                                      t])\)]\ \[Lambda]\_9 + \[Lambda]\_10 - 
                          Cos[2\ \((\[Theta]\_5[t] - \[Theta]\_10[
                                      t])\)]\ \[Lambda]\_10)\) + 
                    c\_S\ \((2\ \[Lambda]\_5 + 
                          3\ \((2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[t]]\^2\ \
\[Lambda]\_6 + 
                                2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[t]]\^2\ \
\[Lambda]\_7 + \[Lambda]\_8 + Cos[2\ \((\[Theta]\_5[t] - \[Theta]\_8[
                                        t])\)]\ \[Lambda]\_8 + \[Lambda]\_9 + 
                                Cos[2\ \((\[Theta]\_5[t] - \[Theta]\_9[
                                        t])\)]\ \[Lambda]\_9 + \[Lambda]\_10 \
+ Cos[2\ \((\[Theta]\_5[t] - \[Theta]\_10[
                                        t])\)]\ \[Lambda]\_10)\))\))\)\), \
\(\(-\(1\/2\)\)\ \[Lambda]\_5\ \[Lambda]\_6\ \((c\_V\ \((2\ Sin[\[Theta]\_5[
                                  t] - \[Theta]\_7[t]]\ Sin[\[Theta]\_6[
                                  t] - \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          2\ Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_5[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_5[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_5[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_5[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_5[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_5\ \[Lambda]\_7\ \((c\_S\ \((Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                  t]]\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_5[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_5[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_5\ \[Lambda]\_8\ \((c\_S\ \((Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                  
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_5\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_5[t] - \[Theta]\_10[
                            t]]\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_5\ \[Lambda]\_10\%2\), \(1\/2\ \
\[Lambda]\_5\ \((c\_S\ \((Sin[\[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ Sin[\[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Sin[\[Theta]\_5[t]]\ \[Lambda]\_7 - 
                          Sin[\[Theta]\_5[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Sin[\[Theta]\_5[t]]\ \[Lambda]\_8 - 
                          Sin[\[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_5[t]]\ \[Lambda]\_9 - 
                          Sin[\[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_5[t]]\ \[Lambda]\_10 - 
                          Sin[\[Theta]\_5[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_V\ \((2\ Cos[\[Theta]\_6[
                                t]]\ Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          2\ Cos[\[Theta]\_7[
                                t]]\ Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Sin[\[Theta]\_5[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_5[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_5[t]]\ \[Lambda]\_10 + 
                          Sin[\[Theta]\_5[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_5\ \((\(-c\_V\)\ \((2\ Sin[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ Sin[\[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          2\ Sin[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ Sin[\[Theta]\_7[t]]\ \[Lambda]\_7 - 
                          Cos[\[Theta]\_5[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_5[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_5[t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_5[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_5[t]]\ \[Lambda]\_5 + 
                          2\ Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ Cos[\[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          Cos[\[Theta]\_5[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_5[t] - 
                                2\ \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_5[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_5[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_5[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_5[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_5[t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_5[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\))\)\), 
              "0", "0", \(\(-Sin[\[Theta]\_5[
                      t]]\)\ \[Lambda]\_5\), \(Cos[\[Theta]\_5[
                    t]]\ \[Lambda]\_5\)},
            {\(\(-\(1\/2\)\)\ \[Lambda]\_1\ \[Lambda]\_6\ \((c\_V\ \((2\ Sin[\
\[Theta]\_1[t] - \[Theta]\_7[t]]\ Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          2\ Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_1[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                  t]]\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_2\ \[Lambda]\_6\ \((c\_V\ \((2\ Sin[\[Theta]\_2[
                                  t] - \[Theta]\_7[t]]\ Sin[\[Theta]\_6[
                                  t] - \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          2\ Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_2[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                  t]]\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_3\ \[Lambda]\_6\ \((c\_V\ \((2\ Sin[\[Theta]\_3[
                                  t] - \[Theta]\_7[t]]\ Sin[\[Theta]\_6[
                                  t] - \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          2\ Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_3[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                  t]]\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_4\ \[Lambda]\_6\ \((c\_V\ \((2\ Sin[\[Theta]\_4[
                                  t] - \[Theta]\_7[t]]\ Sin[\[Theta]\_6[
                                  t] - \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          2\ Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_4[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_4[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          2\ Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                  t]]\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_5\ \[Lambda]\_6\ \((c\_V\ \((2\ Sin[\[Theta]\_5[
                                  t] - \[Theta]\_7[t]]\ Sin[\[Theta]\_6[
                                  t] - \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          2\ Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_5[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 - 
                          Cos[\[Theta]\_5[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_6 + 
                          2\ Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_5[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_5[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_5[t] - \[Theta]\_6[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_5[t] + \[Theta]\_6[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/6\)\
\)\ \[Lambda]\_6\%2\ \((3\ c\_V\ \((2\ Sin[\[Theta]\_6[t] - \
\[Theta]\_7[t]]\^2\ \[Lambda]\_7 + 
                          2\ Sin[\[Theta]\_6[t] - \[Theta]\_8[t]]\^2\ \
\[Lambda]\_8 + \[Lambda]\_9 - 
                          Cos[2\ \((\[Theta]\_6[t] - \[Theta]\_9[
                                      t])\)]\ \[Lambda]\_9 + \[Lambda]\_10 - 
                          Cos[2\ \((\[Theta]\_6[t] - \[Theta]\_10[
                                      t])\)]\ \[Lambda]\_10)\) + 
                    c\_S\ \((2\ \[Lambda]\_6 + 
                          3\ \((2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[t]]\^2\ \
\[Lambda]\_7 + 
                                2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[t]]\^2\ \
\[Lambda]\_8 + \[Lambda]\_9 + Cos[2\ \((\[Theta]\_6[t] - \[Theta]\_9[
                                        t])\)]\ \[Lambda]\_9 + \[Lambda]\_10 \
+ Cos[2\ \((\[Theta]\_6[t] - \[Theta]\_10[
                                        t])\)]\ \[Lambda]\_10)\))\))\)\), \
\(\(-\(1\/2\)\)\ \[Lambda]\_6\ \[Lambda]\_7\ \((c\_S\ \((Cos[\[Theta]\_6[
                                  t] - \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_6[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_6[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_6\ \[Lambda]\_8\ \((c\_S\ \((Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_6\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_6[t] - \[Theta]\_10[
                            t]]\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_6\ \[Lambda]\_10\%2\), \(1\/2\ \
\[Lambda]\_6\ \((c\_S\ \((Sin[\[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ Sin[\[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Sin[\[Theta]\_6[t]]\ \[Lambda]\_8 - 
                          Sin[\[Theta]\_6[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_6[t]]\ \[Lambda]\_9 - 
                          Sin[\[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_6[t]]\ \[Lambda]\_10 - 
                          Sin[\[Theta]\_6[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_V\ \((2\ Cos[\[Theta]\_7[
                                t]]\ Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          2\ Cos[\[Theta]\_8[
                                t]]\ Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_6[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_6[t]]\ \[Lambda]\_10 + 
                          Sin[\[Theta]\_6[t] - 
                                2\ \[Theta]\_10[
                                    t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\
\)\ \[Lambda]\_6\ \((\(-c\_V\)\ \((2\ Sin[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ Sin[\[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          2\ Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_8[t]]\ \[Lambda]\_8 - 
                          Cos[\[Theta]\_6[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 - 
                          Cos[\[Theta]\_6[t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_6[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_S\ \((Cos[\[Theta]\_6[t]]\ \[Lambda]\_6 + 
                          2\ Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ Cos[\[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          Cos[\[Theta]\_6[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_6[t] - 
                                2\ \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_6[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_6[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_6[t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_6[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\))\)\), 
              "0", "0", \(\(-Sin[\[Theta]\_6[
                      t]]\)\ \[Lambda]\_6\), \(Cos[\[Theta]\_6[
                    t]]\ \[Lambda]\_6\)},
            {\(\(-\(1\/2\)\)\ \[Lambda]\_1\ \[Lambda]\_7\ \((c\_S\ \((Cos[\
\[Theta]\_1[t] - \[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_8[
                                  t]]\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_1[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_1[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_1[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_2\ \[Lambda]\_7\ \((c\_S\ \((Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                  t]]\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_2[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_2[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_2[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_3\ \[Lambda]\_7\ \((c\_S\ \((Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                  t]]\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_3[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_3[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_3[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_4\ \[Lambda]\_7\ \((c\_S\ \((Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          2\ Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                  t]]\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_4[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_4[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_4[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_5\ \[Lambda]\_7\ \((c\_S\ \((Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          2\ Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                  t]]\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_5[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_5[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_5[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_5[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_6\ \[Lambda]\_7\ \((c\_S\ \((Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_7 + 
                          2\ Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_6[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_6[t] - \[Theta]\_7[
                                  t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_6[t] + \[Theta]\_7[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/3\)\)\
\ \[Lambda]\_7\%2\ \((3\ c\_V\ \((Sin[\[Theta]\_7[t] - \[Theta]\_8[t]]\^2\ \
\[Lambda]\_8 + Sin[\[Theta]\_7[t] - \[Theta]\_9[t]]\^2\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_7[t] - \[Theta]\_10[t]]\^2\ \[Lambda]\
\_10)\) + c\_S\ \((\[Lambda]\_7 + 
                          3\ \((Cos[\[Theta]\_7[t] - \[Theta]\_8[t]]\^2\ \
\[Lambda]\_8 + Cos[\[Theta]\_7[t] - \[Theta]\_9[t]]\^2\ \[Lambda]\_9 + 
                                Cos[\[Theta]\_7[t] - \[Theta]\_10[t]]\^2\ \
\[Lambda]\_10)\))\))\)\), \(\(-\(1\/2\)\)\ \[Lambda]\_7\ \[Lambda]\_8\ \
\((c\_S\ \((Cos[\[Theta]\_7[t] - \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_7\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_7[t] - \[Theta]\_10[
                            t]]\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_7\ \[Lambda]\_10\%2\), \(1\/2\ \
\[Lambda]\_7\ \((c\_S\ \((Sin[\[Theta]\_7[t]]\ \[Lambda]\_7 + 
                          2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_7[t]]\ \[Lambda]\_9 - 
                          Sin[\[Theta]\_7[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_7[t]]\ \[Lambda]\_10 - 
                          Sin[\[Theta]\_7[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) + 
                    c\_V\ \((2\ Cos[\[Theta]\_8[
                                t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_9[
                                t]]\ Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + \((Sin[\[Theta]\_7[
                                    t]] + 
                                Sin[\[Theta]\_7[t] - 
                                    2\ \[Theta]\_10[
                                        t]])\)\ \[Lambda]\_10)\))\)\), \
\(\(-\(1\/2\)\)\ \[Lambda]\_7\ \((c\_S\ \((Cos[\[Theta]\_7[
                                t]]\ \[Lambda]\_7 + 
                          2\ Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ Cos[\[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Cos[\[Theta]\_7[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_7[t] - 
                                2\ \[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Cos[\[Theta]\_7[t]]\ \[Lambda]\_10 + 
                          Cos[\[Theta]\_7[t] - 
                                2\ \[Theta]\_10[t]]\ \[Lambda]\_10)\) - 
                    2\ c\_V\ \((Sin[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ Sin[\[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_10[
                                t]]\ \[Lambda]\_10)\))\)\), "0", 
              "0", \(\(-Sin[\[Theta]\_7[
                      t]]\)\ \[Lambda]\_7\), \(Cos[\[Theta]\_7[
                    t]]\ \[Lambda]\_7\)},
            {\(\(-\(1\/2\)\)\ \[Lambda]\_1\ \[Lambda]\_8\ \((c\_S\ \((Cos[\
\[Theta]\_1[t] - \[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_1[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_1[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_2\ \[Lambda]\_8\ \((c\_S\ \((Cos[\[Theta]\_2[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_2[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_2[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_3\ \[Lambda]\_8\ \((c\_S\ \((Cos[\[Theta]\_3[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_3[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_3[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_4\ \[Lambda]\_8\ \((c\_S\ \((Cos[\[Theta]\_4[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_4[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_4[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_5\ \[Lambda]\_8\ \((c\_S\ \((Cos[\[Theta]\_5[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_5[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_5[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_6\ \[Lambda]\_8\ \((c\_S\ \((Cos[\[Theta]\_6[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_6[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_6[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_7\ \[Lambda]\_8\ \((c\_S\ \((Cos[\[Theta]\_7[t] - \[Theta]\_8[
                                  t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/3\)\)\
\ \[Lambda]\_8\%2\ \((c\_S\ \((\[Lambda]\_8 + 
                          3\ Cos[\[Theta]\_8[t] - \[Theta]\_9[t]]\^2\ \
\[Lambda]\_9 + 
                          3\ Cos[\[Theta]\_8[t] - \[Theta]\_10[t]]\^2\ \
\[Lambda]\_10)\) + 
                    3\ c\_V\ \((Sin[\[Theta]\_8[t] - \[Theta]\_9[t]]\^2\ \
\[Lambda]\_9 + 
                          Sin[\[Theta]\_8[t] - \[Theta]\_10[t]]\^2\ \[Lambda]\
\_10)\))\)\), \(\(-\(1\/2\)\)\ \[Lambda]\_8\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\
\_8[t] - \[Theta]\_10[t]]\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_8\ \[Lambda]\_10\%2\), \(1\/2\ \
\[Lambda]\_8\ \((c\_V\ \((2\ Cos[\[Theta]\_9[
                                t]]\ Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + \((Sin[\[Theta]\_8[
                                    t]] + 
                                Sin[\[Theta]\_8[t] - 
                                    2\ \[Theta]\_10[
                                        t]])\)\ \[Lambda]\_10)\) + 
                    c\_S\ \((Sin[\[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_10[
                                t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\ \
\[Lambda]\_8\ \((c\_S\ \((Cos[\[Theta]\_8[t]]\ \[Lambda]\_8 + 
                          2\ Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ Cos[\[Theta]\_9[
                                t]]\ \[Lambda]\_9 + \((Cos[\[Theta]\_8[t]] + 
                                Cos[\[Theta]\_8[t] - 
                                    2\ \[Theta]\_10[
                                        t]])\)\ \[Lambda]\_10)\) - 
                    2\ c\_V\ \((Sin[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ Sin[\[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          Sin[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_10[
                                t]]\ \[Lambda]\_10)\))\)\), "0", 
              "0", \(\(-Sin[\[Theta]\_8[
                      t]]\)\ \[Lambda]\_8\), \(Cos[\[Theta]\_8[
                    t]]\ \[Lambda]\_8\)},
            {\(\(-\(1\/2\)\)\ \[Lambda]\_1\ \[Lambda]\_9\ \((2\ \
Sin[\[Theta]\_1[t] - \[Theta]\_10[t]]\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_1[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_2\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_2[t] - \[Theta]\_10[
                            t]]\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_2[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_3\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_3[t] - \[Theta]\_10[
                            t]]\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_3[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_4\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_4[t] - \[Theta]\_10[
                            t]]\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_4[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_5\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_5[t] - \[Theta]\_10[
                            t]]\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_5[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_6\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_6[t] - \[Theta]\_10[
                            t]]\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_6[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_7\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_7[t] - \[Theta]\_10[
                            t]]\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_7[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\
\ \[Lambda]\_8\ \[Lambda]\_9\ \((2\ Sin[\[Theta]\_8[t] - \[Theta]\_10[
                            t]]\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_8[t] - \[Theta]\_9[
                                  t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                                  t]]\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/3\)\)\
\ \[Lambda]\_9\%2\ \((3\ Sin[\[Theta]\_9[t] - \[Theta]\_10[t]]\^2\ c\_V\ \
\[Lambda]\_10 + c\_S\ \((\[Lambda]\_9 + 
                          3\ Cos[\[Theta]\_9[t] - \[Theta]\_10[t]]\^2\ \
\[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_9\ \[Lambda]\_10\%2\), \(1\/2\ \
\[Lambda]\_9\ \((\((Sin[\[Theta]\_9[t]] + 
                          Sin[\[Theta]\_9[t] - 
                              2\ \[Theta]\_10[t]])\)\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Sin[\[Theta]\_9[t]]\ \[Lambda]\_9 + 
                          2\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                                  t]]\ Sin[\[Theta]\_10[
                                t]]\ \[Lambda]\_10)\))\)\), \(\(-\(1\/2\)\)\ \
\[Lambda]\_9\ \((\(-2\)\ Sin[\[Theta]\_9[t] - \[Theta]\_10[
                            t]]\ Sin[\[Theta]\_10[t]]\ c\_V\ \[Lambda]\_10 + 
                    c\_S\ \((Cos[\[Theta]\_9[
                                t]]\ \[Lambda]\_9 + \((Cos[\[Theta]\_9[t]] + 
                                Cos[\[Theta]\_9[t] - 
                                    2\ \[Theta]\_10[
                                        t]])\)\ \[Lambda]\_10)\))\)\), "0", 
              "0", \(\(-Sin[\[Theta]\_9[
                      t]]\)\ \[Lambda]\_9\), \(Cos[\[Theta]\_9[
                    t]]\ \[Lambda]\_9\)},
            {\(\(-\(1\/2\)\)\ Cos[\[Theta]\_1[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_10\%2\), \
\(\(-\(1\/2\)\)\ Cos[\[Theta]\_2[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_10\%2\), \
\(\(-\(1\/2\)\)\ Cos[\[Theta]\_3[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_10\%2\), \
\(\(-\(1\/2\)\)\ Cos[\[Theta]\_4[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_4\ \[Lambda]\_10\%2\), \
\(\(-\(1\/2\)\)\ Cos[\[Theta]\_5[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_5\ \[Lambda]\_10\%2\), \
\(\(-\(1\/2\)\)\ Cos[\[Theta]\_6[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_6\ \[Lambda]\_10\%2\), \
\(\(-\(1\/2\)\)\ Cos[\[Theta]\_7[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_7\ \[Lambda]\_10\%2\), \
\(\(-\(1\/2\)\)\ Cos[\[Theta]\_8[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_8\ \[Lambda]\_10\%2\), \
\(\(-\(1\/2\)\)\ Cos[\[Theta]\_9[t] - \[Theta]\_10[
                      t]]\ c\_S\ \[Lambda]\_9\ \[Lambda]\_10\%2\), \
\(\(-\(1\/3\)\)\ c\_S\ \[Lambda]\_10\%3\), \(1\/2\ Sin[\[Theta]\_10[
                    t]]\ c\_S\ \[Lambda]\_10\%2\), \(\(-\(1\/2\)\)\ Cos[\
\[Theta]\_10[t]]\ c\_S\ \[Lambda]\_10\%2\), "0", 
              "0", \(\(-Sin[\[Theta]\_10[
                      t]]\)\ \[Lambda]\_10\), \(Cos[\[Theta]\_10[
                    t]]\ \[Lambda]\_10\)},
            {\(Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\), \(Sin[\[Theta]\_2[
                    t]]\ \[Lambda]\_2\), \(Sin[\[Theta]\_3[
                    t]]\ \[Lambda]\_3\), \(Sin[\[Theta]\_4[
                    t]]\ \[Lambda]\_4\), \(Sin[\[Theta]\_5[
                    t]]\ \[Lambda]\_5\), \(Sin[\[Theta]\_6[
                    t]]\ \[Lambda]\_6\), \(Sin[\[Theta]\_7[
                    t]]\ \[Lambda]\_7\), \(Sin[\[Theta]\_8[
                    t]]\ \[Lambda]\_8\), \(Sin[\[Theta]\_9[
                    t]]\ \[Lambda]\_9\), \(Sin[\[Theta]\_10[
                    t]]\ \[Lambda]\_10\), \(-1\), "0", "1", "0", "0", "0"},
            {\(\(-Cos[\[Theta]\_1[t]]\)\ \[Lambda]\_1\), \(\(-Cos[\[Theta]\_2[
                      t]]\)\ \[Lambda]\_2\), \(\(-Cos[\[Theta]\_3[
                      t]]\)\ \[Lambda]\_3\), \(\(-Cos[\[Theta]\_4[
                      t]]\)\ \[Lambda]\_4\), \(\(-Cos[\[Theta]\_5[
                      t]]\)\ \[Lambda]\_5\), \(\(-Cos[\[Theta]\_6[
                      t]]\)\ \[Lambda]\_6\), \(\(-Cos[\[Theta]\_7[
                      t]]\)\ \[Lambda]\_7\), \(\(-Cos[\[Theta]\_8[
                      t]]\)\ \[Lambda]\_8\), \(\(-Cos[\[Theta]\_9[
                      t]]\)\ \[Lambda]\_9\), \(\(-Cos[\[Theta]\_10[
                      t]]\)\ \[Lambda]\_10\), "0", \(-1\), "0", "1", "0", 
              "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"],

Cell[BoxData[
    \(7\)], "Print"],

Cell[BoxData[
    \(8\)], "Print"],

Cell[BoxData[
    \(9\)], "Print"],

Cell[BoxData[
    \(10\)], "Print"],

Cell[BoxData[
    \("\n matSys[0] = -(pow(L[1],2)*(Cs*(2*L[1] + 3*(2*pow(cos(Th[1] - \
Th[2]),2)*L[2] + 2*pow(cos(Th[1] - Th[3]),2)*L[3] + L[4] + cos(2*(Th[1] - \
Th[4]))*L[4] + L[5] + cos(2*(Th[1] - Th[5]))*L[5] + L[6] + cos(2*(Th[1] - \
Th[6]))*L[6] + L[7] + cos(2*(Th[1] - Th[7]))*L[7] + L[8] + cos(2*(Th[1] - \
Th[8]))*L[8] + L[9] + cos(2*(Th[1] - Th[9]))*L[9] + L[10] + cos(2*(Th[1] - \
Th[10]))*L[10])) + 3*Cv*(L[4] - cos(2*(Th[1] - Th[4]))*L[4] + L[5] - \
cos(2*(Th[1] - Th[5]))*L[5] + L[6] - cos(2*(Th[1] - Th[6]))*L[6] + L[7] - \
cos(2*(Th[1] - Th[7]))*L[7] + L[8] - cos(2*(Th[1] - Th[8]))*L[8] + L[9] - \
cos(2*(Th[1] - Th[9]))*L[9] + L[10] - cos(2*(Th[1] - Th[10]))*L[10] + \
2*L[2]*pow(sin(Th[1] - Th[2]),2) + 2*L[3]*pow(sin(Th[1] - Th[3]),2))))/6.;\n \
matSys[12] = -(L[1]*L[2]*(Cs*(cos(Th[1] - Th[2])*L[2] + 2*cos(Th[1] - \
Th[3])*cos(Th[2] - Th[3])*L[3] + cos(Th[1] - Th[2])*L[4] + cos(Th[1] + Th[2] \
- 2*Th[4])*L[4] + cos(Th[1] - Th[2])*L[5] + cos(Th[1] + Th[2] - 2*Th[5])*L[5] \
+ cos(Th[1] - Th[2])*L[6] + cos(Th[1] + Th[2] - 2*Th[6])*L[6] + cos(Th[1] - \
Th[2])*L[7] + cos(Th[1] + Th[2] - 2*Th[7])*L[7] + cos(Th[1] - Th[2])*L[8] + \
cos(Th[1] + Th[2] - 2*Th[8])*L[8] + cos(Th[1] - Th[2])*L[9] + cos(Th[1] + \
Th[2] - 2*Th[9])*L[9] + cos(Th[1] - Th[2])*L[10] + cos(Th[1] + Th[2] - \
2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[2])*L[5] - cos(Th[1] + Th[2] - \
2*Th[5])*L[5] + cos(Th[1] - Th[2])*L[6] - cos(Th[1] + Th[2] - 2*Th[6])*L[6] + \
cos(Th[1] - Th[2])*L[7] - cos(Th[1] + Th[2] - 2*Th[7])*L[7] + cos(Th[1] - \
Th[2])*L[8] - cos(Th[1] + Th[2] - 2*Th[8])*L[8] + cos(Th[1] - Th[2])*L[9] - \
cos(Th[1] + Th[2] - 2*Th[9])*L[9] + cos(Th[1] - Th[2])*L[10] - cos(Th[1] + \
Th[2] - 2*Th[10])*L[10] + 2*L[3]*sin(Th[1] - Th[3])*sin(Th[2] - Th[3]) + \
2*L[4]*sin(Th[1] - Th[4])*sin(Th[2] - Th[4]))))/2.;\n matSys[24] = \
-(L[1]*L[3]*(Cs*(cos(Th[1] - Th[3])*L[3] + 2*cos(Th[1] - Th[4])*cos(Th[3] - \
Th[4])*L[4] + cos(Th[1] - Th[3])*L[5] + cos(Th[1] + Th[3] - 2*Th[5])*L[5] + \
cos(Th[1] - Th[3])*L[6] + cos(Th[1] + Th[3] - 2*Th[6])*L[6] + cos(Th[1] - \
Th[3])*L[7] + cos(Th[1] + Th[3] - 2*Th[7])*L[7] + cos(Th[1] - Th[3])*L[8] + \
cos(Th[1] + Th[3] - 2*Th[8])*L[8] + cos(Th[1] - Th[3])*L[9] + cos(Th[1] + \
Th[3] - 2*Th[9])*L[9] + cos(Th[1] - Th[3])*L[10] + cos(Th[1] + Th[3] - \
2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[3])*L[6] - cos(Th[1] + Th[3] - \
2*Th[6])*L[6] + cos(Th[1] - Th[3])*L[7] - cos(Th[1] + Th[3] - 2*Th[7])*L[7] + \
cos(Th[1] - Th[3])*L[8] - cos(Th[1] + Th[3] - 2*Th[8])*L[8] + cos(Th[1] - \
Th[3])*L[9] - cos(Th[1] + Th[3] - 2*Th[9])*L[9] + cos(Th[1] - Th[3])*L[10] - \
cos(Th[1] + Th[3] - 2*Th[10])*L[10] + 2*L[4]*sin(Th[1] - Th[4])*sin(Th[3] - \
Th[4]) + 2*L[5]*sin(Th[1] - Th[5])*sin(Th[3] - Th[5]))))/2.;\n matSys[36] = \
-(L[1]*L[4]*(Cs*(cos(Th[1] - Th[4])*L[4] + 2*cos(Th[1] - Th[5])*cos(Th[4] - \
Th[5])*L[5] + cos(Th[1] - Th[4])*L[6] + cos(Th[1] + Th[4] - 2*Th[6])*L[6] + \
cos(Th[1] - Th[4])*L[7] + cos(Th[1] + Th[4] - 2*Th[7])*L[7] + cos(Th[1] - \
Th[4])*L[8] + cos(Th[1] + Th[4] - 2*Th[8])*L[8] + cos(Th[1] - Th[4])*L[9] + \
cos(Th[1] + Th[4] - 2*Th[9])*L[9] + cos(Th[1] - Th[4])*L[10] + cos(Th[1] + \
Th[4] - 2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[4])*L[7] - cos(Th[1] + Th[4] - \
2*Th[7])*L[7] + cos(Th[1] - Th[4])*L[8] - cos(Th[1] + Th[4] - 2*Th[8])*L[8] + \
cos(Th[1] - Th[4])*L[9] - cos(Th[1] + Th[4] - 2*Th[9])*L[9] + cos(Th[1] - \
Th[4])*L[10] - cos(Th[1] + Th[4] - 2*Th[10])*L[10] + 2*L[5]*sin(Th[1] - \
Th[5])*sin(Th[4] - Th[5]) + 2*L[6]*sin(Th[1] - Th[6])*sin(Th[4] - \
Th[6]))))/2.;\n matSys[48] = -(L[1]*L[5]*(Cs*(cos(Th[1] - Th[5])*L[5] + \
2*cos(Th[1] - Th[6])*cos(Th[5] - Th[6])*L[6] + cos(Th[1] - Th[5])*L[7] + \
cos(Th[1] + Th[5] - 2*Th[7])*L[7] + cos(Th[1] - Th[5])*L[8] + cos(Th[1] + \
Th[5] - 2*Th[8])*L[8] + cos(Th[1] - Th[5])*L[9] + cos(Th[1] + Th[5] - \
2*Th[9])*L[9] + cos(Th[1] - Th[5])*L[10] + cos(Th[1] + Th[5] - \
2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[5])*L[8] - cos(Th[1] + Th[5] - \
2*Th[8])*L[8] + cos(Th[1] - Th[5])*L[9] - cos(Th[1] + Th[5] - 2*Th[9])*L[9] + \
cos(Th[1] - Th[5])*L[10] - cos(Th[1] + Th[5] - 2*Th[10])*L[10] + \
2*L[6]*sin(Th[1] - Th[6])*sin(Th[5] - Th[6]) + 2*L[7]*sin(Th[1] - \
Th[7])*sin(Th[5] - Th[7]))))/2.;\n matSys[60] = -(L[1]*L[6]*(Cs*(cos(Th[1] - \
Th[6])*L[6] + 2*cos(Th[1] - Th[7])*cos(Th[6] - Th[7])*L[7] + cos(Th[1] - \
Th[6])*L[8] + cos(Th[1] + Th[6] - 2*Th[8])*L[8] + cos(Th[1] - Th[6])*L[9] + \
cos(Th[1] + Th[6] - 2*Th[9])*L[9] + cos(Th[1] - Th[6])*L[10] + cos(Th[1] + \
Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[6])*L[9] - cos(Th[1] + Th[6] - \
2*Th[9])*L[9] + cos(Th[1] - Th[6])*L[10] - cos(Th[1] + Th[6] - \
2*Th[10])*L[10] + 2*L[7]*sin(Th[1] - Th[7])*sin(Th[6] - Th[7]) + \
2*L[8]*sin(Th[1] - Th[8])*sin(Th[6] - Th[8]))))/2.;\n matSys[72] = \
-(L[1]*L[7]*(Cs*(cos(Th[1] - Th[7])*L[7] + 2*cos(Th[1] - Th[8])*cos(Th[7] - \
Th[8])*L[8] + cos(Th[1] - Th[7])*L[9] + cos(Th[1] + Th[7] - 2*Th[9])*L[9] + \
cos(Th[1] - Th[7])*L[10] + cos(Th[1] + Th[7] - 2*Th[10])*L[10]) + \
2*Cv*(L[8]*sin(Th[1] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[1] - \
Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[1] - Th[10])*sin(Th[7] - \
Th[10]))))/2.;\n matSys[84] = -(L[1]*L[8]*(Cs*(cos(Th[1] - Th[8])*L[8] + \
2*cos(Th[1] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[1] - \
Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[1] - Th[9])*sin(Th[8] \
- Th[9]) + L[10]*sin(Th[1] - Th[10])*sin(Th[8] - Th[10]))))/2.;\n matSys[96] \
= -(L[1]*L[9]*(Cs*(cos(Th[1] - Th[9])*L[9] + 2*cos(Th[1] - Th[10])*cos(Th[9] \
- Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[1] - Th[10])*sin(Th[9] - Th[10])))/2.;\n \
matSys[108] = -(Cs*cos(Th[1] - Th[10])*L[1]*pow(L[10],2))/2.;\n matSys[120] = \
(L[1]*(Cs*(L[1]*sin(Th[1]) + L[3]*sin(Th[1]) + L[4]*sin(Th[1]) + \
L[5]*sin(Th[1]) + L[6]*sin(Th[1]) + L[7]*sin(Th[1]) + L[8]*sin(Th[1]) + \
L[9]*sin(Th[1]) + L[10]*sin(Th[1]) + 2*cos(Th[1] - Th[2])*L[2]*sin(Th[2]) - \
L[3]*sin(Th[1] - 2*Th[3]) - L[4]*sin(Th[1] - 2*Th[4]) - L[5]*sin(Th[1] - \
2*Th[5]) - L[6]*sin(Th[1] - 2*Th[6]) - L[7]*sin(Th[1] - 2*Th[7]) - \
L[8]*sin(Th[1] - 2*Th[8]) - L[9]*sin(Th[1] - 2*Th[9]) - L[10]*sin(Th[1] - \
2*Th[10])) + Cv*(L[4]*sin(Th[1]) + L[5]*sin(Th[1]) + L[6]*sin(Th[1]) + \
L[7]*sin(Th[1]) + L[8]*sin(Th[1]) + L[9]*sin(Th[1]) + L[10]*sin(Th[1]) + \
2*cos(Th[2])*L[2]*sin(Th[1] - Th[2]) + 2*cos(Th[3])*L[3]*sin(Th[1] - Th[3]) + \
L[4]*sin(Th[1] - 2*Th[4]) + L[5]*sin(Th[1] - 2*Th[5]) + L[6]*sin(Th[1] - \
2*Th[6]) + L[7]*sin(Th[1] - 2*Th[7]) + L[8]*sin(Th[1] - 2*Th[8]) + \
L[9]*sin(Th[1] - 2*Th[9]) + L[10]*sin(Th[1] - 2*Th[10]))))/2.;\n matSys[132] \
= -(L[1]*(Cs*(cos(Th[1])*L[1] + 2*cos(Th[1] - Th[2])*cos(Th[2])*L[2] + \
cos(Th[1])*L[3] + cos(Th[1] - 2*Th[3])*L[3] + cos(Th[1])*L[4] + cos(Th[1] - \
2*Th[4])*L[4] + cos(Th[1])*L[5] + cos(Th[1] - 2*Th[5])*L[5] + cos(Th[1])*L[6] \
+ cos(Th[1] - 2*Th[6])*L[6] + cos(Th[1])*L[7] + cos(Th[1] - 2*Th[7])*L[7] + \
cos(Th[1])*L[8] + cos(Th[1] - 2*Th[8])*L[8] + cos(Th[1])*L[9] + cos(Th[1] - \
2*Th[9])*L[9] + cos(Th[1])*L[10] + cos(Th[1] - 2*Th[10])*L[10]) - \
Cv*(-(cos(Th[1])*L[4]) + cos(Th[1] - 2*Th[4])*L[4] - cos(Th[1])*L[5] + \
cos(Th[1] - 2*Th[5])*L[5] - cos(Th[1])*L[6] + cos(Th[1] - 2*Th[6])*L[6] - \
cos(Th[1])*L[7] + cos(Th[1] - 2*Th[7])*L[7] - cos(Th[1])*L[8] + cos(Th[1] - \
2*Th[8])*L[8] - cos(Th[1])*L[9] + cos(Th[1] - 2*Th[9])*L[9] - \
cos(Th[1])*L[10] + cos(Th[1] - 2*Th[10])*L[10] + 2*L[2]*sin(Th[1] - \
Th[2])*sin(Th[2]) + 2*L[3]*sin(Th[1] - Th[3])*sin(Th[3]))))/2.;\n matSys[144] \
= 0;\n matSys[156] = 0;\n matSys[168] = -(L[1]*sin(Th[1]));\n matSys[180] = \
cos(Th[1])*L[1];\n matSys[1] = -(L[1]*L[2]*(Cs*(cos(Th[1] - Th[2])*L[2] + \
2*cos(Th[1] - Th[3])*cos(Th[2] - Th[3])*L[3] + cos(Th[1] - Th[2])*L[4] + \
cos(Th[1] + Th[2] - 2*Th[4])*L[4] + cos(Th[1] - Th[2])*L[5] + cos(Th[1] + \
Th[2] - 2*Th[5])*L[5] + cos(Th[1] - Th[2])*L[6] + cos(Th[1] + Th[2] - \
2*Th[6])*L[6] + cos(Th[1] - Th[2])*L[7] + cos(Th[1] + Th[2] - 2*Th[7])*L[7] + \
cos(Th[1] - Th[2])*L[8] + cos(Th[1] + Th[2] - 2*Th[8])*L[8] + cos(Th[1] - \
Th[2])*L[9] + cos(Th[1] + Th[2] - 2*Th[9])*L[9] + cos(Th[1] - Th[2])*L[10] + \
cos(Th[1] + Th[2] - 2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[2])*L[5] - \
cos(Th[1] + Th[2] - 2*Th[5])*L[5] + cos(Th[1] - Th[2])*L[6] - cos(Th[1] + \
Th[2] - 2*Th[6])*L[6] + cos(Th[1] - Th[2])*L[7] - cos(Th[1] + Th[2] - \
2*Th[7])*L[7] + cos(Th[1] - Th[2])*L[8] - cos(Th[1] + Th[2] - 2*Th[8])*L[8] + \
cos(Th[1] - Th[2])*L[9] - cos(Th[1] + Th[2] - 2*Th[9])*L[9] + cos(Th[1] - \
Th[2])*L[10] - cos(Th[1] + Th[2] - 2*Th[10])*L[10] + 2*L[3]*sin(Th[1] - \
Th[3])*sin(Th[2] - Th[3]) + 2*L[4]*sin(Th[1] - Th[4])*sin(Th[2] - \
Th[4]))))/2.;\n matSys[13] = -(pow(L[2],2)*(Cs*(2*L[2] + 3*(2*pow(cos(Th[2] - \
Th[3]),2)*L[3] + 2*pow(cos(Th[2] - Th[4]),2)*L[4] + L[5] + cos(2*(Th[2] - \
Th[5]))*L[5] + L[6] + cos(2*(Th[2] - Th[6]))*L[6] + L[7] + cos(2*(Th[2] - \
Th[7]))*L[7] + L[8] + cos(2*(Th[2] - Th[8]))*L[8] + L[9] + cos(2*(Th[2] - \
Th[9]))*L[9] + L[10] + cos(2*(Th[2] - Th[10]))*L[10])) + 3*Cv*(L[5] - \
cos(2*(Th[2] - Th[5]))*L[5] + L[6] - cos(2*(Th[2] - Th[6]))*L[6] + L[7] - \
cos(2*(Th[2] - Th[7]))*L[7] + L[8] - cos(2*(Th[2] - Th[8]))*L[8] + L[9] - \
cos(2*(Th[2] - Th[9]))*L[9] + L[10] - cos(2*(Th[2] - Th[10]))*L[10] + \
2*L[3]*pow(sin(Th[2] - Th[3]),2) + 2*L[4]*pow(sin(Th[2] - Th[4]),2))))/6.;\n \
matSys[25] = -(L[2]*L[3]*(Cs*(cos(Th[2] - Th[3])*L[3] + 2*cos(Th[2] - \
Th[4])*cos(Th[3] - Th[4])*L[4] + cos(Th[2] - Th[3])*L[5] + cos(Th[2] + Th[3] \
- 2*Th[5])*L[5] + cos(Th[2] - Th[3])*L[6] + cos(Th[2] + Th[3] - 2*Th[6])*L[6] \
+ cos(Th[2] - Th[3])*L[7] + cos(Th[2] + Th[3] - 2*Th[7])*L[7] + cos(Th[2] - \
Th[3])*L[8] + cos(Th[2] + Th[3] - 2*Th[8])*L[8] + cos(Th[2] - Th[3])*L[9] + \
cos(Th[2] + Th[3] - 2*Th[9])*L[9] + cos(Th[2] - Th[3])*L[10] + cos(Th[2] + \
Th[3] - 2*Th[10])*L[10]) + Cv*(cos(Th[2] - Th[3])*L[6] - cos(Th[2] + Th[3] - \
2*Th[6])*L[6] + cos(Th[2] - Th[3])*L[7] - cos(Th[2] + Th[3] - 2*Th[7])*L[7] + \
cos(Th[2] - Th[3])*L[8] - cos(Th[2] + Th[3] - 2*Th[8])*L[8] + cos(Th[2] - \
Th[3])*L[9] - cos(Th[2] + Th[3] - 2*Th[9])*L[9] + cos(Th[2] - Th[3])*L[10] - \
cos(Th[2] + Th[3] - 2*Th[10])*L[10] + 2*L[4]*sin(Th[2] - Th[4])*sin(Th[3] - \
Th[4]) + 2*L[5]*sin(Th[2] - Th[5])*sin(Th[3] - Th[5]))))/2.;\n matSys[37] = \
-(L[2]*L[4]*(Cs*(cos(Th[2] - Th[4])*L[4] + 2*cos(Th[2] - Th[5])*cos(Th[4] - \
Th[5])*L[5] + cos(Th[2] - Th[4])*L[6] + cos(Th[2] + Th[4] - 2*Th[6])*L[6] + \
cos(Th[2] - Th[4])*L[7] + cos(Th[2] + Th[4] - 2*Th[7])*L[7] + cos(Th[2] - \
Th[4])*L[8] + cos(Th[2] + Th[4] - 2*Th[8])*L[8] + cos(Th[2] - Th[4])*L[9] + \
cos(Th[2] + Th[4] - 2*Th[9])*L[9] + cos(Th[2] - Th[4])*L[10] + cos(Th[2] + \
Th[4] - 2*Th[10])*L[10]) + Cv*(cos(Th[2] - Th[4])*L[7] - cos(Th[2] + Th[4] - \
2*Th[7])*L[7] + cos(Th[2] - Th[4])*L[8] - cos(Th[2] + Th[4] - 2*Th[8])*L[8] + \
cos(Th[2] - Th[4])*L[9] - cos(Th[2] + Th[4] - 2*Th[9])*L[9] + cos(Th[2] - \
Th[4])*L[10] - cos(Th[2] + Th[4] - 2*Th[10])*L[10] + 2*L[5]*sin(Th[2] - \
Th[5])*sin(Th[4] - Th[5]) + 2*L[6]*sin(Th[2] - Th[6])*sin(Th[4] - \
Th[6]))))/2.;\n matSys[49] = -(L[2]*L[5]*(Cs*(cos(Th[2] - Th[5])*L[5] + \
2*cos(Th[2] - Th[6])*cos(Th[5] - Th[6])*L[6] + cos(Th[2] - Th[5])*L[7] + \
cos(Th[2] + Th[5] - 2*Th[7])*L[7] + cos(Th[2] - Th[5])*L[8] + cos(Th[2] + \
Th[5] - 2*Th[8])*L[8] + cos(Th[2] - Th[5])*L[9] + cos(Th[2] + Th[5] - \
2*Th[9])*L[9] + cos(Th[2] - Th[5])*L[10] + cos(Th[2] + Th[5] - \
2*Th[10])*L[10]) + Cv*(cos(Th[2] - Th[5])*L[8] - cos(Th[2] + Th[5] - \
2*Th[8])*L[8] + cos(Th[2] - Th[5])*L[9] - cos(Th[2] + Th[5] - 2*Th[9])*L[9] + \
cos(Th[2] - Th[5])*L[10] - cos(Th[2] + Th[5] - 2*Th[10])*L[10] + \
2*L[6]*sin(Th[2] - Th[6])*sin(Th[5] - Th[6]) + 2*L[7]*sin(Th[2] - \
Th[7])*sin(Th[5] - Th[7]))))/2.;\n matSys[61] = -(L[2]*L[6]*(Cs*(cos(Th[2] - \
Th[6])*L[6] + 2*cos(Th[2] - Th[7])*cos(Th[6] - Th[7])*L[7] + cos(Th[2] - \
Th[6])*L[8] + cos(Th[2] + Th[6] - 2*Th[8])*L[8] + cos(Th[2] - Th[6])*L[9] + \
cos(Th[2] + Th[6] - 2*Th[9])*L[9] + cos(Th[2] - Th[6])*L[10] + cos(Th[2] + \
Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[2] - Th[6])*L[9] - cos(Th[2] + Th[6] - \
2*Th[9])*L[9] + cos(Th[2] - Th[6])*L[10] - cos(Th[2] + Th[6] - \
2*Th[10])*L[10] + 2*L[7]*sin(Th[2] - Th[7])*sin(Th[6] - Th[7]) + \
2*L[8]*sin(Th[2] - Th[8])*sin(Th[6] - Th[8]))))/2.;\n matSys[73] = \
-(L[2]*L[7]*(Cs*(cos(Th[2] - Th[7])*L[7] + 2*cos(Th[2] - Th[8])*cos(Th[7] - \
Th[8])*L[8] + cos(Th[2] - Th[7])*L[9] + cos(Th[2] + Th[7] - 2*Th[9])*L[9] + \
cos(Th[2] - Th[7])*L[10] + cos(Th[2] + Th[7] - 2*Th[10])*L[10]) + \
2*Cv*(L[8]*sin(Th[2] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[2] - \
Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[2] - Th[10])*sin(Th[7] - \
Th[10]))))/2.;\n matSys[85] = -(L[2]*L[8]*(Cs*(cos(Th[2] - Th[8])*L[8] + \
2*cos(Th[2] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[2] - \
Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[2] - Th[9])*sin(Th[8] \
- Th[9]) + L[10]*sin(Th[2] - Th[10])*sin(Th[8] - Th[10]))))/2.;\n matSys[97] \
= -(L[2]*L[9]*(Cs*(cos(Th[2] - Th[9])*L[9] + 2*cos(Th[2] - Th[10])*cos(Th[9] \
- Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[2] - Th[10])*sin(Th[9] - Th[10])))/2.;\n \
matSys[109] = -(Cs*cos(Th[2] - Th[10])*L[2]*pow(L[10],2))/2.;\n matSys[121] = \
(L[2]*(Cs*(L[2]*sin(Th[2]) + L[4]*sin(Th[2]) + L[5]*sin(Th[2]) + \
L[6]*sin(Th[2]) + L[7]*sin(Th[2]) + L[8]*sin(Th[2]) + L[9]*sin(Th[2]) + \
L[10]*sin(Th[2]) + 2*cos(Th[2] - Th[3])*L[3]*sin(Th[3]) - L[4]*sin(Th[2] - \
2*Th[4]) - L[5]*sin(Th[2] - 2*Th[5]) - L[6]*sin(Th[2] - 2*Th[6]) - \
L[7]*sin(Th[2] - 2*Th[7]) - L[8]*sin(Th[2] - 2*Th[8]) - L[9]*sin(Th[2] - \
2*Th[9]) - L[10]*sin(Th[2] - 2*Th[10])) + Cv*(L[5]*sin(Th[2]) + \
L[6]*sin(Th[2]) + L[7]*sin(Th[2]) + L[8]*sin(Th[2]) + L[9]*sin(Th[2]) + \
L[10]*sin(Th[2]) + 2*cos(Th[3])*L[3]*sin(Th[2] - Th[3]) + \
2*cos(Th[4])*L[4]*sin(Th[2] - Th[4]) + L[5]*sin(Th[2] - 2*Th[5]) + \
L[6]*sin(Th[2] - 2*Th[6]) + L[7]*sin(Th[2] - 2*Th[7]) + L[8]*sin(Th[2] - \
2*Th[8]) + L[9]*sin(Th[2] - 2*Th[9]) + L[10]*sin(Th[2] - 2*Th[10]))))/2.;\n \
matSys[133] = -(L[2]*(Cs*(cos(Th[2])*L[2] + 2*cos(Th[2] - \
Th[3])*cos(Th[3])*L[3] + cos(Th[2])*L[4] + cos(Th[2] - 2*Th[4])*L[4] + \
cos(Th[2])*L[5] + cos(Th[2] - 2*Th[5])*L[5] + cos(Th[2])*L[6] + cos(Th[2] - \
2*Th[6])*L[6] + cos(Th[2])*L[7] + cos(Th[2] - 2*Th[7])*L[7] + cos(Th[2])*L[8] \
+ cos(Th[2] - 2*Th[8])*L[8] + cos(Th[2])*L[9] + cos(Th[2] - 2*Th[9])*L[9] + \
cos(Th[2])*L[10] + cos(Th[2] - 2*Th[10])*L[10]) - Cv*(-(cos(Th[2])*L[5]) + \
cos(Th[2] - 2*Th[5])*L[5] - cos(Th[2])*L[6] + cos(Th[2] - 2*Th[6])*L[6] - \
cos(Th[2])*L[7] + cos(Th[2] - 2*Th[7])*L[7] - cos(Th[2])*L[8] + cos(Th[2] - \
2*Th[8])*L[8] - cos(Th[2])*L[9] + cos(Th[2] - 2*Th[9])*L[9] - \
cos(Th[2])*L[10] + cos(Th[2] - 2*Th[10])*L[10] + 2*L[3]*sin(Th[2] - \
Th[3])*sin(Th[3]) + 2*L[4]*sin(Th[2] - Th[4])*sin(Th[4]))))/2.;\n matSys[145] \
= 0;\n matSys[157] = 0;\n matSys[169] = -(L[2]*sin(Th[2]));\n matSys[181] = \
cos(Th[2])*L[2];\n matSys[2] = -(L[1]*L[3]*(Cs*(cos(Th[1] - Th[3])*L[3] + \
2*cos(Th[1] - Th[4])*cos(Th[3] - Th[4])*L[4] + cos(Th[1] - Th[3])*L[5] + \
cos(Th[1] + Th[3] - 2*Th[5])*L[5] + cos(Th[1] - Th[3])*L[6] + cos(Th[1] + \
Th[3] - 2*Th[6])*L[6] + cos(Th[1] - Th[3])*L[7] + cos(Th[1] + Th[3] - \
2*Th[7])*L[7] + cos(Th[1] - Th[3])*L[8] + cos(Th[1] + Th[3] - 2*Th[8])*L[8] + \
cos(Th[1] - Th[3])*L[9] + cos(Th[1] + Th[3] - 2*Th[9])*L[9] + cos(Th[1] - \
Th[3])*L[10] + cos(Th[1] + Th[3] - 2*Th[10])*L[10]) + Cv*(cos(Th[1] - \
Th[3])*L[6] - cos(Th[1] + Th[3] - 2*Th[6])*L[6] + cos(Th[1] - Th[3])*L[7] - \
cos(Th[1] + Th[3] - 2*Th[7])*L[7] + cos(Th[1] - Th[3])*L[8] - cos(Th[1] + \
Th[3] - 2*Th[8])*L[8] + cos(Th[1] - Th[3])*L[9] - cos(Th[1] + Th[3] - \
2*Th[9])*L[9] + cos(Th[1] - Th[3])*L[10] - cos(Th[1] + Th[3] - \
2*Th[10])*L[10] + 2*L[4]*sin(Th[1] - Th[4])*sin(Th[3] - Th[4]) + \
2*L[5]*sin(Th[1] - Th[5])*sin(Th[3] - Th[5]))))/2.;\n matSys[14] = \
-(L[2]*L[3]*(Cs*(cos(Th[2] - Th[3])*L[3] + 2*cos(Th[2] - Th[4])*cos(Th[3] - \
Th[4])*L[4] + cos(Th[2] - Th[3])*L[5] + cos(Th[2] + Th[3] - 2*Th[5])*L[5] + \
cos(Th[2] - Th[3])*L[6] + cos(Th[2] + Th[3] - 2*Th[6])*L[6] + cos(Th[2] - \
Th[3])*L[7] + cos(Th[2] + Th[3] - 2*Th[7])*L[7] + cos(Th[2] - Th[3])*L[8] + \
cos(Th[2] + Th[3] - 2*Th[8])*L[8] + cos(Th[2] - Th[3])*L[9] + cos(Th[2] + \
Th[3] - 2*Th[9])*L[9] + cos(Th[2] - Th[3])*L[10] + cos(Th[2] + Th[3] - \
2*Th[10])*L[10]) + Cv*(cos(Th[2] - Th[3])*L[6] - cos(Th[2] + Th[3] - \
2*Th[6])*L[6] + cos(Th[2] - Th[3])*L[7] - cos(Th[2] + Th[3] - 2*Th[7])*L[7] + \
cos(Th[2] - Th[3])*L[8] - cos(Th[2] + Th[3] - 2*Th[8])*L[8] + cos(Th[2] - \
Th[3])*L[9] - cos(Th[2] + Th[3] - 2*Th[9])*L[9] + cos(Th[2] - Th[3])*L[10] - \
cos(Th[2] + Th[3] - 2*Th[10])*L[10] + 2*L[4]*sin(Th[2] - Th[4])*sin(Th[3] - \
Th[4]) + 2*L[5]*sin(Th[2] - Th[5])*sin(Th[3] - Th[5]))))/2.;\n matSys[26] = \
-(pow(L[3],2)*(Cs*(2*L[3] + 3*(2*pow(cos(Th[3] - Th[4]),2)*L[4] + \
2*pow(cos(Th[3] - Th[5]),2)*L[5] + L[6] + cos(2*(Th[3] - Th[6]))*L[6] + L[7] \
+ cos(2*(Th[3] - Th[7]))*L[7] + L[8] + cos(2*(Th[3] - Th[8]))*L[8] + L[9] + \
cos(2*(Th[3] - Th[9]))*L[9] + L[10] + cos(2*(Th[3] - Th[10]))*L[10])) + \
3*Cv*(L[6] - cos(2*(Th[3] - Th[6]))*L[6] + L[7] - cos(2*(Th[3] - Th[7]))*L[7] \
+ L[8] - cos(2*(Th[3] - Th[8]))*L[8] + L[9] - cos(2*(Th[3] - Th[9]))*L[9] + \
L[10] - cos(2*(Th[3] - Th[10]))*L[10] + 2*L[4]*pow(sin(Th[3] - Th[4]),2) + \
2*L[5]*pow(sin(Th[3] - Th[5]),2))))/6.;\n matSys[38] = \
-(L[3]*L[4]*(Cs*(cos(Th[3] - Th[4])*L[4] + 2*cos(Th[3] - Th[5])*cos(Th[4] - \
Th[5])*L[5] + cos(Th[3] - Th[4])*L[6] + cos(Th[3] + Th[4] - 2*Th[6])*L[6] + \
cos(Th[3] - Th[4])*L[7] + cos(Th[3] + Th[4] - 2*Th[7])*L[7] + cos(Th[3] - \
Th[4])*L[8] + cos(Th[3] + Th[4] - 2*Th[8])*L[8] + cos(Th[3] - Th[4])*L[9] + \
cos(Th[3] + Th[4] - 2*Th[9])*L[9] + cos(Th[3] - Th[4])*L[10] + cos(Th[3] + \
Th[4] - 2*Th[10])*L[10]) + Cv*(cos(Th[3] - Th[4])*L[7] - cos(Th[3] + Th[4] - \
2*Th[7])*L[7] + cos(Th[3] - Th[4])*L[8] - cos(Th[3] + Th[4] - 2*Th[8])*L[8] + \
cos(Th[3] - Th[4])*L[9] - cos(Th[3] + Th[4] - 2*Th[9])*L[9] + cos(Th[3] - \
Th[4])*L[10] - cos(Th[3] + Th[4] - 2*Th[10])*L[10] + 2*L[5]*sin(Th[3] - \
Th[5])*sin(Th[4] - Th[5]) + 2*L[6]*sin(Th[3] - Th[6])*sin(Th[4] - \
Th[6]))))/2.;\n matSys[50] = -(L[3]*L[5]*(Cs*(cos(Th[3] - Th[5])*L[5] + \
2*cos(Th[3] - Th[6])*cos(Th[5] - Th[6])*L[6] + cos(Th[3] - Th[5])*L[7] + \
cos(Th[3] + Th[5] - 2*Th[7])*L[7] + cos(Th[3] - Th[5])*L[8] + cos(Th[3] + \
Th[5] - 2*Th[8])*L[8] + cos(Th[3] - Th[5])*L[9] + cos(Th[3] + Th[5] - \
2*Th[9])*L[9] + cos(Th[3] - Th[5])*L[10] + cos(Th[3] + Th[5] - \
2*Th[10])*L[10]) + Cv*(cos(Th[3] - Th[5])*L[8] - cos(Th[3] + Th[5] - \
2*Th[8])*L[8] + cos(Th[3] - Th[5])*L[9] - cos(Th[3] + Th[5] - 2*Th[9])*L[9] + \
cos(Th[3] - Th[5])*L[10] - cos(Th[3] + Th[5] - 2*Th[10])*L[10] + \
2*L[6]*sin(Th[3] - Th[6])*sin(Th[5] - Th[6]) + 2*L[7]*sin(Th[3] - \
Th[7])*sin(Th[5] - Th[7]))))/2.;\n matSys[62] = -(L[3]*L[6]*(Cs*(cos(Th[3] - \
Th[6])*L[6] + 2*cos(Th[3] - Th[7])*cos(Th[6] - Th[7])*L[7] + cos(Th[3] - \
Th[6])*L[8] + cos(Th[3] + Th[6] - 2*Th[8])*L[8] + cos(Th[3] - Th[6])*L[9] + \
cos(Th[3] + Th[6] - 2*Th[9])*L[9] + cos(Th[3] - Th[6])*L[10] + cos(Th[3] + \
Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[3] - Th[6])*L[9] - cos(Th[3] + Th[6] - \
2*Th[9])*L[9] + cos(Th[3] - Th[6])*L[10] - cos(Th[3] + Th[6] - \
2*Th[10])*L[10] + 2*L[7]*sin(Th[3] - Th[7])*sin(Th[6] - Th[7]) + \
2*L[8]*sin(Th[3] - Th[8])*sin(Th[6] - Th[8]))))/2.;\n matSys[74] = \
-(L[3]*L[7]*(Cs*(cos(Th[3] - Th[7])*L[7] + 2*cos(Th[3] - Th[8])*cos(Th[7] - \
Th[8])*L[8] + cos(Th[3] - Th[7])*L[9] + cos(Th[3] + Th[7] - 2*Th[9])*L[9] + \
cos(Th[3] - Th[7])*L[10] + cos(Th[3] + Th[7] - 2*Th[10])*L[10]) + \
2*Cv*(L[8]*sin(Th[3] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[3] - \
Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[3] - Th[10])*sin(Th[7] - \
Th[10]))))/2.;\n matSys[86] = -(L[3]*L[8]*(Cs*(cos(Th[3] - Th[8])*L[8] + \
2*cos(Th[3] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[3] - \
Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[3] - Th[9])*sin(Th[8] \
- Th[9]) + L[10]*sin(Th[3] - Th[10])*sin(Th[8] - Th[10]))))/2.;\n matSys[98] \
= -(L[3]*L[9]*(Cs*(cos(Th[3] - Th[9])*L[9] + 2*cos(Th[3] - Th[10])*cos(Th[9] \
- Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[3] - Th[10])*sin(Th[9] - Th[10])))/2.;\n \
matSys[110] = -(Cs*cos(Th[3] - Th[10])*L[3]*pow(L[10],2))/2.;\n matSys[122] = \
(L[3]*(Cs*(L[3]*sin(Th[3]) + L[5]*sin(Th[3]) + L[6]*sin(Th[3]) + \
L[7]*sin(Th[3]) + L[8]*sin(Th[3]) + L[9]*sin(Th[3]) + L[10]*sin(Th[3]) + \
2*cos(Th[3] - Th[4])*L[4]*sin(Th[4]) - L[5]*sin(Th[3] - 2*Th[5]) - \
L[6]*sin(Th[3] - 2*Th[6]) - L[7]*sin(Th[3] - 2*Th[7]) - L[8]*sin(Th[3] - \
2*Th[8]) - L[9]*sin(Th[3] - 2*Th[9]) - L[10]*sin(Th[3] - 2*Th[10])) + \
Cv*(L[6]*sin(Th[3]) + L[7]*sin(Th[3]) + L[8]*sin(Th[3]) + L[9]*sin(Th[3]) + \
L[10]*sin(Th[3]) + 2*cos(Th[4])*L[4]*sin(Th[3] - Th[4]) + \
2*cos(Th[5])*L[5]*sin(Th[3] - Th[5]) + L[6]*sin(Th[3] - 2*Th[6]) + \
L[7]*sin(Th[3] - 2*Th[7]) + L[8]*sin(Th[3] - 2*Th[8]) + L[9]*sin(Th[3] - \
2*Th[9]) + L[10]*sin(Th[3] - 2*Th[10]))))/2.;\n matSys[134] = \
-(L[3]*(Cs*(cos(Th[3])*L[3] + 2*cos(Th[3] - Th[4])*cos(Th[4])*L[4] + \
cos(Th[3])*L[5] + cos(Th[3] - 2*Th[5])*L[5] + cos(Th[3])*L[6] + cos(Th[3] - \
2*Th[6])*L[6] + cos(Th[3])*L[7] + cos(Th[3] - 2*Th[7])*L[7] + cos(Th[3])*L[8] \
+ cos(Th[3] - 2*Th[8])*L[8] + cos(Th[3])*L[9] + cos(Th[3] - 2*Th[9])*L[9] + \
cos(Th[3])*L[10] + cos(Th[3] - 2*Th[10])*L[10]) - Cv*(-(cos(Th[3])*L[6]) + \
cos(Th[3] - 2*Th[6])*L[6] - cos(Th[3])*L[7] + cos(Th[3] - 2*Th[7])*L[7] - \
cos(Th[3])*L[8] + cos(Th[3] - 2*Th[8])*L[8] - cos(Th[3])*L[9] + cos(Th[3] - \
2*Th[9])*L[9] - cos(Th[3])*L[10] + cos(Th[3] - 2*Th[10])*L[10] + \
2*L[4]*sin(Th[3] - Th[4])*sin(Th[4]) + 2*L[5]*sin(Th[3] - \
Th[5])*sin(Th[5]))))/2.;\n matSys[146] = 0;\n matSys[158] = 0;\n matSys[170] \
= -(L[3]*sin(Th[3]));\n matSys[182] = cos(Th[3])*L[3];\n matSys[3] = \
-(L[1]*L[4]*(Cs*(cos(Th[1] - Th[4])*L[4] + 2*cos(Th[1] - Th[5])*cos(Th[4] - \
Th[5])*L[5] + cos(Th[1] - Th[4])*L[6] + cos(Th[1] + Th[4] - 2*Th[6])*L[6] + \
cos(Th[1] - Th[4])*L[7] + cos(Th[1] + Th[4] - 2*Th[7])*L[7] + cos(Th[1] - \
Th[4])*L[8] + cos(Th[1] + Th[4] - 2*Th[8])*L[8] + cos(Th[1] - Th[4])*L[9] + \
cos(Th[1] + Th[4] - 2*Th[9])*L[9] + cos(Th[1] - Th[4])*L[10] + cos(Th[1] + \
Th[4] - 2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[4])*L[7] - cos(Th[1] + Th[4] - \
2*Th[7])*L[7] + cos(Th[1] - Th[4])*L[8] - cos(Th[1] + Th[4] - 2*Th[8])*L[8] + \
cos(Th[1] - Th[4])*L[9] - cos(Th[1] + Th[4] - 2*Th[9])*L[9] + cos(Th[1] - \
Th[4])*L[10] - cos(Th[1] + Th[4] - 2*Th[10])*L[10] + 2*L[5]*sin(Th[1] - \
Th[5])*sin(Th[4] - Th[5]) + 2*L[6]*sin(Th[1] - Th[6])*sin(Th[4] - \
Th[6]))))/2.;\n matSys[15] = -(L[2]*L[4]*(Cs*(cos(Th[2] - Th[4])*L[4] + \
2*cos(Th[2] - Th[5])*cos(Th[4] - Th[5])*L[5] + cos(Th[2] - Th[4])*L[6] + \
cos(Th[2] + Th[4] - 2*Th[6])*L[6] + cos(Th[2] - Th[4])*L[7] + cos(Th[2] + \
Th[4] - 2*Th[7])*L[7] + cos(Th[2] - Th[4])*L[8] + cos(Th[2] + Th[4] - \
2*Th[8])*L[8] + cos(Th[2] - Th[4])*L[9] + cos(Th[2] + Th[4] - 2*Th[9])*L[9] + \
cos(Th[2] - Th[4])*L[10] + cos(Th[2] + Th[4] - 2*Th[10])*L[10]) + \
Cv*(cos(Th[2] - Th[4])*L[7] - cos(Th[2] + Th[4] - 2*Th[7])*L[7] + cos(Th[2] - \
Th[4])*L[8] - cos(Th[2] + Th[4] - 2*Th[8])*L[8] + cos(Th[2] - Th[4])*L[9] - \
cos(Th[2] + Th[4] - 2*Th[9])*L[9] + cos(Th[2] - Th[4])*L[10] - cos(Th[2] + \
Th[4] - 2*Th[10])*L[10] + 2*L[5]*sin(Th[2] - Th[5])*sin(Th[4] - Th[5]) + \
2*L[6]*sin(Th[2] - Th[6])*sin(Th[4] - Th[6]))))/2.;\n matSys[27] = \
-(L[3]*L[4]*(Cs*(cos(Th[3] - Th[4])*L[4] + 2*cos(Th[3] - Th[5])*cos(Th[4] - \
Th[5])*L[5] + cos(Th[3] - Th[4])*L[6] + cos(Th[3] + Th[4] - 2*Th[6])*L[6] + \
cos(Th[3] - Th[4])*L[7] + cos(Th[3] + Th[4] - 2*Th[7])*L[7] + cos(Th[3] - \
Th[4])*L[8] + cos(Th[3] + Th[4] - 2*Th[8])*L[8] + cos(Th[3] - Th[4])*L[9] + \
cos(Th[3] + Th[4] - 2*Th[9])*L[9] + cos(Th[3] - Th[4])*L[10] + cos(Th[3] + \
Th[4] - 2*Th[10])*L[10]) + Cv*(cos(Th[3] - Th[4])*L[7] - cos(Th[3] + Th[4] - \
2*Th[7])*L[7] + cos(Th[3] - Th[4])*L[8] - cos(Th[3] + Th[4] - 2*Th[8])*L[8] + \
cos(Th[3] - Th[4])*L[9] - cos(Th[3] + Th[4] - 2*Th[9])*L[9] + cos(Th[3] - \
Th[4])*L[10] - cos(Th[3] + Th[4] - 2*Th[10])*L[10] + 2*L[5]*sin(Th[3] - \
Th[5])*sin(Th[4] - Th[5]) + 2*L[6]*sin(Th[3] - Th[6])*sin(Th[4] - \
Th[6]))))/2.;\n matSys[39] = -(pow(L[4],2)*(Cs*(2*L[4] + 3*(2*pow(cos(Th[4] - \
Th[5]),2)*L[5] + 2*pow(cos(Th[4] - Th[6]),2)*L[6] + L[7] + cos(2*(Th[4] - \
Th[7]))*L[7] + L[8] + cos(2*(Th[4] - Th[8]))*L[8] + L[9] + cos(2*(Th[4] - \
Th[9]))*L[9] + L[10] + cos(2*(Th[4] - Th[10]))*L[10])) + 3*Cv*(L[7] - \
cos(2*(Th[4] - Th[7]))*L[7] + L[8] - cos(2*(Th[4] - Th[8]))*L[8] + L[9] - \
cos(2*(Th[4] - Th[9]))*L[9] + L[10] - cos(2*(Th[4] - Th[10]))*L[10] + \
2*L[5]*pow(sin(Th[4] - Th[5]),2) + 2*L[6]*pow(sin(Th[4] - Th[6]),2))))/6.;\n \
matSys[51] = -(L[4]*L[5]*(Cs*(cos(Th[4] - Th[5])*L[5] + 2*cos(Th[4] - \
Th[6])*cos(Th[5] - Th[6])*L[6] + cos(Th[4] - Th[5])*L[7] + cos(Th[4] + Th[5] \
- 2*Th[7])*L[7] + cos(Th[4] - Th[5])*L[8] + cos(Th[4] + Th[5] - 2*Th[8])*L[8] \
+ cos(Th[4] - Th[5])*L[9] + cos(Th[4] + Th[5] - 2*Th[9])*L[9] + cos(Th[4] - \
Th[5])*L[10] + cos(Th[4] + Th[5] - 2*Th[10])*L[10]) + Cv*(cos(Th[4] - \
Th[5])*L[8] - cos(Th[4] + Th[5] - 2*Th[8])*L[8] + cos(Th[4] - Th[5])*L[9] - \
cos(Th[4] + Th[5] - 2*Th[9])*L[9] + cos(Th[4] - Th[5])*L[10] - cos(Th[4] + \
Th[5] - 2*Th[10])*L[10] + 2*L[6]*sin(Th[4] - Th[6])*sin(Th[5] - Th[6]) + \
2*L[7]*sin(Th[4] - Th[7])*sin(Th[5] - Th[7]))))/2.;\n matSys[63] = \
-(L[4]*L[6]*(Cs*(cos(Th[4] - Th[6])*L[6] + 2*cos(Th[4] - Th[7])*cos(Th[6] - \
Th[7])*L[7] + cos(Th[4] - Th[6])*L[8] + cos(Th[4] + Th[6] - 2*Th[8])*L[8] + \
cos(Th[4] - Th[6])*L[9] + cos(Th[4] + Th[6] - 2*Th[9])*L[9] + cos(Th[4] - \
Th[6])*L[10] + cos(Th[4] + Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[4] - \
Th[6])*L[9] - cos(Th[4] + Th[6] - 2*Th[9])*L[9] + cos(Th[4] - Th[6])*L[10] - \
cos(Th[4] + Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[4] - Th[7])*sin(Th[6] - \
Th[7]) + 2*L[8]*sin(Th[4] - Th[8])*sin(Th[6] - Th[8]))))/2.;\n matSys[75] = \
-(L[4]*L[7]*(Cs*(cos(Th[4] - Th[7])*L[7] + 2*cos(Th[4] - Th[8])*cos(Th[7] - \
Th[8])*L[8] + cos(Th[4] - Th[7])*L[9] + cos(Th[4] + Th[7] - 2*Th[9])*L[9] + \
cos(Th[4] - Th[7])*L[10] + cos(Th[4] + Th[7] - 2*Th[10])*L[10]) + \
2*Cv*(L[8]*sin(Th[4] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[4] - \
Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[4] - Th[10])*sin(Th[7] - \
Th[10]))))/2.;\n matSys[87] = -(L[4]*L[8]*(Cs*(cos(Th[4] - Th[8])*L[8] + \
2*cos(Th[4] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[4] - \
Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[4] - Th[9])*sin(Th[8] \
- Th[9]) + L[10]*sin(Th[4] - Th[10])*sin(Th[8] - Th[10]))))/2.;\n matSys[99] \
= -(L[4]*L[9]*(Cs*(cos(Th[4] - Th[9])*L[9] + 2*cos(Th[4] - Th[10])*cos(Th[9] \
- Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[4] - Th[10])*sin(Th[9] - Th[10])))/2.;\n \
matSys[111] = -(Cs*cos(Th[4] - Th[10])*L[4]*pow(L[10],2))/2.;\n matSys[123] = \
(L[4]*(Cs*(L[4]*sin(Th[4]) + L[6]*sin(Th[4]) + L[7]*sin(Th[4]) + \
L[8]*sin(Th[4]) + L[9]*sin(Th[4]) + L[10]*sin(Th[4]) + 2*cos(Th[4] - \
Th[5])*L[5]*sin(Th[5]) - L[6]*sin(Th[4] - 2*Th[6]) - L[7]*sin(Th[4] - \
2*Th[7]) - L[8]*sin(Th[4] - 2*Th[8]) - L[9]*sin(Th[4] - 2*Th[9]) - \
L[10]*sin(Th[4] - 2*Th[10])) + Cv*(L[7]*sin(Th[4]) + L[8]*sin(Th[4]) + \
L[9]*sin(Th[4]) + L[10]*sin(Th[4]) + 2*cos(Th[5])*L[5]*sin(Th[4] - Th[5]) + \
2*cos(Th[6])*L[6]*sin(Th[4] - Th[6]) + L[7]*sin(Th[4] - 2*Th[7]) + \
L[8]*sin(Th[4] - 2*Th[8]) + L[9]*sin(Th[4] - 2*Th[9]) + L[10]*sin(Th[4] - \
2*Th[10]))))/2.;\n matSys[135] = -(L[4]*(Cs*(cos(Th[4])*L[4] + 2*cos(Th[4] - \
Th[5])*cos(Th[5])*L[5] + cos(Th[4])*L[6] + cos(Th[4] - 2*Th[6])*L[6] + \
cos(Th[4])*L[7] + cos(Th[4] - 2*Th[7])*L[7] + cos(Th[4])*L[8] + cos(Th[4] - \
2*Th[8])*L[8] + cos(Th[4])*L[9] + cos(Th[4] - 2*Th[9])*L[9] + \
cos(Th[4])*L[10] + cos(Th[4] - 2*Th[10])*L[10]) - Cv*(-(cos(Th[4])*L[7]) + \
cos(Th[4] - 2*Th[7])*L[7] - cos(Th[4])*L[8] + cos(Th[4] - 2*Th[8])*L[8] - \
cos(Th[4])*L[9] + cos(Th[4] - 2*Th[9])*L[9] - cos(Th[4])*L[10] + cos(Th[4] - \
2*Th[10])*L[10] + 2*L[5]*sin(Th[4] - Th[5])*sin(Th[5]) + 2*L[6]*sin(Th[4] - \
Th[6])*sin(Th[6]))))/2.;\n matSys[147] = 0;\n matSys[159] = 0;\n matSys[171] \
= -(L[4]*sin(Th[4]));\n matSys[183] = cos(Th[4])*L[4];\n matSys[4] = \
-(L[1]*L[5]*(Cs*(cos(Th[1] - Th[5])*L[5] + 2*cos(Th[1] - Th[6])*cos(Th[5] - \
Th[6])*L[6] + cos(Th[1] - Th[5])*L[7] + cos(Th[1] + Th[5] - 2*Th[7])*L[7] + \
cos(Th[1] - Th[5])*L[8] + cos(Th[1] + Th[5] - 2*Th[8])*L[8] + cos(Th[1] - \
Th[5])*L[9] + cos(Th[1] + Th[5] - 2*Th[9])*L[9] + cos(Th[1] - Th[5])*L[10] + \
cos(Th[1] + Th[5] - 2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[5])*L[8] - \
cos(Th[1] + Th[5] - 2*Th[8])*L[8] + cos(Th[1] - Th[5])*L[9] - cos(Th[1] + \
Th[5] - 2*Th[9])*L[9] + cos(Th[1] - Th[5])*L[10] - cos(Th[1] + Th[5] - \
2*Th[10])*L[10] + 2*L[6]*sin(Th[1] - Th[6])*sin(Th[5] - Th[6]) + \
2*L[7]*sin(Th[1] - Th[7])*sin(Th[5] - Th[7]))))/2.;\n matSys[16] = \
-(L[2]*L[5]*(Cs*(cos(Th[2] - Th[5])*L[5] + 2*cos(Th[2] - Th[6])*cos(Th[5] - \
Th[6])*L[6] + cos(Th[2] - Th[5])*L[7] + cos(Th[2] + Th[5] - 2*Th[7])*L[7] + \
cos(Th[2] - Th[5])*L[8] + cos(Th[2] + Th[5] - 2*Th[8])*L[8] + cos(Th[2] - \
Th[5])*L[9] + cos(Th[2] + Th[5] - 2*Th[9])*L[9] + cos(Th[2] - Th[5])*L[10] + \
cos(Th[2] + Th[5] - 2*Th[10])*L[10]) + Cv*(cos(Th[2] - Th[5])*L[8] - \
cos(Th[2] + Th[5] - 2*Th[8])*L[8] + cos(Th[2] - Th[5])*L[9] - cos(Th[2] + \
Th[5] - 2*Th[9])*L[9] + cos(Th[2] - Th[5])*L[10] - cos(Th[2] + Th[5] - \
2*Th[10])*L[10] + 2*L[6]*sin(Th[2] - Th[6])*sin(Th[5] - Th[6]) + \
2*L[7]*sin(Th[2] - Th[7])*sin(Th[5] - Th[7]))))/2.;\n matSys[28] = \
-(L[3]*L[5]*(Cs*(cos(Th[3] - Th[5])*L[5] + 2*cos(Th[3] - Th[6])*cos(Th[5] - \
Th[6])*L[6] + cos(Th[3] - Th[5])*L[7] + cos(Th[3] + Th[5] - 2*Th[7])*L[7] + \
cos(Th[3] - Th[5])*L[8] + cos(Th[3] + Th[5] - 2*Th[8])*L[8] + cos(Th[3] - \
Th[5])*L[9] + cos(Th[3] + Th[5] - 2*Th[9])*L[9] + cos(Th[3] - Th[5])*L[10] + \
cos(Th[3] + Th[5] - 2*Th[10])*L[10]) + Cv*(cos(Th[3] - Th[5])*L[8] - \
cos(Th[3] + Th[5] - 2*Th[8])*L[8] + cos(Th[3] - Th[5])*L[9] - cos(Th[3] + \
Th[5] - 2*Th[9])*L[9] + cos(Th[3] - Th[5])*L[10] - cos(Th[3] + Th[5] - \
2*Th[10])*L[10] + 2*L[6]*sin(Th[3] - Th[6])*sin(Th[5] - Th[6]) + \
2*L[7]*sin(Th[3] - Th[7])*sin(Th[5] - Th[7]))))/2.;\n matSys[40] = \
-(L[4]*L[5]*(Cs*(cos(Th[4] - Th[5])*L[5] + 2*cos(Th[4] - Th[6])*cos(Th[5] - \
Th[6])*L[6] + cos(Th[4] - Th[5])*L[7] + cos(Th[4] + Th[5] - 2*Th[7])*L[7] + \
cos(Th[4] - Th[5])*L[8] + cos(Th[4] + Th[5] - 2*Th[8])*L[8] + cos(Th[4] - \
Th[5])*L[9] + cos(Th[4] + Th[5] - 2*Th[9])*L[9] + cos(Th[4] - Th[5])*L[10] + \
cos(Th[4] + Th[5] - 2*Th[10])*L[10]) + Cv*(cos(Th[4] - Th[5])*L[8] - \
cos(Th[4] + Th[5] - 2*Th[8])*L[8] + cos(Th[4] - Th[5])*L[9] - cos(Th[4] + \
Th[5] - 2*Th[9])*L[9] + cos(Th[4] - Th[5])*L[10] - cos(Th[4] + Th[5] - \
2*Th[10])*L[10] + 2*L[6]*sin(Th[4] - Th[6])*sin(Th[5] - Th[6]) + \
2*L[7]*sin(Th[4] - Th[7])*sin(Th[5] - Th[7]))))/2.;\n matSys[52] = \
-(pow(L[5],2)*(Cs*(2*L[5] + 3*(2*pow(cos(Th[5] - Th[6]),2)*L[6] + \
2*pow(cos(Th[5] - Th[7]),2)*L[7] + L[8] + cos(2*(Th[5] - Th[8]))*L[8] + L[9] \
+ cos(2*(Th[5] - Th[9]))*L[9] + L[10] + cos(2*(Th[5] - Th[10]))*L[10])) + \
3*Cv*(L[8] - cos(2*(Th[5] - Th[8]))*L[8] + L[9] - cos(2*(Th[5] - Th[9]))*L[9] \
+ L[10] - cos(2*(Th[5] - Th[10]))*L[10] + 2*L[6]*pow(sin(Th[5] - Th[6]),2) + \
2*L[7]*pow(sin(Th[5] - Th[7]),2))))/6.;\n matSys[64] = \
-(L[5]*L[6]*(Cs*(cos(Th[5] - Th[6])*L[6] + 2*cos(Th[5] - Th[7])*cos(Th[6] - \
Th[7])*L[7] + cos(Th[5] - Th[6])*L[8] + cos(Th[5] + Th[6] - 2*Th[8])*L[8] + \
cos(Th[5] - Th[6])*L[9] + cos(Th[5] + Th[6] - 2*Th[9])*L[9] + cos(Th[5] - \
Th[6])*L[10] + cos(Th[5] + Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[5] - \
Th[6])*L[9] - cos(Th[5] + Th[6] - 2*Th[9])*L[9] + cos(Th[5] - Th[6])*L[10] - \
cos(Th[5] + Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[5] - Th[7])*sin(Th[6] - \
Th[7]) + 2*L[8]*sin(Th[5] - Th[8])*sin(Th[6] - Th[8]))))/2.;\n matSys[76] = \
-(L[5]*L[7]*(Cs*(cos(Th[5] - Th[7])*L[7] + 2*cos(Th[5] - Th[8])*cos(Th[7] - \
Th[8])*L[8] + cos(Th[5] - Th[7])*L[9] + cos(Th[5] + Th[7] - 2*Th[9])*L[9] + \
cos(Th[5] - Th[7])*L[10] + cos(Th[5] + Th[7] - 2*Th[10])*L[10]) + \
2*Cv*(L[8]*sin(Th[5] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[5] - \
Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[5] - Th[10])*sin(Th[7] - \
Th[10]))))/2.;\n matSys[88] = -(L[5]*L[8]*(Cs*(cos(Th[5] - Th[8])*L[8] + \
2*cos(Th[5] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[5] - \
Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[5] - Th[9])*sin(Th[8] \
- Th[9]) + L[10]*sin(Th[5] - Th[10])*sin(Th[8] - Th[10]))))/2.;\n matSys[100] \
= -(L[5]*L[9]*(Cs*(cos(Th[5] - Th[9])*L[9] + 2*cos(Th[5] - Th[10])*cos(Th[9] \
- Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[5] - Th[10])*sin(Th[9] - Th[10])))/2.;\n \
matSys[112] = -(Cs*cos(Th[5] - Th[10])*L[5]*pow(L[10],2))/2.;\n matSys[124] = \
(L[5]*(Cs*(L[5]*sin(Th[5]) + L[7]*sin(Th[5]) + L[8]*sin(Th[5]) + \
L[9]*sin(Th[5]) + L[10]*sin(Th[5]) + 2*cos(Th[5] - Th[6])*L[6]*sin(Th[6]) - \
L[7]*sin(Th[5] - 2*Th[7]) - L[8]*sin(Th[5] - 2*Th[8]) - L[9]*sin(Th[5] - \
2*Th[9]) - L[10]*sin(Th[5] - 2*Th[10])) + Cv*(L[8]*sin(Th[5]) + \
L[9]*sin(Th[5]) + L[10]*sin(Th[5]) + 2*cos(Th[6])*L[6]*sin(Th[5] - Th[6]) + \
2*cos(Th[7])*L[7]*sin(Th[5] - Th[7]) + L[8]*sin(Th[5] - 2*Th[8]) + \
L[9]*sin(Th[5] - 2*Th[9]) + L[10]*sin(Th[5] - 2*Th[10]))))/2.;\n matSys[136] \
= -(L[5]*(Cs*(cos(Th[5])*L[5] + 2*cos(Th[5] - Th[6])*cos(Th[6])*L[6] + \
cos(Th[5])*L[7] + cos(Th[5] - 2*Th[7])*L[7] + cos(Th[5])*L[8] + cos(Th[5] - \
2*Th[8])*L[8] + cos(Th[5])*L[9] + cos(Th[5] - 2*Th[9])*L[9] + \
cos(Th[5])*L[10] + cos(Th[5] - 2*Th[10])*L[10]) - Cv*(-(cos(Th[5])*L[8]) + \
cos(Th[5] - 2*Th[8])*L[8] - cos(Th[5])*L[9] + cos(Th[5] - 2*Th[9])*L[9] - \
cos(Th[5])*L[10] + cos(Th[5] - 2*Th[10])*L[10] + 2*L[6]*sin(Th[5] - \
Th[6])*sin(Th[6]) + 2*L[7]*sin(Th[5] - Th[7])*sin(Th[7]))))/2.;\n matSys[148] \
= 0;\n matSys[160] = 0;\n matSys[172] = -(L[5]*sin(Th[5]));\n matSys[184] = \
cos(Th[5])*L[5];\n matSys[5] = -(L[1]*L[6]*(Cs*(cos(Th[1] - Th[6])*L[6] + \
2*cos(Th[1] - Th[7])*cos(Th[6] - Th[7])*L[7] + cos(Th[1] - Th[6])*L[8] + \
cos(Th[1] + Th[6] - 2*Th[8])*L[8] + cos(Th[1] - Th[6])*L[9] + cos(Th[1] + \
Th[6] - 2*Th[9])*L[9] + cos(Th[1] - Th[6])*L[10] + cos(Th[1] + Th[6] - \
2*Th[10])*L[10]) + Cv*(cos(Th[1] - Th[6])*L[9] - cos(Th[1] + Th[6] - \
2*Th[9])*L[9] + cos(Th[1] - Th[6])*L[10] - cos(Th[1] + Th[6] - \
2*Th[10])*L[10] + 2*L[7]*sin(Th[1] - Th[7])*sin(Th[6] - Th[7]) + \
2*L[8]*sin(Th[1] - Th[8])*sin(Th[6] - Th[8]))))/2.;\n matSys[17] = \
-(L[2]*L[6]*(Cs*(cos(Th[2] - Th[6])*L[6] + 2*cos(Th[2] - Th[7])*cos(Th[6] - \
Th[7])*L[7] + cos(Th[2] - Th[6])*L[8] + cos(Th[2] + Th[6] - 2*Th[8])*L[8] + \
cos(Th[2] - Th[6])*L[9] + cos(Th[2] + Th[6] - 2*Th[9])*L[9] + cos(Th[2] - \
Th[6])*L[10] + cos(Th[2] + Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[2] - \
Th[6])*L[9] - cos(Th[2] + Th[6] - 2*Th[9])*L[9] + cos(Th[2] - Th[6])*L[10] - \
cos(Th[2] + Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[2] - Th[7])*sin(Th[6] - \
Th[7]) + 2*L[8]*sin(Th[2] - Th[8])*sin(Th[6] - Th[8]))))/2.;\n matSys[29] = \
-(L[3]*L[6]*(Cs*(cos(Th[3] - Th[6])*L[6] + 2*cos(Th[3] - Th[7])*cos(Th[6] - \
Th[7])*L[7] + cos(Th[3] - Th[6])*L[8] + cos(Th[3] + Th[6] - 2*Th[8])*L[8] + \
cos(Th[3] - Th[6])*L[9] + cos(Th[3] + Th[6] - 2*Th[9])*L[9] + cos(Th[3] - \
Th[6])*L[10] + cos(Th[3] + Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[3] - \
Th[6])*L[9] - cos(Th[3] + Th[6] - 2*Th[9])*L[9] + cos(Th[3] - Th[6])*L[10] - \
cos(Th[3] + Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[3] - Th[7])*sin(Th[6] - \
Th[7]) + 2*L[8]*sin(Th[3] - Th[8])*sin(Th[6] - Th[8]))))/2.;\n matSys[41] = \
-(L[4]*L[6]*(Cs*(cos(Th[4] - Th[6])*L[6] + 2*cos(Th[4] - Th[7])*cos(Th[6] - \
Th[7])*L[7] + cos(Th[4] - Th[6])*L[8] + cos(Th[4] + Th[6] - 2*Th[8])*L[8] + \
cos(Th[4] - Th[6])*L[9] + cos(Th[4] + Th[6] - 2*Th[9])*L[9] + cos(Th[4] - \
Th[6])*L[10] + cos(Th[4] + Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[4] - \
Th[6])*L[9] - cos(Th[4] + Th[6] - 2*Th[9])*L[9] + cos(Th[4] - Th[6])*L[10] - \
cos(Th[4] + Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[4] - Th[7])*sin(Th[6] - \
Th[7]) + 2*L[8]*sin(Th[4] - Th[8])*sin(Th[6] - Th[8]))))/2.;\n matSys[53] = \
-(L[5]*L[6]*(Cs*(cos(Th[5] - Th[6])*L[6] + 2*cos(Th[5] - Th[7])*cos(Th[6] - \
Th[7])*L[7] + cos(Th[5] - Th[6])*L[8] + cos(Th[5] + Th[6] - 2*Th[8])*L[8] + \
cos(Th[5] - Th[6])*L[9] + cos(Th[5] + Th[6] - 2*Th[9])*L[9] + cos(Th[5] - \
Th[6])*L[10] + cos(Th[5] + Th[6] - 2*Th[10])*L[10]) + Cv*(cos(Th[5] - \
Th[6])*L[9] - cos(Th[5] + Th[6] - 2*Th[9])*L[9] + cos(Th[5] - Th[6])*L[10] - \
cos(Th[5] + Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[5] - Th[7])*sin(Th[6] - \
Th[7]) + 2*L[8]*sin(Th[5] - Th[8])*sin(Th[6] - Th[8]))))/2.;\n matSys[65] = \
-(pow(L[6],2)*(Cs*(2*L[6] + 3*(2*pow(cos(Th[6] - Th[7]),2)*L[7] + \
2*pow(cos(Th[6] - Th[8]),2)*L[8] + L[9] + cos(2*(Th[6] - Th[9]))*L[9] + L[10] \
+ cos(2*(Th[6] - Th[10]))*L[10])) + 3*Cv*(L[9] - cos(2*(Th[6] - Th[9]))*L[9] \
+ L[10] - cos(2*(Th[6] - Th[10]))*L[10] + 2*L[7]*pow(sin(Th[6] - Th[7]),2) + \
2*L[8]*pow(sin(Th[6] - Th[8]),2))))/6.;\n matSys[77] = \
-(L[6]*L[7]*(Cs*(cos(Th[6] - Th[7])*L[7] + 2*cos(Th[6] - Th[8])*cos(Th[7] - \
Th[8])*L[8] + cos(Th[6] - Th[7])*L[9] + cos(Th[6] + Th[7] - 2*Th[9])*L[9] + \
cos(Th[6] - Th[7])*L[10] + cos(Th[6] + Th[7] - 2*Th[10])*L[10]) + \
2*Cv*(L[8]*sin(Th[6] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[6] - \
Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[6] - Th[10])*sin(Th[7] - \
Th[10]))))/2.;\n matSys[89] = -(L[6]*L[8]*(Cs*(cos(Th[6] - Th[8])*L[8] + \
2*cos(Th[6] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[6] - \
Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[6] - Th[9])*sin(Th[8] \
- Th[9]) + L[10]*sin(Th[6] - Th[10])*sin(Th[8] - Th[10]))))/2.;\n matSys[101] \
= -(L[6]*L[9]*(Cs*(cos(Th[6] - Th[9])*L[9] + 2*cos(Th[6] - Th[10])*cos(Th[9] \
- Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[6] - Th[10])*sin(Th[9] - Th[10])))/2.;\n \
matSys[113] = -(Cs*cos(Th[6] - Th[10])*L[6]*pow(L[10],2))/2.;\n matSys[125] = \
(L[6]*(Cs*(L[6]*sin(Th[6]) + L[8]*sin(Th[6]) + L[9]*sin(Th[6]) + \
L[10]*sin(Th[6]) + 2*cos(Th[6] - Th[7])*L[7]*sin(Th[7]) - L[8]*sin(Th[6] - \
2*Th[8]) - L[9]*sin(Th[6] - 2*Th[9]) - L[10]*sin(Th[6] - 2*Th[10])) + \
Cv*(L[9]*sin(Th[6]) + L[10]*sin(Th[6]) + 2*cos(Th[7])*L[7]*sin(Th[6] - Th[7]) \
+ 2*cos(Th[8])*L[8]*sin(Th[6] - Th[8]) + L[9]*sin(Th[6] - 2*Th[9]) + \
L[10]*sin(Th[6] - 2*Th[10]))))/2.;\n matSys[137] = \
-(L[6]*(Cs*(cos(Th[6])*L[6] + 2*cos(Th[6] - Th[7])*cos(Th[7])*L[7] + \
cos(Th[6])*L[8] + cos(Th[6] - 2*Th[8])*L[8] + cos(Th[6])*L[9] + cos(Th[6] - \
2*Th[9])*L[9] + cos(Th[6])*L[10] + cos(Th[6] - 2*Th[10])*L[10]) - \
Cv*(-(cos(Th[6])*L[9]) + cos(Th[6] - 2*Th[9])*L[9] - cos(Th[6])*L[10] + \
cos(Th[6] - 2*Th[10])*L[10] + 2*L[7]*sin(Th[6] - Th[7])*sin(Th[7]) + \
2*L[8]*sin(Th[6] - Th[8])*sin(Th[8]))))/2.;\n matSys[149] = 0;\n matSys[161] \
= 0;\n matSys[173] = -(L[6]*sin(Th[6]));\n matSys[185] = cos(Th[6])*L[6];\n \
matSys[6] = -(L[1]*L[7]*(Cs*(cos(Th[1] - Th[7])*L[7] + 2*cos(Th[1] - \
Th[8])*cos(Th[7] - Th[8])*L[8] + cos(Th[1] - Th[7])*L[9] + cos(Th[1] + Th[7] \
- 2*Th[9])*L[9] + cos(Th[1] - Th[7])*L[10] + cos(Th[1] + Th[7] - \
2*Th[10])*L[10]) + 2*Cv*(L[8]*sin(Th[1] - Th[8])*sin(Th[7] - Th[8]) + \
L[9]*sin(Th[1] - Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[1] - \
Th[10])*sin(Th[7] - Th[10]))))/2.;\n matSys[18] = -(L[2]*L[7]*(Cs*(cos(Th[2] \
- Th[7])*L[7] + 2*cos(Th[2] - Th[8])*cos(Th[7] - Th[8])*L[8] + cos(Th[2] - \
Th[7])*L[9] + cos(Th[2] + Th[7] - 2*Th[9])*L[9] + cos(Th[2] - Th[7])*L[10] + \
cos(Th[2] + Th[7] - 2*Th[10])*L[10]) + 2*Cv*(L[8]*sin(Th[2] - \
Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[2] - Th[9])*sin(Th[7] - Th[9]) + \
L[10]*sin(Th[2] - Th[10])*sin(Th[7] - Th[10]))))/2.;\n matSys[30] = \
-(L[3]*L[7]*(Cs*(cos(Th[3] - Th[7])*L[7] + 2*cos(Th[3] - Th[8])*cos(Th[7] - \
Th[8])*L[8] + cos(Th[3] - Th[7])*L[9] + cos(Th[3] + Th[7] - 2*Th[9])*L[9] + \
cos(Th[3] - Th[7])*L[10] + cos(Th[3] + Th[7] - 2*Th[10])*L[10]) + \
2*Cv*(L[8]*sin(Th[3] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[3] - \
Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[3] - Th[10])*sin(Th[7] - \
Th[10]))))/2.;\n matSys[42] = -(L[4]*L[7]*(Cs*(cos(Th[4] - Th[7])*L[7] + \
2*cos(Th[4] - Th[8])*cos(Th[7] - Th[8])*L[8] + cos(Th[4] - Th[7])*L[9] + \
cos(Th[4] + Th[7] - 2*Th[9])*L[9] + cos(Th[4] - Th[7])*L[10] + cos(Th[4] + \
Th[7] - 2*Th[10])*L[10]) + 2*Cv*(L[8]*sin(Th[4] - Th[8])*sin(Th[7] - Th[8]) + \
L[9]*sin(Th[4] - Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[4] - \
Th[10])*sin(Th[7] - Th[10]))))/2.;\n matSys[54] = -(L[5]*L[7]*(Cs*(cos(Th[5] \
- Th[7])*L[7] + 2*cos(Th[5] - Th[8])*cos(Th[7] - Th[8])*L[8] + cos(Th[5] - \
Th[7])*L[9] + cos(Th[5] + Th[7] - 2*Th[9])*L[9] + cos(Th[5] - Th[7])*L[10] + \
cos(Th[5] + Th[7] - 2*Th[10])*L[10]) + 2*Cv*(L[8]*sin(Th[5] - \
Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[5] - Th[9])*sin(Th[7] - Th[9]) + \
L[10]*sin(Th[5] - Th[10])*sin(Th[7] - Th[10]))))/2.;\n matSys[66] = \
-(L[6]*L[7]*(Cs*(cos(Th[6] - Th[7])*L[7] + 2*cos(Th[6] - Th[8])*cos(Th[7] - \
Th[8])*L[8] + cos(Th[6] - Th[7])*L[9] + cos(Th[6] + Th[7] - 2*Th[9])*L[9] + \
cos(Th[6] - Th[7])*L[10] + cos(Th[6] + Th[7] - 2*Th[10])*L[10]) + \
2*Cv*(L[8]*sin(Th[6] - Th[8])*sin(Th[7] - Th[8]) + L[9]*sin(Th[6] - \
Th[9])*sin(Th[7] - Th[9]) + L[10]*sin(Th[6] - Th[10])*sin(Th[7] - \
Th[10]))))/2.;\n matSys[78] = -(pow(L[7],2)*(Cs*(L[7] + 3*(pow(cos(Th[7] - \
Th[8]),2)*L[8] + pow(cos(Th[7] - Th[9]),2)*L[9] + pow(cos(Th[7] - \
Th[10]),2)*L[10])) + 3*Cv*(L[8]*pow(sin(Th[7] - Th[8]),2) + \
L[9]*pow(sin(Th[7] - Th[9]),2) + L[10]*pow(sin(Th[7] - Th[10]),2))))/3.;\n \
matSys[90] = -(L[7]*L[8]*(Cs*(cos(Th[7] - Th[8])*L[8] + 2*cos(Th[7] - \
Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[7] - Th[10])*cos(Th[8] - \
Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[7] - Th[9])*sin(Th[8] - Th[9]) + \
L[10]*sin(Th[7] - Th[10])*sin(Th[8] - Th[10]))))/2.;\n matSys[102] = \
-(L[7]*L[9]*(Cs*(cos(Th[7] - Th[9])*L[9] + 2*cos(Th[7] - Th[10])*cos(Th[9] - \
Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[7] - Th[10])*sin(Th[9] - Th[10])))/2.;\n \
matSys[114] = -(Cs*cos(Th[7] - Th[10])*L[7]*pow(L[10],2))/2.;\n matSys[126] = \
(L[7]*(Cs*(L[7]*sin(Th[7]) + L[9]*sin(Th[7]) + L[10]*sin(Th[7]) + 2*cos(Th[7] \
- Th[8])*L[8]*sin(Th[8]) - L[9]*sin(Th[7] - 2*Th[9]) - L[10]*sin(Th[7] - \
2*Th[10])) + Cv*(2*cos(Th[8])*L[8]*sin(Th[7] - Th[8]) + \
2*cos(Th[9])*L[9]*sin(Th[7] - Th[9]) + L[10]*(sin(Th[7]) + sin(Th[7] - \
2*Th[10])))))/2.;\n matSys[138] = -(L[7]*(Cs*(cos(Th[7])*L[7] + 2*cos(Th[7] - \
Th[8])*cos(Th[8])*L[8] + cos(Th[7])*L[9] + cos(Th[7] - 2*Th[9])*L[9] + \
cos(Th[7])*L[10] + cos(Th[7] - 2*Th[10])*L[10]) - 2*Cv*(L[8]*sin(Th[7] - \
Th[8])*sin(Th[8]) + L[9]*sin(Th[7] - Th[9])*sin(Th[9]) + L[10]*sin(Th[7] - \
Th[10])*sin(Th[10]))))/2.;\n matSys[150] = 0;\n matSys[162] = 0;\n \
matSys[174] = -(L[7]*sin(Th[7]));\n matSys[186] = cos(Th[7])*L[7];\n \
matSys[7] = -(L[1]*L[8]*(Cs*(cos(Th[1] - Th[8])*L[8] + 2*cos(Th[1] - \
Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[1] - Th[10])*cos(Th[8] - \
Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[1] - Th[9])*sin(Th[8] - Th[9]) + \
L[10]*sin(Th[1] - Th[10])*sin(Th[8] - Th[10]))))/2.;\n matSys[19] = \
-(L[2]*L[8]*(Cs*(cos(Th[2] - Th[8])*L[8] + 2*cos(Th[2] - Th[9])*cos(Th[8] - \
Th[9])*L[9] + 2*cos(Th[2] - Th[10])*cos(Th[8] - Th[10])*L[10]) + \
2*Cv*(L[9]*sin(Th[2] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[2] - \
Th[10])*sin(Th[8] - Th[10]))))/2.;\n matSys[31] = -(L[3]*L[8]*(Cs*(cos(Th[3] \
- Th[8])*L[8] + 2*cos(Th[3] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[3] - \
Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[3] - Th[9])*sin(Th[8] \
- Th[9]) + L[10]*sin(Th[3] - Th[10])*sin(Th[8] - Th[10]))))/2.;\n matSys[43] \
= -(L[4]*L[8]*(Cs*(cos(Th[4] - Th[8])*L[8] + 2*cos(Th[4] - Th[9])*cos(Th[8] - \
Th[9])*L[9] + 2*cos(Th[4] - Th[10])*cos(Th[8] - Th[10])*L[10]) + \
2*Cv*(L[9]*sin(Th[4] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[4] - \
Th[10])*sin(Th[8] - Th[10]))))/2.;\n matSys[55] = -(L[5]*L[8]*(Cs*(cos(Th[5] \
- Th[8])*L[8] + 2*cos(Th[5] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[5] - \
Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[5] - Th[9])*sin(Th[8] \
- Th[9]) + L[10]*sin(Th[5] - Th[10])*sin(Th[8] - Th[10]))))/2.;\n matSys[67] \
= -(L[6]*L[8]*(Cs*(cos(Th[6] - Th[8])*L[8] + 2*cos(Th[6] - Th[9])*cos(Th[8] - \
Th[9])*L[9] + 2*cos(Th[6] - Th[10])*cos(Th[8] - Th[10])*L[10]) + \
2*Cv*(L[9]*sin(Th[6] - Th[9])*sin(Th[8] - Th[9]) + L[10]*sin(Th[6] - \
Th[10])*sin(Th[8] - Th[10]))))/2.;\n matSys[79] = -(L[7]*L[8]*(Cs*(cos(Th[7] \
- Th[8])*L[8] + 2*cos(Th[7] - Th[9])*cos(Th[8] - Th[9])*L[9] + 2*cos(Th[7] - \
Th[10])*cos(Th[8] - Th[10])*L[10]) + 2*Cv*(L[9]*sin(Th[7] - Th[9])*sin(Th[8] \
- Th[9]) + L[10]*sin(Th[7] - Th[10])*sin(Th[8] - Th[10]))))/2.;\n matSys[91] \
= -(pow(L[8],2)*(Cs*(L[8] + 3*pow(cos(Th[8] - Th[9]),2)*L[9] + \
3*pow(cos(Th[8] - Th[10]),2)*L[10]) + 3*Cv*(L[9]*pow(sin(Th[8] - Th[9]),2) + \
L[10]*pow(sin(Th[8] - Th[10]),2))))/3.;\n matSys[103] = \
-(L[8]*L[9]*(Cs*(cos(Th[8] - Th[9])*L[9] + 2*cos(Th[8] - Th[10])*cos(Th[9] - \
Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[8] - Th[10])*sin(Th[9] - Th[10])))/2.;\n \
matSys[115] = -(Cs*cos(Th[8] - Th[10])*L[8]*pow(L[10],2))/2.;\n matSys[127] = \
(L[8]*(Cv*(2*cos(Th[9])*L[9]*sin(Th[8] - Th[9]) + L[10]*(sin(Th[8]) + \
sin(Th[8] - 2*Th[10]))) + Cs*(L[8]*sin(Th[8]) + 2*cos(Th[8] - \
Th[9])*L[9]*sin(Th[9]) + 2*cos(Th[8] - Th[10])*L[10]*sin(Th[10]))))/2.;\n \
matSys[139] = -(L[8]*(Cs*(cos(Th[8])*L[8] + 2*cos(Th[8] - \
Th[9])*cos(Th[9])*L[9] + (cos(Th[8]) + cos(Th[8] - 2*Th[10]))*L[10]) - \
2*Cv*(L[9]*sin(Th[8] - Th[9])*sin(Th[9]) + L[10]*sin(Th[8] - \
Th[10])*sin(Th[10]))))/2.;\n matSys[151] = 0;\n matSys[163] = 0;\n \
matSys[175] = -(L[8]*sin(Th[8]));\n matSys[187] = cos(Th[8])*L[8];\n \
matSys[8] = -(L[1]*L[9]*(Cs*(cos(Th[1] - Th[9])*L[9] + 2*cos(Th[1] - \
Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[1] - Th[10])*sin(Th[9] \
- Th[10])))/2.;\n matSys[20] = -(L[2]*L[9]*(Cs*(cos(Th[2] - Th[9])*L[9] + \
2*cos(Th[2] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[2] - \
Th[10])*sin(Th[9] - Th[10])))/2.;\n matSys[32] = -(L[3]*L[9]*(Cs*(cos(Th[3] - \
Th[9])*L[9] + 2*cos(Th[3] - Th[10])*cos(Th[9] - Th[10])*L[10]) + \
2*Cv*L[10]*sin(Th[3] - Th[10])*sin(Th[9] - Th[10])))/2.;\n matSys[44] = \
-(L[4]*L[9]*(Cs*(cos(Th[4] - Th[9])*L[9] + 2*cos(Th[4] - Th[10])*cos(Th[9] - \
Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[4] - Th[10])*sin(Th[9] - Th[10])))/2.;\n \
matSys[56] = -(L[5]*L[9]*(Cs*(cos(Th[5] - Th[9])*L[9] + 2*cos(Th[5] - \
Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[5] - Th[10])*sin(Th[9] \
- Th[10])))/2.;\n matSys[68] = -(L[6]*L[9]*(Cs*(cos(Th[6] - Th[9])*L[9] + \
2*cos(Th[6] - Th[10])*cos(Th[9] - Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[6] - \
Th[10])*sin(Th[9] - Th[10])))/2.;\n matSys[80] = -(L[7]*L[9]*(Cs*(cos(Th[7] - \
Th[9])*L[9] + 2*cos(Th[7] - Th[10])*cos(Th[9] - Th[10])*L[10]) + \
2*Cv*L[10]*sin(Th[7] - Th[10])*sin(Th[9] - Th[10])))/2.;\n matSys[92] = \
-(L[8]*L[9]*(Cs*(cos(Th[8] - Th[9])*L[9] + 2*cos(Th[8] - Th[10])*cos(Th[9] - \
Th[10])*L[10]) + 2*Cv*L[10]*sin(Th[8] - Th[10])*sin(Th[9] - Th[10])))/2.;\n \
matSys[104] = -(pow(L[9],2)*(Cs*(L[9] + 3*pow(cos(Th[9] - Th[10]),2)*L[10]) + \
3*Cv*L[10]*pow(sin(Th[9] - Th[10]),2)))/3.;\n matSys[116] = -(Cs*cos(Th[9] - \
Th[10])*L[9]*pow(L[10],2))/2.;\n matSys[128] = (L[9]*(Cv*L[10]*(sin(Th[9]) + \
sin(Th[9] - 2*Th[10])) + Cs*(L[9]*sin(Th[9]) + 2*cos(Th[9] - \
Th[10])*L[10]*sin(Th[10]))))/2.;\n matSys[140] = -(L[9]*(Cs*(cos(Th[9])*L[9] \
+ (cos(Th[9]) + cos(Th[9] - 2*Th[10]))*L[10]) - 2*Cv*L[10]*sin(Th[9] - \
Th[10])*sin(Th[10])))/2.;\n matSys[152] = 0;\n matSys[164] = 0;\n matSys[176] \
= -(L[9]*sin(Th[9]));\n matSys[188] = cos(Th[9])*L[9];\n matSys[9] = \
-(Cs*cos(Th[1] - Th[10])*L[1]*pow(L[10],2))/2.;\n matSys[21] = -(Cs*cos(Th[2] \
- Th[10])*L[2]*pow(L[10],2))/2.;\n matSys[33] = -(Cs*cos(Th[3] - \
Th[10])*L[3]*pow(L[10],2))/2.;\n matSys[45] = -(Cs*cos(Th[4] - \
Th[10])*L[4]*pow(L[10],2))/2.;\n matSys[57] = -(Cs*cos(Th[5] - \
Th[10])*L[5]*pow(L[10],2))/2.;\n matSys[69] = -(Cs*cos(Th[6] - \
Th[10])*L[6]*pow(L[10],2))/2.;\n matSys[81] = -(Cs*cos(Th[7] - \
Th[10])*L[7]*pow(L[10],2))/2.;\n matSys[93] = -(Cs*cos(Th[8] - \
Th[10])*L[8]*pow(L[10],2))/2.;\n matSys[105] = -(Cs*cos(Th[9] - \
Th[10])*L[9]*pow(L[10],2))/2.;\n matSys[117] = -(Cs*pow(L[10],3))/3.;\n \
matSys[129] = (Cs*pow(L[10],2)*sin(Th[10]))/2.;\n matSys[141] = \
-(Cs*cos(Th[10])*pow(L[10],2))/2.;\n matSys[153] = 0;\n matSys[165] = 0;\n \
matSys[177] = -(L[10]*sin(Th[10]));\n matSys[189] = cos(Th[10])*L[10];\n \
matSys[10] = L[1]*sin(Th[1]);\n matSys[22] = L[2]*sin(Th[2]);\n matSys[34] = \
L[3]*sin(Th[3]);\n matSys[46] = L[4]*sin(Th[4]);\n matSys[58] = \
L[5]*sin(Th[5]);\n matSys[70] = L[6]*sin(Th[6]);\n matSys[82] = \
L[7]*sin(Th[7]);\n matSys[94] = L[8]*sin(Th[8]);\n matSys[106] = \
L[9]*sin(Th[9]);\n matSys[118] = L[10]*sin(Th[10]);\n matSys[130] = -1;\n \
matSys[142] = 0;\n matSys[154] = 1;\n matSys[166] = 0;\n matSys[178] = 0;\n \
matSys[190] = 0;\n matSys[11] = -(cos(Th[1])*L[1]);\n matSys[23] = \
-(cos(Th[2])*L[2]);\n matSys[35] = -(cos(Th[3])*L[3]);\n matSys[47] = \
-(cos(Th[4])*L[4]);\n matSys[59] = -(cos(Th[5])*L[5]);\n matSys[71] = \
-(cos(Th[6])*L[6]);\n matSys[83] = -(cos(Th[7])*L[7]);\n matSys[95] = \
-(cos(Th[8])*L[8]);\n matSys[107] = -(cos(Th[9])*L[9]);\n matSys[119] = \
-(cos(Th[10])*L[10]);\n matSys[131] = 0;\n matSys[143] = -1;\n matSys[155] = \
0;\n matSys[167] = 1;\n matSys[179] = 0;\n matSys[191] = 0;\n dragForce[0] = \
(L[1]*(-2*Cv*cos(Th[1])*(dxL*cos(Th[1]) + dyL*sin(Th[1])) + \
Cs*(dTh[1]*L[1]*sin(Th[1]) - 2*dxL*pow(sin(Th[1]),2) + \
dyL*sin(2*Th[1]))))/2.;\n dragForce[10] = \
-(L[1]*(Cs*cos(Th[1])*(2*dyL*cos(Th[1]) + dTh[1]*L[1] - 2*dxL*sin(Th[1])) + \
Cv*(2*dyL*pow(sin(Th[1]),2) + dxL*sin(2*Th[1]))))/2.;\n dragForce[1] = \
(L[2]*(-(Cs*sin(Th[2])*(-2*dyL*cos(Th[2]) - 2*cos(Th[1] - Th[2])*dTh[1]*L[1] \
- dTh[2]*L[2] + 2*dxL*sin(Th[2]))) - 2*Cv*cos(Th[2])*(dxL*cos(Th[2]) - \
dTh[1]*L[1]*sin(Th[1] - Th[2]) + dyL*sin(Th[2]))))/2.;\n dragForce[11] = \
-(L[2]*(Cs*cos(Th[2])*(2*dyL*cos(Th[2]) + 2*cos(Th[1] - Th[2])*dTh[1]*L[1] + \
dTh[2]*L[2] - 2*dxL*sin(Th[2])) + 2*Cv*sin(Th[2])*(dxL*cos(Th[2]) - \
dTh[1]*L[1]*sin(Th[1] - Th[2]) + dyL*sin(Th[2]))))/2.;\n dragForce[2] = \
(L[3]*(-(Cs*sin(Th[3])*(-2*dyL*cos(Th[3]) - 2*cos(Th[1] - Th[3])*dTh[1]*L[1] \
- 2*cos(Th[2] - Th[3])*dTh[2]*L[2] - dTh[3]*L[3] + 2*dxL*sin(Th[3]))) + \
2*Cv*cos(Th[3])*(-(dxL*cos(Th[3])) + dTh[1]*L[1]*sin(Th[1] - Th[3]) + \
dTh[2]*L[2]*sin(Th[2] - Th[3]) - dyL*sin(Th[3]))))/2.;\n dragForce[12] = \
-(L[3]*(Cs*cos(Th[3])*(2*dyL*cos(Th[3]) + 2*cos(Th[1] - Th[3])*dTh[1]*L[1] + \
2*cos(Th[2] - Th[3])*dTh[2]*L[2] + dTh[3]*L[3] - 2*dxL*sin(Th[3])) + \
2*Cv*sin(Th[3])*(dxL*cos(Th[3]) - dTh[1]*L[1]*sin(Th[1] - Th[3]) - \
dTh[2]*L[2]*sin(Th[2] - Th[3]) + dyL*sin(Th[3]))))/2.;\n dragForce[3] = \
(L[4]*(-(Cs*sin(Th[4])*(-2*dyL*cos(Th[4]) - 2*cos(Th[1] - Th[4])*dTh[1]*L[1] \
- 2*cos(Th[2] - Th[4])*dTh[2]*L[2] - 2*cos(Th[3] - Th[4])*dTh[3]*L[3] - \
dTh[4]*L[4] + 2*dxL*sin(Th[4]))) + 2*Cv*cos(Th[4])*(-(dxL*cos(Th[4])) + \
dTh[1]*L[1]*sin(Th[1] - Th[4]) + dTh[2]*L[2]*sin(Th[2] - Th[4]) + \
dTh[3]*L[3]*sin(Th[3] - Th[4]) - dyL*sin(Th[4]))))/2.;\n dragForce[13] = \
-(L[4]*(Cs*cos(Th[4])*(2*dyL*cos(Th[4]) + 2*cos(Th[1] - Th[4])*dTh[1]*L[1] + \
2*cos(Th[2] - Th[4])*dTh[2]*L[2] + 2*cos(Th[3] - Th[4])*dTh[3]*L[3] + \
dTh[4]*L[4] - 2*dxL*sin(Th[4])) + 2*Cv*sin(Th[4])*(dxL*cos(Th[4]) - \
dTh[1]*L[1]*sin(Th[1] - Th[4]) - dTh[2]*L[2]*sin(Th[2] - Th[4]) - \
dTh[3]*L[3]*sin(Th[3] - Th[4]) + dyL*sin(Th[4]))))/2.;\n dragForce[4] = \
(L[5]*(-(Cs*sin(Th[5])*(-2*dyL*cos(Th[5]) - 2*cos(Th[1] - Th[5])*dTh[1]*L[1] \
- 2*cos(Th[2] - Th[5])*dTh[2]*L[2] - 2*cos(Th[3] - Th[5])*dTh[3]*L[3] - \
2*cos(Th[4] - Th[5])*dTh[4]*L[4] - dTh[5]*L[5] + 2*dxL*sin(Th[5]))) + \
2*Cv*cos(Th[5])*(-(dxL*cos(Th[5])) + dTh[1]*L[1]*sin(Th[1] - Th[5]) + \
dTh[2]*L[2]*sin(Th[2] - Th[5]) + dTh[3]*L[3]*sin(Th[3] - Th[5]) + \
dTh[4]*L[4]*sin(Th[4] - Th[5]) - dyL*sin(Th[5]))))/2.;\n dragForce[14] = \
-(L[5]*(Cs*cos(Th[5])*(2*dyL*cos(Th[5]) + 2*cos(Th[1] - Th[5])*dTh[1]*L[1] + \
2*cos(Th[2] - Th[5])*dTh[2]*L[2] + 2*cos(Th[3] - Th[5])*dTh[3]*L[3] + \
2*cos(Th[4] - Th[5])*dTh[4]*L[4] + dTh[5]*L[5] - 2*dxL*sin(Th[5])) + \
2*Cv*sin(Th[5])*(dxL*cos(Th[5]) - dTh[1]*L[1]*sin(Th[1] - Th[5]) - \
dTh[2]*L[2]*sin(Th[2] - Th[5]) - dTh[3]*L[3]*sin(Th[3] - Th[5]) - \
dTh[4]*L[4]*sin(Th[4] - Th[5]) + dyL*sin(Th[5]))))/2.;\n dragForce[5] = \
(L[6]*(-(Cs*sin(Th[6])*(-2*dyL*cos(Th[6]) - 2*cos(Th[1] - Th[6])*dTh[1]*L[1] \
- 2*cos(Th[2] - Th[6])*dTh[2]*L[2] - 2*cos(Th[3] - Th[6])*dTh[3]*L[3] - \
2*cos(Th[4] - Th[6])*dTh[4]*L[4] - 2*cos(Th[5] - Th[6])*dTh[5]*L[5] - \
dTh[6]*L[6] + 2*dxL*sin(Th[6]))) + 2*Cv*cos(Th[6])*(-(dxL*cos(Th[6])) + \
dTh[1]*L[1]*sin(Th[1] - Th[6]) + dTh[2]*L[2]*sin(Th[2] - Th[6]) + \
dTh[3]*L[3]*sin(Th[3] - Th[6]) + dTh[4]*L[4]*sin(Th[4] - Th[6]) + \
dTh[5]*L[5]*sin(Th[5] - Th[6]) - dyL*sin(Th[6]))))/2.;\n dragForce[15] = \
(L[6]*(-(Cs*cos(Th[6])*(2*dyL*cos(Th[6]) + 2*cos(Th[1] - Th[6])*dTh[1]*L[1] + \
2*cos(Th[2] - Th[6])*dTh[2]*L[2] + 2*cos(Th[3] - Th[6])*dTh[3]*L[3] + \
2*cos(Th[4] - Th[6])*dTh[4]*L[4] + 2*cos(Th[5] - Th[6])*dTh[5]*L[5] + \
dTh[6]*L[6] - 2*dxL*sin(Th[6]))) + 2*Cv*sin(Th[6])*(-(dxL*cos(Th[6])) + \
dTh[1]*L[1]*sin(Th[1] - Th[6]) + dTh[2]*L[2]*sin(Th[2] - Th[6]) + \
dTh[3]*L[3]*sin(Th[3] - Th[6]) + dTh[4]*L[4]*sin(Th[4] - Th[6]) + \
dTh[5]*L[5]*sin(Th[5] - Th[6]) - dyL*sin(Th[6]))))/2.;\n dragForce[6] = \
(L[7]*(-(Cs*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - Th[7])*dTh[1]*L[1] \
- 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - Th[7])*dTh[3]*L[3] - \
2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - Th[7])*dTh[5]*L[5] - \
2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + 2*dxL*sin(Th[7]))) + \
2*Cv*cos(Th[7])*(-(dxL*cos(Th[7])) + dTh[1]*L[1]*sin(Th[1] - Th[7]) + \
dTh[2]*L[2]*sin(Th[2] - Th[7]) + dTh[3]*L[3]*sin(Th[3] - Th[7]) + \
dTh[4]*L[4]*sin(Th[4] - Th[7]) + dTh[5]*L[5]*sin(Th[5] - Th[7]) + \
dTh[6]*L[6]*sin(Th[6] - Th[7]) - dyL*sin(Th[7]))))/2.;\n dragForce[16] = \
-(L[7]*(Cs*cos(Th[7])*(2*dyL*cos(Th[7]) + 2*cos(Th[1] - Th[7])*dTh[1]*L[1] + \
2*cos(Th[2] - Th[7])*dTh[2]*L[2] + 2*cos(Th[3] - Th[7])*dTh[3]*L[3] + \
2*cos(Th[4] - Th[7])*dTh[4]*L[4] + 2*cos(Th[5] - Th[7])*dTh[5]*L[5] + \
2*cos(Th[6] - Th[7])*dTh[6]*L[6] + dTh[7]*L[7] - 2*dxL*sin(Th[7])) + \
2*Cv*sin(Th[7])*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - \
dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - \
dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - \
dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7]))))/2.;\n dragForce[7] = \
(L[8]*(-(Cs*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - Th[8])*dTh[1]*L[1] \
- 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - Th[8])*dTh[3]*L[3] - \
2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - Th[8])*dTh[5]*L[5] - \
2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - Th[8])*dTh[7]*L[7] - \
dTh[8]*L[8] + 2*dxL*sin(Th[8]))) + 2*Cv*cos(Th[8])*(-(dxL*cos(Th[8])) + \
dTh[1]*L[1]*sin(Th[1] - Th[8]) + dTh[2]*L[2]*sin(Th[2] - Th[8]) + \
dTh[3]*L[3]*sin(Th[3] - Th[8]) + dTh[4]*L[4]*sin(Th[4] - Th[8]) + \
dTh[5]*L[5]*sin(Th[5] - Th[8]) + dTh[6]*L[6]*sin(Th[6] - Th[8]) + \
dTh[7]*L[7]*sin(Th[7] - Th[8]) - dyL*sin(Th[8]))))/2.;\n dragForce[17] = \
-(L[8]*(Cs*cos(Th[8])*(2*dyL*cos(Th[8]) + 2*cos(Th[1] - Th[8])*dTh[1]*L[1] + \
2*cos(Th[2] - Th[8])*dTh[2]*L[2] + 2*cos(Th[3] - Th[8])*dTh[3]*L[3] + \
2*cos(Th[4] - Th[8])*dTh[4]*L[4] + 2*cos(Th[5] - Th[8])*dTh[5]*L[5] + \
2*cos(Th[6] - Th[8])*dTh[6]*L[6] + 2*cos(Th[7] - Th[8])*dTh[7]*L[7] + \
dTh[8]*L[8] - 2*dxL*sin(Th[8])) + 2*Cv*sin(Th[8])*(dxL*cos(Th[8]) - \
dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - \
dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - \
dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - \
dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))))/2.;\n dragForce[8] = \
(L[9]*(-(Cs*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - Th[9])*dTh[1]*L[1] \
- 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - Th[9])*dTh[3]*L[3] - \
2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - Th[9])*dTh[5]*L[5] - \
2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - Th[9])*dTh[7]*L[7] - \
2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + 2*dxL*sin(Th[9]))) + \
2*Cv*cos(Th[9])*(-(dxL*cos(Th[9])) + dTh[1]*L[1]*sin(Th[1] - Th[9]) + \
dTh[2]*L[2]*sin(Th[2] - Th[9]) + dTh[3]*L[3]*sin(Th[3] - Th[9]) + \
dTh[4]*L[4]*sin(Th[4] - Th[9]) + dTh[5]*L[5]*sin(Th[5] - Th[9]) + \
dTh[6]*L[6]*sin(Th[6] - Th[9]) + dTh[7]*L[7]*sin(Th[7] - Th[9]) + \
dTh[8]*L[8]*sin(Th[8] - Th[9]) - dyL*sin(Th[9]))))/2.;\n dragForce[18] = \
-(L[9]*(Cs*cos(Th[9])*(2*dyL*cos(Th[9]) + 2*cos(Th[1] - Th[9])*dTh[1]*L[1] + \
2*cos(Th[2] - Th[9])*dTh[2]*L[2] + 2*cos(Th[3] - Th[9])*dTh[3]*L[3] + \
2*cos(Th[4] - Th[9])*dTh[4]*L[4] + 2*cos(Th[5] - Th[9])*dTh[5]*L[5] + \
2*cos(Th[6] - Th[9])*dTh[6]*L[6] + 2*cos(Th[7] - Th[9])*dTh[7]*L[7] + \
2*cos(Th[8] - Th[9])*dTh[8]*L[8] + dTh[9]*L[9] - 2*dxL*sin(Th[9])) + \
2*Cv*sin(Th[9])*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - \
dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - \
dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - \
dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - \
dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))))/2.;\n dragForce[9] = \
(L[10]*(-(Cs*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10]))) + \
2*Cv*cos(Th[10])*(-(dxL*cos(Th[10])) + dTh[1]*L[1]*sin(Th[1] - Th[10]) + \
dTh[2]*L[2]*sin(Th[2] - Th[10]) + dTh[3]*L[3]*sin(Th[3] - Th[10]) + \
dTh[4]*L[4]*sin(Th[4] - Th[10]) + dTh[5]*L[5]*sin(Th[5] - Th[10]) + \
dTh[6]*L[6]*sin(Th[6] - Th[10]) + dTh[7]*L[7]*sin(Th[7] - Th[10]) + \
dTh[8]*L[8]*sin(Th[8] - Th[10]) + dTh[9]*L[9]*sin(Th[9] - Th[10]) - \
dyL*sin(Th[10]))))/2.;\n dragForce[19] = \
-(L[10]*(Cs*cos(Th[10])*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - \
Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - \
Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - \
Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - \
Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - \
Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])) + \
2*Cv*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - \
dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - \
dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - \
dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - \
dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + \
dyL*sin(Th[10]))))/2.;"\)], "Print"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1360}, {0, 564}},
WindowSize->{1264, 510},
WindowMargins->{{15, Automatic}, {Automatic, -12}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 5587, 110, 1177, "Input"],
Cell[7366, 165, 78, 1, 25, "Print"],
Cell[7447, 168, 34, 1, 25, "Print"],
Cell[7484, 171, 34, 1, 25, "Print"],
Cell[7521, 174, 34, 1, 25, "Print"],
Cell[7558, 177, 34, 1, 25, "Print"],
Cell[7595, 180, 34, 1, 25, "Print"],
Cell[7632, 183, 34, 1, 25, "Print"],
Cell[7669, 186, 34, 1, 25, "Print"],
Cell[7706, 189, 34, 1, 25, "Print"],
Cell[7743, 192, 34, 1, 25, "Print"],
Cell[7780, 195, 35, 1, 25, "Print"],
Cell[7818, 198, 57, 1, 25, "Print"],
Cell[7878, 201, 57, 1, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7972, 207, 3919, 80, 950, "Input"],
Cell[11894, 289, 343, 5, 22, "Message"],
Cell[12240, 296, 343, 5, 22, "Message"],
Cell[12586, 303, 343, 5, 22, "Message"],
Cell[12932, 310, 329, 5, 22, "Message"],
Cell[13264, 317, 342, 5, 22, "Message"],
Cell[13609, 324, 342, 5, 22, "Message"],
Cell[13954, 331, 342, 5, 22, "Message"],
Cell[14299, 338, 329, 5, 22, "Message"],
Cell[14631, 345, 344, 5, 22, "Message"],
Cell[14978, 352, 344, 5, 22, "Message"],
Cell[15325, 359, 344, 5, 22, "Message"],
Cell[15672, 366, 329, 5, 22, "Message"],
Cell[16004, 373, 2357, 34, 67, "Output"],
Cell[18364, 409, 3158, 82, 48, "Output"],
Cell[21525, 493, 168598, 2678, 305, "Output"],
Cell[190126, 3173, 34, 1, 25, "Print"],
Cell[190163, 3176, 34, 1, 25, "Print"],
Cell[190200, 3179, 34, 1, 25, "Print"],
Cell[190237, 3182, 34, 1, 25, "Print"],
Cell[190274, 3185, 34, 1, 25, "Print"],
Cell[190311, 3188, 34, 1, 25, "Print"],
Cell[190348, 3191, 34, 1, 25, "Print"],
Cell[190385, 3194, 34, 1, 25, "Print"],
Cell[190422, 3197, 34, 1, 25, "Print"],
Cell[190459, 3200, 35, 1, 25, "Print"],
Cell[190497, 3203, 58514, 792, 8974, "Print"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

