(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     71050,       1305]*)
(*NotebookOutlinePosition[     71695,       1327]*)
(*  CellTagsIndexPosition[     71651,       1323]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[{
    StyleBox[\(Print["\<Generalized coordinates and drag forces ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(n = 4;\), "\[IndentingNewLine]", 
    StyleBox[\(\[Mu] = 10\^\(-3\);\),
      FontColor->GrayLevel[0.666667]], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[\(reNo = 1.0;\),
        FontColor->GrayLevel[0.666667]], "\[IndentingNewLine]", 
      RowBox[{
        StyleBox["(*",
          FontColor->GrayLevel[0.666667]], 
        StyleBox[" ",
          FontColor->GrayLevel[0.666667]], 
        StyleBox[
          RowBox[{
            
            StyleBox[\(c\_S = \(4\ \[Pi]\ \[Mu]\)\/\(1\/2 - 0.577 - \
Log[reNo\/8]\)\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[";",
              FontColor->GrayLevel[0.666667]], "\[IndentingNewLine]", 
            StyleBox[\(c\_V\  = \(\[Mu]\ 2\ \[Pi]\ 0.1\)\/0.1\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[";",
              FontColor->GrayLevel[0.666667]]}],
          FontColor->GrayLevel[0.666667]], 
        StyleBox[" ",
          FontColor->GrayLevel[0.666667]], 
        StyleBox["*)",
          FontColor->GrayLevel[
          0.666667]]}]}], "\[IndentingNewLine]", \(w\_0 = {x\_L[t], 
          y\_L[t]};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"For", "[", 
        RowBox[{\(a = 1\), ",", \(a \[LessEqual] n\), ",", 
          "\[IndentingNewLine]", 
          RowBox[{\(Print[a]\), ";", "\[IndentingNewLine]", 
            RowBox[{
              StyleBox["(*",
                FontColor->GrayLevel[0.666667]], 
              StyleBox[" ",
                FontColor->GrayLevel[0.666667]], 
              
              StyleBox[\(\[Lambda]\_a = 1.0; \[IndentingNewLine]m\_a = 1.0;\),
                
                FontColor->GrayLevel[0.666667]], 
              StyleBox[" ",
                FontColor->GrayLevel[0.666667]], 
              StyleBox["*)",
                FontColor->GrayLevel[0.666667]]}], 
            "\[IndentingNewLine]", \(th\_a = \[Theta]\_a[t]\), ";", 
            "\[IndentingNewLine]", \(vec\_a = {Cos[th\_a], Sin[th\_a]}\), ";",
             "\[IndentingNewLine]", \(p\_a = 
              w\_\(a - 1\) + \[Lambda]\_a\/2\ vec\_a\), ";", 
            "\[IndentingNewLine]", \(w\_a = 
              w\_\(a - 1\) + \[Lambda]\_a\ vec\_a\), ";", 
            "\[IndentingNewLine]", \(v\_a = D[p\_a, t]\), ";", 
            "\[IndentingNewLine]", \(rotMat\_a = {{Cos[th\_a], 
                  Sin[th\_a]}, {\(-Sin[th\_a]\), Cos[th\_a]}}\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                For\ an\ infinidecimal\ point\ on\ segment\ a\ *) \),
              Background->GrayLevel[0.900008]], 
            "\[IndentingNewLine]", \(pPt\_a = 
              p\_a + s\ {Cos[th\_a], Sin[th\_a]}\), ";", 
            "\[IndentingNewLine]", \(vPt\_a = D[pPt\_a, t]\), ";", 
            "\[IndentingNewLine]", \(vPtLocal\_a = rotMat\_a . vPt\_a\), ";", 
            "\[IndentingNewLine]", \(fPtDrag\_a = 
              Inverse[rotMat\_a] . {\(-c\_V\)\ vPtLocal\_a[\([1]\)], \
\(-c\_S\)\ vPtLocal\_a[\([2]\)]}\), ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ Integrating\ *) \),
              Background->GrayLevel[0.900008]], 
            "\[IndentingNewLine]", \(fDrag\_a = 
              Simplify[
                Chop[Integrate[
                    fPtDrag\_a, {s, \(-\(\[Lambda]\_a\/2\)\), \
\[Lambda]\_a\/2}]]]\), ";", 
            "\[IndentingNewLine]", \(tauDrag\_a = 
              Simplify[
                Chop[Integrate[
                    s\ \((fPtDrag\_a[\([2]\)]\ Cos[th\_a] - 
                          fPtDrag\_a[\([1]\)]\ Sin[
                              th\_a])\), {s, \(-\(\[Lambda]\_a\/2\)\), \
\[Lambda]\_a\/2}]]]\), ";", "\[IndentingNewLine]", \(a++\)}]}], "]"}], 
      ";"}], "\[IndentingNewLine]", 
    StyleBox[\(Print["\<Kinetic Energy ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(ke = 
        Simplify[
          Chop[\[Sum]\+\(k = 1\)\%n\((1\/2\ m\_k\ \((v\_k . v\_k)\) + 
                  1\/2\ \(m\_k\ \[Lambda]\_k\^2\)\/12\ \((D[th\_k, \
t])\)\^2)\)]];\), "\[IndentingNewLine]", 
    StyleBox[\(Print["\<Generalized forces ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(q\_XL = {f\_LX[t], f\_LY[t]} . 
            D[w\_0, x\_L[t]] + \[Sum]\+\(k = 1\)\%n\((fDrag\_k . 
                D[p\_k, x\_L[t]])\) + {f\_RX[t], f\_RY[t]} . 
            D[w\_n, x\_L[t]];\), "\[IndentingNewLine]", \(q\_YL = {f\_LX[t], 
              f\_LY[t]} . 
            D[w\_0, y\_L[t]] + \[Sum]\+\(k = 1\)\%n\((fDrag\_k . 
                D[p\_k, y\_L[t]])\) + {f\_RX[t], f\_RY[t]} . 
            D[w\_n, y\_L[t]];\), "\[IndentingNewLine]", \(For[a = 1, 
      a \[LessEqual] 
        n, \[IndentingNewLine]q\_a = {f\_LX[t], f\_LY[t]} . 
            D[w\_0, \[Theta]\_a[t]] + \[Sum]\+\(k = 1\)\%n\((fDrag\_k . 
                D[p\_k, \[Theta]\_a[t]])\) + {f\_RX[t], f\_RY[t]} . 
            D[w\_n, \[Theta]\_a[t]] + 
          tauDrag\_a; \[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", \
\(q\_1 = q\_1 + \[Tau]\_L[t];\), "\[IndentingNewLine]", \(q\_n = 
        q\_n + \[Tau]\_R[t];\), "\[IndentingNewLine]", 
    StyleBox[\(Print["\<The LHS of the equations ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(Print[
        1];\), "\[IndentingNewLine]", \(eqLHS\_XL = 
        Simplify[
          Chop[D[D[ke, \(x\_L'\)[t]], t] - D[ke, x\_L[t]] - 
              q\_XL]];\), "\[IndentingNewLine]", \(Print[
        2];\), "\[IndentingNewLine]", \(eqLHS\_YL = 
        Simplify[
          Chop[D[D[ke, \(y\_L'\)[t]], t] - D[ke, y\_L[t]] - 
              q\_YL]];\), "\[IndentingNewLine]", \(For[a = 1, 
      a \[LessEqual] n, \[IndentingNewLine]Print[
        a + 2]; \[IndentingNewLine]eqLHS\_a = 
        Simplify[
          Chop[D[D[ke, \(\[Theta]\_a'\)[t]], t] - D[ke, \[Theta]\_a[t]] - 
              q\_a]]; \[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", 
    StyleBox[\(Print["\<The ODEs ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(varReplacement = 
        Table[Null, {n + 2}];\), "\n", \(varReplacement[\([1]\)] = \(x\_L'\)[
            t] \[Rule] 
          dx\_L[t];\), "\n", \(varReplacement[\([2]\)] = \(y\_L'\)[t] \[Rule] 
          dy\_L[t];\), "\n", \(For[a = 1, a \[LessEqual] n, 
        varReplacement[\([a + 2]\)] = \(\[Theta]\_a'\)[t] \[Rule] 
            d\[Theta]\_a[t]; \(a++\)];\), "\[IndentingNewLine]", \(varList = 
        Table[Null, {n + 2}];\), "\[IndentingNewLine]", \(varList[\([1]\)] = 
        x\_L[t];\), "\n", \(varList[\([2]\)] = y\_L[t];\), "\n", \(For[a = 1, 
        a \[LessEqual] n, 
        varList[\([a + 2]\)] = \[Theta]\_a[
            t]; \(a++\)];\), "\[IndentingNewLine]", \(mainEqns = 
        Table[Null, {n + 2}];\), "\[IndentingNewLine]", \(mainEqns[\([1]\)] = 
        eqLHS\_XL;\), "\[IndentingNewLine]", \(mainEqns[\([2]\)] = 
        eqLHS\_YL;\), "\[IndentingNewLine]", \(For[a = 1, a \[LessEqual] n, 
        mainEqns[\([a + 2]\)] = 
          eqLHS\_a; \(a++\)];\), "\[IndentingNewLine]", \(mainEqnsReplaced = 
        mainEqns\  /. \ 
          Join[D[varReplacement, t], 
            varReplacement];\), "\[IndentingNewLine]", \(mainDVars = 
        D[varList, t] /. 
          varReplacement;\), "\[IndentingNewLine]", \(primesZeroReplace = 
        Table[Null, {n + 2}];\), "\[IndentingNewLine]", 
    RowBox[{\(For[a = 1, 
        a \[LessEqual] n + 2, \[IndentingNewLine]primesZeroReplace[\([a]\)] = 
          D[mainDVars[\([a]\)], t] \[Rule] 0; \[IndentingNewLine]\(a++\)]\), 
      "\[IndentingNewLine]", 
      StyleBox[\( (*\ Computing\ the\ LHS\ matrix\ and\ the\ RHS\ *) \),
        Background->GrayLevel[0.900008]]}], "\[IndentingNewLine]", \(matLHS = 
        Table[Null, {n + 2}, {n + 2}];\), "\[IndentingNewLine]", \(vecRHS = 
        Table[Null, {n + 2}];\), "\[IndentingNewLine]", \(For[a = 1, 
      a \[LessEqual] n + 2, \[IndentingNewLine]Print[
        a]; \[IndentingNewLine]For[b = 1, 
        b \[LessEqual] n + 2, \[IndentingNewLine]matLHS[\([a, b]\)] = 
          Chop[FullSimplify[
              Chop[D[mainEqnsReplaced[\([a]\)], 
                  D[mainDVars[\([b]\)], 
                    t]]]]]; \[IndentingNewLine]\(b++\)]; \
\[IndentingNewLine]vecRHS[\([a]\)] = \(-Chop[
            FullSimplify[
              Chop[mainEqnsReplaced[\([a]\)]\  /. \ 
                  primesZeroReplace]]]\); \[IndentingNewLine]\(a++\)]\)}], \
"Input"],

Cell[BoxData[
    \("Generalized coordinates and drag forces ..."\)], "Print"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \("Kinetic Energy ..."\)], "Print"],

Cell[BoxData[
    \("Generalized forces ..."\)], "Print"],

Cell[BoxData[
    \("The LHS of the equations ..."\)], "Print"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"],

Cell[BoxData[
    \("The ODEs ..."\)], "Print"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cformVarReplace = 
        Table[Null, {4\ \((n + 2)\) + 2\ n + 
              8}];\)\), "\[IndentingNewLine]", 
    \(\(For[a = 1, 
        a \[LessEqual] n + 2, \[IndentingNewLine]cformVarReplace[\([a]\)] = 
          varList[\([a]\)] \[Rule] 
            v[\([a]\)]; \[IndentingNewLine]cformVarReplace[\([a + n + 
                2]\)] = \((D[varList[\([a]\)], t] /. 
                varReplacement)\) \[Rule] 
            v[\([a + n + 2]\)]; \[IndentingNewLine]cformVarReplace[\([a + 
                2\ \((n + 2)\)]\)] = 
          D[varList[\([a]\)], t] \[Rule] 
            dv[\([a]\)]; \[IndentingNewLine]cformVarReplace[\([a + 
                3\ \((n + 2)\)]\)] = 
          D[\((D[varList[\([a]\)], t] /. varReplacement)\), t] \[Rule] 
            dv[\([a + n + 
                  2]\)]; \[IndentingNewLine]\(a++\)];\)\), "\
\[IndentingNewLine]", 
    \(For[a = 1, 
      a \[LessEqual] 
        n, \[IndentingNewLine]cformVarReplace[\([a + 4\ \((n + 2)\)]\)] = 
        m\_a \[Rule] 
          M[\([a]\)]; \[IndentingNewLine]cformVarReplace[\([a + 
              4\ \((n + 2)\) + n]\)] = \[Lambda]\_a \[Rule] 
          L[\([a]\)]; \[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ \((n + 2)\) + 2\ n + 1]\)] = 
        c\_V \[Rule] Cv;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ \((n + 2)\) + 2\ n + 2]\)] = 
        c\_S \[Rule] Cs;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ \((n + 2)\) + 2\ n + 3]\)] = \[Tau]\_L[
            t] \[Rule] tauL;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ \((n + 2)\) + 2\ n + 4]\)] = 
        f\_LX[t] \[Rule] forceLX;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ \((n + 2)\) + 2\ n + 5]\)] = 
        f\_LY[t] \[Rule] forceLY;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ \((n + 2)\) + 2\ n + 6]\)] = \[Tau]\_R[
            t] \[Rule] tauR;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([4\ \((n + 2)\) + 2\ n + 7]\)] = 
        f\_RX[t] \[Rule] forceRX;\)\), "\n", 
    \(\(cformVarReplace[\([4\ \((n + 2)\) + 2\ n + 8]\)] = 
        f\_RY[t] \[Rule] forceRY;\)\), "\[IndentingNewLine]", 
    \(matLHS\  // \ MatrixForm\), "\n", 
    \(vecRHS\  // \ MatrixForm\), "\[IndentingNewLine]", 
    \(cformVarReplace\), "\[IndentingNewLine]", 
    \(\(outCString = "\<\>";\)\), "\[IndentingNewLine]", 
    \(For[a = 1, 
      a \[LessEqual] n + 2, \[IndentingNewLine]For[b = 1, 
        b \[LessEqual] n + 2, \[IndentingNewLine]outCString = 
          outCString <> "\<\n coefMat[\>" <> 
            ToString[CForm[\((b - 1)\)\ \((n + 2)\) + a - 1]] <> "\<] = \>" <> 
            ToString[
              CForm[matLHS[\([a, b]\)]\  /. \ 
                  cformVarReplace]] <> "\<;\>"; \[IndentingNewLine]\(b++\)]; \
\[IndentingNewLine]outCString = 
        outCString <> "\<\n rhsVec[\>" <> 
          ToString[CForm[a - 1]] <> "\<] = \>" <> 
          ToString[
            CForm[vecRHS[\([a]\)]\  /. \ 
                cformVarReplace]] <> "\<;\>"; \[IndentingNewLine]\(a++\)]\), \
"\[IndentingNewLine]", 
    \(\(outCString = 
        StringReplace[
          outCString, {"\<Cos\>" \[Rule] "\<cos\>", "\<Sin\>" \[Rule] \
"\<sin\>", "\<Tan\>" \[Rule] "\<tan\>", "\<Power\>" \[Rule] "\<pow\>"}];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[outCString];\)\), "\[IndentingNewLine]", 
    \(\(SetSystemOptions["\<BinaryFormat\>" -> True];\)\), "\n", 
    \(\(BinaryWrite["\<boom4.txt\>", 
        outCString];\)\), "\[IndentingNewLine]", 
    \(\(Close["\<boom4.txt\>"];\)\)}], "Input"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(v \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(v \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(v \[LeftDoubleBracket] 7 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Part :: \\\"partd\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(M \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(L \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(M \[LeftDoubleBracket] 2 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Part :: \\\"partd\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(forceLY\\)\\\" is similar to existing symbol \
\\\"\\!\\(forceLX\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(tauR\\)\\\" is similar to existing symbol \\\
\"\\!\\(tauL\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(forceRX\\)\\\" is similar to existing symbol \
\\\"\\!\\(forceLX\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"spell"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(forceRY\\)\\\" is similar to existing \
symbols \\!\\({forceLY, forceRX}\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\
\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(m\_1 + m\_2 + m\_3 + m\_4\), 
              "0", \(\(-\(1\/2\)\)\ Sin[\[Theta]\_1[t]]\ \((m\_1 + 
                    2\ \((m\_2 + m\_3 + 
                          m\_4)\))\)\ \[Lambda]\_1\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_2[t]]\ \((m\_2 + 
                    2\ \((m\_3 + 
                          m\_4)\))\)\ \[Lambda]\_2\), \(\(-\(1\/2\)\)\ Sin[\
\[Theta]\_3[t]]\ \((m\_3 + 
                    2\ m\_4)\)\ \[Lambda]\_3\), \(\(-\(1\/2\)\)\ Sin[\[Theta]\
\_4[t]]\ m\_4\ \[Lambda]\_4\)},
            {
              "0", \(m\_1 + m\_2 + m\_3 + 
                m\_4\), \(1\/2\ Cos[\[Theta]\_1[t]]\ \((m\_1 + 
                    2\ \((m\_2 + m\_3 + 
                          m\_4)\))\)\ \[Lambda]\_1\), \(1\/2\ Cos[\[Theta]\_2[
                    t]]\ \((m\_2 + 
                    2\ \((m\_3 + 
                          m\_4)\))\)\ \[Lambda]\_2\), \(1\/2\ Cos[\[Theta]\_3[
                    t]]\ \((m\_3 + 
                    2\ m\_4)\)\ \[Lambda]\_3\), \(1\/2\ Cos[\[Theta]\_4[
                    t]]\ m\_4\ \[Lambda]\_4\)},
            {\(\(-\(1\/2\)\)\ Sin[\[Theta]\_1[t]]\ \((m\_1 + 
                    2\ \((m\_2 + m\_3 + 
                          m\_4)\))\)\ \[Lambda]\_1\), \(1\/2\ Cos[\[Theta]\_1[
                    t]]\ \((m\_1 + 
                    2\ \((m\_2 + m\_3 + 
                          m\_4)\))\)\ \[Lambda]\_1\), \(1\/3\ \((m\_1 + 
                    3\ \((m\_2 + m\_3 + 
                          m\_4)\))\)\ \[Lambda]\_1\%2\), \(1\/2\ Cos[\[Theta]\
\_1[t] - \[Theta]\_2[t]]\ \((m\_2 + 
                    2\ \((m\_3 + 
                          m\_4)\))\)\ \[Lambda]\_1\ \[Lambda]\_2\), \(1\/2\ \
Cos[\[Theta]\_1[t] - \[Theta]\_3[t]]\ \((m\_3 + 
                    2\ m\_4)\)\ \[Lambda]\_1\ \[Lambda]\_3\), \(1\/2\ Cos[\
\[Theta]\_1[t] - \[Theta]\_4[t]]\ m\_4\ \[Lambda]\_1\ \[Lambda]\_4\)},
            {\(\(-\(1\/2\)\)\ Sin[\[Theta]\_2[t]]\ \((m\_2 + 
                    2\ \((m\_3 + 
                          m\_4)\))\)\ \[Lambda]\_2\), \(1\/2\ Cos[\[Theta]\_2[
                    t]]\ \((m\_2 + 
                    2\ \((m\_3 + 
                          m\_4)\))\)\ \[Lambda]\_2\), \(1\/2\ Cos[\[Theta]\_1[
                      t] - \[Theta]\_2[t]]\ \((m\_2 + 
                    2\ \((m\_3 + 
                          m\_4)\))\)\ \[Lambda]\_1\ \[Lambda]\_2\), \(1\/3\ \
\((m\_2 + 3\ \((m\_3 + m\_4)\))\)\ \[Lambda]\_2\%2\), \(1\/2\ Cos[\[Theta]\_2[
                      t] - \[Theta]\_3[t]]\ \((m\_3 + 
                    2\ m\_4)\)\ \[Lambda]\_2\ \[Lambda]\_3\), \(1\/2\ Cos[\
\[Theta]\_2[t] - \[Theta]\_4[t]]\ m\_4\ \[Lambda]\_2\ \[Lambda]\_4\)},
            {\(\(-\(1\/2\)\)\ Sin[\[Theta]\_3[t]]\ \((m\_3 + 
                    2\ m\_4)\)\ \[Lambda]\_3\), \(1\/2\ Cos[\[Theta]\_3[
                    t]]\ \((m\_3 + 
                    2\ m\_4)\)\ \[Lambda]\_3\), \(1\/2\ Cos[\[Theta]\_1[
                      t] - \[Theta]\_3[t]]\ \((m\_3 + 
                    2\ m\_4)\)\ \[Lambda]\_1\ \[Lambda]\_3\), \(1\/2\ Cos[\
\[Theta]\_2[t] - \[Theta]\_3[t]]\ \((m\_3 + 
                    2\ m\_4)\)\ \[Lambda]\_2\ \[Lambda]\_3\), \(1\/3\ \((m\_3 \
+ 3\ m\_4)\)\ \[Lambda]\_3\%2\), \(1\/2\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                      t]]\ m\_4\ \[Lambda]\_3\ \[Lambda]\_4\)},
            {\(\(-\(1\/2\)\)\ Sin[\[Theta]\_4[
                    t]]\ m\_4\ \[Lambda]\_4\), \(1\/2\ Cos[\[Theta]\_4[
                    t]]\ m\_4\ \[Lambda]\_4\), \(1\/2\ Cos[\[Theta]\_1[
                      t] - \[Theta]\_4[
                      t]]\ m\_4\ \[Lambda]\_1\ \[Lambda]\_4\), \(1\/2\ Cos[\
\[Theta]\_2[t] - \[Theta]\_4[
                      t]]\ m\_4\ \[Lambda]\_2\ \[Lambda]\_4\), \(1\/2\ Cos[\
\[Theta]\_3[t] - \[Theta]\_4[
                      t]]\ m\_4\ \[Lambda]\_3\ \[Lambda]\_4\), \(1\/3\ m\_4\ \
\[Lambda]\_4\%2\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", 
        TagBox[GridBox[{
              {\(1\/2\ \((Cos[\[Theta]\_1[
                            t]]\ m\_1\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 + \
\[Lambda]\_1\ \((Cos[2\ \[Theta]\_1[t]]\ \((c\_S - c\_V)\)\ dx\_L[
                                t] - \((c\_S + c\_V)\)\ dx\_L[t] + 
                            Sin[2\ \[Theta]\_1[t]]\ \((c\_S - c\_V)\)\ dy\_L[
                                t] + Sin[\[Theta]\_1[
                                  t]]\ c\_S\ \[Lambda]\_1\ d\[Theta]\_1[
                                t])\) + 
                      m\_2\ \((2\ Cos[\[Theta]\_1[
                                  t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 + 
                            Cos[\[Theta]\_2[
                                  t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2)\) + \
\[Lambda]\_2\ \((\(-2\)\ Cos[\[Theta]\_2[
                                  t]]\ c\_V\ \((Cos[\[Theta]\_2[t]]\ dx\_L[
                                      t] + Sin[\[Theta]\_2[t]]\ dy\_L[t] - 
                                  Sin[\[Theta]\_1[t] - \[Theta]\_2[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                      t])\) + 
                            Sin[\[Theta]\_2[
                                  t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_2[
                                        t]]\ dx\_L[t] + 
                                  2\ Cos[\[Theta]\_2[t]]\ dy\_L[t] + 
                                  2\ Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                      t] + \[Lambda]\_2\ d\[Theta]\_2[
                                      t])\))\) + 
                      m\_3\ \((2\ Cos[\[Theta]\_1[
                                  t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 + 
                            2\ Cos[\[Theta]\_2[
                                  t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 + 
                            Cos[\[Theta]\_3[
                                  t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\) + \
\[Lambda]\_3\ \((2\ Cos[\[Theta]\_3[
                                  t]]\ c\_V\ \((\(-Cos[\[Theta]\_3[
                                        t]]\)\ dx\_L[t] - 
                                  Sin[\[Theta]\_3[t]]\ dy\_L[t] + 
                                  Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                                  Sin[\[Theta]\_2[t] - \[Theta]\_3[
                                        t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                      t])\) + 
                            Sin[\[Theta]\_3[
                                  t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_3[
                                        t]]\ dx\_L[t] + 
                                  2\ Cos[\[Theta]\_3[t]]\ dy\_L[t] + 
                                  2\ Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                                  2\ Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                        t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                      t] + \[Lambda]\_3\ d\[Theta]\_3[
                                      t])\))\) + 
                      m\_4\ \((2\ Cos[\[Theta]\_1[
                                  t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 + 
                            2\ Cos[\[Theta]\_2[
                                  t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 + 
                            2\ Cos[\[Theta]\_3[
                                  t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 + 
                            Cos[\[Theta]\_4[
                                  t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\) + \
\[Lambda]\_4\ \((2\ Cos[\[Theta]\_4[
                                  t]]\ c\_V\ \((\(-Cos[\[Theta]\_4[
                                        t]]\)\ dx\_L[t] - 
                                  Sin[\[Theta]\_4[t]]\ dy\_L[t] + 
                                  Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                                  Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                                  Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                      t])\) + 
                            Sin[\[Theta]\_4[
                                  t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_4[
                                        t]]\ dx\_L[t] + 
                                  2\ \((Cos[\[Theta]\_4[t]]\ dy\_L[t] + 
                                        Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                                        Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                                        Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                        t])\) + \[Lambda]\_4\ d\[Theta]\_4[
                                      t])\))\) + 2\ f\_LX[t] + 
                      2\ f\_RX[t])\)\)},
              {\(1\/2\ \((Sin[\[Theta]\_1[
                            t]]\ m\_1\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - \
\[Lambda]\_1\ \((c\_V\ \((Sin[2\ \[Theta]\_1[t]]\ dx\_L[t] + 
                                  2\ Sin[\[Theta]\_1[t]]\^2\ dy\_L[t])\) + 
                            Cos[\[Theta]\_1[
                                  t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_1[
                                        t]]\ dx\_L[t] + 
                                  2\ Cos[\[Theta]\_1[t]]\ dy\_L[
                                      t] + \[Lambda]\_1\ d\[Theta]\_1[
                                      t])\))\) + 
                      m\_2\ \((2\ Sin[\[Theta]\_1[
                                  t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 + 
                            Sin[\[Theta]\_2[
                                  t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2)\) - \
\[Lambda]\_2\ \((2\ Sin[\[Theta]\_2[
                                  t]]\ c\_V\ \((Cos[\[Theta]\_2[t]]\ dx\_L[
                                      t] + Sin[\[Theta]\_2[t]]\ dy\_L[t] - 
                                  Sin[\[Theta]\_1[t] - \[Theta]\_2[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                      t])\) + 
                            Cos[\[Theta]\_2[
                                  t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_2[
                                        t]]\ dx\_L[t] + 
                                  2\ Cos[\[Theta]\_2[t]]\ dy\_L[t] + 
                                  2\ Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                      t] + \[Lambda]\_2\ d\[Theta]\_2[
                                      t])\))\) + 
                      m\_3\ \((2\ Sin[\[Theta]\_1[
                                  t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 + 
                            2\ Sin[\[Theta]\_2[
                                  t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 + 
                            Sin[\[Theta]\_3[
                                  t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2)\) - \
\[Lambda]\_3\ \((2\ Sin[\[Theta]\_3[
                                  t]]\ c\_V\ \((Cos[\[Theta]\_3[t]]\ dx\_L[
                                      t] + Sin[\[Theta]\_3[t]]\ dy\_L[t] - 
                                  Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                                  Sin[\[Theta]\_2[t] - \[Theta]\_3[
                                        t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                      t])\) + 
                            Cos[\[Theta]\_3[
                                  t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_3[
                                        t]]\ dx\_L[t] + 
                                  2\ Cos[\[Theta]\_3[t]]\ dy\_L[t] + 
                                  2\ Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                                  2\ Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                        t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                      t] + \[Lambda]\_3\ d\[Theta]\_3[
                                      t])\))\) + 
                      m\_4\ \((2\ Sin[\[Theta]\_1[
                                  t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 + 
                            2\ Sin[\[Theta]\_2[
                                  t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 + 
                            2\ Sin[\[Theta]\_3[
                                  t]]\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 + 
                            Sin[\[Theta]\_4[
                                  t]]\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2)\) - \
\[Lambda]\_4\ \((2\ Sin[\[Theta]\_4[
                                  t]]\ c\_V\ \((Cos[\[Theta]\_4[t]]\ dx\_L[
                                      t] + Sin[\[Theta]\_4[t]]\ dy\_L[t] - 
                                  Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                                  Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] - 
                                  Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                      t])\) + 
                            Cos[\[Theta]\_4[
                                  t]]\ c\_S\ \((\(-2\)\ Sin[\[Theta]\_4[
                                        t]]\ dx\_L[t] + 
                                  2\ \((Cos[\[Theta]\_4[t]]\ dy\_L[t] + 
                                        Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                                        Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                                        Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                        t])\) + \[Lambda]\_4\ d\[Theta]\_4[
                                      t])\))\) + 2\ f\_LY[t] + 
                      2\ f\_RY[t])\)\)},
              {\(\(-\(1\/6\)\)\ \[Lambda]\_1\ \((c\_S\ \((2\ \[Lambda]\_1\%2\ \
d\[Theta]\_1[t] + 3\ \[Lambda]\_1\ \((\(-Sin[\[Theta]\_1[t]]\)\ dx\_L[t] + 
                                    Cos[\[Theta]\_1[t]]\ dy\_L[t] + 
                                    2\ \((Cos[\[Theta]\_1[t] - \
\[Theta]\_2[t]]\^2\ \[Lambda]\_2 + 
                                        Cos[\[Theta]\_1[t] - \
\[Theta]\_3[t]]\^2\ \[Lambda]\_3 + 
                                        Cos[\[Theta]\_1[t] - \
\[Theta]\_4[t]]\^2\ \[Lambda]\_4)\)\ d\[Theta]\_1[t])\) + 
                              3\ \((Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                        t]]\ \[Lambda]\_2\%2\ d\[Theta]\_2[
                                        t] + 
                                    2\ \[Lambda]\_2\ \((Cos[\[Theta]\_1[
                                        t] - \[Theta]\_2[
                                        t]]\ \((\(-Sin[\[Theta]\_2[
                                        t]]\)\ dx\_L[t] + 
                                        Cos[\[Theta]\_2[t]]\ dy\_L[
                                        t])\) + \((Cos[\[Theta]\_1[
                                        t] - \[Theta]\_3[t]]\ Cos[\[Theta]\_2[
                                        t] - \[Theta]\_3[t]]\ \[Lambda]\_3 + 
                                        Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                        t]]\ Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_4)\)\ d\[Theta]\_2[
                                        t])\) + 
                                    Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                        t]]\ \[Lambda]\_3\%2\ d\[Theta]\_3[
                                        t] + 
                                    2\ \[Lambda]\_3\ \((Cos[\[Theta]\_1[
                                        t] - \[Theta]\_3[
                                        t]]\ \((\(-Sin[\[Theta]\_3[
                                        t]]\)\ dx\_L[t] + 
                                        Cos[\[Theta]\_3[t]]\ dy\_L[t])\) + 
                                        Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                        t]]\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_4\ d\[Theta]\_3[
                                        t])\) + 
                                    Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_4\ \((\(-2\)\ Sin[\
\[Theta]\_4[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_4[t]]\ dy\_L[
                                        t] + \[Lambda]\_4\ d\[Theta]\_4[
                                        t])\))\))\) + 
                        3\ \((Sin[\[Theta]\_1[t] - \[Theta]\_2[
                                      t]]\ m\_2\ \[Lambda]\_2\ \
d\[Theta]\_2[t]\^2 + 2\ Sin[\[Theta]\_1[t] - \[Theta]\_2[
                                      t]]\ m\_3\ \[Lambda]\_2\ \
d\[Theta]\_2[t]\^2 + 2\ Sin[\[Theta]\_1[t] - \[Theta]\_2[
                                      t]]\ m\_4\ \[Lambda]\_2\ \
d\[Theta]\_2[t]\^2 + Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                      t]]\ m\_3\ \[Lambda]\_3\ \
d\[Theta]\_3[t]\^2 + 2\ Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                      t]]\ m\_4\ \[Lambda]\_3\ \
d\[Theta]\_3[t]\^2 - 2\ c\_V\ \((Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_4\ \((Cos[\[Theta]\_4[
                                        t]]\ dx\_L[t] + 
                                        Sin[\[Theta]\_4[t]]\ dy\_L[t] - 
                                        Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                        t])\) + \[Lambda]\_2\ \((Sin[\[Theta]\
\_1[t] - \[Theta]\_2[t]]\ \((Cos[\[Theta]\_2[t]]\ dx\_L[t] + 
                                        Sin[\[Theta]\_2[t]]\ dy\_L[t] - 
                                        Sin[\[Theta]\_1[t] - \[Theta]\_2[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                        t])\) - \((Sin[\[Theta]\_1[
                                        t] - \[Theta]\_3[t]]\ Sin[\[Theta]\_2[
                                        t] - \[Theta]\_3[t]]\ \[Lambda]\_3 + 
                                        Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                        t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_4)\)\ d\[Theta]\_2[
                                        t])\) + \[Lambda]\_3\ \((Sin[\[Theta]\
\_1[t] - \[Theta]\_3[t]]\ \((Cos[\[Theta]\_3[t]]\ dx\_L[t] + 
                                        Sin[\[Theta]\_3[t]]\ dy\_L[t] - 
                                        Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                        t])\) - 
                                        Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                        t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_4\ d\[Theta]\_3[
                                        t])\))\) + 
                              Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                      t]]\ m\_4\ \[Lambda]\_4\ \
d\[Theta]\_4[t]\^2 + 2\ Sin[\[Theta]\_1[t]]\ f\_RX[t] - 
                              2\ Cos[\[Theta]\_1[t]]\ f\_RY[
                                  t])\))\) + \[Tau]\_L[t]\)},
              {\(\(-\(1\/6\)\)\ \[Lambda]\_2\ \((\(-3\)\ Sin[\[Theta]\_1[
                              t] - \[Theta]\_2[
                              t]]\ m\_2\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                      6\ Sin[\[Theta]\_1[t] - \[Theta]\_2[
                              t]]\ m\_3\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 - 
                      6\ Sin[\[Theta]\_1[t] - \[Theta]\_2[
                              t]]\ m\_4\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 + 
                      3\ Sin[\[Theta]\_2[t] - \[Theta]\_3[
                              t]]\ m\_3\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 + 
                      6\ Sin[\[Theta]\_2[t] - \[Theta]\_3[
                              t]]\ m\_4\ \[Lambda]\_3\ d\[Theta]\_3[t]\^2 - 
                      6\ c\_V\ \((Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ \((Cos[\[Theta]\_4[
                                        t]]\ dx\_L[t] + 
                                  Sin[\[Theta]\_4[t]]\ dy\_L[t] - 
                                  Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                                  Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                      t])\) + \[Lambda]\_3\ \
\((Sin[\[Theta]\_2[t] - \[Theta]\_3[t]]\ \((Cos[\[Theta]\_3[t]]\ dx\_L[t] + 
                                        Sin[\[Theta]\_3[t]]\ dy\_L[t] - 
                                        Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] - 
                                        Sin[\[Theta]\_2[t] - \[Theta]\_3[
                                        t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                        t])\) - 
                                  Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                        t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_4\ d\[Theta]\_3[
                                      t])\))\) + 
                      3\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                              t]]\ m\_4\ \[Lambda]\_4\ d\[Theta]\_4[t]\^2 + 
                      c\_S\ \((2\ \[Lambda]\_2\%2\ d\[Theta]\_2[t] + 
                            3\ \[Lambda]\_2\ \((\(-Sin[\[Theta]\_2[
                                        t]]\)\ dx\_L[t] + 
                                  Cos[\[Theta]\_2[t]]\ dy\_L[t] + 
                                  Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                                  2\ \((Cos[\[Theta]\_2[t] - \
\[Theta]\_3[t]]\^2\ \[Lambda]\_3 + 
                                        Cos[\[Theta]\_2[t] - \
\[Theta]\_4[t]]\^2\ \[Lambda]\_4)\)\ d\[Theta]\_2[t])\) + 
                            3\ Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                    t]]\ \[Lambda]\_3\%2\ d\[Theta]\_3[t] + 
                            6\ \[Lambda]\_3\ \((Cos[\[Theta]\_2[
                                        t] - \[Theta]\_3[
                                        t]]\ \((\(-Sin[\[Theta]\_3[
                                        t]]\)\ dx\_L[t] + 
                                        Cos[\[Theta]\_3[t]]\ dy\_L[t] + 
                                        Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                        t])\) + 
                                  Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                        t]]\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_4\ d\[Theta]\_3[
                                      t])\) + 
                            3\ Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ \((\(-2\)\ \
Sin[\[Theta]\_4[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_4[t]]\ dy\_L[t] + 
                                  2\ Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[
                                      t] + \[Lambda]\_4\ d\[Theta]\_4[
                                      t])\))\) + 
                      6\ Sin[\[Theta]\_2[t]]\ f\_RX[t] - 
                      6\ Cos[\[Theta]\_2[t]]\ f\_RY[t])\)\)},
              {\(\(-\(1\/6\)\)\ \[Lambda]\_3\ \((c\_S\ \((2\ \[Lambda]\_3\%2\ \
d\[Theta]\_3[t] + 3\ \[Lambda]\_3\ \((\(-Sin[\[Theta]\_3[t]]\)\ dx\_L[t] + 
                                  Cos[\[Theta]\_3[t]]\ dy\_L[t] + 
                                  Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                                  Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                        t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                                  2\ Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\^2\ \
\[Lambda]\_4\ d\[Theta]\_3[t])\) + 
                            3\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                    t]]\ \[Lambda]\_4\ \((\(-2\)\ \
Sin[\[Theta]\_4[t]]\ dx\_L[t] + 2\ Cos[\[Theta]\_4[t]]\ dy\_L[t] + 
                                  2\ Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                                  2\ Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_2\ d\[Theta]\_2[
                                      t] + \[Lambda]\_4\ d\[Theta]\_4[
                                      t])\))\) - 
                      3\ \((\((m\_3 + 
                                  2\ m\_4)\)\ \((Sin[\[Theta]\_1[
                                        t] - \[Theta]\_3[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
+ Sin[\[Theta]\_2[t] - \[Theta]\_3[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2)\) - 
                            2\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                    t]]\ c\_V\ \[Lambda]\_4\ \((\(-Cos[\
\[Theta]\_4[t]]\)\ dx\_L[t] - Sin[\[Theta]\_4[t]]\ dy\_L[t] + 
                                  Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                                  Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                                  Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                      t])\) - 
                            Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                    t]]\ m\_4\ \[Lambda]\_4\ \
d\[Theta]\_4[t]\^2 - 2\ Sin[\[Theta]\_3[t]]\ f\_RX[t] + 
                            2\ Cos[\[Theta]\_3[t]]\ f\_RY[t])\))\)\)},
              {\(1\/6\ \((\(-c\_S\)\ \[Lambda]\_4\%2\ \((\(-3\)\ Sin[\[Theta]\
\_4[t]]\ dx\_L[t] + 3\ \((Cos[\[Theta]\_4[t]]\ dy\_L[t] + 
                                  Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t] + 
                                  Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_2\ d\[Theta]\_2[t] + 
                                  Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_3\ d\[Theta]\_3[
                                      t])\) + 
                            2\ \[Lambda]\_4\ d\[Theta]\_4[t])\) + 
                      3\ \[Lambda]\_4\ \((m\_4\ \((Sin[\[Theta]\_1[
                                        t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_1\ d\[Theta]\_1[t]\^2 \
+ Sin[\[Theta]\_2[t] - \[Theta]\_4[t]]\ \[Lambda]\_2\ d\[Theta]\_2[t]\^2 + 
                                  Sin[\[Theta]\_3[t] - \[Theta]\_4[
                                        t]]\ \[Lambda]\_3\ \
d\[Theta]\_3[t]\^2)\) - 2\ Sin[\[Theta]\_4[t]]\ f\_RX[t] + 
                            2\ Cos[\[Theta]\_4[t]]\ f\_RY[t])\) + 
                      6\ \[Tau]\_R[t])\)\)}
              },
            RowSpacings->1,
            ColumnAlignments->{Left}],
          Column], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(x\_L[t] \[Rule] v\[LeftDoubleBracket]1\[RightDoubleBracket]\),
         ",", \(y\_L[t] \[Rule] v\[LeftDoubleBracket]2\[RightDoubleBracket]\),
         ",", \(\[Theta]\_1[t] \[Rule] 
          v\[LeftDoubleBracket]3\[RightDoubleBracket]\), 
        ",", \(\[Theta]\_2[t] \[Rule] 
          v\[LeftDoubleBracket]4\[RightDoubleBracket]\), 
        ",", \(\[Theta]\_3[t] \[Rule] 
          v\[LeftDoubleBracket]5\[RightDoubleBracket]\), 
        ",", \(\[Theta]\_4[t] \[Rule] 
          v\[LeftDoubleBracket]6\[RightDoubleBracket]\), 
        ",", \(dx\_L[t] \[Rule] v\[LeftDoubleBracket]7\[RightDoubleBracket]\),
         ",", \(dy\_L[t] \[Rule] 
          v\[LeftDoubleBracket]8\[RightDoubleBracket]\), 
        ",", \(d\[Theta]\_1[t] \[Rule] 
          v\[LeftDoubleBracket]9\[RightDoubleBracket]\), 
        ",", \(d\[Theta]\_2[t] \[Rule] 
          v\[LeftDoubleBracket]10\[RightDoubleBracket]\), 
        ",", \(d\[Theta]\_3[t] \[Rule] 
          v\[LeftDoubleBracket]11\[RightDoubleBracket]\), 
        ",", \(d\[Theta]\_4[t] \[Rule] 
          v\[LeftDoubleBracket]12\[RightDoubleBracket]\), ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox[\(x\_L\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]1\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(y\_L\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]2\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_1\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]3\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_2\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]4\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_3\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]5\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_4\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]6\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(dx\_L\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]7\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(dy\_L\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]8\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(d\[Theta]\_1\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]9\[RightDoubleBracket]\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox[\(d\[Theta]\_2\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]10\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(d\[Theta]\_3\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]11\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(d\[Theta]\_4\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dv\[LeftDoubleBracket]12\[RightDoubleBracket]\)}], 
        ",", \(m\_1 \[Rule] M\[LeftDoubleBracket]1\[RightDoubleBracket]\), 
        ",", \(m\_2 \[Rule] M\[LeftDoubleBracket]2\[RightDoubleBracket]\), 
        ",", \(m\_3 \[Rule] M\[LeftDoubleBracket]3\[RightDoubleBracket]\), 
        ",", \(m\_4 \[Rule] M\[LeftDoubleBracket]4\[RightDoubleBracket]\), 
        ",", \(\[Lambda]\_1 \[Rule] 
          L\[LeftDoubleBracket]1\[RightDoubleBracket]\), 
        ",", \(\[Lambda]\_2 \[Rule] 
          L\[LeftDoubleBracket]2\[RightDoubleBracket]\), 
        ",", \(\[Lambda]\_3 \[Rule] 
          L\[LeftDoubleBracket]3\[RightDoubleBracket]\), 
        ",", \(\[Lambda]\_4 \[Rule] 
          L\[LeftDoubleBracket]4\[RightDoubleBracket]\), 
        ",", \(c\_V \[Rule] Cv\), ",", \(c\_S \[Rule] Cs\), 
        ",", \(\[Tau]\_L[t] \[Rule] tauL\), ",", \(f\_LX[t] \[Rule] forceLX\),
         ",", \(f\_LY[t] \[Rule] forceLY\), 
        ",", \(\[Tau]\_R[t] \[Rule] tauR\), ",", \(f\_RX[t] \[Rule] forceRX\),
         ",", \(f\_RY[t] \[Rule] forceRY\)}], "}"}]], "Output"],

Cell[BoxData[
    \("\n coefMat[0] = M[1] + M[2] + M[3] + M[4];\n coefMat[6] = 0;\n \
coefMat[12] = -(L[1]*(M[1] + 2*(M[2] + M[3] + M[4]))*sin(v[3]))/2.;\n \
coefMat[18] = -(L[2]*(M[2] + 2*(M[3] + M[4]))*sin(v[4]))/2.;\n coefMat[24] = \
-(L[3]*(M[3] + 2*M[4])*sin(v[5]))/2.;\n coefMat[30] = \
-(L[4]*M[4]*sin(v[6]))/2.;\n rhsVec[0] = (2*forceLX + 2*forceRX + \
cos(v[3])*L[1]*M[1]*pow(v[9],2) + M[2]*(2*cos(v[3])*L[1]*pow(v[9],2) + \
cos(v[4])*L[2]*pow(v[10],2)) + M[3]*(2*cos(v[3])*L[1]*pow(v[9],2) + \
2*cos(v[4])*L[2]*pow(v[10],2) + cos(v[5])*L[3]*pow(v[11],2)) + \
M[4]*(2*cos(v[3])*L[1]*pow(v[9],2) + 2*cos(v[4])*L[2]*pow(v[10],2) + \
2*cos(v[5])*L[3]*pow(v[11],2) + cos(v[6])*L[4]*pow(v[12],2)) + L[1]*(-((Cs + \
Cv)*v[7]) + (Cs - Cv)*cos(2*v[3])*v[7] + Cs*L[1]*v[9]*sin(v[3]) + (Cs - \
Cv)*v[8]*sin(2*v[3])) + L[2]*(Cs*sin(v[4])*(2*cos(v[4])*v[8] + 2*cos(v[3] - \
v[4])*L[1]*v[9] + L[2]*v[10] - 2*v[7]*sin(v[4])) - \
2*Cv*cos(v[4])*(cos(v[4])*v[7] - L[1]*v[9]*sin(v[3] - v[4]) + \
v[8]*sin(v[4]))) + L[3]*(Cs*sin(v[5])*(2*cos(v[5])*v[8] + 2*cos(v[3] - \
v[5])*L[1]*v[9] + 2*cos(v[4] - v[5])*L[2]*v[10] + L[3]*v[11] - \
2*v[7]*sin(v[5])) + 2*Cv*cos(v[5])*(-(cos(v[5])*v[7]) + L[1]*v[9]*sin(v[3] - \
v[5]) + L[2]*v[10]*sin(v[4] - v[5]) - v[8]*sin(v[5]))) + \
L[4]*(Cs*sin(v[6])*(2*(cos(v[6])*v[8] + cos(v[3] - v[6])*L[1]*v[9] + cos(v[4] \
- v[6])*L[2]*v[10] + cos(v[5] - v[6])*L[3]*v[11]) + L[4]*v[12] - \
2*v[7]*sin(v[6])) + 2*Cv*cos(v[6])*(-(cos(v[6])*v[7]) + L[1]*v[9]*sin(v[3] - \
v[6]) + L[2]*v[10]*sin(v[4] - v[6]) + L[3]*v[11]*sin(v[5] - v[6]) - \
v[8]*sin(v[6]))))/2.;\n coefMat[1] = 0;\n coefMat[7] = M[1] + M[2] + M[3] + \
M[4];\n coefMat[13] = (cos(v[3])*L[1]*(M[1] + 2*(M[2] + M[3] + M[4])))/2.;\n \
coefMat[19] = (cos(v[4])*L[2]*(M[2] + 2*(M[3] + M[4])))/2.;\n coefMat[25] = \
(cos(v[5])*L[3]*(M[3] + 2*M[4]))/2.;\n coefMat[31] = \
(cos(v[6])*L[4]*M[4])/2.;\n rhsVec[1] = (2*forceLY + 2*forceRY + \
L[1]*M[1]*pow(v[9],2)*sin(v[3]) - L[1]*(Cs*cos(v[3])*(2*cos(v[3])*v[8] + \
L[1]*v[9] - 2*v[7]*sin(v[3])) + Cv*(2*v[8]*pow(sin(v[3]),2) + \
v[7]*sin(2*v[3]))) + M[2]*(2*L[1]*pow(v[9],2)*sin(v[3]) + \
L[2]*pow(v[10],2)*sin(v[4])) - L[2]*(Cs*cos(v[4])*(2*cos(v[4])*v[8] + \
2*cos(v[3] - v[4])*L[1]*v[9] + L[2]*v[10] - 2*v[7]*sin(v[4])) + \
2*Cv*sin(v[4])*(cos(v[4])*v[7] - L[1]*v[9]*sin(v[3] - v[4]) + \
v[8]*sin(v[4]))) + M[3]*(2*L[1]*pow(v[9],2)*sin(v[3]) + \
2*L[2]*pow(v[10],2)*sin(v[4]) + L[3]*pow(v[11],2)*sin(v[5])) - \
L[3]*(Cs*cos(v[5])*(2*cos(v[5])*v[8] + 2*cos(v[3] - v[5])*L[1]*v[9] + \
2*cos(v[4] - v[5])*L[2]*v[10] + L[3]*v[11] - 2*v[7]*sin(v[5])) + \
2*Cv*sin(v[5])*(cos(v[5])*v[7] - L[1]*v[9]*sin(v[3] - v[5]) - \
L[2]*v[10]*sin(v[4] - v[5]) + v[8]*sin(v[5]))) + \
M[4]*(2*L[1]*pow(v[9],2)*sin(v[3]) + 2*L[2]*pow(v[10],2)*sin(v[4]) + \
2*L[3]*pow(v[11],2)*sin(v[5]) + L[4]*pow(v[12],2)*sin(v[6])) - \
L[4]*(Cs*cos(v[6])*(2*(cos(v[6])*v[8] + cos(v[3] - v[6])*L[1]*v[9] + cos(v[4] \
- v[6])*L[2]*v[10] + cos(v[5] - v[6])*L[3]*v[11]) + L[4]*v[12] - \
2*v[7]*sin(v[6])) + 2*Cv*sin(v[6])*(cos(v[6])*v[7] - L[1]*v[9]*sin(v[3] - \
v[6]) - L[2]*v[10]*sin(v[4] - v[6]) - L[3]*v[11]*sin(v[5] - v[6]) + \
v[8]*sin(v[6]))))/2.;\n coefMat[2] = -(L[1]*(M[1] + 2*(M[2] + M[3] + \
M[4]))*sin(v[3]))/2.;\n coefMat[8] = (cos(v[3])*L[1]*(M[1] + 2*(M[2] + M[3] + \
M[4])))/2.;\n coefMat[14] = (pow(L[1],2)*(M[1] + 3*(M[2] + M[3] + M[4])))/3.;\
\n coefMat[20] = (cos(v[3] - v[4])*L[1]*L[2]*(M[2] + 2*(M[3] + M[4])))/2.;\n \
coefMat[26] = (cos(v[3] - v[5])*L[1]*L[3]*(M[3] + 2*M[4]))/2.;\n coefMat[32] \
= (cos(v[3] - v[6])*L[1]*L[4]*M[4])/2.;\n rhsVec[2] = tauL - \
(L[1]*(Cs*(2*pow(L[1],2)*v[9] + 3*L[1]*(cos(v[3])*v[8] + 2*(pow(cos(v[3] - \
v[4]),2)*L[2] + pow(cos(v[3] - v[5]),2)*L[3] + pow(cos(v[3] - \
v[6]),2)*L[4])*v[9] - v[7]*sin(v[3])) + 3*(cos(v[3] - v[4])*pow(L[2],2)*v[10] \
+ cos(v[3] - v[5])*pow(L[3],2)*v[11] + 2*L[2]*((cos(v[3] - v[5])*cos(v[4] - \
v[5])*L[3] + cos(v[3] - v[6])*cos(v[4] - v[6])*L[4])*v[10] + cos(v[3] - \
v[4])*(cos(v[4])*v[8] - v[7]*sin(v[4]))) + 2*L[3]*(cos(v[3] - v[6])*cos(v[5] \
- v[6])*L[4]*v[11] + cos(v[3] - v[5])*(cos(v[5])*v[8] - v[7]*sin(v[5]))) + \
cos(v[3] - v[6])*L[4]*(2*cos(v[6])*v[8] + L[4]*v[12] - 2*v[7]*sin(v[6])))) + \
3*(-2*forceRY*cos(v[3]) + 2*forceRX*sin(v[3]) + \
L[2]*M[2]*pow(v[10],2)*sin(v[3] - v[4]) + 2*L[2]*M[3]*pow(v[10],2)*sin(v[3] - \
v[4]) + 2*L[2]*M[4]*pow(v[10],2)*sin(v[3] - v[4]) + \
L[3]*M[3]*pow(v[11],2)*sin(v[3] - v[5]) + 2*L[3]*M[4]*pow(v[11],2)*sin(v[3] - \
v[5]) + L[4]*M[4]*pow(v[12],2)*sin(v[3] - v[6]) - 2*Cv*(L[2]*(sin(v[3] - \
v[4])*(cos(v[4])*v[7] - L[1]*v[9]*sin(v[3] - v[4]) + v[8]*sin(v[4])) - \
v[10]*(L[3]*sin(v[3] - v[5])*sin(v[4] - v[5]) + L[4]*sin(v[3] - \
v[6])*sin(v[4] - v[6]))) + L[3]*(sin(v[3] - v[5])*(cos(v[5])*v[7] - \
L[1]*v[9]*sin(v[3] - v[5]) + v[8]*sin(v[5])) - L[4]*v[11]*sin(v[3] - \
v[6])*sin(v[5] - v[6])) + L[4]*sin(v[3] - v[6])*(cos(v[6])*v[7] - \
L[1]*v[9]*sin(v[3] - v[6]) + v[8]*sin(v[6]))))))/6.;\n coefMat[3] = \
-(L[2]*(M[2] + 2*(M[3] + M[4]))*sin(v[4]))/2.;\n coefMat[9] = \
(cos(v[4])*L[2]*(M[2] + 2*(M[3] + M[4])))/2.;\n coefMat[15] = (cos(v[3] - \
v[4])*L[1]*L[2]*(M[2] + 2*(M[3] + M[4])))/2.;\n coefMat[21] = \
(pow(L[2],2)*(M[2] + 3*(M[3] + M[4])))/3.;\n coefMat[27] = (cos(v[4] - \
v[5])*L[2]*L[3]*(M[3] + 2*M[4]))/2.;\n coefMat[33] = (cos(v[4] - \
v[6])*L[2]*L[4]*M[4])/2.;\n rhsVec[3] = -(L[2]*(-6*forceRY*cos(v[4]) - \
3*L[1]*M[2]*pow(v[9],2)*sin(v[3] - v[4]) - 6*L[1]*M[3]*pow(v[9],2)*sin(v[3] - \
v[4]) - 6*L[1]*M[4]*pow(v[9],2)*sin(v[3] - v[4]) + 6*forceRX*sin(v[4]) + \
3*L[3]*M[3]*pow(v[11],2)*sin(v[4] - v[5]) + 6*L[3]*M[4]*pow(v[11],2)*sin(v[4] \
- v[5]) + 3*L[4]*M[4]*pow(v[12],2)*sin(v[4] - v[6]) + Cs*(2*pow(L[2],2)*v[10] \
+ 3*cos(v[4] - v[5])*pow(L[3],2)*v[11] + 3*L[2]*(cos(v[4])*v[8] + cos(v[3] - \
v[4])*L[1]*v[9] + 2*(pow(cos(v[4] - v[5]),2)*L[3] + pow(cos(v[4] - \
v[6]),2)*L[4])*v[10] - v[7]*sin(v[4])) + 6*L[3]*(cos(v[4] - v[6])*cos(v[5] - \
v[6])*L[4]*v[11] + cos(v[4] - v[5])*(cos(v[5])*v[8] + cos(v[3] - \
v[5])*L[1]*v[9] - v[7]*sin(v[5]))) + 3*cos(v[4] - \
v[6])*L[4]*(2*cos(v[6])*v[8] + 2*cos(v[3] - v[6])*L[1]*v[9] + L[4]*v[12] - \
2*v[7]*sin(v[6]))) - 6*Cv*(L[3]*(sin(v[4] - v[5])*(cos(v[5])*v[7] - \
L[1]*v[9]*sin(v[3] - v[5]) - L[2]*v[10]*sin(v[4] - v[5]) + v[8]*sin(v[5])) - \
L[4]*v[11]*sin(v[4] - v[6])*sin(v[5] - v[6])) + L[4]*sin(v[4] - \
v[6])*(cos(v[6])*v[7] - L[1]*v[9]*sin(v[3] - v[6]) - L[2]*v[10]*sin(v[4] - \
v[6]) + v[8]*sin(v[6])))))/6.;\n coefMat[4] = -(L[3]*(M[3] + \
2*M[4])*sin(v[5]))/2.;\n coefMat[10] = (cos(v[5])*L[3]*(M[3] + 2*M[4]))/2.;\n \
coefMat[16] = (cos(v[3] - v[5])*L[1]*L[3]*(M[3] + 2*M[4]))/2.;\n coefMat[22] \
= (cos(v[4] - v[5])*L[2]*L[3]*(M[3] + 2*M[4]))/2.;\n coefMat[28] = \
(pow(L[3],2)*(M[3] + 3*M[4]))/3.;\n coefMat[34] = (cos(v[5] - \
v[6])*L[3]*L[4]*M[4])/2.;\n rhsVec[4] = -(L[3]*(Cs*(2*pow(L[3],2)*v[11] + \
3*L[3]*(cos(v[5])*v[8] + cos(v[3] - v[5])*L[1]*v[9] + cos(v[4] - \
v[5])*L[2]*v[10] + 2*pow(cos(v[5] - v[6]),2)*L[4]*v[11] - v[7]*sin(v[5])) + \
3*cos(v[5] - v[6])*L[4]*(2*cos(v[6])*v[8] + 2*cos(v[3] - v[6])*L[1]*v[9] + \
2*cos(v[4] - v[6])*L[2]*v[10] + L[4]*v[12] - 2*v[7]*sin(v[6]))) - \
3*(2*forceRY*cos(v[5]) + (M[3] + 2*M[4])*(L[1]*pow(v[9],2)*sin(v[3] - v[5]) + \
L[2]*pow(v[10],2)*sin(v[4] - v[5])) - 2*forceRX*sin(v[5]) - \
L[4]*M[4]*pow(v[12],2)*sin(v[5] - v[6]) - 2*Cv*L[4]*sin(v[5] - \
v[6])*(-(cos(v[6])*v[7]) + L[1]*v[9]*sin(v[3] - v[6]) + L[2]*v[10]*sin(v[4] - \
v[6]) + L[3]*v[11]*sin(v[5] - v[6]) - v[8]*sin(v[6])))))/6.;\n coefMat[5] = \
-(L[4]*M[4]*sin(v[6]))/2.;\n coefMat[11] = (cos(v[6])*L[4]*M[4])/2.;\n \
coefMat[17] = (cos(v[3] - v[6])*L[1]*L[4]*M[4])/2.;\n coefMat[23] = (cos(v[4] \
- v[6])*L[2]*L[4]*M[4])/2.;\n coefMat[29] = (cos(v[5] - \
v[6])*L[3]*L[4]*M[4])/2.;\n coefMat[35] = (pow(L[4],2)*M[4])/3.;\n rhsVec[5] \
= (6*tauR + 3*L[4]*(2*forceRY*cos(v[6]) + M[4]*(L[1]*pow(v[9],2)*sin(v[3] - \
v[6]) + L[2]*pow(v[10],2)*sin(v[4] - v[6]) + L[3]*pow(v[11],2)*sin(v[5] - \
v[6])) - 2*forceRX*sin(v[6])) - Cs*pow(L[4],2)*(3*(cos(v[6])*v[8] + cos(v[3] \
- v[6])*L[1]*v[9] + cos(v[4] - v[6])*L[2]*v[10] + cos(v[5] - \
v[6])*L[3]*v[11]) + 2*L[4]*v[12] - 3*v[7]*sin(v[6])))/6.;"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(vecRHS[\([3]\)]\  /. \ cformVarReplace\)], "Input"],

Cell[BoxData[
    \(tauL - 
      1\/6\ L\[LeftDoubleBracket]1\[RightDoubleBracket]\ \((Cs\ \((2\ L\
\[LeftDoubleBracket]1\[RightDoubleBracket]\^2\ v\[LeftDoubleBracket]9\
\[RightDoubleBracket] + 
                  3\ L\[LeftDoubleBracket]1\[RightDoubleBracket]\ \((Cos[
                            v\[LeftDoubleBracket]3\[RightDoubleBracket]]\ v\
\[LeftDoubleBracket]8\[RightDoubleBracket] + 
                        2\ \((Cos[v\[LeftDoubleBracket]3\[RightDoubleBracket] \
- v\[LeftDoubleBracket]4\[RightDoubleBracket]]\^2\ L\[LeftDoubleBracket]2\
\[RightDoubleBracket] + 
                              Cos[v\[LeftDoubleBracket]3\[RightDoubleBracket] \
- v\[LeftDoubleBracket]5\[RightDoubleBracket]]\^2\ L\[LeftDoubleBracket]3\
\[RightDoubleBracket] + 
                              Cos[v\[LeftDoubleBracket]3\[RightDoubleBracket] \
- v\[LeftDoubleBracket]6\[RightDoubleBracket]]\^2\ L\[LeftDoubleBracket]4\
\[RightDoubleBracket])\)\ v\[LeftDoubleBracket]9\[RightDoubleBracket] - 
                        v\[LeftDoubleBracket]7\[RightDoubleBracket]\ Sin[
                            v\[LeftDoubleBracket]3\[RightDoubleBracket]])\) + 
                  3\ \((Cos[
                            v\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                              v\[LeftDoubleBracket]4\[RightDoubleBracket]]\ L\
\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ v\[LeftDoubleBracket]10\
\[RightDoubleBracket] + 
                        Cos[v\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                              v\[LeftDoubleBracket]5\[RightDoubleBracket]]\ L\
\[LeftDoubleBracket]3\[RightDoubleBracket]\^2\ v\[LeftDoubleBracket]11\
\[RightDoubleBracket] + 
                        2\ L\[LeftDoubleBracket]2\[RightDoubleBracket]\ \
\((\((Cos[v\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                                        v\[LeftDoubleBracket]5\
\[RightDoubleBracket]]\ Cos[v\[LeftDoubleBracket]4\[RightDoubleBracket] - 
                                        v\[LeftDoubleBracket]5\
\[RightDoubleBracket]]\ L\[LeftDoubleBracket]3\[RightDoubleBracket] + 
                                    Cos[v\[LeftDoubleBracket]3\
\[RightDoubleBracket] - v\[LeftDoubleBracket]6\[RightDoubleBracket]]\ Cos[
                                        v\[LeftDoubleBracket]4\
\[RightDoubleBracket] - 
                                        v\[LeftDoubleBracket]6\
\[RightDoubleBracket]]\ L\[LeftDoubleBracket]4\[RightDoubleBracket])\)\ v\
\[LeftDoubleBracket]10\[RightDoubleBracket] + 
                              Cos[
                                  v\[LeftDoubleBracket]3\[RightDoubleBracket] \
- v\[LeftDoubleBracket]4\[RightDoubleBracket]]\ \((Cos[
                                        v\[LeftDoubleBracket]4\
\[RightDoubleBracket]]\ v\[LeftDoubleBracket]8\[RightDoubleBracket] - 
                                    v\[LeftDoubleBracket]7\
\[RightDoubleBracket]\ Sin[
                                        v\[LeftDoubleBracket]4\
\[RightDoubleBracket]])\))\) + 
                        2\ L\[LeftDoubleBracket]3\[RightDoubleBracket]\ \
\((Cos[v\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                                    v\[LeftDoubleBracket]6\
\[RightDoubleBracket]]\ Cos[v\[LeftDoubleBracket]5\[RightDoubleBracket] - 
                                    v\[LeftDoubleBracket]6\
\[RightDoubleBracket]]\ L\[LeftDoubleBracket]4\[RightDoubleBracket]\ v\
\[LeftDoubleBracket]11\[RightDoubleBracket] + 
                              Cos[v\[LeftDoubleBracket]3\[RightDoubleBracket] \
- v\[LeftDoubleBracket]5\[RightDoubleBracket]]\ \((Cos[
                                        v\[LeftDoubleBracket]5\
\[RightDoubleBracket]]\ v\[LeftDoubleBracket]8\[RightDoubleBracket] - 
                                    v\[LeftDoubleBracket]7\
\[RightDoubleBracket]\ Sin[
                                        v\[LeftDoubleBracket]5\
\[RightDoubleBracket]])\))\) + 
                        Cos[v\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                              v\[LeftDoubleBracket]6\[RightDoubleBracket]]\ L\
\[LeftDoubleBracket]4\[RightDoubleBracket]\ \((2\ Cos[
                                  v\[LeftDoubleBracket]6\[RightDoubleBracket]]\
\ v\[LeftDoubleBracket]8\[RightDoubleBracket] + 
                              L\[LeftDoubleBracket]4\[RightDoubleBracket]\ v\
\[LeftDoubleBracket]12\[RightDoubleBracket] - 
                              2\ v\[LeftDoubleBracket]7\[RightDoubleBracket]\ \
Sin[v\[LeftDoubleBracket]6\[RightDoubleBracket]])\))\))\) + 
            3\ \((\(-2\)\ forceRY\ Cos[
                      v\[LeftDoubleBracket]3\[RightDoubleBracket]] + 
                  2\ forceRX\ Sin[
                      v\[LeftDoubleBracket]3\[RightDoubleBracket]] + 
                  L\[LeftDoubleBracket]2\[RightDoubleBracket]\ M\
\[LeftDoubleBracket]2\[RightDoubleBracket]\ v\[LeftDoubleBracket]10\
\[RightDoubleBracket]\^2\ Sin[
                      v\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                        v\[LeftDoubleBracket]4\[RightDoubleBracket]] + 
                  2\ L\[LeftDoubleBracket]2\[RightDoubleBracket]\ M\
\[LeftDoubleBracket]3\[RightDoubleBracket]\ v\[LeftDoubleBracket]10\
\[RightDoubleBracket]\^2\ Sin[
                      v\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                        v\[LeftDoubleBracket]4\[RightDoubleBracket]] + 
                  2\ L\[LeftDoubleBracket]2\[RightDoubleBracket]\ M\
\[LeftDoubleBracket]4\[RightDoubleBracket]\ v\[LeftDoubleBracket]10\
\[RightDoubleBracket]\^2\ Sin[
                      v\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                        v\[LeftDoubleBracket]4\[RightDoubleBracket]] + 
                  L\[LeftDoubleBracket]3\[RightDoubleBracket]\ M\
\[LeftDoubleBracket]3\[RightDoubleBracket]\ v\[LeftDoubleBracket]11\
\[RightDoubleBracket]\^2\ Sin[
                      v\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                        v\[LeftDoubleBracket]5\[RightDoubleBracket]] + 
                  2\ L\[LeftDoubleBracket]3\[RightDoubleBracket]\ M\
\[LeftDoubleBracket]4\[RightDoubleBracket]\ v\[LeftDoubleBracket]11\
\[RightDoubleBracket]\^2\ Sin[
                      v\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                        v\[LeftDoubleBracket]5\[RightDoubleBracket]] + 
                  L\[LeftDoubleBracket]4\[RightDoubleBracket]\ M\
\[LeftDoubleBracket]4\[RightDoubleBracket]\ v\[LeftDoubleBracket]12\
\[RightDoubleBracket]\^2\ Sin[
                      v\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                        v\[LeftDoubleBracket]6\[RightDoubleBracket]] - 
                  2\ Cv\ \((L\[LeftDoubleBracket]2\[RightDoubleBracket]\ \
\((Sin[v\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                                    v\[LeftDoubleBracket]4\
\[RightDoubleBracket]]\ \((Cos[
                                        v\[LeftDoubleBracket]4\
\[RightDoubleBracket]]\ v\[LeftDoubleBracket]7\[RightDoubleBracket] - 
                                    L\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ v\[LeftDoubleBracket]9\[RightDoubleBracket]\ Sin[
                                        v\[LeftDoubleBracket]3\
\[RightDoubleBracket] - v\[LeftDoubleBracket]4\[RightDoubleBracket]] + 
                                    v\[LeftDoubleBracket]8\
\[RightDoubleBracket]\ Sin[v\[LeftDoubleBracket]4\[RightDoubleBracket]])\) - 
                              v\[LeftDoubleBracket]10\[RightDoubleBracket]\ \
\((L\[LeftDoubleBracket]3\[RightDoubleBracket]\ Sin[
                                        v\[LeftDoubleBracket]3\
\[RightDoubleBracket] - v\[LeftDoubleBracket]5\[RightDoubleBracket]]\ Sin[
                                        v\[LeftDoubleBracket]4\
\[RightDoubleBracket] - v\[LeftDoubleBracket]5\[RightDoubleBracket]] + 
                                    L\[LeftDoubleBracket]4\
\[RightDoubleBracket]\ Sin[v\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                                        v\[LeftDoubleBracket]6\
\[RightDoubleBracket]]\ Sin[v\[LeftDoubleBracket]4\[RightDoubleBracket] - 
                                        v\[LeftDoubleBracket]6\
\[RightDoubleBracket]])\))\) + 
                        L\[LeftDoubleBracket]3\[RightDoubleBracket]\ \((Sin[
                                  v\[LeftDoubleBracket]3\[RightDoubleBracket] \
- v\[LeftDoubleBracket]5\[RightDoubleBracket]]\ \((Cos[
                                        v\[LeftDoubleBracket]5\
\[RightDoubleBracket]]\ v\[LeftDoubleBracket]7\[RightDoubleBracket] - 
                                    L\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ v\[LeftDoubleBracket]9\[RightDoubleBracket]\ Sin[
                                        v\[LeftDoubleBracket]3\
\[RightDoubleBracket] - v\[LeftDoubleBracket]5\[RightDoubleBracket]] + 
                                    v\[LeftDoubleBracket]8\
\[RightDoubleBracket]\ Sin[v\[LeftDoubleBracket]5\[RightDoubleBracket]])\) - 
                              L\[LeftDoubleBracket]4\[RightDoubleBracket]\ v\
\[LeftDoubleBracket]11\[RightDoubleBracket]\ Sin[
                                  v\[LeftDoubleBracket]3\[RightDoubleBracket] \
- v\[LeftDoubleBracket]6\[RightDoubleBracket]]\ Sin[
                                  v\[LeftDoubleBracket]5\[RightDoubleBracket] \
- v\[LeftDoubleBracket]6\[RightDoubleBracket]])\) + 
                        L\[LeftDoubleBracket]4\[RightDoubleBracket]\ Sin[
                            v\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                              v\[LeftDoubleBracket]6\[RightDoubleBracket]]\ \
\((Cos[v\[LeftDoubleBracket]6\[RightDoubleBracket]]\ v\[LeftDoubleBracket]7\
\[RightDoubleBracket] - 
                              L\[LeftDoubleBracket]1\[RightDoubleBracket]\ v\
\[LeftDoubleBracket]9\[RightDoubleBracket]\ Sin[
                                  v\[LeftDoubleBracket]3\[RightDoubleBracket] \
- v\[LeftDoubleBracket]6\[RightDoubleBracket]] + 
                              v\[LeftDoubleBracket]8\[RightDoubleBracket]\ \
Sin[v\[LeftDoubleBracket]6\[RightDoubleBracket]])\))\))\))\)\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1352}, {0, 560}},
WindowSize->{1204, 510},
WindowMargins->{{46, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 8578, 172, 1658, "Input"],
Cell[10357, 227, 78, 1, 25, "Print"],
Cell[10438, 230, 34, 1, 25, "Print"],
Cell[10475, 233, 34, 1, 25, "Print"],
Cell[10512, 236, 34, 1, 25, "Print"],
Cell[10549, 239, 34, 1, 25, "Print"],
Cell[10586, 242, 53, 1, 25, "Print"],
Cell[10642, 245, 57, 1, 25, "Print"],
Cell[10702, 248, 63, 1, 25, "Print"],
Cell[10768, 251, 34, 1, 25, "Print"],
Cell[10805, 254, 34, 1, 25, "Print"],
Cell[10842, 257, 34, 1, 25, "Print"],
Cell[10879, 260, 34, 1, 25, "Print"],
Cell[10916, 263, 34, 1, 25, "Print"],
Cell[10953, 266, 34, 1, 25, "Print"],
Cell[10990, 269, 47, 1, 25, "Print"],
Cell[11040, 272, 34, 1, 25, "Print"],
Cell[11077, 275, 34, 1, 25, "Print"],
Cell[11114, 278, 34, 1, 25, "Print"],
Cell[11151, 281, 34, 1, 25, "Print"],
Cell[11188, 284, 34, 1, 25, "Print"],
Cell[11225, 287, 34, 1, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11296, 293, 3571, 70, 690, "Input"],
Cell[14870, 365, 342, 5, 22, "Message"],
Cell[15215, 372, 342, 5, 22, "Message"],
Cell[15560, 379, 342, 5, 22, "Message"],
Cell[15905, 386, 329, 5, 22, "Message"],
Cell[16237, 393, 342, 5, 22, "Message"],
Cell[16582, 400, 342, 5, 22, "Message"],
Cell[16927, 407, 342, 5, 22, "Message"],
Cell[17272, 414, 329, 5, 22, "Message"],
Cell[17604, 421, 362, 5, 22, "Message"],
Cell[17969, 428, 356, 5, 22, "Message"],
Cell[18328, 435, 362, 5, 22, "Message"],
Cell[18693, 442, 364, 5, 22, "Message"],
Cell[19060, 449, 4078, 76, 173, "Output"],
Cell[23141, 527, 24696, 380, 173, "Output"],
Cell[47840, 909, 4984, 110, 86, "Output"],
Cell[52827, 1021, 8130, 114, 1545, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60994, 1140, 71, 1, 30, "Input"],
Cell[61068, 1143, 9966, 159, 215, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

