(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     37429,        726]*)
(*NotebookOutlinePosition[     38076,        748]*)
(*  CellTagsIndexPosition[     38032,        744]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[{\(mySimplify[expr_] := Chop[expr];\), "\[IndentingNewLine]", 
    StyleBox[\(Print["\<Generalized coordinates and drag forces ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(n = 4;\), "\[IndentingNewLine]", 
    StyleBox[\(\[Mu] = 10\^\(-3\);\),
      FontColor->GrayLevel[0.666667]], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[\(reNo = 1.0;\),
        FontColor->GrayLevel[0.666667]], "\[IndentingNewLine]", 
      StyleBox[
        RowBox[{"(*", " ", 
          RowBox[{
            
            StyleBox[\(c\_S = \(4\ \[Pi]\ \[Mu]\)\/\(1\/2 - 0.577 - \
Log[reNo\/8]\)\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[";",
              FontColor->GrayLevel[0.666667]], "\[IndentingNewLine]", 
            StyleBox[\(c\_V\  = \(\[Mu]\ 2\ \[Pi]\ 0.1\)\/0.1\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[";",
              FontColor->GrayLevel[0.666667]]}], " ", "*)"}],
        FontColor->GrayLevel[
        0.666667]]}], "\[IndentingNewLine]", \(w\_0 = {x\_L[t], 
          y\_L[t]};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"For", "[", 
        RowBox[{\(a = 1\), ",", \(a \[LessEqual] n\), ",", 
          "\[IndentingNewLine]", 
          RowBox[{\(Print[a]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ \[Lambda]\_a = 1.0; \[IndentingNewLine]m\_a = 
                  1.0;\ *) \),
              FontColor->GrayLevel[0.666667]], 
            "\[IndentingNewLine]", \(th\_a = \[Theta]\_a[t]\), ";", 
            "\[IndentingNewLine]", \(vec\_a = {Cos[th\_a], Sin[th\_a]}\), ";",
             "\[IndentingNewLine]", \(p\_a = 
              w\_\(a - 1\) + \[Lambda]\_a\/2\ vec\_a\), ";", 
            "\[IndentingNewLine]", \(w\_a = 
              w\_\(a - 1\) + \[Lambda]\_a\ vec\_a\), ";", 
            "\[IndentingNewLine]", \(v\_a = D[p\_a, t]\), ";", 
            "\[IndentingNewLine]", \(rotMat\_a = {{Cos[th\_a], 
                  Sin[th\_a]}, {\(-Sin[th\_a]\), Cos[th\_a]}}\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ 
                For\ an\ infinidecimal\ point\ on\ segment\ a\ *) \),
              Background->GrayLevel[0.900008]], 
            "\[IndentingNewLine]", \(pPt\_a = 
              p\_a + s\ {Cos[th\_a], Sin[th\_a]}\), ";", 
            "\[IndentingNewLine]", \(vPt\_a = D[pPt\_a, t]\), ";", 
            "\[IndentingNewLine]", \(vPtLocal\_a = rotMat\_a . vPt\_a\), ";", 
            "\[IndentingNewLine]", \(fPtDrag\_a = 
              Inverse[rotMat\_a] . {\(-c\_V\)\ vPtLocal\_a[\([1]\)], \
\(-c\_S\)\ vPtLocal\_a[\([2]\)]}\), ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ Integrating\ *) \),
              Background->GrayLevel[0.900008]], 
            "\[IndentingNewLine]", \(fDrag\_a = 
              mySimplify[
                Integrate[
                  fPtDrag\_a, {s, \(-\(\[Lambda]\_a\/2\)\), \
\[Lambda]\_a\/2}]]\), ";", 
            "\[IndentingNewLine]", \(tauDrag\_a = 
              mySimplify[
                Integrate[
                  s\ \((fPtDrag\_a[\([2]\)]\ Cos[th\_a] - 
                        fPtDrag\_a[\([1]\)]\ Sin[
                            th\_a])\), {s, \(-\(\[Lambda]\_a\/2\)\), \
\[Lambda]\_a\/2}]]\), ";", "\[IndentingNewLine]", \(a++\)}]}], "]"}], 
      ";"}], "\[IndentingNewLine]", 
    StyleBox[\(Print["\<Generalized forces ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(thetaDotSubsZeros = 
        Table[Null, {n}];\), "\[IndentingNewLine]", \(For[a = 1, 
      a \[LessEqual] 
        n, \[IndentingNewLine]q\_a = \[Sum]\+\(k = 1\)\%n\((fDrag\_k . 
                D[p\_k, \[Theta]\_a[t]])\) + {f\_RX[t], f\_RY[t]} . 
            D[w\_n, \[Theta]\_a[t]] + 
          tauDrag\_a; \[IndentingNewLine]thetaDotSubsZeros[\([a]\)] = 
        D[\[Theta]\_a[t], t] \[Rule] 
          0; \[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", \(q\_\(n + \
1\) = D[x\_R[t] - w\_n[\([1]\)], t];\), "\[IndentingNewLine]", 
    RowBox[{\(q\_\(n + 2\) = D[y\_R[t] - w\_n[\([2]\)], t];\), 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      StyleBox[\( (*\ 
          Computing\ the\ LHS\ matrix\ and\ the\ RHS\ matrix\ \ *) \),
        Background->GrayLevel[
        0.900008]]}], "\[IndentingNewLine]", \(varlist = 
        Table[Null, {n + 6}];\), "\[IndentingNewLine]", \(For[a = 1, 
      a \[LessEqual] n, 
      varlist[\([a]\)] = \(\[Theta]\_a'\)[
          t]; \(a++\)]\), "\[IndentingNewLine]", \(varlist[\([n + 
              1]\)] = \(x\_L'\)[
          t];\), "\[IndentingNewLine]", \(varlist[\([n + 2]\)] = \(y\_L'\)[
          t];\), "\[IndentingNewLine]", \(varlist[\([n + 3]\)] = \(x\_R'\)[
          t];\), "\[IndentingNewLine]", \(varlist[\([n + 4]\)] = \(y\_R'\)[
          t];\), "\[IndentingNewLine]", \(varlist[\([n + 5]\)] = 
        f\_RX[t];\), "\[IndentingNewLine]", 
    RowBox[{\(varlist[\([n + 6]\)] = f\_RY[t];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(matSys = 
        Table[Null, {n + 2}, {n + 6}];\), "\[IndentingNewLine]", \(For[a = 1, 
      a \[LessEqual] 
        n + 2, \[IndentingNewLine]For[b = 1, 
          b \[LessEqual] n + 6, \[IndentingNewLine]matSys[\([a, b]\)] = 
            Chop[mySimplify[\ 
                D[q\_a, 
                  varlist[\([b]\)]]\ ]]; \[IndentingNewLine]\(b++\)]\
\[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", 
    StyleBox[\(Print["\<Simplifying Matrix ...\>"];\),
      Background->GrayLevel[
      0.666667]], "\[IndentingNewLine]", \(matSys = 
        Simplify[matSys];\)}], "Input"],

Cell[BoxData[
    \("Generalized coordinates and drag forces ..."\)], "Print"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \("Generalized forces ..."\)], "Print"],

Cell[BoxData[
    \("Simplifying Matrix ..."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cformVarReplace = 
        Table[Null, {3\ n + 6}];\)\), "\[IndentingNewLine]", 
    \(\(For[a = 1, 
        a \[LessEqual] 
          n, \[IndentingNewLine]cformVarReplace[\([a]\)] = \[Theta]\_a[
              t] \[Rule] 
            Th[\([a]\)]; \[IndentingNewLine]\(a++\)];\)\), "\
\[IndentingNewLine]", 
    \(For[a = 1, 
      a \[LessEqual] n, \[IndentingNewLine]cformVarReplace[\([a + n]\)] = 
        m\_a \[Rule] 
          M[\([a]\)]; \[IndentingNewLine]cformVarReplace[\([a + 
              2\ n]\)] = \[Lambda]\_a \[Rule] 
          L[\([a]\)]; \[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([3\ n + 1]\)] = 
        c\_V \[Rule] Cv;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([3\ n + 2]\)] = 
        c\_S \[Rule] Cs;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([3\ n + 3]\)] = x\_L[t] \[Rule] xL;\)\), "\n", 
    \(\(cformVarReplace[\([3\ n + 4]\)] = 
        y\_L[t] \[Rule] yL;\)\), "\[IndentingNewLine]", 
    \(\(cformVarReplace[\([3\ n + 5]\)] = x\_R[t] \[Rule] xR;\)\), "\n", 
    \(\(\(cformVarReplace[\([3\ n + 6]\)] = 
        y\_R[t] \[Rule] yR;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(cformDVarReplace = Table[Null, {n + 4}];\)\), "\[IndentingNewLine]", 
    \(\(For[a = 1, 
        a \[LessEqual] 
          n, \[IndentingNewLine]cformDVarReplace[\([a]\)] = \(\[Theta]\_a'\)[
              t] \[Rule] 
            dTh[\([a]\)]; \[IndentingNewLine]\(a++\)];\)\), "\
\[IndentingNewLine]", 
    \(\(cformDVarReplace[\([n + 1]\)] = \(x\_L'\)[t] \[Rule] dxL;\)\), "\n", 
    \(\(cformDVarReplace[\([n + 2]\)] = \(y\_L'\)[t] \[Rule] dyL;\)\), "\n", 
    \(\(cformDVarReplace[\([n + 3]\)] = \(x\_R'\)[t] \[Rule] dxR;\)\), "\n", 
    \(\(\(cformDVarReplace[\([n + 4]\)] = \(y\_R'\)[t] \[Rule] 
          dyR;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(cformVarReplace\), "\[IndentingNewLine]", 
    \(cformDVarReplace\), "\[IndentingNewLine]", 
    \(\(\(matSys\  // \ MatrixForm\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(outCString = "\<\>";\)\), "\[IndentingNewLine]", 
    \(For[a = 1, 
      a \[LessEqual] n + 2, \[IndentingNewLine]For[b = 1, 
        b \[LessEqual] n + 6, \[IndentingNewLine]outCString = 
          outCString <> "\<\n matSys[\>" <> 
            ToString[CForm[\((b - 1)\)\ \((n + 2)\) + a - 1]] <> "\<] = \>" <> 
            ToString[
              CForm[matSys[\([a, b]\)]\  /. \ 
                  cformVarReplace]] <> "\<;\>"; \[IndentingNewLine]\(b++\)]; \
\[IndentingNewLine]\(a++\)]\), "\[IndentingNewLine]", 
    \(\(For[a = 1, 
        a \[LessEqual] n, \[IndentingNewLine]Print[
          a]; \[IndentingNewLine]fDrag\_a = 
          Simplify[fDrag\_a]; \[IndentingNewLine]outCString = 
          outCString <> "\<\n dragForce[\>" <> 
            ToString[CForm[a - 1]] <> "\<] = \>" <> 
            ToString[
              CForm[Simplify[fDrag\_a[\([1]\)]]\  /. \ 
                  Join[cformVarReplace, 
                    cformDVarReplace]]] <> "\<;\>"; \
\[IndentingNewLine]outCString = 
          outCString <> "\<\n dragForce[\>" <> 
            ToString[CForm[n + a - 1]] <> "\<] = \>" <> 
            ToString[
              CForm[Simplify[fDrag\_a[\([2]\)]]\  /. \ 
                  Join[cformVarReplace, 
                    cformDVarReplace]]] <> "\<;\>"; \
\[IndentingNewLine]\(a++\)];\)\), "\[IndentingNewLine]", 
    \(\(outCString = 
        StringReplace[
          outCString, {"\<Cos\>" \[Rule] "\<cos\>", "\<Sin\>" \[Rule] \
"\<sin\>", "\<Tan\>" \[Rule] "\<tan\>", "\<Power\>" \[Rule] "\<pow\>"}];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[outCString];\)\), "\[IndentingNewLine]", 
    \(\(SetSystemOptions["\<BinaryFormat\>" -> True];\)\), "\n", 
    \(\(BinaryWrite["\<boom4dd.txt\>", 
        outCString];\)\), "\[IndentingNewLine]", 
    \(\(Close["\<boom4dd.txt\>"];\)\)}], "Input"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(Th \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(Th \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(Th \[LeftDoubleBracket] 2 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Part :: \\\"partd\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(M \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(L \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(M \[LeftDoubleBracket] 2 \[RightDoubleBracket]\\) is longer than depth \
of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Part :: \\\"partd\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(cformDVarReplace\\)\\\" is similar to \
existing symbol \\\"\\!\\(cformVarReplace\\)\\\". \\!\\(\\*ButtonBox[\\\"More\
\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(dTh \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than \
depth of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(dTh \[LeftDoubleBracket] 2 \[RightDoubleBracket]\\) is longer than \
depth of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Part::"partd"\), \(\(:\)\(\ \)\), "\<\"Part specification \
\\!\\(dTh \[LeftDoubleBracket] 3 \[RightDoubleBracket]\\) is longer than \
depth of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Part :: \\\"partd\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    \({\[Theta]\_1[t] \[Rule] 
        Th\[LeftDoubleBracket]1\[RightDoubleBracket], \[Theta]\_2[t] \[Rule] 
        Th\[LeftDoubleBracket]2\[RightDoubleBracket], \[Theta]\_3[t] \[Rule] 
        Th\[LeftDoubleBracket]3\[RightDoubleBracket], \[Theta]\_4[t] \[Rule] 
        Th\[LeftDoubleBracket]4\[RightDoubleBracket], 
      m\_1 \[Rule] M\[LeftDoubleBracket]1\[RightDoubleBracket], 
      m\_2 \[Rule] M\[LeftDoubleBracket]2\[RightDoubleBracket], 
      m\_3 \[Rule] M\[LeftDoubleBracket]3\[RightDoubleBracket], 
      m\_4 \[Rule] 
        M\[LeftDoubleBracket]4\[RightDoubleBracket], \[Lambda]\_1 \[Rule] 
        L\[LeftDoubleBracket]1\[RightDoubleBracket], \[Lambda]\_2 \[Rule] 
        L\[LeftDoubleBracket]2\[RightDoubleBracket], \[Lambda]\_3 \[Rule] 
        L\[LeftDoubleBracket]3\[RightDoubleBracket], \[Lambda]\_4 \[Rule] 
        L\[LeftDoubleBracket]4\[RightDoubleBracket], c\_V \[Rule] Cv, 
      c\_S \[Rule] Cs, x\_L[t] \[Rule] xL, y\_L[t] \[Rule] yL, 
      x\_R[t] \[Rule] xR, y\_R[t] \[Rule] yR}\)], "Output"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_1\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dTh\[LeftDoubleBracket]1\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_2\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dTh\[LeftDoubleBracket]2\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_3\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dTh\[LeftDoubleBracket]3\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(\[Theta]\_4\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Rule]", \(dTh\[LeftDoubleBracket]4\[RightDoubleBracket]\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox[\(x\_L\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "dxL"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox[\(y\_L\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "dyL"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox[\(x\_R\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "dxR"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox[\(y\_R\), "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "dyR"}]}],
       "}"}]], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(-\(1\/3\)\)\ \[Lambda]\_1\%2\ \((3\ c\_V\ \
\((Sin[\[Theta]\_1[t] - \[Theta]\_2[t]]\^2\ \[Lambda]\_2 + 
                          Sin[\[Theta]\_1[t] - \[Theta]\_3[t]]\^2\ \
\[Lambda]\_3 + Sin[\[Theta]\_1[t] - \[Theta]\_4[t]]\^2\ \[Lambda]\_4)\) + 
                    c\_S\ \((\[Lambda]\_1 + 
                          3\ \((Cos[\[Theta]\_1[t] - \[Theta]\_2[t]]\^2\ \
\[Lambda]\_2 + Cos[\[Theta]\_1[t] - \[Theta]\_3[t]]\^2\ \[Lambda]\_3 + 
                                Cos[\[Theta]\_1[t] - \[Theta]\_4[t]]\^2\ \
\[Lambda]\_4)\))\))\)\), \(\(-\(1\/2\)\)\ \[Lambda]\_1\ \[Lambda]\_2\ \((c\_S\
\ \((Cos[\[Theta]\_1[t] - \[Theta]\_2[t]]\ \[Lambda]\_2 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4)\))\)\), \(\(-\(1\/2\)\)\ \
\[Lambda]\_1\ \[Lambda]\_3\ \((2\ Sin[\[Theta]\_1[t] - \[Theta]\_4[
                            t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                            t]]\ c\_V\ \[Lambda]\_4 + 
                    c\_S\ \((Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4)\))\)\), \(\(-\(1\/2\)\)\ \
Cos[\[Theta]\_1[t] - \[Theta]\_4[
                      t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\%2\), \(1\/2\ \
\[Lambda]\_1\ \((c\_S\ \((Sin[\[Theta]\_1[t]]\ \[Lambda]\_1 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ Sin[\[Theta]\_2[t]]\ \[Lambda]\_2 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_3 - 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_3[t]]\ \[Lambda]\_3 + 
                          Sin[\[Theta]\_1[t]]\ \[Lambda]\_4 - 
                          Sin[\[Theta]\_1[t] - 
                                2\ \[Theta]\_4[t]]\ \[Lambda]\_4)\) + 
                    2\ c\_V\ \((Cos[\[Theta]\_2[
                                t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ \[Lambda]\_2 + 
                          Cos[\[Theta]\_3[
                                t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          Cos[\[Theta]\_4[
                                t]]\ Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4)\))\)\), \(\(-\(1\/2\)\)\ \
\[Lambda]\_1\ \((c\_S\ \((Cos[\[Theta]\_1[t]]\ \[Lambda]\_1 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ Cos[\[Theta]\_2[t]]\ \[Lambda]\_2 + 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_3 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_3[t]]\ \[Lambda]\_3 + 
                          Cos[\[Theta]\_1[t]]\ \[Lambda]\_4 + 
                          Cos[\[Theta]\_1[t] - 
                                2\ \[Theta]\_4[t]]\ \[Lambda]\_4)\) - 
                    2\ c\_V\ \((Sin[\[Theta]\_1[t] - \[Theta]\_2[
                                  t]]\ Sin[\[Theta]\_2[t]]\ \[Lambda]\_2 + 
                          Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ Sin[\[Theta]\_3[t]]\ \[Lambda]\_3 + 
                          Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ Sin[\[Theta]\_4[
                                t]]\ \[Lambda]\_4)\))\)\), "0", 
              "0", \(\(-Sin[\[Theta]\_1[
                      t]]\)\ \[Lambda]\_1\), \(Cos[\[Theta]\_1[
                    t]]\ \[Lambda]\_1\)},
            {\(\(-\(1\/2\)\)\ \[Lambda]\_1\ \[Lambda]\_2\ \((c\_S\ \((Cos[\
\[Theta]\_1[t] - \[Theta]\_2[t]]\ \[Lambda]\_2 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4)\) + 
                    2\ c\_V\ \((Sin[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          Sin[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4)\))\)\), \(\(-\(1\/3\)\)\ \
\[Lambda]\_2\%2\ \((c\_S\ \((\[Lambda]\_2 + 
                          3\ Cos[\[Theta]\_2[t] - \[Theta]\_3[t]]\^2\ \
\[Lambda]\_3 + 3\ Cos[\[Theta]\_2[t] - \[Theta]\_4[t]]\^2\ \[Lambda]\_4)\) + 
                    3\ c\_V\ \((Sin[\[Theta]\_2[t] - \[Theta]\_3[t]]\^2\ \
\[Lambda]\_3 + 
                          Sin[\[Theta]\_2[t] - \[Theta]\_4[t]]\^2\ \
\[Lambda]\_4)\))\)\), \(\(-\(1\/2\)\)\ \[Lambda]\_2\ \[Lambda]\_3\ \((2\ Sin[\
\[Theta]\_2[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                            t]]\ c\_V\ \[Lambda]\_4 + 
                    c\_S\ \((Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4)\))\)\), \(\(-\(1\/2\)\)\ \
Cos[\[Theta]\_2[t] - \[Theta]\_4[
                      t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\%2\), \(1\/2\ \
\[Lambda]\_2\ \((2\ c\_V\ \((Cos[\[Theta]\_3[
                                t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          Cos[\[Theta]\_4[
                                t]]\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4)\) + 
                    c\_S\ \((Sin[\[Theta]\_2[t]]\ \[Lambda]\_2 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ Sin[\[Theta]\_3[t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ Sin[\[Theta]\_4[
                                t]]\ \[Lambda]\_4)\))\)\), \(\(-\(1\/2\)\)\ \
\[Lambda]\_2\ \((c\_S\ \((Cos[\[Theta]\_2[t]]\ \[Lambda]\_2 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ Cos[\[Theta]\_3[t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ Cos[\[Theta]\_4[t]]\ \[Lambda]\_4)\) - 
                    2\ c\_V\ \((Sin[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ Sin[\[Theta]\_3[t]]\ \[Lambda]\_3 + 
                          Sin[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ Sin[\[Theta]\_4[
                                t]]\ \[Lambda]\_4)\))\)\), "0", 
              "0", \(\(-Sin[\[Theta]\_2[
                      t]]\)\ \[Lambda]\_2\), \(Cos[\[Theta]\_2[
                    t]]\ \[Lambda]\_2\)},
            {\(\(-\(1\/2\)\)\ \[Lambda]\_1\ \[Lambda]\_3\ \((2\ \
Sin[\[Theta]\_1[t] - \[Theta]\_4[t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                            t]]\ c\_V\ \[Lambda]\_4 + 
                    c\_S\ \((Cos[\[Theta]\_1[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_1[t] - \[Theta]\_4[
                                  t]]\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4)\))\)\), \(\(-\(1\/2\)\)\ \
\[Lambda]\_2\ \[Lambda]\_3\ \((2\ Sin[\[Theta]\_2[t] - \[Theta]\_4[
                            t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                            t]]\ c\_V\ \[Lambda]\_4 + 
                    c\_S\ \((Cos[\[Theta]\_2[t] - \[Theta]\_3[
                                  t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_2[t] - \[Theta]\_4[
                                  t]]\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ \[Lambda]\_4)\))\)\), \(\(-\(1\/3\)\)\ \
\[Lambda]\_3\%2\ \((3\ Sin[\[Theta]\_3[t] - \[Theta]\_4[t]]\^2\ c\_V\ \
\[Lambda]\_4 + c\_S\ \((\[Lambda]\_3 + 
                          3\ Cos[\[Theta]\_3[t] - \[Theta]\_4[t]]\^2\ \
\[Lambda]\_4)\))\)\), \(\(-\(1\/2\)\)\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                      t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\%2\), \(1\/2\ \
\[Lambda]\_3\ \((2\ Cos[\[Theta]\_4[
                          t]]\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                            t]]\ c\_V\ \[Lambda]\_4 + 
                    c\_S\ \((Sin[\[Theta]\_3[t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ Sin[\[Theta]\_4[
                                t]]\ \[Lambda]\_4)\))\)\), \(\(-\(1\/2\)\)\ \
\[Lambda]\_3\ \((\(-2\)\ Sin[\[Theta]\_3[t] - \[Theta]\_4[
                            t]]\ Sin[\[Theta]\_4[t]]\ c\_V\ \[Lambda]\_4 + 
                    c\_S\ \((Cos[\[Theta]\_3[t]]\ \[Lambda]\_3 + 
                          2\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                                  t]]\ Cos[\[Theta]\_4[
                                t]]\ \[Lambda]\_4)\))\)\), "0", 
              "0", \(\(-Sin[\[Theta]\_3[
                      t]]\)\ \[Lambda]\_3\), \(Cos[\[Theta]\_3[
                    t]]\ \[Lambda]\_3\)},
            {\(\(-\(1\/2\)\)\ Cos[\[Theta]\_1[t] - \[Theta]\_4[
                      t]]\ c\_S\ \[Lambda]\_1\ \[Lambda]\_4\%2\), \(\(-\(1\/2\
\)\)\ Cos[\[Theta]\_2[t] - \[Theta]\_4[
                      t]]\ c\_S\ \[Lambda]\_2\ \[Lambda]\_4\%2\), \(\(-\(1\/2\
\)\)\ Cos[\[Theta]\_3[t] - \[Theta]\_4[
                      t]]\ c\_S\ \[Lambda]\_3\ \[Lambda]\_4\%2\), \(\(-\(1\/3\
\)\)\ c\_S\ \[Lambda]\_4\%3\), \(1\/2\ Sin[\[Theta]\_4[
                    t]]\ c\_S\ \[Lambda]\_4\%2\), \(\(-\(1\/2\)\)\ Cos[\
\[Theta]\_4[t]]\ c\_S\ \[Lambda]\_4\%2\), "0", 
              "0", \(\(-Sin[\[Theta]\_4[
                      t]]\)\ \[Lambda]\_4\), \(Cos[\[Theta]\_4[
                    t]]\ \[Lambda]\_4\)},
            {\(Sin[\[Theta]\_1[t]]\ \[Lambda]\_1\), \(Sin[\[Theta]\_2[
                    t]]\ \[Lambda]\_2\), \(Sin[\[Theta]\_3[
                    t]]\ \[Lambda]\_3\), \(Sin[\[Theta]\_4[
                    t]]\ \[Lambda]\_4\), \(-1\), "0", "1", "0", "0", "0"},
            {\(\(-Cos[\[Theta]\_1[t]]\)\ \[Lambda]\_1\), \(\(-Cos[\[Theta]\_2[
                      t]]\)\ \[Lambda]\_2\), \(\(-Cos[\[Theta]\_3[
                      t]]\)\ \[Lambda]\_3\), \(\(-Cos[\[Theta]\_4[
                      t]]\)\ \[Lambda]\_4\), "0", \(-1\), "0", "1", "0", "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \("\n matSys[0] = -(pow(L[1],2)*(Cs*(L[1] + 3*(pow(cos(Th[1] - \
Th[2]),2)*L[2] + pow(cos(Th[1] - Th[3]),2)*L[3] + pow(cos(Th[1] - \
Th[4]),2)*L[4])) + 3*Cv*(L[2]*pow(sin(Th[1] - Th[2]),2) + L[3]*pow(sin(Th[1] \
- Th[3]),2) + L[4]*pow(sin(Th[1] - Th[4]),2))))/3.;\n matSys[6] = \
-(L[1]*L[2]*(Cs*(cos(Th[1] - Th[2])*L[2] + 2*cos(Th[1] - Th[3])*cos(Th[2] - \
Th[3])*L[3] + 2*cos(Th[1] - Th[4])*cos(Th[2] - Th[4])*L[4]) + \
2*Cv*(L[3]*sin(Th[1] - Th[3])*sin(Th[2] - Th[3]) + L[4]*sin(Th[1] - \
Th[4])*sin(Th[2] - Th[4]))))/2.;\n matSys[12] = -(L[1]*L[3]*(Cs*(cos(Th[1] - \
Th[3])*L[3] + 2*cos(Th[1] - Th[4])*cos(Th[3] - Th[4])*L[4]) + \
2*Cv*L[4]*sin(Th[1] - Th[4])*sin(Th[3] - Th[4])))/2.;\n matSys[18] = \
-(Cs*cos(Th[1] - Th[4])*L[1]*pow(L[4],2))/2.;\n matSys[24] = \
(L[1]*(Cs*(L[1]*sin(Th[1]) + L[3]*sin(Th[1]) + L[4]*sin(Th[1]) + 2*cos(Th[1] \
- Th[2])*L[2]*sin(Th[2]) - L[3]*sin(Th[1] - 2*Th[3]) - L[4]*sin(Th[1] - \
2*Th[4])) + 2*Cv*(cos(Th[2])*L[2]*sin(Th[1] - Th[2]) + \
cos(Th[3])*L[3]*sin(Th[1] - Th[3]) + cos(Th[4])*L[4]*sin(Th[1] - \
Th[4]))))/2.;\n matSys[30] = -(L[1]*(Cs*(cos(Th[1])*L[1] + 2*cos(Th[1] - \
Th[2])*cos(Th[2])*L[2] + cos(Th[1])*L[3] + cos(Th[1] - 2*Th[3])*L[3] + \
cos(Th[1])*L[4] + cos(Th[1] - 2*Th[4])*L[4]) - 2*Cv*(L[2]*sin(Th[1] - \
Th[2])*sin(Th[2]) + L[3]*sin(Th[1] - Th[3])*sin(Th[3]) + L[4]*sin(Th[1] - \
Th[4])*sin(Th[4]))))/2.;\n matSys[36] = 0;\n matSys[42] = 0;\n matSys[48] = \
-(L[1]*sin(Th[1]));\n matSys[54] = cos(Th[1])*L[1];\n matSys[1] = \
-(L[1]*L[2]*(Cs*(cos(Th[1] - Th[2])*L[2] + 2*cos(Th[1] - Th[3])*cos(Th[2] - \
Th[3])*L[3] + 2*cos(Th[1] - Th[4])*cos(Th[2] - Th[4])*L[4]) + \
2*Cv*(L[3]*sin(Th[1] - Th[3])*sin(Th[2] - Th[3]) + L[4]*sin(Th[1] - \
Th[4])*sin(Th[2] - Th[4]))))/2.;\n matSys[7] = -(pow(L[2],2)*(Cs*(L[2] + \
3*pow(cos(Th[2] - Th[3]),2)*L[3] + 3*pow(cos(Th[2] - Th[4]),2)*L[4]) + \
3*Cv*(L[3]*pow(sin(Th[2] - Th[3]),2) + L[4]*pow(sin(Th[2] - Th[4]),2))))/3.;\n\
 matSys[13] = -(L[2]*L[3]*(Cs*(cos(Th[2] - Th[3])*L[3] + 2*cos(Th[2] - \
Th[4])*cos(Th[3] - Th[4])*L[4]) + 2*Cv*L[4]*sin(Th[2] - Th[4])*sin(Th[3] - \
Th[4])))/2.;\n matSys[19] = -(Cs*cos(Th[2] - Th[4])*L[2]*pow(L[4],2))/2.;\n \
matSys[25] = (L[2]*(2*Cv*(cos(Th[3])*L[3]*sin(Th[2] - Th[3]) + \
cos(Th[4])*L[4]*sin(Th[2] - Th[4])) + Cs*(L[2]*sin(Th[2]) + 2*cos(Th[2] - \
Th[3])*L[3]*sin(Th[3]) + 2*cos(Th[2] - Th[4])*L[4]*sin(Th[4]))))/2.;\n \
matSys[31] = -(L[2]*(Cs*(cos(Th[2])*L[2] + 2*cos(Th[2] - \
Th[3])*cos(Th[3])*L[3] + 2*cos(Th[2] - Th[4])*cos(Th[4])*L[4]) - \
2*Cv*(L[3]*sin(Th[2] - Th[3])*sin(Th[3]) + L[4]*sin(Th[2] - \
Th[4])*sin(Th[4]))))/2.;\n matSys[37] = 0;\n matSys[43] = 0;\n matSys[49] = \
-(L[2]*sin(Th[2]));\n matSys[55] = cos(Th[2])*L[2];\n matSys[2] = \
-(L[1]*L[3]*(Cs*(cos(Th[1] - Th[3])*L[3] + 2*cos(Th[1] - Th[4])*cos(Th[3] - \
Th[4])*L[4]) + 2*Cv*L[4]*sin(Th[1] - Th[4])*sin(Th[3] - Th[4])))/2.;\n \
matSys[8] = -(L[2]*L[3]*(Cs*(cos(Th[2] - Th[3])*L[3] + 2*cos(Th[2] - \
Th[4])*cos(Th[3] - Th[4])*L[4]) + 2*Cv*L[4]*sin(Th[2] - Th[4])*sin(Th[3] - \
Th[4])))/2.;\n matSys[14] = -(pow(L[3],2)*(Cs*(L[3] + 3*pow(cos(Th[3] - \
Th[4]),2)*L[4]) + 3*Cv*L[4]*pow(sin(Th[3] - Th[4]),2)))/3.;\n matSys[20] = \
-(Cs*cos(Th[3] - Th[4])*L[3]*pow(L[4],2))/2.;\n matSys[26] = \
(L[3]*(2*Cv*cos(Th[4])*L[4]*sin(Th[3] - Th[4]) + Cs*(L[3]*sin(Th[3]) + \
2*cos(Th[3] - Th[4])*L[4]*sin(Th[4]))))/2.;\n matSys[32] = \
-(L[3]*(Cs*(cos(Th[3])*L[3] + 2*cos(Th[3] - Th[4])*cos(Th[4])*L[4]) - \
2*Cv*L[4]*sin(Th[3] - Th[4])*sin(Th[4])))/2.;\n matSys[38] = 0;\n matSys[44] \
= 0;\n matSys[50] = -(L[3]*sin(Th[3]));\n matSys[56] = cos(Th[3])*L[3];\n \
matSys[3] = -(Cs*cos(Th[1] - Th[4])*L[1]*pow(L[4],2))/2.;\n matSys[9] = \
-(Cs*cos(Th[2] - Th[4])*L[2]*pow(L[4],2))/2.;\n matSys[15] = -(Cs*cos(Th[3] - \
Th[4])*L[3]*pow(L[4],2))/2.;\n matSys[21] = -(Cs*pow(L[4],3))/3.;\n \
matSys[27] = (Cs*pow(L[4],2)*sin(Th[4]))/2.;\n matSys[33] = \
-(Cs*cos(Th[4])*pow(L[4],2))/2.;\n matSys[39] = 0;\n matSys[45] = 0;\n \
matSys[51] = -(L[4]*sin(Th[4]));\n matSys[57] = cos(Th[4])*L[4];\n matSys[4] \
= L[1]*sin(Th[1]);\n matSys[10] = L[2]*sin(Th[2]);\n matSys[16] = \
L[3]*sin(Th[3]);\n matSys[22] = L[4]*sin(Th[4]);\n matSys[28] = -1;\n \
matSys[34] = 0;\n matSys[40] = 1;\n matSys[46] = 0;\n matSys[52] = 0;\n \
matSys[58] = 0;\n matSys[5] = -(cos(Th[1])*L[1]);\n matSys[11] = \
-(cos(Th[2])*L[2]);\n matSys[17] = -(cos(Th[3])*L[3]);\n matSys[23] = \
-(cos(Th[4])*L[4]);\n matSys[29] = 0;\n matSys[35] = -1;\n matSys[41] = 0;\n \
matSys[47] = 1;\n matSys[53] = 0;\n matSys[59] = 0;\n dragForce[0] = \
(L[1]*(-2*Cv*cos(Th[1])*(dxL*cos(Th[1]) + dyL*sin(Th[1])) + \
Cs*(dTh[1]*L[1]*sin(Th[1]) - 2*dxL*pow(sin(Th[1]),2) + \
dyL*sin(2*Th[1]))))/2.;\n dragForce[4] = \
-(L[1]*(Cs*cos(Th[1])*(2*dyL*cos(Th[1]) + dTh[1]*L[1] - 2*dxL*sin(Th[1])) + \
Cv*(2*dyL*pow(sin(Th[1]),2) + dxL*sin(2*Th[1]))))/2.;\n dragForce[1] = \
(L[2]*(-(Cs*sin(Th[2])*(-2*dyL*cos(Th[2]) - 2*cos(Th[1] - Th[2])*dTh[1]*L[1] \
- dTh[2]*L[2] + 2*dxL*sin(Th[2]))) - 2*Cv*cos(Th[2])*(dxL*cos(Th[2]) - \
dTh[1]*L[1]*sin(Th[1] - Th[2]) + dyL*sin(Th[2]))))/2.;\n dragForce[5] = \
-(L[2]*(Cs*cos(Th[2])*(2*dyL*cos(Th[2]) + 2*cos(Th[1] - Th[2])*dTh[1]*L[1] + \
dTh[2]*L[2] - 2*dxL*sin(Th[2])) + 2*Cv*sin(Th[2])*(dxL*cos(Th[2]) - \
dTh[1]*L[1]*sin(Th[1] - Th[2]) + dyL*sin(Th[2]))))/2.;\n dragForce[2] = \
(L[3]*(-(Cs*sin(Th[3])*(-2*dyL*cos(Th[3]) - 2*cos(Th[1] - Th[3])*dTh[1]*L[1] \
- 2*cos(Th[2] - Th[3])*dTh[2]*L[2] - dTh[3]*L[3] + 2*dxL*sin(Th[3]))) + \
2*Cv*cos(Th[3])*(-(dxL*cos(Th[3])) + dTh[1]*L[1]*sin(Th[1] - Th[3]) + \
dTh[2]*L[2]*sin(Th[2] - Th[3]) - dyL*sin(Th[3]))))/2.;\n dragForce[6] = \
-(L[3]*(Cs*cos(Th[3])*(2*dyL*cos(Th[3]) + 2*cos(Th[1] - Th[3])*dTh[1]*L[1] + \
2*cos(Th[2] - Th[3])*dTh[2]*L[2] + dTh[3]*L[3] - 2*dxL*sin(Th[3])) + \
2*Cv*sin(Th[3])*(dxL*cos(Th[3]) - dTh[1]*L[1]*sin(Th[1] - Th[3]) - \
dTh[2]*L[2]*sin(Th[2] - Th[3]) + dyL*sin(Th[3]))))/2.;\n dragForce[3] = \
(L[4]*(-(Cs*sin(Th[4])*(-2*dyL*cos(Th[4]) - 2*cos(Th[1] - Th[4])*dTh[1]*L[1] \
- 2*cos(Th[2] - Th[4])*dTh[2]*L[2] - 2*cos(Th[3] - Th[4])*dTh[3]*L[3] - \
dTh[4]*L[4] + 2*dxL*sin(Th[4]))) + 2*Cv*cos(Th[4])*(-(dxL*cos(Th[4])) + \
dTh[1]*L[1]*sin(Th[1] - Th[4]) + dTh[2]*L[2]*sin(Th[2] - Th[4]) + \
dTh[3]*L[3]*sin(Th[3] - Th[4]) - dyL*sin(Th[4]))))/2.;\n dragForce[7] = \
-(L[4]*(Cs*cos(Th[4])*(2*dyL*cos(Th[4]) + 2*cos(Th[1] - Th[4])*dTh[1]*L[1] + \
2*cos(Th[2] - Th[4])*dTh[2]*L[2] + 2*cos(Th[3] - Th[4])*dTh[3]*L[3] + \
dTh[4]*L[4] - 2*dxL*sin(Th[4])) + 2*Cv*sin(Th[4])*(dxL*cos(Th[4]) - \
dTh[1]*L[1]*sin(Th[1] - Th[4]) - dTh[2]*L[2]*sin(Th[2] - Th[4]) - \
dTh[3]*L[3]*sin(Th[3] - Th[4]) + dyL*sin(Th[4]))))/2.;"\)], "Print"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1360}, {0, 564}},
WindowSize->{1264, 510},
WindowMargins->{{15, Automatic}, {Automatic, -12}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 5586, 110, 1177, "Input"],
Cell[7365, 165, 78, 1, 25, "Print"],
Cell[7446, 168, 34, 1, 25, "Print"],
Cell[7483, 171, 34, 1, 25, "Print"],
Cell[7520, 174, 34, 1, 25, "Print"],
Cell[7557, 177, 34, 1, 25, "Print"],
Cell[7594, 180, 57, 1, 25, "Print"],
Cell[7654, 183, 57, 1, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7748, 189, 3917, 80, 950, "Input"],
Cell[11668, 271, 343, 5, 22, "Message"],
Cell[12014, 278, 343, 5, 22, "Message"],
Cell[12360, 285, 343, 5, 22, "Message"],
Cell[12706, 292, 329, 5, 22, "Message"],
Cell[13038, 299, 342, 5, 22, "Message"],
Cell[13383, 306, 342, 5, 22, "Message"],
Cell[13728, 313, 342, 5, 22, "Message"],
Cell[14073, 320, 329, 5, 22, "Message"],
Cell[14405, 327, 379, 5, 22, "Message"],
Cell[14787, 334, 344, 5, 22, "Message"],
Cell[15134, 341, 344, 5, 22, "Message"],
Cell[15481, 348, 344, 5, 22, "Message"],
Cell[15828, 355, 329, 5, 22, "Message"],
Cell[16160, 362, 1043, 16, 48, "Output"],
Cell[17206, 380, 1722, 46, 29, "Output"],
Cell[18931, 428, 11714, 189, 155, "Output"],
Cell[30648, 619, 34, 1, 25, "Print"],
Cell[30685, 622, 34, 1, 25, "Print"],
Cell[30722, 625, 34, 1, 25, "Print"],
Cell[30759, 628, 34, 1, 25, "Print"],
Cell[30796, 631, 6617, 92, 1621, "Print"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

