/*
Use: [mainMat, mainVec] = getDs(v, p, M, L, [Cs Cv])
 where,
  v = [th1,th2,...,thn, Dth1,Dth2,...,Dthn] is the state vector
  p = is the coordinates of the ends and their derivatives
 The main equations of motion are given by
  mainMat * [forceLX,forceLY,forceRX,forceRY, DDth1,DDth2,...,DDthn]' = mainVec;
*/

#include "math.h"
#include "stdio.h"
#include "stdlib.h"
#include "mex.h"   //--This one is required

void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
    int nx2, n, a;
    double* v0;
    double* Th;
    double* dTh;
    double* endPoses;
    double* coefMat;
    double* rhsVec;
    //double tauL, forceLX, forceLY, tauR, forceRX, forceRY;
    //double tauL=0.0, tauR=0.0;
    double xL,yL,xR,yR,dxL,dyL,dxR,dyR,ddxL,ddyL,ddxR,ddyR,tauL,tauR;
    double* M0;
    double* L0;
    double* M;
    double* L;
    double* fricCoefs;
    double Cv, Cs;
    
    v0 = mxGetPr(prhs[0]);
    nx2 = mxGetM(prhs[0]);
    n = nx2 / 2;
    Th = (double*) mxMalloc((n+1)*sizeof(double));
    dTh = (double*) mxMalloc((n+1)*sizeof(double));
    for(a=0; a<n; a++)
    {
        Th[a+1] = v0[a];
        dTh[a+1] = v0[a+n];
    }
    
    endPoses = mxGetPr(prhs[1]);
    xL = endPoses[0];
    yL = endPoses[1];
    xR = endPoses[2];
    yR = endPoses[3];
    dxL = endPoses[4];
    dyL = endPoses[5];
    dxR = endPoses[6];
    dyR = endPoses[7];
    ddxL = endPoses[8];
    ddyL = endPoses[9];
    ddxR = endPoses[10];
    ddyR = endPoses[11];
    tauL = 0;
    tauR = 0;
    
    M0 = (double*) mxMalloc(n*sizeof(double));
    L0 = (double*) mxMalloc(n*sizeof(double));
    M0 = mxGetPr(prhs[2]);
    L0 = mxGetPr(prhs[3]);
    M = (double*) mxMalloc(n*sizeof(double));
    L = (double*) mxMalloc(n*sizeof(double));
    for(a=0; a<n; a++)
    {
        M[a+1] = M0[a];
        L[a+1] = L0[a];
    }
    fricCoefs = mxGetPr(prhs[4]);
    Cs = fricCoefs[0];
    Cv = fricCoefs[1];
    
    plhs[0] = mxCreateDoubleMatrix(n+4, n+4, mxREAL);
    plhs[1] = mxCreateDoubleMatrix(n+4, 1, mxREAL);
    coefMat = mxGetPr(plhs[0]);
    rhsVec = mxGetPr(plhs[1]);
    
    // Assignments go here
    // ===================

 coefMat[0] = -1;
 coefMat[14] = 0;
 coefMat[28] = -1;
 coefMat[42] = 0;
 coefMat[56] = -(L[1]*M[1]*sin(Th[1]))/2. - L[1]*M[2]*sin(Th[1]) - L[1]*M[3]*sin(Th[1]) - L[1]*M[4]*sin(Th[1]) - L[1]*M[5]*sin(Th[1]) - L[1]*M[6]*sin(Th[1]) - L[1]*M[7]*sin(Th[1]) - L[1]*M[8]*sin(Th[1]) - L[1]*M[9]*sin(Th[1]) - L[1]*M[10]*sin(Th[1]);
 coefMat[70] = -(L[2]*M[2]*sin(Th[2]))/2. - L[2]*M[3]*sin(Th[2]) - L[2]*M[4]*sin(Th[2]) - L[2]*M[5]*sin(Th[2]) - L[2]*M[6]*sin(Th[2]) - L[2]*M[7]*sin(Th[2]) - L[2]*M[8]*sin(Th[2]) - L[2]*M[9]*sin(Th[2]) - L[2]*M[10]*sin(Th[2]);
 coefMat[84] = -(L[3]*M[3]*sin(Th[3]))/2. - L[3]*M[4]*sin(Th[3]) - L[3]*M[5]*sin(Th[3]) - L[3]*M[6]*sin(Th[3]) - L[3]*M[7]*sin(Th[3]) - L[3]*M[8]*sin(Th[3]) - L[3]*M[9]*sin(Th[3]) - L[3]*M[10]*sin(Th[3]);
 coefMat[98] = -(L[4]*M[4]*sin(Th[4]))/2. - L[4]*M[5]*sin(Th[4]) - L[4]*M[6]*sin(Th[4]) - L[4]*M[7]*sin(Th[4]) - L[4]*M[8]*sin(Th[4]) - L[4]*M[9]*sin(Th[4]) - L[4]*M[10]*sin(Th[4]);
 coefMat[112] = -(L[5]*M[5]*sin(Th[5]))/2. - L[5]*M[6]*sin(Th[5]) - L[5]*M[7]*sin(Th[5]) - L[5]*M[8]*sin(Th[5]) - L[5]*M[9]*sin(Th[5]) - L[5]*M[10]*sin(Th[5]);
 coefMat[126] = -(L[6]*M[6]*sin(Th[6]))/2. - L[6]*M[7]*sin(Th[6]) - L[6]*M[8]*sin(Th[6]) - L[6]*M[9]*sin(Th[6]) - L[6]*M[10]*sin(Th[6]);
 coefMat[140] = -(L[7]*M[7]*sin(Th[7]))/2. - L[7]*M[8]*sin(Th[7]) - L[7]*M[9]*sin(Th[7]) - L[7]*M[10]*sin(Th[7]);
 coefMat[154] = -(L[8]*M[8]*sin(Th[8]))/2. - L[8]*M[9]*sin(Th[8]) - L[8]*M[10]*sin(Th[8]);
 coefMat[168] = -(L[9]*M[9]*sin(Th[9]))/2. - L[9]*M[10]*sin(Th[9]);
 coefMat[182] = -(L[10]*M[10]*sin(Th[10]))/2.;
 rhsVec[0] = -(Cv*dxL*pow(cos(Th[1]),2)*L[1]) - Cv*dxL*pow(cos(Th[2]),2)*L[2] - Cv*dxL*pow(cos(Th[3]),2)*L[3] - Cv*dxL*pow(cos(Th[4]),2)*L[4] - (ddxL - (cos(Th[1])*pow(dTh[1],2)*L[1])/2.)*M[1] - (ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - (cos(Th[2])*pow(dTh[2],2)*L[2])/2.)*M[2] - (ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - (cos(Th[3])*pow(dTh[3],2)*L[3])/2.)*M[3] - (ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - (cos(Th[4])*pow(dTh[4],2)*L[4])/2.)*M[4] - (ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - (cos(Th[5])*pow(dTh[5],2)*L[5])/2.)*M[5] - (ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - (cos(Th[6])*pow(dTh[6],2)*L[6])/2.)*M[6] - (ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - (cos(Th[7])*pow(dTh[7],2)*L[7])/2.)*M[7] - (ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - (cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*M[8] - (ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - (cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*M[9] - (ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - cos(Th[9])*pow(dTh[9],2)*L[9] - (cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*M[10] + Cs*dyL*cos(Th[1])*L[1]*sin(Th[1]) - Cv*dyL*cos(Th[1])*L[1]*sin(Th[1]) + (Cs*dTh[1]*pow(L[1],2)*sin(Th[1]))/2. - Cs*dxL*L[1]*pow(sin(Th[1]),2) + Cv*cos(Th[2])*dTh[1]*L[1]*L[2]*sin(Th[1] - Th[2]) + Cs*dyL*cos(Th[2])*L[2]*sin(Th[2]) - Cv*dyL*cos(Th[2])*L[2]*sin(Th[2]) + Cs*cos(Th[1] - Th[2])*dTh[1]*L[1]*L[2]*sin(Th[2]) + (Cs*dTh[2]*pow(L[2],2)*sin(Th[2]))/2. - Cs*dxL*L[2]*pow(sin(Th[2]),2) + Cv*cos(Th[3])*dTh[1]*L[1]*L[3]*sin(Th[1] - Th[3]) + Cv*cos(Th[3])*dTh[2]*L[2]*L[3]*sin(Th[2] - Th[3]) + Cs*dyL*cos(Th[3])*L[3]*sin(Th[3]) - Cv*dyL*cos(Th[3])*L[3]*sin(Th[3]) + Cs*cos(Th[1] - Th[3])*dTh[1]*L[1]*L[3]*sin(Th[3]) + Cs*cos(Th[2] - Th[3])*dTh[2]*L[2]*L[3]*sin(Th[3]) + (Cs*dTh[3]*pow(L[3],2)*sin(Th[3]))/2. - Cs*dxL*L[3]*pow(sin(Th[3]),2) + Cv*cos(Th[4])*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4]) + Cv*cos(Th[4])*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4]) + Cv*cos(Th[4])*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4]) + Cs*dyL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dyL*cos(Th[4])*L[4]*sin(Th[4]) + Cs*cos(Th[1] - Th[4])*dTh[1]*L[1]*L[4]*sin(Th[4]) + Cs*cos(Th[2] - Th[4])*dTh[2]*L[2]*L[4]*sin(Th[4]) + Cs*cos(Th[3] - Th[4])*dTh[3]*L[3]*L[4]*sin(Th[4]) + (Cs*dTh[4]*pow(L[4],2)*sin(Th[4]))/2. - Cs*dxL*L[4]*pow(sin(Th[4]),2) + (L[5]*(-(Cs*sin(Th[5])*(-2*dyL*cos(Th[5]) - 2*cos(Th[1] - Th[5])*dTh[1]*L[1] - 2*cos(Th[2] - Th[5])*dTh[2]*L[2] - 2*cos(Th[3] - Th[5])*dTh[3]*L[3] - 2*cos(Th[4] - Th[5])*dTh[4]*L[4] - dTh[5]*L[5] + 2*dxL*sin(Th[5]))) + 2*Cv*cos(Th[5])*(-(dxL*cos(Th[5])) + dTh[1]*L[1]*sin(Th[1] - Th[5]) + dTh[2]*L[2]*sin(Th[2] - Th[5]) + dTh[3]*L[3]*sin(Th[3] - Th[5]) + dTh[4]*L[4]*sin(Th[4] - Th[5]) - dyL*sin(Th[5]))))/2. + (L[6]*(-(Cs*sin(Th[6])*(-2*dyL*cos(Th[6]) - 2*cos(Th[1] - Th[6])*dTh[1]*L[1] - 2*cos(Th[2] - Th[6])*dTh[2]*L[2] - 2*cos(Th[3] - Th[6])*dTh[3]*L[3] - 2*cos(Th[4] - Th[6])*dTh[4]*L[4] - 2*cos(Th[5] - Th[6])*dTh[5]*L[5] - dTh[6]*L[6] + 2*dxL*sin(Th[6]))) + 2*Cv*cos(Th[6])*(-(dxL*cos(Th[6])) + dTh[1]*L[1]*sin(Th[1] - Th[6]) + dTh[2]*L[2]*sin(Th[2] - Th[6]) + dTh[3]*L[3]*sin(Th[3] - Th[6]) + dTh[4]*L[4]*sin(Th[4] - Th[6]) + dTh[5]*L[5]*sin(Th[5] - Th[6]) - dyL*sin(Th[6]))))/2. - (Cs*L[7]*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + 2*dxL*sin(Th[7])))/2. - Cv*cos(Th[7])*L[7]*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7])) - (Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8])) - (Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + 2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9])) - (Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]));
 coefMat[1] = 0;
 coefMat[15] = -1;
 coefMat[29] = 0;
 coefMat[43] = -1;
 coefMat[57] = (cos(Th[1])*L[1]*M[1])/2. + cos(Th[1])*L[1]*M[2] + cos(Th[1])*L[1]*M[3] + cos(Th[1])*L[1]*M[4] + cos(Th[1])*L[1]*M[5] + cos(Th[1])*L[1]*M[6] + cos(Th[1])*L[1]*M[7] + cos(Th[1])*L[1]*M[8] + cos(Th[1])*L[1]*M[9] + cos(Th[1])*L[1]*M[10];
 coefMat[71] = (cos(Th[2])*L[2]*M[2])/2. + cos(Th[2])*L[2]*M[3] + cos(Th[2])*L[2]*M[4] + cos(Th[2])*L[2]*M[5] + cos(Th[2])*L[2]*M[6] + cos(Th[2])*L[2]*M[7] + cos(Th[2])*L[2]*M[8] + cos(Th[2])*L[2]*M[9] + cos(Th[2])*L[2]*M[10];
 coefMat[85] = (cos(Th[3])*L[3]*M[3])/2. + cos(Th[3])*L[3]*M[4] + cos(Th[3])*L[3]*M[5] + cos(Th[3])*L[3]*M[6] + cos(Th[3])*L[3]*M[7] + cos(Th[3])*L[3]*M[8] + cos(Th[3])*L[3]*M[9] + cos(Th[3])*L[3]*M[10];
 coefMat[99] = (cos(Th[4])*L[4]*M[4])/2. + cos(Th[4])*L[4]*M[5] + cos(Th[4])*L[4]*M[6] + cos(Th[4])*L[4]*M[7] + cos(Th[4])*L[4]*M[8] + cos(Th[4])*L[4]*M[9] + cos(Th[4])*L[4]*M[10];
 coefMat[113] = (cos(Th[5])*L[5]*M[5])/2. + cos(Th[5])*L[5]*M[6] + cos(Th[5])*L[5]*M[7] + cos(Th[5])*L[5]*M[8] + cos(Th[5])*L[5]*M[9] + cos(Th[5])*L[5]*M[10];
 coefMat[127] = (cos(Th[6])*L[6]*M[6])/2. + cos(Th[6])*L[6]*M[7] + cos(Th[6])*L[6]*M[8] + cos(Th[6])*L[6]*M[9] + cos(Th[6])*L[6]*M[10];
 coefMat[141] = (cos(Th[7])*L[7]*M[7])/2. + cos(Th[7])*L[7]*M[8] + cos(Th[7])*L[7]*M[9] + cos(Th[7])*L[7]*M[10];
 coefMat[155] = (cos(Th[8])*L[8]*M[8])/2. + cos(Th[8])*L[8]*M[9] + cos(Th[8])*L[8]*M[10];
 coefMat[169] = (cos(Th[9])*L[9]*M[9])/2. + cos(Th[9])*L[9]*M[10];
 coefMat[183] = (cos(Th[10])*L[10]*M[10])/2.;
 rhsVec[1] = -(Cs*dyL*pow(cos(Th[1]),2)*L[1]) - (Cs*cos(Th[1])*dTh[1]*pow(L[1],2))/2. - Cs*dyL*pow(cos(Th[2]),2)*L[2] - Cs*cos(Th[1] - Th[2])*cos(Th[2])*dTh[1]*L[1]*L[2] - (Cs*cos(Th[2])*dTh[2]*pow(L[2],2))/2. - Cs*dyL*pow(cos(Th[3]),2)*L[3] - Cs*cos(Th[1] - Th[3])*cos(Th[3])*dTh[1]*L[1]*L[3] - Cs*cos(Th[2] - Th[3])*cos(Th[3])*dTh[2]*L[2]*L[3] - (Cs*cos(Th[3])*dTh[3]*pow(L[3],2))/2. - Cs*dyL*pow(cos(Th[4]),2)*L[4] - Cs*cos(Th[1] - Th[4])*cos(Th[4])*dTh[1]*L[1]*L[4] - Cs*cos(Th[2] - Th[4])*cos(Th[4])*dTh[2]*L[2]*L[4] - Cs*cos(Th[3] - Th[4])*cos(Th[4])*dTh[3]*L[3]*L[4] - (Cs*cos(Th[4])*dTh[4]*pow(L[4],2))/2. + Cs*dxL*cos(Th[1])*L[1]*sin(Th[1]) - Cv*dxL*cos(Th[1])*L[1]*sin(Th[1]) - Cv*dyL*L[1]*pow(sin(Th[1]),2) - M[1]*(ddyL - (pow(dTh[1],2)*L[1]*sin(Th[1]))/2.) + Cs*dxL*cos(Th[2])*L[2]*sin(Th[2]) - Cv*dxL*cos(Th[2])*L[2]*sin(Th[2]) + Cv*dTh[1]*L[1]*L[2]*sin(Th[1] - Th[2])*sin(Th[2]) - Cv*dyL*L[2]*pow(sin(Th[2]),2) - M[2]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - (pow(dTh[2],2)*L[2]*sin(Th[2]))/2.) + Cs*dxL*cos(Th[3])*L[3]*sin(Th[3]) - Cv*dxL*cos(Th[3])*L[3]*sin(Th[3]) + Cv*dTh[1]*L[1]*L[3]*sin(Th[1] - Th[3])*sin(Th[3]) + Cv*dTh[2]*L[2]*L[3]*sin(Th[2] - Th[3])*sin(Th[3]) - Cv*dyL*L[3]*pow(sin(Th[3]),2) - M[3]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - (pow(dTh[3],2)*L[3]*sin(Th[3]))/2.) + Cs*dxL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dxL*cos(Th[4])*L[4]*sin(Th[4]) + Cv*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4])*sin(Th[4]) + Cv*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4])*sin(Th[4]) + Cv*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4])*sin(Th[4]) - Cv*dyL*L[4]*pow(sin(Th[4]),2) - M[4]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - (pow(dTh[4],2)*L[4]*sin(Th[4]))/2.) - M[5]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - (pow(dTh[5],2)*L[5]*sin(Th[5]))/2.) - (L[5]*(Cs*cos(Th[5])*(2*dyL*cos(Th[5]) + 2*cos(Th[1] - Th[5])*dTh[1]*L[1] + 2*cos(Th[2] - Th[5])*dTh[2]*L[2] + 2*cos(Th[3] - Th[5])*dTh[3]*L[3] + 2*cos(Th[4] - Th[5])*dTh[4]*L[4] + dTh[5]*L[5] - 2*dxL*sin(Th[5])) + 2*Cv*sin(Th[5])*(dxL*cos(Th[5]) - dTh[1]*L[1]*sin(Th[1] - Th[5]) - dTh[2]*L[2]*sin(Th[2] - Th[5]) - dTh[3]*L[3]*sin(Th[3] - Th[5]) - dTh[4]*L[4]*sin(Th[4] - Th[5]) + dyL*sin(Th[5]))))/2. - M[6]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - (pow(dTh[6],2)*L[6]*sin(Th[6]))/2.) - (L[6]*(Cs*cos(Th[6])*(2*dyL*cos(Th[6]) + 2*cos(Th[1] - Th[6])*dTh[1]*L[1] + 2*cos(Th[2] - Th[6])*dTh[2]*L[2] + 2*cos(Th[3] - Th[6])*dTh[3]*L[3] + 2*cos(Th[4] - Th[6])*dTh[4]*L[4] + 2*cos(Th[5] - Th[6])*dTh[5]*L[5] + dTh[6]*L[6] - 2*dxL*sin(Th[6])) + 2*Cv*sin(Th[6])*(dxL*cos(Th[6]) - dTh[1]*L[1]*sin(Th[1] - Th[6]) - dTh[2]*L[2]*sin(Th[2] - Th[6]) - dTh[3]*L[3]*sin(Th[3] - Th[6]) - dTh[4]*L[4]*sin(Th[4] - Th[6]) - dTh[5]*L[5]*sin(Th[5] - Th[6]) + dyL*sin(Th[6]))))/2. - (Cs*cos(Th[7])*L[7]*(2*dyL*cos(Th[7]) + 2*cos(Th[1] - Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + 2*cos(Th[3] - Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + 2*cos(Th[5] - Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + dTh[7]*L[7] - 2*dxL*sin(Th[7])))/2. - Cv*L[7]*sin(Th[7])*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7])) - M[7]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - (pow(dTh[7],2)*L[7]*sin(Th[7]))/2.) - (Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + 2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + 2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + 2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + 2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8])) - M[8]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.) - (Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + 2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + 2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + 2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + 2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9])) - M[9]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.) - (Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10])) - M[10]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.);
 coefMat[2] = 0;
 coefMat[16] = 0;
 coefMat[30] = 0;
 coefMat[44] = 0;
 coefMat[58] = L[1]*sin(Th[1]);
 coefMat[72] = L[2]*sin(Th[2]);
 coefMat[86] = L[3]*sin(Th[3]);
 coefMat[100] = L[4]*sin(Th[4]);
 coefMat[114] = L[5]*sin(Th[5]);
 coefMat[128] = L[6]*sin(Th[6]);
 coefMat[142] = L[7]*sin(Th[7]);
 coefMat[156] = L[8]*sin(Th[8]);
 coefMat[170] = L[9]*sin(Th[9]);
 coefMat[184] = L[10]*sin(Th[10]);
 rhsVec[2] = ddxL - ddxR - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - cos(Th[9])*pow(dTh[9],2)*L[9] - cos(Th[10])*pow(dTh[10],2)*L[10];
 coefMat[3] = 0;
 coefMat[17] = 0;
 coefMat[31] = 0;
 coefMat[45] = 0;
 coefMat[59] = -(cos(Th[1])*L[1]);
 coefMat[73] = -(cos(Th[2])*L[2]);
 coefMat[87] = -(cos(Th[3])*L[3]);
 coefMat[101] = -(cos(Th[4])*L[4]);
 coefMat[115] = -(cos(Th[5])*L[5]);
 coefMat[129] = -(cos(Th[6])*L[6]);
 coefMat[143] = -(cos(Th[7])*L[7]);
 coefMat[157] = -(cos(Th[8])*L[8]);
 coefMat[171] = -(cos(Th[9])*L[9]);
 coefMat[185] = -(cos(Th[10])*L[10]);
 rhsVec[3] = ddyL - ddyR - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - pow(dTh[9],2)*L[9]*sin(Th[9]) - pow(dTh[10],2)*L[10]*sin(Th[10]);
 coefMat[4] = 0;
 coefMat[18] = 0;
 coefMat[32] = L[1]*sin(Th[1]);
 coefMat[46] = -(cos(Th[1])*L[1]);
 coefMat[60] = (pow(L[1],2)*M[1])/12. + (M[1]*((pow(cos(Th[1]),2)*pow(L[1],2))/2. + (pow(L[1],2)*pow(sin(Th[1]),2))/2.))/2. + (M[2]*(2*pow(cos(Th[1]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(Th[1]),2)))/2. + (M[3]*(2*pow(cos(Th[1]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(Th[1]),2)))/2. + (M[4]*(2*pow(cos(Th[1]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(Th[1]),2)))/2. + (M[5]*(2*pow(cos(Th[1]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(Th[1]),2)))/2. + (M[6]*(2*pow(cos(Th[1]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(Th[1]),2)))/2. + (M[7]*(2*pow(cos(Th[1]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(Th[1]),2)))/2. + (M[8]*(2*pow(cos(Th[1]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(Th[1]),2)))/2. + (M[9]*(2*pow(cos(Th[1]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(Th[1]),2)))/2. + (M[10]*(2*pow(cos(Th[1]),2)*pow(L[1],2) + 2*pow(L[1],2)*pow(sin(Th[1]),2)))/2.;
 coefMat[74] = (M[2]*(cos(Th[1])*cos(Th[2])*L[1]*L[2] + L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + (M[3]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + 2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + (M[4]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + 2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + (M[5]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + 2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + (M[6]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + 2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + (M[7]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + 2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + (M[8]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + 2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + (M[9]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + 2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + (M[10]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + 2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2.;
 coefMat[88] = (M[3]*(cos(Th[1])*cos(Th[3])*L[1]*L[3] + L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + (M[4]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + 2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + (M[5]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + 2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + (M[6]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + 2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + (M[7]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + 2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + (M[8]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + 2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + (M[9]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + 2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + (M[10]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + 2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2.;
 coefMat[102] = (M[4]*(cos(Th[1])*cos(Th[4])*L[1]*L[4] + L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + (M[5]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + 2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + (M[6]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + 2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + (M[7]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + 2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + (M[8]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + 2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + (M[9]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + 2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + (M[10]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + 2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2.;
 coefMat[116] = (M[5]*(cos(Th[1])*cos(Th[5])*L[1]*L[5] + L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + (M[6]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + 2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + (M[7]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + 2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + (M[8]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + 2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + (M[9]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + 2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + (M[10]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + 2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2.;
 coefMat[130] = (M[6]*(cos(Th[1])*cos(Th[6])*L[1]*L[6] + L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2. + (M[7]*(2*cos(Th[1])*cos(Th[6])*L[1]*L[6] + 2*L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2. + (M[8]*(2*cos(Th[1])*cos(Th[6])*L[1]*L[6] + 2*L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2. + (M[9]*(2*cos(Th[1])*cos(Th[6])*L[1]*L[6] + 2*L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2. + (M[10]*(2*cos(Th[1])*cos(Th[6])*L[1]*L[6] + 2*L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2.;
 coefMat[144] = (M[7]*(cos(Th[1])*cos(Th[7])*L[1]*L[7] + L[1]*L[7]*sin(Th[1])*sin(Th[7])))/2. + (M[8]*(2*cos(Th[1])*cos(Th[7])*L[1]*L[7] + 2*L[1]*L[7]*sin(Th[1])*sin(Th[7])))/2. + (M[9]*(2*cos(Th[1])*cos(Th[7])*L[1]*L[7] + 2*L[1]*L[7]*sin(Th[1])*sin(Th[7])))/2. + (M[10]*(2*cos(Th[1])*cos(Th[7])*L[1]*L[7] + 2*L[1]*L[7]*sin(Th[1])*sin(Th[7])))/2.;
 coefMat[158] = (M[8]*(cos(Th[1])*cos(Th[8])*L[1]*L[8] + L[1]*L[8]*sin(Th[1])*sin(Th[8])))/2. + (M[9]*(2*cos(Th[1])*cos(Th[8])*L[1]*L[8] + 2*L[1]*L[8]*sin(Th[1])*sin(Th[8])))/2. + (M[10]*(2*cos(Th[1])*cos(Th[8])*L[1]*L[8] + 2*L[1]*L[8]*sin(Th[1])*sin(Th[8])))/2.;
 coefMat[172] = (M[9]*(cos(Th[1])*cos(Th[9])*L[1]*L[9] + L[1]*L[9]*sin(Th[1])*sin(Th[9])))/2. + (M[10]*(2*cos(Th[1])*cos(Th[9])*L[1]*L[9] + 2*L[1]*L[9]*sin(Th[1])*sin(Th[9])))/2.;
 coefMat[186] = (M[10]*(cos(Th[1])*cos(Th[10])*L[1]*L[10] + L[1]*L[10]*sin(Th[1])*sin(Th[10])))/2.;
 rhsVec[4] = tauL - (Cs*dTh[1]*pow(L[1],3))/12. - (L[1]*sin(Th[1])*(-(Cv*dxL*pow(cos(Th[1]),2)*L[1]) + Cs*dyL*cos(Th[1])*L[1]*sin(Th[1]) - Cv*dyL*cos(Th[1])*L[1]*sin(Th[1]) + (Cs*dTh[1]*pow(L[1],2)*sin(Th[1]))/2. - Cs*dxL*L[1]*pow(sin(Th[1]),2)))/2. + (cos(Th[1])*L[1]*(-(Cs*dyL*pow(cos(Th[1]),2)*L[1]) - (Cs*cos(Th[1])*dTh[1]*pow(L[1],2))/2. + Cs*dxL*cos(Th[1])*L[1]*sin(Th[1]) - Cv*dxL*cos(Th[1])*L[1]*sin(Th[1]) - Cv*dyL*L[1]*pow(sin(Th[1]),2)))/2. + (M[1]*(-(dTh[1]*L[1]*(dyL + (cos(Th[1])*dTh[1]*L[1])/2.)*sin(Th[1])) - cos(Th[1])*dTh[1]*L[1]*(dxL - (dTh[1]*L[1]*sin(Th[1]))/2.)))/2. - (M[1]*(-(dTh[1]*L[1]*(dyL + (cos(Th[1])*dTh[1]*L[1])/2.)*sin(Th[1])) - L[1]*(ddxL - (cos(Th[1])*pow(dTh[1],2)*L[1])/2.)*sin(Th[1]) - cos(Th[1])*dTh[1]*L[1]*(dxL - (dTh[1]*L[1]*sin(Th[1]))/2.) + cos(Th[1])*L[1]*(ddyL - (pow(dTh[1],2)*L[1]*sin(Th[1]))/2.)))/2. - L[1]*sin(Th[1])*(-(Cv*dxL*pow(cos(Th[2]),2)*L[2]) + Cv*cos(Th[2])*dTh[1]*L[1]*L[2]*sin(Th[1] - Th[2]) + Cs*dyL*cos(Th[2])*L[2]*sin(Th[2]) - Cv*dyL*cos(Th[2])*L[2]*sin(Th[2]) + Cs*cos(Th[1] - Th[2])*dTh[1]*L[1]*L[2]*sin(Th[2]) + (Cs*dTh[2]*pow(L[2],2)*sin(Th[2]))/2. - Cs*dxL*L[2]*pow(sin(Th[2]),2)) + cos(Th[1])*L[1]*(-(Cs*dyL*pow(cos(Th[2]),2)*L[2]) - Cs*cos(Th[1] - Th[2])*cos(Th[2])*dTh[1]*L[1]*L[2] - (Cs*cos(Th[2])*dTh[2]*pow(L[2],2))/2. + Cs*dxL*cos(Th[2])*L[2]*sin(Th[2]) - Cv*dxL*cos(Th[2])*L[2]*sin(Th[2]) + Cv*dTh[1]*L[1]*L[2]*sin(Th[1] - Th[2])*sin(Th[2]) - Cv*dyL*L[2]*pow(sin(Th[2]),2)) + (M[2]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + (cos(Th[2])*dTh[2]*L[2])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - (dTh[2]*L[2]*sin(Th[2]))/2.)))/2. - (M[2]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + (cos(Th[2])*dTh[2]*L[2])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - (cos(Th[2])*pow(dTh[2],2)*L[2])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - (dTh[2]*L[2]*sin(Th[2]))/2.) + 2*cos(Th[1])*L[1]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - (pow(dTh[2],2)*L[2]*sin(Th[2]))/2.)))/2. - L[1]*sin(Th[1])*(-(Cv*dxL*pow(cos(Th[3]),2)*L[3]) + Cv*cos(Th[3])*dTh[1]*L[1]*L[3]*sin(Th[1] - Th[3]) + Cv*cos(Th[3])*dTh[2]*L[2]*L[3]*sin(Th[2] - Th[3]) + Cs*dyL*cos(Th[3])*L[3]*sin(Th[3]) - Cv*dyL*cos(Th[3])*L[3]*sin(Th[3]) + Cs*cos(Th[1] - Th[3])*dTh[1]*L[1]*L[3]*sin(Th[3]) + Cs*cos(Th[2] - Th[3])*dTh[2]*L[2]*L[3]*sin(Th[3]) + (Cs*dTh[3]*pow(L[3],2)*sin(Th[3]))/2. - Cs*dxL*L[3]*pow(sin(Th[3]),2)) + cos(Th[1])*L[1]*(-(Cs*dyL*pow(cos(Th[3]),2)*L[3]) - Cs*cos(Th[1] - Th[3])*cos(Th[3])*dTh[1]*L[1]*L[3] - Cs*cos(Th[2] - Th[3])*cos(Th[3])*dTh[2]*L[2]*L[3] - (Cs*cos(Th[3])*dTh[3]*pow(L[3],2))/2. + Cs*dxL*cos(Th[3])*L[3]*sin(Th[3]) - Cv*dxL*cos(Th[3])*L[3]*sin(Th[3]) + Cv*dTh[1]*L[1]*L[3]*sin(Th[1] - Th[3])*sin(Th[3]) + Cv*dTh[2]*L[2]*L[3]*sin(Th[2] - Th[3])*sin(Th[3]) - Cv*dyL*L[3]*pow(sin(Th[3]),2)) + (M[3]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + (cos(Th[3])*dTh[3]*L[3])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - (dTh[3]*L[3]*sin(Th[3]))/2.)))/2. - (M[3]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + (cos(Th[3])*dTh[3]*L[3])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - (cos(Th[3])*pow(dTh[3],2)*L[3])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - (dTh[3]*L[3]*sin(Th[3]))/2.) + 2*cos(Th[1])*L[1]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - (pow(dTh[3],2)*L[3]*sin(Th[3]))/2.)))/2. - L[1]*sin(Th[1])*(-(Cv*dxL*pow(cos(Th[4]),2)*L[4]) + Cv*cos(Th[4])*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4]) + Cv*cos(Th[4])*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4]) + Cv*cos(Th[4])*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4]) + Cs*dyL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dyL*cos(Th[4])*L[4]*sin(Th[4]) + Cs*cos(Th[1] - Th[4])*dTh[1]*L[1]*L[4]*sin(Th[4]) + Cs*cos(Th[2] - Th[4])*dTh[2]*L[2]*L[4]*sin(Th[4]) + Cs*cos(Th[3] - Th[4])*dTh[3]*L[3]*L[4]*sin(Th[4]) + (Cs*dTh[4]*pow(L[4],2)*sin(Th[4]))/2. - Cs*dxL*L[4]*pow(sin(Th[4]),2)) + cos(Th[1])*L[1]*(-(Cs*dyL*pow(cos(Th[4]),2)*L[4]) - Cs*cos(Th[1] - Th[4])*cos(Th[4])*dTh[1]*L[1]*L[4] - Cs*cos(Th[2] - Th[4])*cos(Th[4])*dTh[2]*L[2]*L[4] - Cs*cos(Th[3] - Th[4])*cos(Th[4])*dTh[3]*L[3]*L[4] - (Cs*cos(Th[4])*dTh[4]*pow(L[4],2))/2. + Cs*dxL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dxL*cos(Th[4])*L[4]*sin(Th[4]) + Cv*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4])*sin(Th[4]) + Cv*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4])*sin(Th[4]) + Cv*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4])*sin(Th[4]) - Cv*dyL*L[4]*pow(sin(Th[4]),2)) + (M[4]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + (cos(Th[4])*dTh[4]*L[4])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - (dTh[4]*L[4]*sin(Th[4]))/2.)))/2. - (M[4]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + (cos(Th[4])*dTh[4]*L[4])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - (cos(Th[4])*pow(dTh[4],2)*L[4])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - (dTh[4]*L[4]*sin(Th[4]))/2.) + 2*cos(Th[1])*L[1]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - (pow(dTh[4],2)*L[4]*sin(Th[4]))/2.)))/2. - (L[1]*L[5]*sin(Th[1])*(-(Cs*sin(Th[5])*(-2*dyL*cos(Th[5]) - 2*cos(Th[1] - Th[5])*dTh[1]*L[1] - 2*cos(Th[2] - Th[5])*dTh[2]*L[2] - 2*cos(Th[3] - Th[5])*dTh[3]*L[3] - 2*cos(Th[4] - Th[5])*dTh[4]*L[4] - dTh[5]*L[5] + 2*dxL*sin(Th[5]))) + 2*Cv*cos(Th[5])*(-(dxL*cos(Th[5])) + dTh[1]*L[1]*sin(Th[1] - Th[5]) + dTh[2]*L[2]*sin(Th[2] - Th[5]) + dTh[3]*L[3]*sin(Th[3] - Th[5]) + dTh[4]*L[4]*sin(Th[4] - Th[5]) - dyL*sin(Th[5]))))/2. - (cos(Th[1])*L[1]*L[5]*(Cs*cos(Th[5])*(2*dyL*cos(Th[5]) + 2*cos(Th[1] - Th[5])*dTh[1]*L[1] + 2*cos(Th[2] - Th[5])*dTh[2]*L[2] + 2*cos(Th[3] - Th[5])*dTh[3]*L[3] + 2*cos(Th[4] - Th[5])*dTh[4]*L[4] + dTh[5]*L[5] - 2*dxL*sin(Th[5])) + 2*Cv*sin(Th[5])*(dxL*cos(Th[5]) - dTh[1]*L[1]*sin(Th[1] - Th[5]) - dTh[2]*L[2]*sin(Th[2] - Th[5]) - dTh[3]*L[3]*sin(Th[3] - Th[5]) - dTh[4]*L[4]*sin(Th[4] - Th[5]) + dyL*sin(Th[5]))))/2. + (M[5]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + (cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - (dTh[5]*L[5]*sin(Th[5]))/2.)))/2. - (M[5]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + (cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - (cos(Th[5])*pow(dTh[5],2)*L[5])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - (dTh[5]*L[5]*sin(Th[5]))/2.) + 2*cos(Th[1])*L[1]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - (pow(dTh[5],2)*L[5]*sin(Th[5]))/2.)))/2. - (L[1]*L[6]*sin(Th[1])*(-(Cs*sin(Th[6])*(-2*dyL*cos(Th[6]) - 2*cos(Th[1] - Th[6])*dTh[1]*L[1] - 2*cos(Th[2] - Th[6])*dTh[2]*L[2] - 2*cos(Th[3] - Th[6])*dTh[3]*L[3] - 2*cos(Th[4] - Th[6])*dTh[4]*L[4] - 2*cos(Th[5] - Th[6])*dTh[5]*L[5] - dTh[6]*L[6] + 2*dxL*sin(Th[6]))) + 2*Cv*cos(Th[6])*(-(dxL*cos(Th[6])) + dTh[1]*L[1]*sin(Th[1] - Th[6]) + dTh[2]*L[2]*sin(Th[2] - Th[6]) + dTh[3]*L[3]*sin(Th[3] - Th[6]) + dTh[4]*L[4]*sin(Th[4] - Th[6]) + dTh[5]*L[5]*sin(Th[5] - Th[6]) - dyL*sin(Th[6]))))/2. - (cos(Th[1])*L[1]*L[6]*(Cs*cos(Th[6])*(2*dyL*cos(Th[6]) + 2*cos(Th[1] - Th[6])*dTh[1]*L[1] + 2*cos(Th[2] - Th[6])*dTh[2]*L[2] + 2*cos(Th[3] - Th[6])*dTh[3]*L[3] + 2*cos(Th[4] - Th[6])*dTh[4]*L[4] + 2*cos(Th[5] - Th[6])*dTh[5]*L[5] + dTh[6]*L[6] - 2*dxL*sin(Th[6])) + 2*Cv*sin(Th[6])*(dxL*cos(Th[6]) - dTh[1]*L[1]*sin(Th[1] - Th[6]) - dTh[2]*L[2]*sin(Th[2] - Th[6]) - dTh[3]*L[3]*sin(Th[3] - Th[6]) - dTh[4]*L[4]*sin(Th[4] - Th[6]) - dTh[5]*L[5]*sin(Th[5] - Th[6]) + dyL*sin(Th[6]))))/2. + (M[6]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.)))/2. - (M[6]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - (cos(Th[6])*pow(dTh[6],2)*L[6])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.) + 2*cos(Th[1])*L[1]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - (pow(dTh[6],2)*L[6]*sin(Th[6]))/2.)))/2. - L[1]*sin(Th[1])*(-(Cs*L[7]*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + 2*dxL*sin(Th[7])))/2. - Cv*cos(Th[7])*L[7]*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7]))) + cos(Th[1])*L[1]*(-(Cs*cos(Th[7])*L[7]*(2*dyL*cos(Th[7]) + 2*cos(Th[1] - Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + 2*cos(Th[3] - Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + 2*cos(Th[5] - Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + dTh[7]*L[7] - 2*dxL*sin(Th[7])))/2. - Cv*L[7]*sin(Th[7])*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7]))) + (M[7]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + (cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - (dTh[7]*L[7]*sin(Th[7]))/2.)))/2. - (M[7]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + (cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - (cos(Th[7])*pow(dTh[7],2)*L[7])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - (dTh[7]*L[7]*sin(Th[7]))/2.) + 2*cos(Th[1])*L[1]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - (pow(dTh[7],2)*L[7]*sin(Th[7]))/2.)))/2. - L[1]*sin(Th[1])*(-(Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))) + cos(Th[1])*L[1]*(-(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + 2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + 2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + 2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + 2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))) + (M[8]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + (cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.)))/2. - (M[8]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + (cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - (cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.) + 2*cos(Th[1])*L[1]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.)))/2. - L[1]*sin(Th[1])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + 2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))) + cos(Th[1])*L[1]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + 2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + 2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + 2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + 2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))) + (M[9]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - (M[9]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - (cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + 2*cos(Th[1])*L[1]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - L[1]*sin(Th[1])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + cos(Th[1])*L[1]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + (M[10]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[1]*L[1]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[1]) - 2*L[1]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - cos(Th[9])*pow(dTh[9],2)*L[9] - (cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[1]) - 2*cos(Th[1])*dTh[1]*L[1]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[1])*L[1]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;
 coefMat[5] = 0;
 coefMat[19] = 0;
 coefMat[33] = L[2]*sin(Th[2]);
 coefMat[47] = -(cos(Th[2])*L[2]);
 coefMat[61] = (M[2]*(cos(Th[1])*cos(Th[2])*L[1]*L[2] + L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + (M[3]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + 2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + (M[4]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + 2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + (M[5]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + 2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + (M[6]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + 2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + (M[7]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + 2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + (M[8]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + 2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + (M[9]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + 2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2. + (M[10]*(2*cos(Th[1])*cos(Th[2])*L[1]*L[2] + 2*L[1]*L[2]*sin(Th[1])*sin(Th[2])))/2.;
 coefMat[75] = (pow(L[2],2)*M[2])/12. + (M[2]*((pow(cos(Th[2]),2)*pow(L[2],2))/2. + (pow(L[2],2)*pow(sin(Th[2]),2))/2.))/2. + (M[3]*(2*pow(cos(Th[2]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(Th[2]),2)))/2. + (M[4]*(2*pow(cos(Th[2]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(Th[2]),2)))/2. + (M[5]*(2*pow(cos(Th[2]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(Th[2]),2)))/2. + (M[6]*(2*pow(cos(Th[2]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(Th[2]),2)))/2. + (M[7]*(2*pow(cos(Th[2]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(Th[2]),2)))/2. + (M[8]*(2*pow(cos(Th[2]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(Th[2]),2)))/2. + (M[9]*(2*pow(cos(Th[2]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(Th[2]),2)))/2. + (M[10]*(2*pow(cos(Th[2]),2)*pow(L[2],2) + 2*pow(L[2],2)*pow(sin(Th[2]),2)))/2.;
 coefMat[89] = (M[3]*(cos(Th[2])*cos(Th[3])*L[2]*L[3] + L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + (M[4]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + 2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + (M[5]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + 2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + (M[6]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + 2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + (M[7]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + 2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + (M[8]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + 2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + (M[9]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + 2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + (M[10]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + 2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2.;
 coefMat[103] = (M[4]*(cos(Th[2])*cos(Th[4])*L[2]*L[4] + L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + (M[5]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + 2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + (M[6]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + 2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + (M[7]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + 2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + (M[8]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + 2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + (M[9]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + 2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + (M[10]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + 2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2.;
 coefMat[117] = (M[5]*(cos(Th[2])*cos(Th[5])*L[2]*L[5] + L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + (M[6]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + 2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + (M[7]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + 2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + (M[8]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + 2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + (M[9]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + 2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + (M[10]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + 2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2.;
 coefMat[131] = (M[6]*(cos(Th[2])*cos(Th[6])*L[2]*L[6] + L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2. + (M[7]*(2*cos(Th[2])*cos(Th[6])*L[2]*L[6] + 2*L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2. + (M[8]*(2*cos(Th[2])*cos(Th[6])*L[2]*L[6] + 2*L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2. + (M[9]*(2*cos(Th[2])*cos(Th[6])*L[2]*L[6] + 2*L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2. + (M[10]*(2*cos(Th[2])*cos(Th[6])*L[2]*L[6] + 2*L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2.;
 coefMat[145] = (M[7]*(cos(Th[2])*cos(Th[7])*L[2]*L[7] + L[2]*L[7]*sin(Th[2])*sin(Th[7])))/2. + (M[8]*(2*cos(Th[2])*cos(Th[7])*L[2]*L[7] + 2*L[2]*L[7]*sin(Th[2])*sin(Th[7])))/2. + (M[9]*(2*cos(Th[2])*cos(Th[7])*L[2]*L[7] + 2*L[2]*L[7]*sin(Th[2])*sin(Th[7])))/2. + (M[10]*(2*cos(Th[2])*cos(Th[7])*L[2]*L[7] + 2*L[2]*L[7]*sin(Th[2])*sin(Th[7])))/2.;
 coefMat[159] = (M[8]*(cos(Th[2])*cos(Th[8])*L[2]*L[8] + L[2]*L[8]*sin(Th[2])*sin(Th[8])))/2. + (M[9]*(2*cos(Th[2])*cos(Th[8])*L[2]*L[8] + 2*L[2]*L[8]*sin(Th[2])*sin(Th[8])))/2. + (M[10]*(2*cos(Th[2])*cos(Th[8])*L[2]*L[8] + 2*L[2]*L[8]*sin(Th[2])*sin(Th[8])))/2.;
 coefMat[173] = (M[9]*(cos(Th[2])*cos(Th[9])*L[2]*L[9] + L[2]*L[9]*sin(Th[2])*sin(Th[9])))/2. + (M[10]*(2*cos(Th[2])*cos(Th[9])*L[2]*L[9] + 2*L[2]*L[9]*sin(Th[2])*sin(Th[9])))/2.;
 coefMat[187] = (M[10]*(cos(Th[2])*cos(Th[10])*L[2]*L[10] + L[2]*L[10]*sin(Th[2])*sin(Th[10])))/2.;
 rhsVec[5] = -(Cs*dTh[2]*pow(L[2],3))/12. - (L[2]*sin(Th[2])*(-(Cv*dxL*pow(cos(Th[2]),2)*L[2]) + Cv*cos(Th[2])*dTh[1]*L[1]*L[2]*sin(Th[1] - Th[2]) + Cs*dyL*cos(Th[2])*L[2]*sin(Th[2]) - Cv*dyL*cos(Th[2])*L[2]*sin(Th[2]) + Cs*cos(Th[1] - Th[2])*dTh[1]*L[1]*L[2]*sin(Th[2]) + (Cs*dTh[2]*pow(L[2],2)*sin(Th[2]))/2. - Cs*dxL*L[2]*pow(sin(Th[2]),2)))/2. + (cos(Th[2])*L[2]*(-(Cs*dyL*pow(cos(Th[2]),2)*L[2]) - Cs*cos(Th[1] - Th[2])*cos(Th[2])*dTh[1]*L[1]*L[2] - (Cs*cos(Th[2])*dTh[2]*pow(L[2],2))/2. + Cs*dxL*cos(Th[2])*L[2]*sin(Th[2]) - Cv*dxL*cos(Th[2])*L[2]*sin(Th[2]) + Cv*dTh[1]*L[1]*L[2]*sin(Th[1] - Th[2])*sin(Th[2]) - Cv*dyL*L[2]*pow(sin(Th[2]),2)))/2. + (M[2]*(-(dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + (cos(Th[2])*dTh[2]*L[2])/2.)*sin(Th[2])) - cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - (dTh[2]*L[2]*sin(Th[2]))/2.)))/2. - (M[2]*(-(dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + (cos(Th[2])*dTh[2]*L[2])/2.)*sin(Th[2])) - L[2]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - (cos(Th[2])*pow(dTh[2],2)*L[2])/2.)*sin(Th[2]) - cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - (dTh[2]*L[2]*sin(Th[2]))/2.) + cos(Th[2])*L[2]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - (pow(dTh[2],2)*L[2]*sin(Th[2]))/2.)))/2. - L[2]*sin(Th[2])*(-(Cv*dxL*pow(cos(Th[3]),2)*L[3]) + Cv*cos(Th[3])*dTh[1]*L[1]*L[3]*sin(Th[1] - Th[3]) + Cv*cos(Th[3])*dTh[2]*L[2]*L[3]*sin(Th[2] - Th[3]) + Cs*dyL*cos(Th[3])*L[3]*sin(Th[3]) - Cv*dyL*cos(Th[3])*L[3]*sin(Th[3]) + Cs*cos(Th[1] - Th[3])*dTh[1]*L[1]*L[3]*sin(Th[3]) + Cs*cos(Th[2] - Th[3])*dTh[2]*L[2]*L[3]*sin(Th[3]) + (Cs*dTh[3]*pow(L[3],2)*sin(Th[3]))/2. - Cs*dxL*L[3]*pow(sin(Th[3]),2)) + cos(Th[2])*L[2]*(-(Cs*dyL*pow(cos(Th[3]),2)*L[3]) - Cs*cos(Th[1] - Th[3])*cos(Th[3])*dTh[1]*L[1]*L[3] - Cs*cos(Th[2] - Th[3])*cos(Th[3])*dTh[2]*L[2]*L[3] - (Cs*cos(Th[3])*dTh[3]*pow(L[3],2))/2. + Cs*dxL*cos(Th[3])*L[3]*sin(Th[3]) - Cv*dxL*cos(Th[3])*L[3]*sin(Th[3]) + Cv*dTh[1]*L[1]*L[3]*sin(Th[1] - Th[3])*sin(Th[3]) + Cv*dTh[2]*L[2]*L[3]*sin(Th[2] - Th[3])*sin(Th[3]) - Cv*dyL*L[3]*pow(sin(Th[3]),2)) + (M[3]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + (cos(Th[3])*dTh[3]*L[3])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - (dTh[3]*L[3]*sin(Th[3]))/2.)))/2. - (M[3]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + (cos(Th[3])*dTh[3]*L[3])/2.)*sin(Th[2]) - 2*L[2]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - (cos(Th[3])*pow(dTh[3],2)*L[3])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - (dTh[3]*L[3]*sin(Th[3]))/2.) + 2*cos(Th[2])*L[2]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - (pow(dTh[3],2)*L[3]*sin(Th[3]))/2.)))/2. - L[2]*sin(Th[2])*(-(Cv*dxL*pow(cos(Th[4]),2)*L[4]) + Cv*cos(Th[4])*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4]) + Cv*cos(Th[4])*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4]) + Cv*cos(Th[4])*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4]) + Cs*dyL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dyL*cos(Th[4])*L[4]*sin(Th[4]) + Cs*cos(Th[1] - Th[4])*dTh[1]*L[1]*L[4]*sin(Th[4]) + Cs*cos(Th[2] - Th[4])*dTh[2]*L[2]*L[4]*sin(Th[4]) + Cs*cos(Th[3] - Th[4])*dTh[3]*L[3]*L[4]*sin(Th[4]) + (Cs*dTh[4]*pow(L[4],2)*sin(Th[4]))/2. - Cs*dxL*L[4]*pow(sin(Th[4]),2)) + cos(Th[2])*L[2]*(-(Cs*dyL*pow(cos(Th[4]),2)*L[4]) - Cs*cos(Th[1] - Th[4])*cos(Th[4])*dTh[1]*L[1]*L[4] - Cs*cos(Th[2] - Th[4])*cos(Th[4])*dTh[2]*L[2]*L[4] - Cs*cos(Th[3] - Th[4])*cos(Th[4])*dTh[3]*L[3]*L[4] - (Cs*cos(Th[4])*dTh[4]*pow(L[4],2))/2. + Cs*dxL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dxL*cos(Th[4])*L[4]*sin(Th[4]) + Cv*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4])*sin(Th[4]) + Cv*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4])*sin(Th[4]) + Cv*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4])*sin(Th[4]) - Cv*dyL*L[4]*pow(sin(Th[4]),2)) + (M[4]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + (cos(Th[4])*dTh[4]*L[4])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - (dTh[4]*L[4]*sin(Th[4]))/2.)))/2. - (M[4]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + (cos(Th[4])*dTh[4]*L[4])/2.)*sin(Th[2]) - 2*L[2]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - (cos(Th[4])*pow(dTh[4],2)*L[4])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - (dTh[4]*L[4]*sin(Th[4]))/2.) + 2*cos(Th[2])*L[2]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - (pow(dTh[4],2)*L[4]*sin(Th[4]))/2.)))/2. - (L[2]*L[5]*sin(Th[2])*(-(Cs*sin(Th[5])*(-2*dyL*cos(Th[5]) - 2*cos(Th[1] - Th[5])*dTh[1]*L[1] - 2*cos(Th[2] - Th[5])*dTh[2]*L[2] - 2*cos(Th[3] - Th[5])*dTh[3]*L[3] - 2*cos(Th[4] - Th[5])*dTh[4]*L[4] - dTh[5]*L[5] + 2*dxL*sin(Th[5]))) + 2*Cv*cos(Th[5])*(-(dxL*cos(Th[5])) + dTh[1]*L[1]*sin(Th[1] - Th[5]) + dTh[2]*L[2]*sin(Th[2] - Th[5]) + dTh[3]*L[3]*sin(Th[3] - Th[5]) + dTh[4]*L[4]*sin(Th[4] - Th[5]) - dyL*sin(Th[5]))))/2. - (cos(Th[2])*L[2]*L[5]*(Cs*cos(Th[5])*(2*dyL*cos(Th[5]) + 2*cos(Th[1] - Th[5])*dTh[1]*L[1] + 2*cos(Th[2] - Th[5])*dTh[2]*L[2] + 2*cos(Th[3] - Th[5])*dTh[3]*L[3] + 2*cos(Th[4] - Th[5])*dTh[4]*L[4] + dTh[5]*L[5] - 2*dxL*sin(Th[5])) + 2*Cv*sin(Th[5])*(dxL*cos(Th[5]) - dTh[1]*L[1]*sin(Th[1] - Th[5]) - dTh[2]*L[2]*sin(Th[2] - Th[5]) - dTh[3]*L[3]*sin(Th[3] - Th[5]) - dTh[4]*L[4]*sin(Th[4] - Th[5]) + dyL*sin(Th[5]))))/2. + (M[5]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + (cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - (dTh[5]*L[5]*sin(Th[5]))/2.)))/2. - (M[5]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + (cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[2]) - 2*L[2]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - (cos(Th[5])*pow(dTh[5],2)*L[5])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - (dTh[5]*L[5]*sin(Th[5]))/2.) + 2*cos(Th[2])*L[2]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - (pow(dTh[5],2)*L[5]*sin(Th[5]))/2.)))/2. - (L[2]*L[6]*sin(Th[2])*(-(Cs*sin(Th[6])*(-2*dyL*cos(Th[6]) - 2*cos(Th[1] - Th[6])*dTh[1]*L[1] - 2*cos(Th[2] - Th[6])*dTh[2]*L[2] - 2*cos(Th[3] - Th[6])*dTh[3]*L[3] - 2*cos(Th[4] - Th[6])*dTh[4]*L[4] - 2*cos(Th[5] - Th[6])*dTh[5]*L[5] - dTh[6]*L[6] + 2*dxL*sin(Th[6]))) + 2*Cv*cos(Th[6])*(-(dxL*cos(Th[6])) + dTh[1]*L[1]*sin(Th[1] - Th[6]) + dTh[2]*L[2]*sin(Th[2] - Th[6]) + dTh[3]*L[3]*sin(Th[3] - Th[6]) + dTh[4]*L[4]*sin(Th[4] - Th[6]) + dTh[5]*L[5]*sin(Th[5] - Th[6]) - dyL*sin(Th[6]))))/2. - (cos(Th[2])*L[2]*L[6]*(Cs*cos(Th[6])*(2*dyL*cos(Th[6]) + 2*cos(Th[1] - Th[6])*dTh[1]*L[1] + 2*cos(Th[2] - Th[6])*dTh[2]*L[2] + 2*cos(Th[3] - Th[6])*dTh[3]*L[3] + 2*cos(Th[4] - Th[6])*dTh[4]*L[4] + 2*cos(Th[5] - Th[6])*dTh[5]*L[5] + dTh[6]*L[6] - 2*dxL*sin(Th[6])) + 2*Cv*sin(Th[6])*(dxL*cos(Th[6]) - dTh[1]*L[1]*sin(Th[1] - Th[6]) - dTh[2]*L[2]*sin(Th[2] - Th[6]) - dTh[3]*L[3]*sin(Th[3] - Th[6]) - dTh[4]*L[4]*sin(Th[4] - Th[6]) - dTh[5]*L[5]*sin(Th[5] - Th[6]) + dyL*sin(Th[6]))))/2. + (M[6]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.)))/2. - (M[6]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[2]) - 2*L[2]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - (cos(Th[6])*pow(dTh[6],2)*L[6])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.) + 2*cos(Th[2])*L[2]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - (pow(dTh[6],2)*L[6]*sin(Th[6]))/2.)))/2. - L[2]*sin(Th[2])*(-(Cs*L[7]*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + 2*dxL*sin(Th[7])))/2. - Cv*cos(Th[7])*L[7]*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7]))) + cos(Th[2])*L[2]*(-(Cs*cos(Th[7])*L[7]*(2*dyL*cos(Th[7]) + 2*cos(Th[1] - Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + 2*cos(Th[3] - Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + 2*cos(Th[5] - Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + dTh[7]*L[7] - 2*dxL*sin(Th[7])))/2. - Cv*L[7]*sin(Th[7])*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7]))) + (M[7]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + (cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - (dTh[7]*L[7]*sin(Th[7]))/2.)))/2. - (M[7]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + (cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[2]) - 2*L[2]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - (cos(Th[7])*pow(dTh[7],2)*L[7])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - (dTh[7]*L[7]*sin(Th[7]))/2.) + 2*cos(Th[2])*L[2]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - (pow(dTh[7],2)*L[7]*sin(Th[7]))/2.)))/2. - L[2]*sin(Th[2])*(-(Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))) + cos(Th[2])*L[2]*(-(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + 2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + 2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + 2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + 2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))) + (M[8]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + (cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.)))/2. - (M[8]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + (cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[2]) - 2*L[2]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - (cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.) + 2*cos(Th[2])*L[2]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.)))/2. - L[2]*sin(Th[2])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + 2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))) + cos(Th[2])*L[2]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + 2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + 2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + 2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + 2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))) + (M[9]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - (M[9]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[2]) - 2*L[2]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - (cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + 2*cos(Th[2])*L[2]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - L[2]*sin(Th[2])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + cos(Th[2])*L[2]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + (M[10]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[2]*L[2]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[2]) - 2*L[2]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - cos(Th[9])*pow(dTh[9],2)*L[9] - (cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[2]) - 2*cos(Th[2])*dTh[2]*L[2]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[2])*L[2]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;
 coefMat[6] = 0;
 coefMat[20] = 0;
 coefMat[34] = L[3]*sin(Th[3]);
 coefMat[48] = -(cos(Th[3])*L[3]);
 coefMat[62] = (M[3]*(cos(Th[1])*cos(Th[3])*L[1]*L[3] + L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + (M[4]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + 2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + (M[5]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + 2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + (M[6]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + 2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + (M[7]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + 2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + (M[8]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + 2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + (M[9]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + 2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2. + (M[10]*(2*cos(Th[1])*cos(Th[3])*L[1]*L[3] + 2*L[1]*L[3]*sin(Th[1])*sin(Th[3])))/2.;
 coefMat[76] = (M[3]*(cos(Th[2])*cos(Th[3])*L[2]*L[3] + L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + (M[4]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + 2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + (M[5]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + 2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + (M[6]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + 2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + (M[7]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + 2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + (M[8]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + 2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + (M[9]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + 2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2. + (M[10]*(2*cos(Th[2])*cos(Th[3])*L[2]*L[3] + 2*L[2]*L[3]*sin(Th[2])*sin(Th[3])))/2.;
 coefMat[90] = (pow(L[3],2)*M[3])/12. + (M[3]*((pow(cos(Th[3]),2)*pow(L[3],2))/2. + (pow(L[3],2)*pow(sin(Th[3]),2))/2.))/2. + (M[4]*(2*pow(cos(Th[3]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(Th[3]),2)))/2. + (M[5]*(2*pow(cos(Th[3]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(Th[3]),2)))/2. + (M[6]*(2*pow(cos(Th[3]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(Th[3]),2)))/2. + (M[7]*(2*pow(cos(Th[3]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(Th[3]),2)))/2. + (M[8]*(2*pow(cos(Th[3]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(Th[3]),2)))/2. + (M[9]*(2*pow(cos(Th[3]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(Th[3]),2)))/2. + (M[10]*(2*pow(cos(Th[3]),2)*pow(L[3],2) + 2*pow(L[3],2)*pow(sin(Th[3]),2)))/2.;
 coefMat[104] = (M[4]*(cos(Th[3])*cos(Th[4])*L[3]*L[4] + L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + (M[5]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + 2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + (M[6]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + 2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + (M[7]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + 2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + (M[8]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + 2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + (M[9]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + 2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + (M[10]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + 2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2.;
 coefMat[118] = (M[5]*(cos(Th[3])*cos(Th[5])*L[3]*L[5] + L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + (M[6]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + 2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + (M[7]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + 2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + (M[8]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + 2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + (M[9]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + 2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + (M[10]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + 2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2.;
 coefMat[132] = (M[6]*(cos(Th[3])*cos(Th[6])*L[3]*L[6] + L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2. + (M[7]*(2*cos(Th[3])*cos(Th[6])*L[3]*L[6] + 2*L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2. + (M[8]*(2*cos(Th[3])*cos(Th[6])*L[3]*L[6] + 2*L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2. + (M[9]*(2*cos(Th[3])*cos(Th[6])*L[3]*L[6] + 2*L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2. + (M[10]*(2*cos(Th[3])*cos(Th[6])*L[3]*L[6] + 2*L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2.;
 coefMat[146] = (M[7]*(cos(Th[3])*cos(Th[7])*L[3]*L[7] + L[3]*L[7]*sin(Th[3])*sin(Th[7])))/2. + (M[8]*(2*cos(Th[3])*cos(Th[7])*L[3]*L[7] + 2*L[3]*L[7]*sin(Th[3])*sin(Th[7])))/2. + (M[9]*(2*cos(Th[3])*cos(Th[7])*L[3]*L[7] + 2*L[3]*L[7]*sin(Th[3])*sin(Th[7])))/2. + (M[10]*(2*cos(Th[3])*cos(Th[7])*L[3]*L[7] + 2*L[3]*L[7]*sin(Th[3])*sin(Th[7])))/2.;
 coefMat[160] = (M[8]*(cos(Th[3])*cos(Th[8])*L[3]*L[8] + L[3]*L[8]*sin(Th[3])*sin(Th[8])))/2. + (M[9]*(2*cos(Th[3])*cos(Th[8])*L[3]*L[8] + 2*L[3]*L[8]*sin(Th[3])*sin(Th[8])))/2. + (M[10]*(2*cos(Th[3])*cos(Th[8])*L[3]*L[8] + 2*L[3]*L[8]*sin(Th[3])*sin(Th[8])))/2.;
 coefMat[174] = (M[9]*(cos(Th[3])*cos(Th[9])*L[3]*L[9] + L[3]*L[9]*sin(Th[3])*sin(Th[9])))/2. + (M[10]*(2*cos(Th[3])*cos(Th[9])*L[3]*L[9] + 2*L[3]*L[9]*sin(Th[3])*sin(Th[9])))/2.;
 coefMat[188] = (M[10]*(cos(Th[3])*cos(Th[10])*L[3]*L[10] + L[3]*L[10]*sin(Th[3])*sin(Th[10])))/2.;
 rhsVec[6] = -(Cs*dTh[3]*pow(L[3],3))/12. - (L[3]*sin(Th[3])*(-(Cv*dxL*pow(cos(Th[3]),2)*L[3]) + Cv*cos(Th[3])*dTh[1]*L[1]*L[3]*sin(Th[1] - Th[3]) + Cv*cos(Th[3])*dTh[2]*L[2]*L[3]*sin(Th[2] - Th[3]) + Cs*dyL*cos(Th[3])*L[3]*sin(Th[3]) - Cv*dyL*cos(Th[3])*L[3]*sin(Th[3]) + Cs*cos(Th[1] - Th[3])*dTh[1]*L[1]*L[3]*sin(Th[3]) + Cs*cos(Th[2] - Th[3])*dTh[2]*L[2]*L[3]*sin(Th[3]) + (Cs*dTh[3]*pow(L[3],2)*sin(Th[3]))/2. - Cs*dxL*L[3]*pow(sin(Th[3]),2)))/2. + (cos(Th[3])*L[3]*(-(Cs*dyL*pow(cos(Th[3]),2)*L[3]) - Cs*cos(Th[1] - Th[3])*cos(Th[3])*dTh[1]*L[1]*L[3] - Cs*cos(Th[2] - Th[3])*cos(Th[3])*dTh[2]*L[2]*L[3] - (Cs*cos(Th[3])*dTh[3]*pow(L[3],2))/2. + Cs*dxL*cos(Th[3])*L[3]*sin(Th[3]) - Cv*dxL*cos(Th[3])*L[3]*sin(Th[3]) + Cv*dTh[1]*L[1]*L[3]*sin(Th[1] - Th[3])*sin(Th[3]) + Cv*dTh[2]*L[2]*L[3]*sin(Th[2] - Th[3])*sin(Th[3]) - Cv*dyL*L[3]*pow(sin(Th[3]),2)))/2. + (M[3]*(-(dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + (cos(Th[3])*dTh[3]*L[3])/2.)*sin(Th[3])) - cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - (dTh[3]*L[3]*sin(Th[3]))/2.)))/2. - (M[3]*(-(dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + (cos(Th[3])*dTh[3]*L[3])/2.)*sin(Th[3])) - L[3]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - (cos(Th[3])*pow(dTh[3],2)*L[3])/2.)*sin(Th[3]) - cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - (dTh[3]*L[3]*sin(Th[3]))/2.) + cos(Th[3])*L[3]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - (pow(dTh[3],2)*L[3]*sin(Th[3]))/2.)))/2. - L[3]*sin(Th[3])*(-(Cv*dxL*pow(cos(Th[4]),2)*L[4]) + Cv*cos(Th[4])*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4]) + Cv*cos(Th[4])*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4]) + Cv*cos(Th[4])*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4]) + Cs*dyL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dyL*cos(Th[4])*L[4]*sin(Th[4]) + Cs*cos(Th[1] - Th[4])*dTh[1]*L[1]*L[4]*sin(Th[4]) + Cs*cos(Th[2] - Th[4])*dTh[2]*L[2]*L[4]*sin(Th[4]) + Cs*cos(Th[3] - Th[4])*dTh[3]*L[3]*L[4]*sin(Th[4]) + (Cs*dTh[4]*pow(L[4],2)*sin(Th[4]))/2. - Cs*dxL*L[4]*pow(sin(Th[4]),2)) + cos(Th[3])*L[3]*(-(Cs*dyL*pow(cos(Th[4]),2)*L[4]) - Cs*cos(Th[1] - Th[4])*cos(Th[4])*dTh[1]*L[1]*L[4] - Cs*cos(Th[2] - Th[4])*cos(Th[4])*dTh[2]*L[2]*L[4] - Cs*cos(Th[3] - Th[4])*cos(Th[4])*dTh[3]*L[3]*L[4] - (Cs*cos(Th[4])*dTh[4]*pow(L[4],2))/2. + Cs*dxL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dxL*cos(Th[4])*L[4]*sin(Th[4]) + Cv*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4])*sin(Th[4]) + Cv*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4])*sin(Th[4]) + Cv*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4])*sin(Th[4]) - Cv*dyL*L[4]*pow(sin(Th[4]),2)) + (M[4]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + (cos(Th[4])*dTh[4]*L[4])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - (dTh[4]*L[4]*sin(Th[4]))/2.)))/2. - (M[4]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + (cos(Th[4])*dTh[4]*L[4])/2.)*sin(Th[3]) - 2*L[3]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - (cos(Th[4])*pow(dTh[4],2)*L[4])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - (dTh[4]*L[4]*sin(Th[4]))/2.) + 2*cos(Th[3])*L[3]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - (pow(dTh[4],2)*L[4]*sin(Th[4]))/2.)))/2. - (L[3]*L[5]*sin(Th[3])*(-(Cs*sin(Th[5])*(-2*dyL*cos(Th[5]) - 2*cos(Th[1] - Th[5])*dTh[1]*L[1] - 2*cos(Th[2] - Th[5])*dTh[2]*L[2] - 2*cos(Th[3] - Th[5])*dTh[3]*L[3] - 2*cos(Th[4] - Th[5])*dTh[4]*L[4] - dTh[5]*L[5] + 2*dxL*sin(Th[5]))) + 2*Cv*cos(Th[5])*(-(dxL*cos(Th[5])) + dTh[1]*L[1]*sin(Th[1] - Th[5]) + dTh[2]*L[2]*sin(Th[2] - Th[5]) + dTh[3]*L[3]*sin(Th[3] - Th[5]) + dTh[4]*L[4]*sin(Th[4] - Th[5]) - dyL*sin(Th[5]))))/2. - (cos(Th[3])*L[3]*L[5]*(Cs*cos(Th[5])*(2*dyL*cos(Th[5]) + 2*cos(Th[1] - Th[5])*dTh[1]*L[1] + 2*cos(Th[2] - Th[5])*dTh[2]*L[2] + 2*cos(Th[3] - Th[5])*dTh[3]*L[3] + 2*cos(Th[4] - Th[5])*dTh[4]*L[4] + dTh[5]*L[5] - 2*dxL*sin(Th[5])) + 2*Cv*sin(Th[5])*(dxL*cos(Th[5]) - dTh[1]*L[1]*sin(Th[1] - Th[5]) - dTh[2]*L[2]*sin(Th[2] - Th[5]) - dTh[3]*L[3]*sin(Th[3] - Th[5]) - dTh[4]*L[4]*sin(Th[4] - Th[5]) + dyL*sin(Th[5]))))/2. + (M[5]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + (cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - (dTh[5]*L[5]*sin(Th[5]))/2.)))/2. - (M[5]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + (cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[3]) - 2*L[3]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - (cos(Th[5])*pow(dTh[5],2)*L[5])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - (dTh[5]*L[5]*sin(Th[5]))/2.) + 2*cos(Th[3])*L[3]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - (pow(dTh[5],2)*L[5]*sin(Th[5]))/2.)))/2. - (L[3]*L[6]*sin(Th[3])*(-(Cs*sin(Th[6])*(-2*dyL*cos(Th[6]) - 2*cos(Th[1] - Th[6])*dTh[1]*L[1] - 2*cos(Th[2] - Th[6])*dTh[2]*L[2] - 2*cos(Th[3] - Th[6])*dTh[3]*L[3] - 2*cos(Th[4] - Th[6])*dTh[4]*L[4] - 2*cos(Th[5] - Th[6])*dTh[5]*L[5] - dTh[6]*L[6] + 2*dxL*sin(Th[6]))) + 2*Cv*cos(Th[6])*(-(dxL*cos(Th[6])) + dTh[1]*L[1]*sin(Th[1] - Th[6]) + dTh[2]*L[2]*sin(Th[2] - Th[6]) + dTh[3]*L[3]*sin(Th[3] - Th[6]) + dTh[4]*L[4]*sin(Th[4] - Th[6]) + dTh[5]*L[5]*sin(Th[5] - Th[6]) - dyL*sin(Th[6]))))/2. - (cos(Th[3])*L[3]*L[6]*(Cs*cos(Th[6])*(2*dyL*cos(Th[6]) + 2*cos(Th[1] - Th[6])*dTh[1]*L[1] + 2*cos(Th[2] - Th[6])*dTh[2]*L[2] + 2*cos(Th[3] - Th[6])*dTh[3]*L[3] + 2*cos(Th[4] - Th[6])*dTh[4]*L[4] + 2*cos(Th[5] - Th[6])*dTh[5]*L[5] + dTh[6]*L[6] - 2*dxL*sin(Th[6])) + 2*Cv*sin(Th[6])*(dxL*cos(Th[6]) - dTh[1]*L[1]*sin(Th[1] - Th[6]) - dTh[2]*L[2]*sin(Th[2] - Th[6]) - dTh[3]*L[3]*sin(Th[3] - Th[6]) - dTh[4]*L[4]*sin(Th[4] - Th[6]) - dTh[5]*L[5]*sin(Th[5] - Th[6]) + dyL*sin(Th[6]))))/2. + (M[6]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.)))/2. - (M[6]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[3]) - 2*L[3]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - (cos(Th[6])*pow(dTh[6],2)*L[6])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.) + 2*cos(Th[3])*L[3]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - (pow(dTh[6],2)*L[6]*sin(Th[6]))/2.)))/2. - L[3]*sin(Th[3])*(-(Cs*L[7]*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + 2*dxL*sin(Th[7])))/2. - Cv*cos(Th[7])*L[7]*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7]))) + cos(Th[3])*L[3]*(-(Cs*cos(Th[7])*L[7]*(2*dyL*cos(Th[7]) + 2*cos(Th[1] - Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + 2*cos(Th[3] - Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + 2*cos(Th[5] - Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + dTh[7]*L[7] - 2*dxL*sin(Th[7])))/2. - Cv*L[7]*sin(Th[7])*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7]))) + (M[7]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + (cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - (dTh[7]*L[7]*sin(Th[7]))/2.)))/2. - (M[7]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + (cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[3]) - 2*L[3]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - (cos(Th[7])*pow(dTh[7],2)*L[7])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - (dTh[7]*L[7]*sin(Th[7]))/2.) + 2*cos(Th[3])*L[3]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - (pow(dTh[7],2)*L[7]*sin(Th[7]))/2.)))/2. - L[3]*sin(Th[3])*(-(Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))) + cos(Th[3])*L[3]*(-(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + 2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + 2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + 2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + 2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))) + (M[8]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + (cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.)))/2. - (M[8]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + (cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[3]) - 2*L[3]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - (cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.) + 2*cos(Th[3])*L[3]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.)))/2. - L[3]*sin(Th[3])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + 2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))) + cos(Th[3])*L[3]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + 2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + 2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + 2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + 2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))) + (M[9]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - (M[9]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[3]) - 2*L[3]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - (cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + 2*cos(Th[3])*L[3]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - L[3]*sin(Th[3])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + cos(Th[3])*L[3]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + (M[10]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[3]*L[3]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[3]) - 2*L[3]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - cos(Th[9])*pow(dTh[9],2)*L[9] - (cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[3]) - 2*cos(Th[3])*dTh[3]*L[3]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[3])*L[3]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;
 coefMat[7] = 0;
 coefMat[21] = 0;
 coefMat[35] = L[4]*sin(Th[4]);
 coefMat[49] = -(cos(Th[4])*L[4]);
 coefMat[63] = (M[4]*(cos(Th[1])*cos(Th[4])*L[1]*L[4] + L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + (M[5]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + 2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + (M[6]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + 2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + (M[7]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + 2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + (M[8]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + 2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + (M[9]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + 2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2. + (M[10]*(2*cos(Th[1])*cos(Th[4])*L[1]*L[4] + 2*L[1]*L[4]*sin(Th[1])*sin(Th[4])))/2.;
 coefMat[77] = (M[4]*(cos(Th[2])*cos(Th[4])*L[2]*L[4] + L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + (M[5]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + 2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + (M[6]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + 2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + (M[7]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + 2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + (M[8]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + 2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + (M[9]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + 2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2. + (M[10]*(2*cos(Th[2])*cos(Th[4])*L[2]*L[4] + 2*L[2]*L[4]*sin(Th[2])*sin(Th[4])))/2.;
 coefMat[91] = (M[4]*(cos(Th[3])*cos(Th[4])*L[3]*L[4] + L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + (M[5]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + 2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + (M[6]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + 2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + (M[7]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + 2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + (M[8]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + 2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + (M[9]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + 2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2. + (M[10]*(2*cos(Th[3])*cos(Th[4])*L[3]*L[4] + 2*L[3]*L[4]*sin(Th[3])*sin(Th[4])))/2.;
 coefMat[105] = (pow(L[4],2)*M[4])/12. + (M[4]*((pow(cos(Th[4]),2)*pow(L[4],2))/2. + (pow(L[4],2)*pow(sin(Th[4]),2))/2.))/2. + (M[5]*(2*pow(cos(Th[4]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(Th[4]),2)))/2. + (M[6]*(2*pow(cos(Th[4]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(Th[4]),2)))/2. + (M[7]*(2*pow(cos(Th[4]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(Th[4]),2)))/2. + (M[8]*(2*pow(cos(Th[4]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(Th[4]),2)))/2. + (M[9]*(2*pow(cos(Th[4]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(Th[4]),2)))/2. + (M[10]*(2*pow(cos(Th[4]),2)*pow(L[4],2) + 2*pow(L[4],2)*pow(sin(Th[4]),2)))/2.;
 coefMat[119] = (M[5]*(cos(Th[4])*cos(Th[5])*L[4]*L[5] + L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + (M[6]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + 2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + (M[7]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + 2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + (M[8]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + 2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + (M[9]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + 2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + (M[10]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + 2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2.;
 coefMat[133] = (M[6]*(cos(Th[4])*cos(Th[6])*L[4]*L[6] + L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2. + (M[7]*(2*cos(Th[4])*cos(Th[6])*L[4]*L[6] + 2*L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2. + (M[8]*(2*cos(Th[4])*cos(Th[6])*L[4]*L[6] + 2*L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2. + (M[9]*(2*cos(Th[4])*cos(Th[6])*L[4]*L[6] + 2*L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2. + (M[10]*(2*cos(Th[4])*cos(Th[6])*L[4]*L[6] + 2*L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2.;
 coefMat[147] = (M[7]*(cos(Th[4])*cos(Th[7])*L[4]*L[7] + L[4]*L[7]*sin(Th[4])*sin(Th[7])))/2. + (M[8]*(2*cos(Th[4])*cos(Th[7])*L[4]*L[7] + 2*L[4]*L[7]*sin(Th[4])*sin(Th[7])))/2. + (M[9]*(2*cos(Th[4])*cos(Th[7])*L[4]*L[7] + 2*L[4]*L[7]*sin(Th[4])*sin(Th[7])))/2. + (M[10]*(2*cos(Th[4])*cos(Th[7])*L[4]*L[7] + 2*L[4]*L[7]*sin(Th[4])*sin(Th[7])))/2.;
 coefMat[161] = (M[8]*(cos(Th[4])*cos(Th[8])*L[4]*L[8] + L[4]*L[8]*sin(Th[4])*sin(Th[8])))/2. + (M[9]*(2*cos(Th[4])*cos(Th[8])*L[4]*L[8] + 2*L[4]*L[8]*sin(Th[4])*sin(Th[8])))/2. + (M[10]*(2*cos(Th[4])*cos(Th[8])*L[4]*L[8] + 2*L[4]*L[8]*sin(Th[4])*sin(Th[8])))/2.;
 coefMat[175] = (M[9]*(cos(Th[4])*cos(Th[9])*L[4]*L[9] + L[4]*L[9]*sin(Th[4])*sin(Th[9])))/2. + (M[10]*(2*cos(Th[4])*cos(Th[9])*L[4]*L[9] + 2*L[4]*L[9]*sin(Th[4])*sin(Th[9])))/2.;
 coefMat[189] = (M[10]*(cos(Th[4])*cos(Th[10])*L[4]*L[10] + L[4]*L[10]*sin(Th[4])*sin(Th[10])))/2.;
 rhsVec[7] = -(Cs*dTh[4]*pow(L[4],3))/12. - (L[4]*sin(Th[4])*(-(Cv*dxL*pow(cos(Th[4]),2)*L[4]) + Cv*cos(Th[4])*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4]) + Cv*cos(Th[4])*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4]) + Cv*cos(Th[4])*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4]) + Cs*dyL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dyL*cos(Th[4])*L[4]*sin(Th[4]) + Cs*cos(Th[1] - Th[4])*dTh[1]*L[1]*L[4]*sin(Th[4]) + Cs*cos(Th[2] - Th[4])*dTh[2]*L[2]*L[4]*sin(Th[4]) + Cs*cos(Th[3] - Th[4])*dTh[3]*L[3]*L[4]*sin(Th[4]) + (Cs*dTh[4]*pow(L[4],2)*sin(Th[4]))/2. - Cs*dxL*L[4]*pow(sin(Th[4]),2)))/2. + (cos(Th[4])*L[4]*(-(Cs*dyL*pow(cos(Th[4]),2)*L[4]) - Cs*cos(Th[1] - Th[4])*cos(Th[4])*dTh[1]*L[1]*L[4] - Cs*cos(Th[2] - Th[4])*cos(Th[4])*dTh[2]*L[2]*L[4] - Cs*cos(Th[3] - Th[4])*cos(Th[4])*dTh[3]*L[3]*L[4] - (Cs*cos(Th[4])*dTh[4]*pow(L[4],2))/2. + Cs*dxL*cos(Th[4])*L[4]*sin(Th[4]) - Cv*dxL*cos(Th[4])*L[4]*sin(Th[4]) + Cv*dTh[1]*L[1]*L[4]*sin(Th[1] - Th[4])*sin(Th[4]) + Cv*dTh[2]*L[2]*L[4]*sin(Th[2] - Th[4])*sin(Th[4]) + Cv*dTh[3]*L[3]*L[4]*sin(Th[3] - Th[4])*sin(Th[4]) - Cv*dyL*L[4]*pow(sin(Th[4]),2)))/2. + (M[4]*(-(dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + (cos(Th[4])*dTh[4]*L[4])/2.)*sin(Th[4])) - cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - (dTh[4]*L[4]*sin(Th[4]))/2.)))/2. - (M[4]*(-(dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + (cos(Th[4])*dTh[4]*L[4])/2.)*sin(Th[4])) - L[4]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - (cos(Th[4])*pow(dTh[4],2)*L[4])/2.)*sin(Th[4]) - cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - (dTh[4]*L[4]*sin(Th[4]))/2.) + cos(Th[4])*L[4]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - (pow(dTh[4],2)*L[4]*sin(Th[4]))/2.)))/2. - (L[4]*L[5]*sin(Th[4])*(-(Cs*sin(Th[5])*(-2*dyL*cos(Th[5]) - 2*cos(Th[1] - Th[5])*dTh[1]*L[1] - 2*cos(Th[2] - Th[5])*dTh[2]*L[2] - 2*cos(Th[3] - Th[5])*dTh[3]*L[3] - 2*cos(Th[4] - Th[5])*dTh[4]*L[4] - dTh[5]*L[5] + 2*dxL*sin(Th[5]))) + 2*Cv*cos(Th[5])*(-(dxL*cos(Th[5])) + dTh[1]*L[1]*sin(Th[1] - Th[5]) + dTh[2]*L[2]*sin(Th[2] - Th[5]) + dTh[3]*L[3]*sin(Th[3] - Th[5]) + dTh[4]*L[4]*sin(Th[4] - Th[5]) - dyL*sin(Th[5]))))/2. - (cos(Th[4])*L[4]*L[5]*(Cs*cos(Th[5])*(2*dyL*cos(Th[5]) + 2*cos(Th[1] - Th[5])*dTh[1]*L[1] + 2*cos(Th[2] - Th[5])*dTh[2]*L[2] + 2*cos(Th[3] - Th[5])*dTh[3]*L[3] + 2*cos(Th[4] - Th[5])*dTh[4]*L[4] + dTh[5]*L[5] - 2*dxL*sin(Th[5])) + 2*Cv*sin(Th[5])*(dxL*cos(Th[5]) - dTh[1]*L[1]*sin(Th[1] - Th[5]) - dTh[2]*L[2]*sin(Th[2] - Th[5]) - dTh[3]*L[3]*sin(Th[3] - Th[5]) - dTh[4]*L[4]*sin(Th[4] - Th[5]) + dyL*sin(Th[5]))))/2. + (M[5]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + (cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[4]) - 2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - (dTh[5]*L[5]*sin(Th[5]))/2.)))/2. - (M[5]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + (cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[4]) - 2*L[4]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - (cos(Th[5])*pow(dTh[5],2)*L[5])/2.)*sin(Th[4]) - 2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - (dTh[5]*L[5]*sin(Th[5]))/2.) + 2*cos(Th[4])*L[4]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - (pow(dTh[5],2)*L[5]*sin(Th[5]))/2.)))/2. - (L[4]*L[6]*sin(Th[4])*(-(Cs*sin(Th[6])*(-2*dyL*cos(Th[6]) - 2*cos(Th[1] - Th[6])*dTh[1]*L[1] - 2*cos(Th[2] - Th[6])*dTh[2]*L[2] - 2*cos(Th[3] - Th[6])*dTh[3]*L[3] - 2*cos(Th[4] - Th[6])*dTh[4]*L[4] - 2*cos(Th[5] - Th[6])*dTh[5]*L[5] - dTh[6]*L[6] + 2*dxL*sin(Th[6]))) + 2*Cv*cos(Th[6])*(-(dxL*cos(Th[6])) + dTh[1]*L[1]*sin(Th[1] - Th[6]) + dTh[2]*L[2]*sin(Th[2] - Th[6]) + dTh[3]*L[3]*sin(Th[3] - Th[6]) + dTh[4]*L[4]*sin(Th[4] - Th[6]) + dTh[5]*L[5]*sin(Th[5] - Th[6]) - dyL*sin(Th[6]))))/2. - (cos(Th[4])*L[4]*L[6]*(Cs*cos(Th[6])*(2*dyL*cos(Th[6]) + 2*cos(Th[1] - Th[6])*dTh[1]*L[1] + 2*cos(Th[2] - Th[6])*dTh[2]*L[2] + 2*cos(Th[3] - Th[6])*dTh[3]*L[3] + 2*cos(Th[4] - Th[6])*dTh[4]*L[4] + 2*cos(Th[5] - Th[6])*dTh[5]*L[5] + dTh[6]*L[6] - 2*dxL*sin(Th[6])) + 2*Cv*sin(Th[6])*(dxL*cos(Th[6]) - dTh[1]*L[1]*sin(Th[1] - Th[6]) - dTh[2]*L[2]*sin(Th[2] - Th[6]) - dTh[3]*L[3]*sin(Th[3] - Th[6]) - dTh[4]*L[4]*sin(Th[4] - Th[6]) - dTh[5]*L[5]*sin(Th[5] - Th[6]) + dyL*sin(Th[6]))))/2. + (M[6]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[4]) - 2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.)))/2. - (M[6]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[4]) - 2*L[4]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - (cos(Th[6])*pow(dTh[6],2)*L[6])/2.)*sin(Th[4]) - 2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.) + 2*cos(Th[4])*L[4]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - (pow(dTh[6],2)*L[6]*sin(Th[6]))/2.)))/2. - L[4]*sin(Th[4])*(-(Cs*L[7]*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + 2*dxL*sin(Th[7])))/2. - Cv*cos(Th[7])*L[7]*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7]))) + cos(Th[4])*L[4]*(-(Cs*cos(Th[7])*L[7]*(2*dyL*cos(Th[7]) + 2*cos(Th[1] - Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + 2*cos(Th[3] - Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + 2*cos(Th[5] - Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + dTh[7]*L[7] - 2*dxL*sin(Th[7])))/2. - Cv*L[7]*sin(Th[7])*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7]))) + (M[7]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + (cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[4]) - 2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - (dTh[7]*L[7]*sin(Th[7]))/2.)))/2. - (M[7]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + (cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[4]) - 2*L[4]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - (cos(Th[7])*pow(dTh[7],2)*L[7])/2.)*sin(Th[4]) - 2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - (dTh[7]*L[7]*sin(Th[7]))/2.) + 2*cos(Th[4])*L[4]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - (pow(dTh[7],2)*L[7]*sin(Th[7]))/2.)))/2. - L[4]*sin(Th[4])*(-(Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))) + cos(Th[4])*L[4]*(-(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + 2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + 2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + 2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + 2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))) + (M[8]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + (cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[4]) - 2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.)))/2. - (M[8]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + (cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[4]) - 2*L[4]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - (cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*sin(Th[4]) - 2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.) + 2*cos(Th[4])*L[4]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.)))/2. - L[4]*sin(Th[4])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + 2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))) + cos(Th[4])*L[4]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + 2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + 2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + 2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + 2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))) + (M[9]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[4]) - 2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - (M[9]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[4]) - 2*L[4]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - (cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[4]) - 2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + 2*cos(Th[4])*L[4]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - L[4]*sin(Th[4])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + cos(Th[4])*L[4]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + (M[10]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[4]) - 2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[4]*L[4]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[4]) - 2*L[4]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - cos(Th[9])*pow(dTh[9],2)*L[9] - (cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[4]) - 2*cos(Th[4])*dTh[4]*L[4]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[4])*L[4]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;
 coefMat[8] = 0;
 coefMat[22] = 0;
 coefMat[36] = L[5]*sin(Th[5]);
 coefMat[50] = -(cos(Th[5])*L[5]);
 coefMat[64] = (M[5]*(cos(Th[1])*cos(Th[5])*L[1]*L[5] + L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + (M[6]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + 2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + (M[7]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + 2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + (M[8]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + 2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + (M[9]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + 2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2. + (M[10]*(2*cos(Th[1])*cos(Th[5])*L[1]*L[5] + 2*L[1]*L[5]*sin(Th[1])*sin(Th[5])))/2.;
 coefMat[78] = (M[5]*(cos(Th[2])*cos(Th[5])*L[2]*L[5] + L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + (M[6]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + 2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + (M[7]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + 2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + (M[8]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + 2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + (M[9]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + 2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2. + (M[10]*(2*cos(Th[2])*cos(Th[5])*L[2]*L[5] + 2*L[2]*L[5]*sin(Th[2])*sin(Th[5])))/2.;
 coefMat[92] = (M[5]*(cos(Th[3])*cos(Th[5])*L[3]*L[5] + L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + (M[6]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + 2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + (M[7]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + 2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + (M[8]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + 2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + (M[9]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + 2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2. + (M[10]*(2*cos(Th[3])*cos(Th[5])*L[3]*L[5] + 2*L[3]*L[5]*sin(Th[3])*sin(Th[5])))/2.;
 coefMat[106] = (M[5]*(cos(Th[4])*cos(Th[5])*L[4]*L[5] + L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + (M[6]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + 2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + (M[7]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + 2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + (M[8]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + 2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + (M[9]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + 2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2. + (M[10]*(2*cos(Th[4])*cos(Th[5])*L[4]*L[5] + 2*L[4]*L[5]*sin(Th[4])*sin(Th[5])))/2.;
 coefMat[120] = (pow(L[5],2)*M[5])/12. + (M[5]*((pow(cos(Th[5]),2)*pow(L[5],2))/2. + (pow(L[5],2)*pow(sin(Th[5]),2))/2.))/2. + (M[6]*(2*pow(cos(Th[5]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(Th[5]),2)))/2. + (M[7]*(2*pow(cos(Th[5]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(Th[5]),2)))/2. + (M[8]*(2*pow(cos(Th[5]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(Th[5]),2)))/2. + (M[9]*(2*pow(cos(Th[5]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(Th[5]),2)))/2. + (M[10]*(2*pow(cos(Th[5]),2)*pow(L[5],2) + 2*pow(L[5],2)*pow(sin(Th[5]),2)))/2.;
 coefMat[134] = (M[6]*(cos(Th[5])*cos(Th[6])*L[5]*L[6] + L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2. + (M[7]*(2*cos(Th[5])*cos(Th[6])*L[5]*L[6] + 2*L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2. + (M[8]*(2*cos(Th[5])*cos(Th[6])*L[5]*L[6] + 2*L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2. + (M[9]*(2*cos(Th[5])*cos(Th[6])*L[5]*L[6] + 2*L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2. + (M[10]*(2*cos(Th[5])*cos(Th[6])*L[5]*L[6] + 2*L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2.;
 coefMat[148] = (M[7]*(cos(Th[5])*cos(Th[7])*L[5]*L[7] + L[5]*L[7]*sin(Th[5])*sin(Th[7])))/2. + (M[8]*(2*cos(Th[5])*cos(Th[7])*L[5]*L[7] + 2*L[5]*L[7]*sin(Th[5])*sin(Th[7])))/2. + (M[9]*(2*cos(Th[5])*cos(Th[7])*L[5]*L[7] + 2*L[5]*L[7]*sin(Th[5])*sin(Th[7])))/2. + (M[10]*(2*cos(Th[5])*cos(Th[7])*L[5]*L[7] + 2*L[5]*L[7]*sin(Th[5])*sin(Th[7])))/2.;
 coefMat[162] = (M[8]*(cos(Th[5])*cos(Th[8])*L[5]*L[8] + L[5]*L[8]*sin(Th[5])*sin(Th[8])))/2. + (M[9]*(2*cos(Th[5])*cos(Th[8])*L[5]*L[8] + 2*L[5]*L[8]*sin(Th[5])*sin(Th[8])))/2. + (M[10]*(2*cos(Th[5])*cos(Th[8])*L[5]*L[8] + 2*L[5]*L[8]*sin(Th[5])*sin(Th[8])))/2.;
 coefMat[176] = (M[9]*(cos(Th[5])*cos(Th[9])*L[5]*L[9] + L[5]*L[9]*sin(Th[5])*sin(Th[9])))/2. + (M[10]*(2*cos(Th[5])*cos(Th[9])*L[5]*L[9] + 2*L[5]*L[9]*sin(Th[5])*sin(Th[9])))/2.;
 coefMat[190] = (M[10]*(cos(Th[5])*cos(Th[10])*L[5]*L[10] + L[5]*L[10]*sin(Th[5])*sin(Th[10])))/2.;
 rhsVec[8] = -(Cs*dTh[5]*pow(L[5],3))/12. - (pow(L[5],2)*sin(Th[5])*(-(Cs*sin(Th[5])*(-2*dyL*cos(Th[5]) - 2*cos(Th[1] - Th[5])*dTh[1]*L[1] - 2*cos(Th[2] - Th[5])*dTh[2]*L[2] - 2*cos(Th[3] - Th[5])*dTh[3]*L[3] - 2*cos(Th[4] - Th[5])*dTh[4]*L[4] - dTh[5]*L[5] + 2*dxL*sin(Th[5]))) + 2*Cv*cos(Th[5])*(-(dxL*cos(Th[5])) + dTh[1]*L[1]*sin(Th[1] - Th[5]) + dTh[2]*L[2]*sin(Th[2] - Th[5]) + dTh[3]*L[3]*sin(Th[3] - Th[5]) + dTh[4]*L[4]*sin(Th[4] - Th[5]) - dyL*sin(Th[5]))))/4. - (cos(Th[5])*pow(L[5],2)*(Cs*cos(Th[5])*(2*dyL*cos(Th[5]) + 2*cos(Th[1] - Th[5])*dTh[1]*L[1] + 2*cos(Th[2] - Th[5])*dTh[2]*L[2] + 2*cos(Th[3] - Th[5])*dTh[3]*L[3] + 2*cos(Th[4] - Th[5])*dTh[4]*L[4] + dTh[5]*L[5] - 2*dxL*sin(Th[5])) + 2*Cv*sin(Th[5])*(dxL*cos(Th[5]) - dTh[1]*L[1]*sin(Th[1] - Th[5]) - dTh[2]*L[2]*sin(Th[2] - Th[5]) - dTh[3]*L[3]*sin(Th[3] - Th[5]) - dTh[4]*L[4]*sin(Th[4] - Th[5]) + dyL*sin(Th[5]))))/4. + (M[5]*(-(dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + (cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[5])) - cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - (dTh[5]*L[5]*sin(Th[5]))/2.)))/2. - (M[5]*(-(dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + (cos(Th[5])*dTh[5]*L[5])/2.)*sin(Th[5])) - L[5]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - (cos(Th[5])*pow(dTh[5],2)*L[5])/2.)*sin(Th[5]) - cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - (dTh[5]*L[5]*sin(Th[5]))/2.) + cos(Th[5])*L[5]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - (pow(dTh[5],2)*L[5]*sin(Th[5]))/2.)))/2. - (L[5]*L[6]*sin(Th[5])*(-(Cs*sin(Th[6])*(-2*dyL*cos(Th[6]) - 2*cos(Th[1] - Th[6])*dTh[1]*L[1] - 2*cos(Th[2] - Th[6])*dTh[2]*L[2] - 2*cos(Th[3] - Th[6])*dTh[3]*L[3] - 2*cos(Th[4] - Th[6])*dTh[4]*L[4] - 2*cos(Th[5] - Th[6])*dTh[5]*L[5] - dTh[6]*L[6] + 2*dxL*sin(Th[6]))) + 2*Cv*cos(Th[6])*(-(dxL*cos(Th[6])) + dTh[1]*L[1]*sin(Th[1] - Th[6]) + dTh[2]*L[2]*sin(Th[2] - Th[6]) + dTh[3]*L[3]*sin(Th[3] - Th[6]) + dTh[4]*L[4]*sin(Th[4] - Th[6]) + dTh[5]*L[5]*sin(Th[5] - Th[6]) - dyL*sin(Th[6]))))/2. - (cos(Th[5])*L[5]*L[6]*(Cs*cos(Th[6])*(2*dyL*cos(Th[6]) + 2*cos(Th[1] - Th[6])*dTh[1]*L[1] + 2*cos(Th[2] - Th[6])*dTh[2]*L[2] + 2*cos(Th[3] - Th[6])*dTh[3]*L[3] + 2*cos(Th[4] - Th[6])*dTh[4]*L[4] + 2*cos(Th[5] - Th[6])*dTh[5]*L[5] + dTh[6]*L[6] - 2*dxL*sin(Th[6])) + 2*Cv*sin(Th[6])*(dxL*cos(Th[6]) - dTh[1]*L[1]*sin(Th[1] - Th[6]) - dTh[2]*L[2]*sin(Th[2] - Th[6]) - dTh[3]*L[3]*sin(Th[3] - Th[6]) - dTh[4]*L[4]*sin(Th[4] - Th[6]) - dTh[5]*L[5]*sin(Th[5] - Th[6]) + dyL*sin(Th[6]))))/2. + (M[6]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[5]) - 2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.)))/2. - (M[6]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[5]) - 2*L[5]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - (cos(Th[6])*pow(dTh[6],2)*L[6])/2.)*sin(Th[5]) - 2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.) + 2*cos(Th[5])*L[5]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - (pow(dTh[6],2)*L[6]*sin(Th[6]))/2.)))/2. - L[5]*sin(Th[5])*(-(Cs*L[7]*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + 2*dxL*sin(Th[7])))/2. - Cv*cos(Th[7])*L[7]*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7]))) + cos(Th[5])*L[5]*(-(Cs*cos(Th[7])*L[7]*(2*dyL*cos(Th[7]) + 2*cos(Th[1] - Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + 2*cos(Th[3] - Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + 2*cos(Th[5] - Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + dTh[7]*L[7] - 2*dxL*sin(Th[7])))/2. - Cv*L[7]*sin(Th[7])*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7]))) + (M[7]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + (cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[5]) - 2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - (dTh[7]*L[7]*sin(Th[7]))/2.)))/2. - (M[7]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + (cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[5]) - 2*L[5]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - (cos(Th[7])*pow(dTh[7],2)*L[7])/2.)*sin(Th[5]) - 2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - (dTh[7]*L[7]*sin(Th[7]))/2.) + 2*cos(Th[5])*L[5]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - (pow(dTh[7],2)*L[7]*sin(Th[7]))/2.)))/2. - L[5]*sin(Th[5])*(-(Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))) + cos(Th[5])*L[5]*(-(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + 2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + 2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + 2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + 2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))) + (M[8]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + (cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[5]) - 2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.)))/2. - (M[8]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + (cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[5]) - 2*L[5]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - (cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*sin(Th[5]) - 2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.) + 2*cos(Th[5])*L[5]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.)))/2. - L[5]*sin(Th[5])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + 2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))) + cos(Th[5])*L[5]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + 2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + 2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + 2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + 2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))) + (M[9]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[5]) - 2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - (M[9]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[5]) - 2*L[5]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - (cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[5]) - 2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + 2*cos(Th[5])*L[5]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - L[5]*sin(Th[5])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + cos(Th[5])*L[5]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + (M[10]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[5]) - 2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[5]*L[5]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[5]) - 2*L[5]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - cos(Th[9])*pow(dTh[9],2)*L[9] - (cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[5]) - 2*cos(Th[5])*dTh[5]*L[5]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[5])*L[5]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;
 coefMat[9] = 0;
 coefMat[23] = 0;
 coefMat[37] = L[6]*sin(Th[6]);
 coefMat[51] = -(cos(Th[6])*L[6]);
 coefMat[65] = (M[6]*(cos(Th[1])*cos(Th[6])*L[1]*L[6] + L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2. + (M[7]*(2*cos(Th[1])*cos(Th[6])*L[1]*L[6] + 2*L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2. + (M[8]*(2*cos(Th[1])*cos(Th[6])*L[1]*L[6] + 2*L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2. + (M[9]*(2*cos(Th[1])*cos(Th[6])*L[1]*L[6] + 2*L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2. + (M[10]*(2*cos(Th[1])*cos(Th[6])*L[1]*L[6] + 2*L[1]*L[6]*sin(Th[1])*sin(Th[6])))/2.;
 coefMat[79] = (M[6]*(cos(Th[2])*cos(Th[6])*L[2]*L[6] + L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2. + (M[7]*(2*cos(Th[2])*cos(Th[6])*L[2]*L[6] + 2*L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2. + (M[8]*(2*cos(Th[2])*cos(Th[6])*L[2]*L[6] + 2*L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2. + (M[9]*(2*cos(Th[2])*cos(Th[6])*L[2]*L[6] + 2*L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2. + (M[10]*(2*cos(Th[2])*cos(Th[6])*L[2]*L[6] + 2*L[2]*L[6]*sin(Th[2])*sin(Th[6])))/2.;
 coefMat[93] = (M[6]*(cos(Th[3])*cos(Th[6])*L[3]*L[6] + L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2. + (M[7]*(2*cos(Th[3])*cos(Th[6])*L[3]*L[6] + 2*L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2. + (M[8]*(2*cos(Th[3])*cos(Th[6])*L[3]*L[6] + 2*L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2. + (M[9]*(2*cos(Th[3])*cos(Th[6])*L[3]*L[6] + 2*L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2. + (M[10]*(2*cos(Th[3])*cos(Th[6])*L[3]*L[6] + 2*L[3]*L[6]*sin(Th[3])*sin(Th[6])))/2.;
 coefMat[107] = (M[6]*(cos(Th[4])*cos(Th[6])*L[4]*L[6] + L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2. + (M[7]*(2*cos(Th[4])*cos(Th[6])*L[4]*L[6] + 2*L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2. + (M[8]*(2*cos(Th[4])*cos(Th[6])*L[4]*L[6] + 2*L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2. + (M[9]*(2*cos(Th[4])*cos(Th[6])*L[4]*L[6] + 2*L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2. + (M[10]*(2*cos(Th[4])*cos(Th[6])*L[4]*L[6] + 2*L[4]*L[6]*sin(Th[4])*sin(Th[6])))/2.;
 coefMat[121] = (M[6]*(cos(Th[5])*cos(Th[6])*L[5]*L[6] + L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2. + (M[7]*(2*cos(Th[5])*cos(Th[6])*L[5]*L[6] + 2*L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2. + (M[8]*(2*cos(Th[5])*cos(Th[6])*L[5]*L[6] + 2*L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2. + (M[9]*(2*cos(Th[5])*cos(Th[6])*L[5]*L[6] + 2*L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2. + (M[10]*(2*cos(Th[5])*cos(Th[6])*L[5]*L[6] + 2*L[5]*L[6]*sin(Th[5])*sin(Th[6])))/2.;
 coefMat[135] = (pow(L[6],2)*M[6])/12. + (M[6]*((pow(cos(Th[6]),2)*pow(L[6],2))/2. + (pow(L[6],2)*pow(sin(Th[6]),2))/2.))/2. + (M[7]*(2*pow(cos(Th[6]),2)*pow(L[6],2) + 2*pow(L[6],2)*pow(sin(Th[6]),2)))/2. + (M[8]*(2*pow(cos(Th[6]),2)*pow(L[6],2) + 2*pow(L[6],2)*pow(sin(Th[6]),2)))/2. + (M[9]*(2*pow(cos(Th[6]),2)*pow(L[6],2) + 2*pow(L[6],2)*pow(sin(Th[6]),2)))/2. + (M[10]*(2*pow(cos(Th[6]),2)*pow(L[6],2) + 2*pow(L[6],2)*pow(sin(Th[6]),2)))/2.;
 coefMat[149] = (M[7]*(cos(Th[6])*cos(Th[7])*L[6]*L[7] + L[6]*L[7]*sin(Th[6])*sin(Th[7])))/2. + (M[8]*(2*cos(Th[6])*cos(Th[7])*L[6]*L[7] + 2*L[6]*L[7]*sin(Th[6])*sin(Th[7])))/2. + (M[9]*(2*cos(Th[6])*cos(Th[7])*L[6]*L[7] + 2*L[6]*L[7]*sin(Th[6])*sin(Th[7])))/2. + (M[10]*(2*cos(Th[6])*cos(Th[7])*L[6]*L[7] + 2*L[6]*L[7]*sin(Th[6])*sin(Th[7])))/2.;
 coefMat[163] = (M[8]*(cos(Th[6])*cos(Th[8])*L[6]*L[8] + L[6]*L[8]*sin(Th[6])*sin(Th[8])))/2. + (M[9]*(2*cos(Th[6])*cos(Th[8])*L[6]*L[8] + 2*L[6]*L[8]*sin(Th[6])*sin(Th[8])))/2. + (M[10]*(2*cos(Th[6])*cos(Th[8])*L[6]*L[8] + 2*L[6]*L[8]*sin(Th[6])*sin(Th[8])))/2.;
 coefMat[177] = (M[9]*(cos(Th[6])*cos(Th[9])*L[6]*L[9] + L[6]*L[9]*sin(Th[6])*sin(Th[9])))/2. + (M[10]*(2*cos(Th[6])*cos(Th[9])*L[6]*L[9] + 2*L[6]*L[9]*sin(Th[6])*sin(Th[9])))/2.;
 coefMat[191] = (M[10]*(cos(Th[6])*cos(Th[10])*L[6]*L[10] + L[6]*L[10]*sin(Th[6])*sin(Th[10])))/2.;
 rhsVec[9] = -(Cs*dTh[6]*pow(L[6],3))/12. - (pow(L[6],2)*sin(Th[6])*(-(Cs*sin(Th[6])*(-2*dyL*cos(Th[6]) - 2*cos(Th[1] - Th[6])*dTh[1]*L[1] - 2*cos(Th[2] - Th[6])*dTh[2]*L[2] - 2*cos(Th[3] - Th[6])*dTh[3]*L[3] - 2*cos(Th[4] - Th[6])*dTh[4]*L[4] - 2*cos(Th[5] - Th[6])*dTh[5]*L[5] - dTh[6]*L[6] + 2*dxL*sin(Th[6]))) + 2*Cv*cos(Th[6])*(-(dxL*cos(Th[6])) + dTh[1]*L[1]*sin(Th[1] - Th[6]) + dTh[2]*L[2]*sin(Th[2] - Th[6]) + dTh[3]*L[3]*sin(Th[3] - Th[6]) + dTh[4]*L[4]*sin(Th[4] - Th[6]) + dTh[5]*L[5]*sin(Th[5] - Th[6]) - dyL*sin(Th[6]))))/4. - (cos(Th[6])*pow(L[6],2)*(Cs*cos(Th[6])*(2*dyL*cos(Th[6]) + 2*cos(Th[1] - Th[6])*dTh[1]*L[1] + 2*cos(Th[2] - Th[6])*dTh[2]*L[2] + 2*cos(Th[3] - Th[6])*dTh[3]*L[3] + 2*cos(Th[4] - Th[6])*dTh[4]*L[4] + 2*cos(Th[5] - Th[6])*dTh[5]*L[5] + dTh[6]*L[6] - 2*dxL*sin(Th[6])) + 2*Cv*sin(Th[6])*(dxL*cos(Th[6]) - dTh[1]*L[1]*sin(Th[1] - Th[6]) - dTh[2]*L[2]*sin(Th[2] - Th[6]) - dTh[3]*L[3]*sin(Th[3] - Th[6]) - dTh[4]*L[4]*sin(Th[4] - Th[6]) - dTh[5]*L[5]*sin(Th[5] - Th[6]) + dyL*sin(Th[6]))))/4. + (M[6]*(-(dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[6])) - cos(Th[6])*dTh[6]*L[6]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.)))/2. - (M[6]*(-(dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + (cos(Th[6])*dTh[6]*L[6])/2.)*sin(Th[6])) - L[6]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - (cos(Th[6])*pow(dTh[6],2)*L[6])/2.)*sin(Th[6]) - cos(Th[6])*dTh[6]*L[6]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - (dTh[6]*L[6]*sin(Th[6]))/2.) + cos(Th[6])*L[6]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - (pow(dTh[6],2)*L[6]*sin(Th[6]))/2.)))/2. - L[6]*sin(Th[6])*(-(Cs*L[7]*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + 2*dxL*sin(Th[7])))/2. - Cv*cos(Th[7])*L[7]*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7]))) + cos(Th[6])*L[6]*(-(Cs*cos(Th[7])*L[7]*(2*dyL*cos(Th[7]) + 2*cos(Th[1] - Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + 2*cos(Th[3] - Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + 2*cos(Th[5] - Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + dTh[7]*L[7] - 2*dxL*sin(Th[7])))/2. - Cv*L[7]*sin(Th[7])*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7]))) + (M[7]*(-2*dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + (cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[6]) - 2*cos(Th[6])*dTh[6]*L[6]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - (dTh[7]*L[7]*sin(Th[7]))/2.)))/2. - (M[7]*(-2*dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + (cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[6]) - 2*L[6]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - (cos(Th[7])*pow(dTh[7],2)*L[7])/2.)*sin(Th[6]) - 2*cos(Th[6])*dTh[6]*L[6]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - (dTh[7]*L[7]*sin(Th[7]))/2.) + 2*cos(Th[6])*L[6]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - (pow(dTh[7],2)*L[7]*sin(Th[7]))/2.)))/2. - L[6]*sin(Th[6])*(-(Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))) + cos(Th[6])*L[6]*(-(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + 2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + 2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + 2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + 2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))) + (M[8]*(-2*dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + (cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[6]) - 2*cos(Th[6])*dTh[6]*L[6]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.)))/2. - (M[8]*(-2*dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + (cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[6]) - 2*L[6]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - (cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*sin(Th[6]) - 2*cos(Th[6])*dTh[6]*L[6]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.) + 2*cos(Th[6])*L[6]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.)))/2. - L[6]*sin(Th[6])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + 2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))) + cos(Th[6])*L[6]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + 2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + 2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + 2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + 2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))) + (M[9]*(-2*dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[6]) - 2*cos(Th[6])*dTh[6]*L[6]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - (M[9]*(-2*dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[6]) - 2*L[6]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - (cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[6]) - 2*cos(Th[6])*dTh[6]*L[6]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + 2*cos(Th[6])*L[6]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - L[6]*sin(Th[6])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + cos(Th[6])*L[6]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + (M[10]*(-2*dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[6]) - 2*cos(Th[6])*dTh[6]*L[6]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[6]*L[6]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[6]) - 2*L[6]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - cos(Th[9])*pow(dTh[9],2)*L[9] - (cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[6]) - 2*cos(Th[6])*dTh[6]*L[6]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[6])*L[6]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;
 coefMat[10] = 0;
 coefMat[24] = 0;
 coefMat[38] = L[7]*sin(Th[7]);
 coefMat[52] = -(cos(Th[7])*L[7]);
 coefMat[66] = (M[7]*(cos(Th[1])*cos(Th[7])*L[1]*L[7] + L[1]*L[7]*sin(Th[1])*sin(Th[7])))/2. + (M[8]*(2*cos(Th[1])*cos(Th[7])*L[1]*L[7] + 2*L[1]*L[7]*sin(Th[1])*sin(Th[7])))/2. + (M[9]*(2*cos(Th[1])*cos(Th[7])*L[1]*L[7] + 2*L[1]*L[7]*sin(Th[1])*sin(Th[7])))/2. + (M[10]*(2*cos(Th[1])*cos(Th[7])*L[1]*L[7] + 2*L[1]*L[7]*sin(Th[1])*sin(Th[7])))/2.;
 coefMat[80] = (M[7]*(cos(Th[2])*cos(Th[7])*L[2]*L[7] + L[2]*L[7]*sin(Th[2])*sin(Th[7])))/2. + (M[8]*(2*cos(Th[2])*cos(Th[7])*L[2]*L[7] + 2*L[2]*L[7]*sin(Th[2])*sin(Th[7])))/2. + (M[9]*(2*cos(Th[2])*cos(Th[7])*L[2]*L[7] + 2*L[2]*L[7]*sin(Th[2])*sin(Th[7])))/2. + (M[10]*(2*cos(Th[2])*cos(Th[7])*L[2]*L[7] + 2*L[2]*L[7]*sin(Th[2])*sin(Th[7])))/2.;
 coefMat[94] = (M[7]*(cos(Th[3])*cos(Th[7])*L[3]*L[7] + L[3]*L[7]*sin(Th[3])*sin(Th[7])))/2. + (M[8]*(2*cos(Th[3])*cos(Th[7])*L[3]*L[7] + 2*L[3]*L[7]*sin(Th[3])*sin(Th[7])))/2. + (M[9]*(2*cos(Th[3])*cos(Th[7])*L[3]*L[7] + 2*L[3]*L[7]*sin(Th[3])*sin(Th[7])))/2. + (M[10]*(2*cos(Th[3])*cos(Th[7])*L[3]*L[7] + 2*L[3]*L[7]*sin(Th[3])*sin(Th[7])))/2.;
 coefMat[108] = (M[7]*(cos(Th[4])*cos(Th[7])*L[4]*L[7] + L[4]*L[7]*sin(Th[4])*sin(Th[7])))/2. + (M[8]*(2*cos(Th[4])*cos(Th[7])*L[4]*L[7] + 2*L[4]*L[7]*sin(Th[4])*sin(Th[7])))/2. + (M[9]*(2*cos(Th[4])*cos(Th[7])*L[4]*L[7] + 2*L[4]*L[7]*sin(Th[4])*sin(Th[7])))/2. + (M[10]*(2*cos(Th[4])*cos(Th[7])*L[4]*L[7] + 2*L[4]*L[7]*sin(Th[4])*sin(Th[7])))/2.;
 coefMat[122] = (M[7]*(cos(Th[5])*cos(Th[7])*L[5]*L[7] + L[5]*L[7]*sin(Th[5])*sin(Th[7])))/2. + (M[8]*(2*cos(Th[5])*cos(Th[7])*L[5]*L[7] + 2*L[5]*L[7]*sin(Th[5])*sin(Th[7])))/2. + (M[9]*(2*cos(Th[5])*cos(Th[7])*L[5]*L[7] + 2*L[5]*L[7]*sin(Th[5])*sin(Th[7])))/2. + (M[10]*(2*cos(Th[5])*cos(Th[7])*L[5]*L[7] + 2*L[5]*L[7]*sin(Th[5])*sin(Th[7])))/2.;
 coefMat[136] = (M[7]*(cos(Th[6])*cos(Th[7])*L[6]*L[7] + L[6]*L[7]*sin(Th[6])*sin(Th[7])))/2. + (M[8]*(2*cos(Th[6])*cos(Th[7])*L[6]*L[7] + 2*L[6]*L[7]*sin(Th[6])*sin(Th[7])))/2. + (M[9]*(2*cos(Th[6])*cos(Th[7])*L[6]*L[7] + 2*L[6]*L[7]*sin(Th[6])*sin(Th[7])))/2. + (M[10]*(2*cos(Th[6])*cos(Th[7])*L[6]*L[7] + 2*L[6]*L[7]*sin(Th[6])*sin(Th[7])))/2.;
 coefMat[150] = (pow(L[7],2)*M[7])/12. + (M[7]*((pow(cos(Th[7]),2)*pow(L[7],2))/2. + (pow(L[7],2)*pow(sin(Th[7]),2))/2.))/2. + (M[8]*(2*pow(cos(Th[7]),2)*pow(L[7],2) + 2*pow(L[7],2)*pow(sin(Th[7]),2)))/2. + (M[9]*(2*pow(cos(Th[7]),2)*pow(L[7],2) + 2*pow(L[7],2)*pow(sin(Th[7]),2)))/2. + (M[10]*(2*pow(cos(Th[7]),2)*pow(L[7],2) + 2*pow(L[7],2)*pow(sin(Th[7]),2)))/2.;
 coefMat[164] = (M[8]*(cos(Th[7])*cos(Th[8])*L[7]*L[8] + L[7]*L[8]*sin(Th[7])*sin(Th[8])))/2. + (M[9]*(2*cos(Th[7])*cos(Th[8])*L[7]*L[8] + 2*L[7]*L[8]*sin(Th[7])*sin(Th[8])))/2. + (M[10]*(2*cos(Th[7])*cos(Th[8])*L[7]*L[8] + 2*L[7]*L[8]*sin(Th[7])*sin(Th[8])))/2.;
 coefMat[178] = (M[9]*(cos(Th[7])*cos(Th[9])*L[7]*L[9] + L[7]*L[9]*sin(Th[7])*sin(Th[9])))/2. + (M[10]*(2*cos(Th[7])*cos(Th[9])*L[7]*L[9] + 2*L[7]*L[9]*sin(Th[7])*sin(Th[9])))/2.;
 coefMat[192] = (M[10]*(cos(Th[7])*cos(Th[10])*L[7]*L[10] + L[7]*L[10]*sin(Th[7])*sin(Th[10])))/2.;
 rhsVec[10] = -(Cs*dTh[7]*pow(L[7],3))/12. - (L[7]*sin(Th[7])*(-(Cs*L[7]*sin(Th[7])*(-2*dyL*cos(Th[7]) - 2*cos(Th[1] - Th[7])*dTh[1]*L[1] - 2*cos(Th[2] - Th[7])*dTh[2]*L[2] - 2*cos(Th[3] - Th[7])*dTh[3]*L[3] - 2*cos(Th[4] - Th[7])*dTh[4]*L[4] - 2*cos(Th[5] - Th[7])*dTh[5]*L[5] - 2*cos(Th[6] - Th[7])*dTh[6]*L[6] - dTh[7]*L[7] + 2*dxL*sin(Th[7])))/2. - Cv*cos(Th[7])*L[7]*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7]))))/2. + (cos(Th[7])*L[7]*(-(Cs*cos(Th[7])*L[7]*(2*dyL*cos(Th[7]) + 2*cos(Th[1] - Th[7])*dTh[1]*L[1] + 2*cos(Th[2] - Th[7])*dTh[2]*L[2] + 2*cos(Th[3] - Th[7])*dTh[3]*L[3] + 2*cos(Th[4] - Th[7])*dTh[4]*L[4] + 2*cos(Th[5] - Th[7])*dTh[5]*L[5] + 2*cos(Th[6] - Th[7])*dTh[6]*L[6] + dTh[7]*L[7] - 2*dxL*sin(Th[7])))/2. - Cv*L[7]*sin(Th[7])*(dxL*cos(Th[7]) - dTh[1]*L[1]*sin(Th[1] - Th[7]) - dTh[2]*L[2]*sin(Th[2] - Th[7]) - dTh[3]*L[3]*sin(Th[3] - Th[7]) - dTh[4]*L[4]*sin(Th[4] - Th[7]) - dTh[5]*L[5]*sin(Th[5] - Th[7]) - dTh[6]*L[6]*sin(Th[6] - Th[7]) + dyL*sin(Th[7]))))/2. + (M[7]*(-(dTh[7]*L[7]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + (cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[7])) - cos(Th[7])*dTh[7]*L[7]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - (dTh[7]*L[7]*sin(Th[7]))/2.)))/2. - (M[7]*(-(dTh[7]*L[7]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + (cos(Th[7])*dTh[7]*L[7])/2.)*sin(Th[7])) - L[7]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - (cos(Th[7])*pow(dTh[7],2)*L[7])/2.)*sin(Th[7]) - cos(Th[7])*dTh[7]*L[7]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - (dTh[7]*L[7]*sin(Th[7]))/2.) + cos(Th[7])*L[7]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - (pow(dTh[7],2)*L[7]*sin(Th[7]))/2.)))/2. - L[7]*sin(Th[7])*(-(Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))) + cos(Th[7])*L[7]*(-(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + 2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + 2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + 2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + 2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))) + (M[8]*(-2*dTh[7]*L[7]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + (cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[7]) - 2*cos(Th[7])*dTh[7]*L[7]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.)))/2. - (M[8]*(-2*dTh[7]*L[7]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + (cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[7]) - 2*L[7]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - (cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*sin(Th[7]) - 2*cos(Th[7])*dTh[7]*L[7]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.) + 2*cos(Th[7])*L[7]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.)))/2. - L[7]*sin(Th[7])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + 2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))) + cos(Th[7])*L[7]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + 2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + 2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + 2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + 2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))) + (M[9]*(-2*dTh[7]*L[7]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[7]) - 2*cos(Th[7])*dTh[7]*L[7]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - (M[9]*(-2*dTh[7]*L[7]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[7]) - 2*L[7]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - (cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[7]) - 2*cos(Th[7])*dTh[7]*L[7]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + 2*cos(Th[7])*L[7]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - L[7]*sin(Th[7])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + cos(Th[7])*L[7]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + (M[10]*(-2*dTh[7]*L[7]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[7]) - 2*cos(Th[7])*dTh[7]*L[7]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[7]*L[7]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[7]) - 2*L[7]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - cos(Th[9])*pow(dTh[9],2)*L[9] - (cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[7]) - 2*cos(Th[7])*dTh[7]*L[7]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[7])*L[7]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;
 coefMat[11] = 0;
 coefMat[25] = 0;
 coefMat[39] = L[8]*sin(Th[8]);
 coefMat[53] = -(cos(Th[8])*L[8]);
 coefMat[67] = (M[8]*(cos(Th[1])*cos(Th[8])*L[1]*L[8] + L[1]*L[8]*sin(Th[1])*sin(Th[8])))/2. + (M[9]*(2*cos(Th[1])*cos(Th[8])*L[1]*L[8] + 2*L[1]*L[8]*sin(Th[1])*sin(Th[8])))/2. + (M[10]*(2*cos(Th[1])*cos(Th[8])*L[1]*L[8] + 2*L[1]*L[8]*sin(Th[1])*sin(Th[8])))/2.;
 coefMat[81] = (M[8]*(cos(Th[2])*cos(Th[8])*L[2]*L[8] + L[2]*L[8]*sin(Th[2])*sin(Th[8])))/2. + (M[9]*(2*cos(Th[2])*cos(Th[8])*L[2]*L[8] + 2*L[2]*L[8]*sin(Th[2])*sin(Th[8])))/2. + (M[10]*(2*cos(Th[2])*cos(Th[8])*L[2]*L[8] + 2*L[2]*L[8]*sin(Th[2])*sin(Th[8])))/2.;
 coefMat[95] = (M[8]*(cos(Th[3])*cos(Th[8])*L[3]*L[8] + L[3]*L[8]*sin(Th[3])*sin(Th[8])))/2. + (M[9]*(2*cos(Th[3])*cos(Th[8])*L[3]*L[8] + 2*L[3]*L[8]*sin(Th[3])*sin(Th[8])))/2. + (M[10]*(2*cos(Th[3])*cos(Th[8])*L[3]*L[8] + 2*L[3]*L[8]*sin(Th[3])*sin(Th[8])))/2.;
 coefMat[109] = (M[8]*(cos(Th[4])*cos(Th[8])*L[4]*L[8] + L[4]*L[8]*sin(Th[4])*sin(Th[8])))/2. + (M[9]*(2*cos(Th[4])*cos(Th[8])*L[4]*L[8] + 2*L[4]*L[8]*sin(Th[4])*sin(Th[8])))/2. + (M[10]*(2*cos(Th[4])*cos(Th[8])*L[4]*L[8] + 2*L[4]*L[8]*sin(Th[4])*sin(Th[8])))/2.;
 coefMat[123] = (M[8]*(cos(Th[5])*cos(Th[8])*L[5]*L[8] + L[5]*L[8]*sin(Th[5])*sin(Th[8])))/2. + (M[9]*(2*cos(Th[5])*cos(Th[8])*L[5]*L[8] + 2*L[5]*L[8]*sin(Th[5])*sin(Th[8])))/2. + (M[10]*(2*cos(Th[5])*cos(Th[8])*L[5]*L[8] + 2*L[5]*L[8]*sin(Th[5])*sin(Th[8])))/2.;
 coefMat[137] = (M[8]*(cos(Th[6])*cos(Th[8])*L[6]*L[8] + L[6]*L[8]*sin(Th[6])*sin(Th[8])))/2. + (M[9]*(2*cos(Th[6])*cos(Th[8])*L[6]*L[8] + 2*L[6]*L[8]*sin(Th[6])*sin(Th[8])))/2. + (M[10]*(2*cos(Th[6])*cos(Th[8])*L[6]*L[8] + 2*L[6]*L[8]*sin(Th[6])*sin(Th[8])))/2.;
 coefMat[151] = (M[8]*(cos(Th[7])*cos(Th[8])*L[7]*L[8] + L[7]*L[8]*sin(Th[7])*sin(Th[8])))/2. + (M[9]*(2*cos(Th[7])*cos(Th[8])*L[7]*L[8] + 2*L[7]*L[8]*sin(Th[7])*sin(Th[8])))/2. + (M[10]*(2*cos(Th[7])*cos(Th[8])*L[7]*L[8] + 2*L[7]*L[8]*sin(Th[7])*sin(Th[8])))/2.;
 coefMat[165] = (pow(L[8],2)*M[8])/12. + (M[8]*((pow(cos(Th[8]),2)*pow(L[8],2))/2. + (pow(L[8],2)*pow(sin(Th[8]),2))/2.))/2. + (M[9]*(2*pow(cos(Th[8]),2)*pow(L[8],2) + 2*pow(L[8],2)*pow(sin(Th[8]),2)))/2. + (M[10]*(2*pow(cos(Th[8]),2)*pow(L[8],2) + 2*pow(L[8],2)*pow(sin(Th[8]),2)))/2.;
 coefMat[179] = (M[9]*(cos(Th[8])*cos(Th[9])*L[8]*L[9] + L[8]*L[9]*sin(Th[8])*sin(Th[9])))/2. + (M[10]*(2*cos(Th[8])*cos(Th[9])*L[8]*L[9] + 2*L[8]*L[9]*sin(Th[8])*sin(Th[9])))/2.;
 coefMat[193] = (M[10]*(cos(Th[8])*cos(Th[10])*L[8]*L[10] + L[8]*L[10]*sin(Th[8])*sin(Th[10])))/2.;
 rhsVec[11] = -(Cs*dTh[8]*pow(L[8],3))/12. - (L[8]*sin(Th[8])*(-(Cs*L[8]*sin(Th[8])*(-2*dyL*cos(Th[8]) - 2*cos(Th[1] - Th[8])*dTh[1]*L[1] - 2*cos(Th[2] - Th[8])*dTh[2]*L[2] - 2*cos(Th[3] - Th[8])*dTh[3]*L[3] - 2*cos(Th[4] - Th[8])*dTh[4]*L[4] - 2*cos(Th[5] - Th[8])*dTh[5]*L[5] - 2*cos(Th[6] - Th[8])*dTh[6]*L[6] - 2*cos(Th[7] - Th[8])*dTh[7]*L[7] - dTh[8]*L[8] + 2*dxL*sin(Th[8])))/2. - Cv*cos(Th[8])*L[8]*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))))/2. + (cos(Th[8])*L[8]*(-(Cs*cos(Th[8])*L[8]*(2*dyL*cos(Th[8]) + 2*cos(Th[1] - Th[8])*dTh[1]*L[1] + 2*cos(Th[2] - Th[8])*dTh[2]*L[2] + 2*cos(Th[3] - Th[8])*dTh[3]*L[3] + 2*cos(Th[4] - Th[8])*dTh[4]*L[4] + 2*cos(Th[5] - Th[8])*dTh[5]*L[5] + 2*cos(Th[6] - Th[8])*dTh[6]*L[6] + 2*cos(Th[7] - Th[8])*dTh[7]*L[7] + dTh[8]*L[8] - 2*dxL*sin(Th[8])))/2. - Cv*L[8]*sin(Th[8])*(dxL*cos(Th[8]) - dTh[1]*L[1]*sin(Th[1] - Th[8]) - dTh[2]*L[2]*sin(Th[2] - Th[8]) - dTh[3]*L[3]*sin(Th[3] - Th[8]) - dTh[4]*L[4]*sin(Th[4] - Th[8]) - dTh[5]*L[5]*sin(Th[5] - Th[8]) - dTh[6]*L[6]*sin(Th[6] - Th[8]) - dTh[7]*L[7]*sin(Th[7] - Th[8]) + dyL*sin(Th[8]))))/2. + (M[8]*(-(dTh[8]*L[8]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + (cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[8])) - cos(Th[8])*dTh[8]*L[8]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.)))/2. - (M[8]*(-(dTh[8]*L[8]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + (cos(Th[8])*dTh[8]*L[8])/2.)*sin(Th[8])) - L[8]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - (cos(Th[8])*pow(dTh[8],2)*L[8])/2.)*sin(Th[8]) - cos(Th[8])*dTh[8]*L[8]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - (dTh[8]*L[8]*sin(Th[8]))/2.) + cos(Th[8])*L[8]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - (pow(dTh[8],2)*L[8]*sin(Th[8]))/2.)))/2. - L[8]*sin(Th[8])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + 2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))) + cos(Th[8])*L[8]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + 2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + 2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + 2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + 2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))) + (M[9]*(-2*dTh[8]*L[8]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[8]) - 2*cos(Th[8])*dTh[8]*L[8]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - (M[9]*(-2*dTh[8]*L[8]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[8]) - 2*L[8]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - (cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[8]) - 2*cos(Th[8])*dTh[8]*L[8]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + 2*cos(Th[8])*L[8]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - L[8]*sin(Th[8])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + cos(Th[8])*L[8]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + (M[10]*(-2*dTh[8]*L[8]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[8]) - 2*cos(Th[8])*dTh[8]*L[8]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[8]*L[8]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[8]) - 2*L[8]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - cos(Th[9])*pow(dTh[9],2)*L[9] - (cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[8]) - 2*cos(Th[8])*dTh[8]*L[8]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[8])*L[8]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;
 coefMat[12] = 0;
 coefMat[26] = 0;
 coefMat[40] = L[9]*sin(Th[9]);
 coefMat[54] = -(cos(Th[9])*L[9]);
 coefMat[68] = (M[9]*(cos(Th[1])*cos(Th[9])*L[1]*L[9] + L[1]*L[9]*sin(Th[1])*sin(Th[9])))/2. + (M[10]*(2*cos(Th[1])*cos(Th[9])*L[1]*L[9] + 2*L[1]*L[9]*sin(Th[1])*sin(Th[9])))/2.;
 coefMat[82] = (M[9]*(cos(Th[2])*cos(Th[9])*L[2]*L[9] + L[2]*L[9]*sin(Th[2])*sin(Th[9])))/2. + (M[10]*(2*cos(Th[2])*cos(Th[9])*L[2]*L[9] + 2*L[2]*L[9]*sin(Th[2])*sin(Th[9])))/2.;
 coefMat[96] = (M[9]*(cos(Th[3])*cos(Th[9])*L[3]*L[9] + L[3]*L[9]*sin(Th[3])*sin(Th[9])))/2. + (M[10]*(2*cos(Th[3])*cos(Th[9])*L[3]*L[9] + 2*L[3]*L[9]*sin(Th[3])*sin(Th[9])))/2.;
 coefMat[110] = (M[9]*(cos(Th[4])*cos(Th[9])*L[4]*L[9] + L[4]*L[9]*sin(Th[4])*sin(Th[9])))/2. + (M[10]*(2*cos(Th[4])*cos(Th[9])*L[4]*L[9] + 2*L[4]*L[9]*sin(Th[4])*sin(Th[9])))/2.;
 coefMat[124] = (M[9]*(cos(Th[5])*cos(Th[9])*L[5]*L[9] + L[5]*L[9]*sin(Th[5])*sin(Th[9])))/2. + (M[10]*(2*cos(Th[5])*cos(Th[9])*L[5]*L[9] + 2*L[5]*L[9]*sin(Th[5])*sin(Th[9])))/2.;
 coefMat[138] = (M[9]*(cos(Th[6])*cos(Th[9])*L[6]*L[9] + L[6]*L[9]*sin(Th[6])*sin(Th[9])))/2. + (M[10]*(2*cos(Th[6])*cos(Th[9])*L[6]*L[9] + 2*L[6]*L[9]*sin(Th[6])*sin(Th[9])))/2.;
 coefMat[152] = (M[9]*(cos(Th[7])*cos(Th[9])*L[7]*L[9] + L[7]*L[9]*sin(Th[7])*sin(Th[9])))/2. + (M[10]*(2*cos(Th[7])*cos(Th[9])*L[7]*L[9] + 2*L[7]*L[9]*sin(Th[7])*sin(Th[9])))/2.;
 coefMat[166] = (M[9]*(cos(Th[8])*cos(Th[9])*L[8]*L[9] + L[8]*L[9]*sin(Th[8])*sin(Th[9])))/2. + (M[10]*(2*cos(Th[8])*cos(Th[9])*L[8]*L[9] + 2*L[8]*L[9]*sin(Th[8])*sin(Th[9])))/2.;
 coefMat[180] = (pow(L[9],2)*M[9])/12. + (M[9]*((pow(cos(Th[9]),2)*pow(L[9],2))/2. + (pow(L[9],2)*pow(sin(Th[9]),2))/2.))/2. + (M[10]*(2*pow(cos(Th[9]),2)*pow(L[9],2) + 2*pow(L[9],2)*pow(sin(Th[9]),2)))/2.;
 coefMat[194] = (M[10]*(cos(Th[9])*cos(Th[10])*L[9]*L[10] + L[9]*L[10]*sin(Th[9])*sin(Th[10])))/2.;
 rhsVec[12] = -(Cs*dTh[9]*pow(L[9],3))/12. - (L[9]*sin(Th[9])*(-(Cs*L[9]*sin(Th[9])*(-2*dyL*cos(Th[9]) - 2*cos(Th[1] - Th[9])*dTh[1]*L[1] - 2*cos(Th[2] - Th[9])*dTh[2]*L[2] - 2*cos(Th[3] - Th[9])*dTh[3]*L[3] - 2*cos(Th[4] - Th[9])*dTh[4]*L[4] - 2*cos(Th[5] - Th[9])*dTh[5]*L[5] - 2*cos(Th[6] - Th[9])*dTh[6]*L[6] - 2*cos(Th[7] - Th[9])*dTh[7]*L[7] - 2*cos(Th[8] - Th[9])*dTh[8]*L[8] - dTh[9]*L[9] + 2*dxL*sin(Th[9])))/2. - Cv*cos(Th[9])*L[9]*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))))/2. + (cos(Th[9])*L[9]*(-(Cs*cos(Th[9])*L[9]*(2*dyL*cos(Th[9]) + 2*cos(Th[1] - Th[9])*dTh[1]*L[1] + 2*cos(Th[2] - Th[9])*dTh[2]*L[2] + 2*cos(Th[3] - Th[9])*dTh[3]*L[3] + 2*cos(Th[4] - Th[9])*dTh[4]*L[4] + 2*cos(Th[5] - Th[9])*dTh[5]*L[5] + 2*cos(Th[6] - Th[9])*dTh[6]*L[6] + 2*cos(Th[7] - Th[9])*dTh[7]*L[7] + 2*cos(Th[8] - Th[9])*dTh[8]*L[8] + dTh[9]*L[9] - 2*dxL*sin(Th[9])))/2. - Cv*L[9]*sin(Th[9])*(dxL*cos(Th[9]) - dTh[1]*L[1]*sin(Th[1] - Th[9]) - dTh[2]*L[2]*sin(Th[2] - Th[9]) - dTh[3]*L[3]*sin(Th[3] - Th[9]) - dTh[4]*L[4]*sin(Th[4] - Th[9]) - dTh[5]*L[5]*sin(Th[5] - Th[9]) - dTh[6]*L[6]*sin(Th[6] - Th[9]) - dTh[7]*L[7]*sin(Th[7] - Th[9]) - dTh[8]*L[8]*sin(Th[8] - Th[9]) + dyL*sin(Th[9]))))/2. + (M[9]*(-(dTh[9]*L[9]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[9])) - cos(Th[9])*dTh[9]*L[9]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.)))/2. - (M[9]*(-(dTh[9]*L[9]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + (cos(Th[9])*dTh[9]*L[9])/2.)*sin(Th[9])) - L[9]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - (cos(Th[9])*pow(dTh[9],2)*L[9])/2.)*sin(Th[9]) - cos(Th[9])*dTh[9]*L[9]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - (dTh[9]*L[9]*sin(Th[9]))/2.) + cos(Th[9])*L[9]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - (pow(dTh[9],2)*L[9]*sin(Th[9]))/2.)))/2. - L[9]*sin(Th[9])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + cos(Th[9])*L[9]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))) + (M[10]*(-2*dTh[9]*L[9]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[9]) - 2*cos(Th[9])*dTh[9]*L[9]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-2*dTh[9]*L[9]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[9]) - 2*L[9]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - cos(Th[9])*pow(dTh[9],2)*L[9] - (cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[9]) - 2*cos(Th[9])*dTh[9]*L[9]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.) + 2*cos(Th[9])*L[9]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;
 coefMat[13] = 0;
 coefMat[27] = 0;
 coefMat[41] = L[10]*sin(Th[10]);
 coefMat[55] = -(cos(Th[10])*L[10]);
 coefMat[69] = (M[10]*(cos(Th[1])*cos(Th[10])*L[1]*L[10] + L[1]*L[10]*sin(Th[1])*sin(Th[10])))/2.;
 coefMat[83] = (M[10]*(cos(Th[2])*cos(Th[10])*L[2]*L[10] + L[2]*L[10]*sin(Th[2])*sin(Th[10])))/2.;
 coefMat[97] = (M[10]*(cos(Th[3])*cos(Th[10])*L[3]*L[10] + L[3]*L[10]*sin(Th[3])*sin(Th[10])))/2.;
 coefMat[111] = (M[10]*(cos(Th[4])*cos(Th[10])*L[4]*L[10] + L[4]*L[10]*sin(Th[4])*sin(Th[10])))/2.;
 coefMat[125] = (M[10]*(cos(Th[5])*cos(Th[10])*L[5]*L[10] + L[5]*L[10]*sin(Th[5])*sin(Th[10])))/2.;
 coefMat[139] = (M[10]*(cos(Th[6])*cos(Th[10])*L[6]*L[10] + L[6]*L[10]*sin(Th[6])*sin(Th[10])))/2.;
 coefMat[153] = (M[10]*(cos(Th[7])*cos(Th[10])*L[7]*L[10] + L[7]*L[10]*sin(Th[7])*sin(Th[10])))/2.;
 coefMat[167] = (M[10]*(cos(Th[8])*cos(Th[10])*L[8]*L[10] + L[8]*L[10]*sin(Th[8])*sin(Th[10])))/2.;
 coefMat[181] = (M[10]*(cos(Th[9])*cos(Th[10])*L[9]*L[10] + L[9]*L[10]*sin(Th[9])*sin(Th[10])))/2.;
 coefMat[195] = (pow(L[10],2)*M[10])/12. + (M[10]*((pow(cos(Th[10]),2)*pow(L[10],2))/2. + (pow(L[10],2)*pow(sin(Th[10]),2))/2.))/2.;
 rhsVec[13] = tauR - (Cs*dTh[10]*pow(L[10],3))/12. - (L[10]*sin(Th[10])*(-(Cs*L[10]*sin(Th[10])*(-2*dyL*cos(Th[10]) - 2*cos(Th[1] - Th[10])*dTh[1]*L[1] - 2*cos(Th[2] - Th[10])*dTh[2]*L[2] - 2*cos(Th[3] - Th[10])*dTh[3]*L[3] - 2*cos(Th[4] - Th[10])*dTh[4]*L[4] - 2*cos(Th[5] - Th[10])*dTh[5]*L[5] - 2*cos(Th[6] - Th[10])*dTh[6]*L[6] - 2*cos(Th[7] - Th[10])*dTh[7]*L[7] - 2*cos(Th[8] - Th[10])*dTh[8]*L[8] - 2*cos(Th[9] - Th[10])*dTh[9]*L[9] - dTh[10]*L[10] + 2*dxL*sin(Th[10])))/2. - Cv*cos(Th[10])*L[10]*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))))/2. + (cos(Th[10])*L[10]*(-(Cs*cos(Th[10])*L[10]*(2*dyL*cos(Th[10]) + 2*cos(Th[1] - Th[10])*dTh[1]*L[1] + 2*cos(Th[2] - Th[10])*dTh[2]*L[2] + 2*cos(Th[3] - Th[10])*dTh[3]*L[3] + 2*cos(Th[4] - Th[10])*dTh[4]*L[4] + 2*cos(Th[5] - Th[10])*dTh[5]*L[5] + 2*cos(Th[6] - Th[10])*dTh[6]*L[6] + 2*cos(Th[7] - Th[10])*dTh[7]*L[7] + 2*cos(Th[8] - Th[10])*dTh[8]*L[8] + 2*cos(Th[9] - Th[10])*dTh[9]*L[9] + dTh[10]*L[10] - 2*dxL*sin(Th[10])))/2. - Cv*L[10]*sin(Th[10])*(dxL*cos(Th[10]) - dTh[1]*L[1]*sin(Th[1] - Th[10]) - dTh[2]*L[2]*sin(Th[2] - Th[10]) - dTh[3]*L[3]*sin(Th[3] - Th[10]) - dTh[4]*L[4]*sin(Th[4] - Th[10]) - dTh[5]*L[5]*sin(Th[5] - Th[10]) - dTh[6]*L[6]*sin(Th[6] - Th[10]) - dTh[7]*L[7]*sin(Th[7] - Th[10]) - dTh[8]*L[8]*sin(Th[8] - Th[10]) - dTh[9]*L[9]*sin(Th[9] - Th[10]) + dyL*sin(Th[10]))))/2. + (M[10]*(-(dTh[10]*L[10]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[10])) - cos(Th[10])*dTh[10]*L[10]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.)))/2. - (M[10]*(-(dTh[10]*L[10]*(dyL + cos(Th[1])*dTh[1]*L[1] + cos(Th[2])*dTh[2]*L[2] + cos(Th[3])*dTh[3]*L[3] + cos(Th[4])*dTh[4]*L[4] + cos(Th[5])*dTh[5]*L[5] + cos(Th[6])*dTh[6]*L[6] + cos(Th[7])*dTh[7]*L[7] + cos(Th[8])*dTh[8]*L[8] + cos(Th[9])*dTh[9]*L[9] + (cos(Th[10])*dTh[10]*L[10])/2.)*sin(Th[10])) - L[10]*(ddxL - cos(Th[1])*pow(dTh[1],2)*L[1] - cos(Th[2])*pow(dTh[2],2)*L[2] - cos(Th[3])*pow(dTh[3],2)*L[3] - cos(Th[4])*pow(dTh[4],2)*L[4] - cos(Th[5])*pow(dTh[5],2)*L[5] - cos(Th[6])*pow(dTh[6],2)*L[6] - cos(Th[7])*pow(dTh[7],2)*L[7] - cos(Th[8])*pow(dTh[8],2)*L[8] - cos(Th[9])*pow(dTh[9],2)*L[9] - (cos(Th[10])*pow(dTh[10],2)*L[10])/2.)*sin(Th[10]) - cos(Th[10])*dTh[10]*L[10]*(dxL - dTh[1]*L[1]*sin(Th[1]) - dTh[2]*L[2]*sin(Th[2]) - dTh[3]*L[3]*sin(Th[3]) - dTh[4]*L[4]*sin(Th[4]) - dTh[5]*L[5]*sin(Th[5]) - dTh[6]*L[6]*sin(Th[6]) - dTh[7]*L[7]*sin(Th[7]) - dTh[8]*L[8]*sin(Th[8]) - dTh[9]*L[9]*sin(Th[9]) - (dTh[10]*L[10]*sin(Th[10]))/2.) + cos(Th[10])*L[10]*(ddyL - pow(dTh[1],2)*L[1]*sin(Th[1]) - pow(dTh[2],2)*L[2]*sin(Th[2]) - pow(dTh[3],2)*L[3]*sin(Th[3]) - pow(dTh[4],2)*L[4]*sin(Th[4]) - pow(dTh[5],2)*L[5]*sin(Th[5]) - pow(dTh[6],2)*L[6]*sin(Th[6]) - pow(dTh[7],2)*L[7]*sin(Th[7]) - pow(dTh[8],2)*L[8]*sin(Th[8]) - pow(dTh[9],2)*L[9]*sin(Th[9]) - (pow(dTh[10],2)*L[10]*sin(Th[10]))/2.)))/2.;
    
 // ===================
    
    
}
